;;; ja-dic.el --- dictionary for Japanese input method
;;	Generated by the command `skkdic-convert'
;;	Date: Sat Dec 16 09:09:04 2000
;;	Original SKK dictionary file: SKK-JISYO.L

;;; Commentary:

;; Do byte-compile this file again after any modification.

;;; Start of the header of the original SKK dictionary.

;; Large size dictionary for SKK system
;; version 8.1 of May 24, 1995.
;; This dictionary contains 152639 entries.
;; 
;; Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995
;; Masahiko Sato (masahiko@sato.riec.tohoku.ac.jp),
;; Hironobu Takahashi (takahasi@tiny.or.jp),
;; Masahiro Doteguchi, Miki Inooka,
;; Yukiyoshi Kameyama, Akihiko Sasaki, Dai Ando, Junichi Okukawa, 
;; Katsushi Sato and Nobuhiro Yamagishi
;; 
;; This file is part of GNU Emacs.
;;
;; This dictionary is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either versions 2, or (at your option)
;; any later version.
;; 
;; This dictionary is distributed in the hope that it will be useful
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;; 
;; You should have received a copy of the GNU General Public License
;; along with SKK, see the file COPYING.  If not, write to the Free
;; Software Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;; 
;; okuri-ari entries.

;;; Code:

(eval-when-compile (require 'ja-dic-cnv))

;; Setting okuri-ari entries.
(skkdic-set-okuri-ari
"をs 惜"
"ゐr 居"
"われらg 我等"
"われしr 我知"
"われr 我"
"わるがしこi 悪賢"
"わるs 悪"
"わるk 悪 惡"
"わるi 悪 惡"
"わるg 悪"
"わりふt 割り振"
"わりふr 割り振 割振"
"わりびk 割引"
"わりびi 割引"
"わりつk 割り付 割付"
"わりだs 割出 割り出"
"わりこn 割り込"
"わりこm 割込 割り込"
"わりきt 割切 割り切"
"わりきr 割切 割り切"
"わりあてr 割当"
"わりあt 割当 割り当"
"わりあi 割合 割り合"
"わりt 割"
"わらw 笑"
"わらu 笑 嗤"
"わらt 笑"
"わらi 笑"
"わらh 笑"
"わらe 笑"
"わめk 喚 叫"
"わびしi 侘"
"わびs 侘"
"わびr 侘"
"わのr 輪乗"
"わななk 戦慄"
"わづらh 煩"
"わだかまr 蟠"
"わたりあるk 渡り歩"
"わたりあるi 渡り歩"
"わたt 渡 亘"
"わたs 渡"
"わたr 渡 亘 亙 航 渉"
"わせだどおr 早稲田通"
"わずらw 煩"
"わずらu 患 煩"
"わずらt 患"
"わずらi 患"
"わずk 僅 微 毫"
"わすr 忘"
"わざわi 災 禍 厄"
"わけあw 分け合"
"わけあu 分け合"
"わけあt 分け合"
"わけあo 分け合"
"わけあi 分け合"
"わけあe 分け合"
"わけr 分"
"わくぐm 枠組"
"わきまe 弁"
"わきづk 脇付"
"わきたt 沸き立"
"わきがたm 脇固"
"わきあg 沸き上"
"わかりやすk 判り易 理解り易"
"わかがえt 若返"
"わかがえr 若返"
"わかt 判 分 解 觧 別"
"わかs 若"
"わかr 別 分 判 解 理解 觧"
"わかk 若"
"わかi 若"
"わかc 解"
"わt 割"
"わs 和"
"わr 割"
"わk 分 沸 湧 訳 涌"
"わi 湧"
"わg 我"
"わb 詫 侘"
"ろんz 論"
"ろんj 論"
"ろくがどr 録画撮"
"ろくn 碌"
"ろうをおs 労を惜"
"ろうs 労 弄 聾"
"れんらくいただk 連絡頂"
"れんらくいただi 連絡頂"
"れんらくいたs 連絡致"
"れんきゅうあk 連休明"
"れいぎただs 礼儀正"
"れいn 例"
"るいs 類"
"りりs 凛々 凛凛 律々"
"りようくだs 利用下"
"りょこううかがi 旅行伺"
"りょうほうもt 両方持"
"りょうほうもc 両方持"
"りょうほうとr 両方取"
"りょうほうつかu 両方使"
"りょうほうつかt 両方使"
"りょうほうつかo 両方使"
"りょうほうつかi 両方使"
"りょうほうつかe 両方使"
"りょうしょうくだs 了承下"
"りゅうこうおくr 流行遅"
"りゃくs 略"
"りづm 理詰"
"りっs 律"
"りだすk 利助"
"りくつどおr 理屈通"
"りきm 力"
"りs 利"
"らうs 労"
"よんd 読ん"
"よわよわs 弱々"
"よわすg 弱過"
"よわt 弱"
"よわs 弱"
"よわr 弱"
"よわm 弱"
"よわk 弱"
"よわi 弱"
"よろしk 宜"
"よろこんd 喜ん"
"よろこn 喜"
"よろこb 喜 慶"
"よろs 宜"
"よるおそk 夜遅"
"よるおそi 夜遅"
"よりそt 寄り添"
"よりきt 寄り切"
"よりきr 寄り切"
"よめいr 嫁入"
"よみはじm 読み始"
"よみにくi 読み難"
"よみなおs 読み直"
"よみなr 読み慣"
"よみとt 読取 読み取"
"よみとr 読み取 読取"
"よみとb 読み飛"
"よみだs 読み出 読出"
"よみすすm 読み進"
"よみこn 読み込 読込 詠み込"
"よみこm 読み込 読込 詠み込"
"よみがえt 甦 蘇 蘓"
"よみがえr 蘇 甦 蘓"
"よみがe 蘇 蘓"
"よみかえs 読み返"
"よみかk 読み書"
"よみかe 読み換 読み変"
"よみおw 読み終"
"よみおe 読み終"
"よみあg 読み上"
"よふかs 夜更"
"よふk 夜更"
"よびよs 呼び寄"
"よびもどs 呼び戻"
"よびとm 呼び止"
"よびだs 呼出 呼び出"
"よびたt 呼び立"
"よびすt 呼び捨"
"よびさm 呼び覚"
"よびこn 呼び込"
"よびこm 呼び込"
"よびかw 呼び交"
"よびかk 呼び掛"
"よびおk 呼び起"
"よびあつm 呼び集"
"よばi 夜這"
"よなおs 世直"
"よどおs 夜通"
"よどn 淀 澱"
"よどm 澱 淀"
"よとおr 四通"
"よていどおr 予定通"
"よづr 夜釣"
"よっぱらt 酔っ払"
"よっt 四"
"よそほu 裝"
"よそおu 装 裝"
"よそおt 装 裝"
"よそおi 装 裝"
"よそおh 裝"
"よそうどおr 予想通"
"よそu 装"
"よそh 装"
"よせがk 寄書 寄せ書"
"よせあつm 寄せ集"
"よすg 良過"
"よじr 捩"
"よごs 汚"
"よごr 汚"
"よこならb 横並"
"よこどr 横取"
"よこづk 横付"
"よこすべr 横滑"
"よこくどおr 予告通"
"よこぎt 横切"
"よこぎr 横切"
"よこがk 横書"
"よこt 横"
"よこs 寄越 遣"
"よくばt 欲張"
"よくばr 欲張"
"よくb 欲"
"よぎなk 余儀無"
"よぎr 過"
"よぎn 余儀"
"ようよu 漸"
"ようやk 漸"
"ようだt 用立"
"ようじんぶかk 用心深"
"ようじんぶかi 用心深"
"ようしゃねがu 容赦願"
"ようしゃねがi 容赦願"
"ようしゃくだs 容赦下"
"よういs 用意"
"よういn 容易"
"よういd 容易"
"ようs 要 擁"
"ようn 様 陽 樣"
"よいざm 酔醒"
"よあるk 夜歩"
"よあそb 夜遊"
"よあk 夜明"
"よw 酔 醉"
"よu 酔 醉"
"よt 寄 酔 四 因 ４ 選 醉 依 拠"
"よs 寄 良"
"よr 寄 因 依 拠 選 撚 憑 縒"
"よp 酔"
"よn 読 呼 世 丗 讀 詠"
"よm 読 呼 詠 讀"
"よk 良 善 除 避 譱"
"よj 攀"
"よi 良 酔 善 好 譱 醉 佳"
"よg 善"
"よe 酔 醉"
"よb 呼 喚"
"よa 良"
"ゆわk 湯沸"
"ゆれうごi 揺れ動"
"ゆるy 緩"
"ゆるs 許 赦"
"ゆるn 緩"
"ゆるm 緩 弛"
"ゆるk 緩"
"ゆるi 緩"
"ゆるg 揺"
"ゆゆs 由々 由由 忌々"
"ゆみけずr 弓削"
"ゆびづかi 指使"
"ゆびさs 指差"
"ゆどおs 湯通"
"ゆづr 讓"
"ゆだn 委"
"ゆたk 豊 豐"
"ゆずりわたs 譲り渡"
"ゆずりうk 譲り受"
"ゆずt 譲 讓"
"ゆずr 譲 讓"
"ゆすぶr 揺振"
"ゆすt 揺"
"ゆさぶr 揺振"
"ゆきわたt 行き渡"
"ゆきわたr 行き渡"
"ゆきまつr 雪祭"
"ゆきなやn 行き悩"
"ゆきなやm 行き悩"
"ゆきどm 行き止"
"ゆきどk 雪解"
"ゆきとどk 行き届"
"ゆきとどi 行き届"
"ゆきづm 行き詰"
"ゆきつk 行き付"
"ゆきつi 行き付"
"ゆきちがi 行き違"
"ゆきだおr 行き倒"
"ゆきすg 行き過"
"ゆきがk 行き掛"
"ゆきかよu 行き通"
"ゆきかよt 行き通"
"ゆきかえr 行き帰"
"ゆきかu 行き交"
"ゆきかt 行き交"
"ゆきおr 雪下"
"ゆきあu 行き合"
"ゆきあt 行き合 行き当"
"ゆきあk 雪明"
"ゆがn 歪"
"ゆがm 歪"
"ゆえn 故"
"ゆうりn 有利"
"ゆうめいすg 有名過"
"ゆうびんきょくてつづk 郵便局手続"
"ゆうそういたs 郵送致"
"ゆうしょうあらそi 優勝争"
"ゆうしゅうn 優秀"
"ゆうぐr 夕暮"
"ゆうきづk 勇気付"
"ゆうs 有"
"ゆいしょただs 由緒正"
"ゆw 結"
"ゆu 結"
"ゆt 結"
"ゆs 揺 搖"
"ゆr 揺 搖"
"ゆk 行 往 征 徃"
"ゆh 結"
"ゆe 結"
"ゆd 茹"
"やんごとなs 止事無"
"やわらかk 柔"
"やわr 柔 和 軟"
"やわi 柔"
"やりこm 遣り込"
"やむごとなs 止事無"
"やみとりひk 闇取り引"
"やみあがr 病み上"
"やまもr 山盛"
"やままw 山回"
"やまのぼr 山登"
"やまづm 山積"
"やまそだt 山育"
"やまくずs 山崩"
"やまあるk 山歩"
"やまs 疾 疚"
"やぶれr 殕"
"やぶさk 吝"
"やぶt 破"
"やぶr 破 敗"
"やぶi 破"
"やはr 柔 軟 和 矢張"
"やはi 柔"
"やにさg 脂下"
"やどさがs 宿探"
"やどt 宿"
"やどr 宿"
"やとw 雇"
"やとu 雇 傭"
"やとt 雇"
"やとi 雇"
"やとh 雇 傭"
"やとe 雇"
"やつs 窶"
"やつr 窶"
"やっt 八"
"やすものがi 安物買"
"やすみあk 休み明"
"やすすg 安過"
"やすくにどおr 靖国通"
"やすうけあi 安請け合"
"やすうr 安売"
"やすあがr 安上"
"やすあg 安上"
"やすs 易 安"
"やすr 安"
"やすn 休"
"やすm 休 安"
"やすk 安 易"
"やすi 安 易 廉"
"やじr 野次"
"やしなu 養 豢"
"やしなt 養"
"やしなi 養"
"やしなh 養"
"やしなe 養"
"やさしi 優し"
"やさs 優 易"
"やけこg 焼け焦"
"やくわr 役割"
"やくよk 厄除"
"やくまわr 役回"
"やくひんくさi 薬品臭"
"やくばらi 厄払"
"やくはらi 厄祓"
"やくはらh 厄祓"
"やくにたt 役に立"
"やくづk 役付"
"やくだt 役立"
"やくだc 役立"
"やくたt 役立"
"やくそくどおr 約束通"
"やくs 訳 譯"
"やくn 役"
"やきはらu 焼き払"
"やきなまs 焼き鈍"
"やきなおs 焼き直"
"やきつk 焼き付"
"やかまs 喧"
"やうやu 漸"
"やうやk 漸"
"やt 演 八"
"やs 痩"
"やr 演 遣 殺"
"やn 止 病"
"やm 止 辞 病 辭 罷 已 熄"
"やk 焼 妬 灼 燒"
"やi 焼 妬 燒"
"もろk 脆"
"もろi 脆"
"もれだs 漏れ出"
"もりさg 盛り下"
"もりこn 盛り込"
"もりこm 盛り込"
"もりあがr 盛り上"
"もりあg 盛り上 盛上"
"もらw 貰"
"もらu 貰"
"もらt 貰"
"もらo 貰"
"もらi 貰"
"もらe 貰"
"もよおs 催"
"もよr 最寄"
"もやu 舫"
"ものものs 物々"
"ものもc 物持"
"ものたr 物足"
"ものずk 物好"
"ものすごk 物凄"
"ものすごi 物凄"
"ものぐさi 懶"
"ものがたt 物語"
"ものがたr 物語"
"ものかk 物書"
"ものかi 物書"
"ものおもi 物思"
"ものおぼe 物覚"
"ものおj 物怖"
"ものうk 物憂"
"ものうi 物憂"
"ものうg 物憂"
"ものいi 物言"
"もぬk 蛻"
"もどt 戻"
"もどs 戻"
"もどr 戻"
"もとづk 基"
"もとづi 基"
"もとz 基"
"もとr 戻 悖"
"もとn 基 元"
"もとm 求"
"もとd 基"
"もてあまs 持て余"
"もてあそb 弄 玩"
"もつr 縺"
"もっぱr 専 專"
"もっとm 最 尤"
"もってかえr 持って帰"
"もっt 以"
"もぢr 捩"
"もちはこb 持ち運"
"もちなおs 持ち直"
"もちつづk 持ち続"
"もちだs 持ち出"
"もちさr 持ち去"
"もちこたe 持ち堪"
"もちこs 持ち越"
"もちこn 持ち込 持込"
"もちこm 持ち込 持込"
"もちかえt 持ち帰"
"もちかえr 持ち帰"
"もちかk 持ち掛"
"もちいt 用い"
"もちあるk 持ち歩"
"もちあg 持ち上"
"もちw 用"
"もちi 用"
"もだe 悶"
"もたらs 齎"
"もたr 凭 靠"
"もたg 擡"
"もじみとm 文字認"
"もじまちがi 文字間違"
"もじばk 文字化"
"もじどおr 文字通"
"もじおc 文字落"
"もじr 捩"
"もぐりこn 潜り込"
"もぐりこm 潜り込"
"もぐt 潜"
"もぐr 潜 潛 濳"
"もくろn 目論"
"もくろm 目論"
"もくs 黙 目"
"もがk 藻掻"
"もえあg 燃え上"
"もうしわk 申し分"
"もうしひらk 申し開"
"もうしでt 申し出"
"もうしでr 申し出"
"もうしつk 申し付"
"もうしたt 申し立"
"もうしそe 申し添"
"もうしこn 申し込"
"もうしこm 申し込"
"もうしおくr 申し遅"
"もうしいr 申し入"
"もうしあw 申し合"
"もうしあg 申し上"
"もうs 申"
"もうk 設 儲"
"もうd 詣"
"もy 燃"
"もt 持 盛 以 保"
"もs 若 模 燃"
"もr 盛 漏 洩 守"
"もn 揉"
"もm 揉"
"もe 燃"
"もc 持"
"めんばs 面罵"
"めんどくさk 面倒臭"
"めんどくさi 面倒臭"
"めんどうくさi 面倒臭"
"めんどうくさg 面倒臭"
"めんくr 面喰"
"めんきょとr 免許取"
"めんs 面"
"めんj 免"
"めりこm 減り込"
"めもr メモ"
"めべr 目減"
"めとr 娶"
"めづらs 珍 珎"
"めつk 目付 眼付"
"めだt 目立"
"めだc 目立"
"めずらs 珍 珎"
"めじろどおr 目白通"
"めざわr 目障"
"めざまs 目覚"
"めざはr 目障"
"めざとi 目敏"
"めざs 目指 目刺"
"めざm 目覚 目醒"
"めぐろどおr 目黒通"
"めぐりめぐt 巡り巡"
"めぐt 巡"
"めぐr 巡 廻 繚 回 繞"
"めぐn 恵 惠"
"めぐm 恵 惠"
"めくらm 眩"
"めくばs 目配"
"めくばr 目配"
"めくr 捲"
"めかくs 目隠"
"めおs 目押"
"めうつr 目移"
"めいわくかk 迷惑掛"
"めいじどおr 明治通"
"めいうt 銘打"
"めいz 命"
"めいt 滅入"
"めいs 冥"
"めいr 滅入"
"めいj 命 銘"
"めあわs 娶"
"めあたらs 目新"
"めあw 妻合"
"めあt 目当"
"めあk 目明"
"めs 召"
"めr 減"
"めn 目"
"めd 愛 目 賞"
"むりn 無理"
"むらg 群 叢 簇"
"むねやk 胸焼"
"むにきs 無に帰"
"むなさわg 胸騒"
"むなs 空 虚"
"むづかs 難"
"むづかr 憤"
"むつかs 難"
"むつm 睦"
"むっt 六"
"むちうt 鞭打 鞭"
"むだづかi 無駄遣 無駄使"
"むだn 無駄"
"むせかえr 蒸返 噎返"
"むせb 咽 噎"
"むずかs 難"
"むずかr 憤"
"むすびつk 結び付"
"むすn 結"
"むすb 結 掬"
"むしばm 蝕 蠹 蠧"
"むしとr 虫取"
"むしくi 虫食"
"むしあつs 蒸し暑"
"むしあつi 蒸し暑"
"むしs 無視"
"むしr 寧 毟"
"むさぼr 貪"
"むごi 酷 惨"
"むこu 向"
"むくw 報"
"むくu 報"
"むくi 報 酬"
"むかしなつk 昔懐"
"むかしきk 昔聞"
"むかしきi 昔聞"
"むかu 対"
"むかt 向"
"むかi 向"
"むかh 迎 対 邀"
"むかe 迎 邀"
"むt 六"
"むs 蒸 咽 噎"
"むr 群 蒸"
"むk 向 剥"
"むi 向 剥"
"みわたs 見渡"
"みわすr 見忘"
"みわk 見分"
"みょうn 妙"
"みやぶr 見破"
"みやびy 雅"
"みやすk 見易"
"みやすi 見易"
"みむk 見向"
"みみなr 耳馴"
"みみざわr 耳障"
"みまわs 見回"
"みまわr 見回"
"みまもt 見守"
"みまもr 見守"
"みまちがu 見間違"
"みまちがi 見間違"
"みまちがe 見間違"
"みまかr 身罷"
"みまいもうs 見舞申"
"みまu 見舞"
"みまi 見舞"
"みまh 見舞"
"みぶるi 身震"
"みぶr 身振 見振"
"みひらk 見開"
"みひらi 見開"
"みばe 見栄"
"みはらs 見晴"
"みはらi 未払"
"みはなs 見放"
"みはっt 見張"
"みはじm 見始"
"みはからi 見計"
"みはかr 見計"
"みはt 見張"
"みはr 見張 見晴 瞠"
"みのがs 見逃"
"みのt 実"
"みのr 実"
"みのg 見逃"
"みねうt 峰打"
"みぬk 見抜"
"みぬi 見抜"
"みにつk 身に付"
"みにつi 身に付"
"みにくk 醜 見難"
"みにくi 醜 儖 見難"
"みにいk 見に行"
"みならw 見習"
"みならu 見習"
"みならt 見習"
"みならi 見習"
"みなすk 皆好"
"みなぎr 漲"
"みなおなj 皆同"
"みなおs 見直"
"みなs 皆 看倣 見倣 見做"
"みなr 見慣 見馴"
"みとどk 見届"
"みとがm 見咎"
"みとおs 見通"
"みとうs 見透 見通"
"みとr 見惚 見蕩"
"みとm 認"
"みてとr 見て取"
"みづらk 見辛"
"みづらi 見辛"
"みづかr 自"
"みつもt 見積"
"みつもr 見積"
"みつづk 見続 密漬"
"みつけだs 見つけ出 見付け出"
"みつくろu 見繕"
"みつくろt 見繕"
"みつくろh 見繕"
"みつかr 見付か"
"みつn 密"
"みつm 見積 凝視 瞶"
"みつk 見付"
"みつi 貢"
"みつg 貢"
"みっt 三"
"みぢかn 身近"
"みちゆk 道行"
"みちむk 道向"
"みちびきだs 導き出"
"みちびk 導"
"みちびi 導"
"みちがu 見違"
"みだs 見出 乱 亂"
"みだr 乱 淫 亂 妄"
"みたt 見立"
"みたs 満"
"みそづk 味噌漬"
"みそこn 見損"
"みそいたm 味噌炒"
"みそm 見初"
"みせびらk 店開"
"みずみずs 瑞々"
"みずまわr 水回"
"みずまs 水増"
"みずびたs 水浸"
"みずだs 水出"
"みずたまr 水溜"
"みずくさi 水臭"
"みずかr 自"
"みずあかとr 水垢取"
"みずあb 水浴"
"みすかs 見透"
"みすt 見捨"
"みすg 見過"
"みすe 見据 視据"
"みじかすg 短過"
"みじかs 短"
"みじかn 短 身近"
"みじかm 短"
"みじかk 短"
"みじかi 短 身近"
"みじm 慘 惨"
"みしr 見知"
"みさだm 見定"
"みごろs 見殺"
"みごとかえr 見事返"
"みこs 見越"
"みこn 見込"
"みこm 見込"
"みぐるs 見苦"
"みくらb 見比"
"みくだs 見下"
"みぎまわr 右回"
"みぎどなr 右隣"
"みぎぞろe 右揃"
"みぎそろe 右揃"
"みきわm 見極"
"みきt 見切"
"みきr 見切"
"みきk 見聞"
"みがわr 身代"
"みがまe 身構"
"みがk 磨"
"みがi 磨"
"みかぎt 見限"
"みかぎr 見限"
"みかえs 見返"
"みかえr 見返"
"みかk 見掛"
"みおわr 見終"
"みおぼe 見覚"
"みおとs 見落"
"みおとr 見劣"
"みおくt 見送"
"みおくr 見送"
"みおw 見終"
"みおt 見落"
"みおr 見下"
"みうしなu 見失"
"みうしなt 見失"
"みうしなi 見失"
"みうごk 身動 見動"
"みうr 身売"
"みうk 見受"
"みいだs 見出"
"みいt 見入"
"みいr 見入"
"みあw 見合"
"みあu 見合"
"みあt 見当 見合"
"みあk 見飽"
"みあi 見合"
"みあg 見上"
"みz 見"
"みy 見"
"みw 見 身"
"みu 見"
"みt 見 満 観 三 診 充 視 滿 觀 看 盈"
"みs 見 魅 観 視"
"みr 見 観 診 視 觀 看"
"みn 見 身 観 視"
"みm 見 観 視"
"みk 見"
"みi 見"
"みh 見"
"みe 見 観 視"
"みd 見"
"みc 満 滿 見"
"みa 見"
"まんがずk 漫画好"
"まんがかk 漫画描"
"まゐr 參"
"まわりこn 回り込"
"まわりこm 回り込"
"まわt 回 廻 囘 周"
"まわs 回 周 廻 囘"
"まわr 周 回 廻 巡 囘"
"まるやk 丸焼"
"まるめこn 丸め込"
"まるめこm 丸め込"
"まるみe 丸見"
"まるだs 丸出"
"まるm 丸"
"まるk 丸"
"まるi 丸 円 圓 槫"
"まよいこn 迷い込"
"まよいこm 迷い込"
"まよw 迷"
"まよu 迷"
"まよt 迷"
"まよk 魔除"
"まよi 迷"
"まよh 迷"
"まよe 迷"
"まやかs 瞞"
"まもなk 間も無"
"まもなi 間も無"
"まもt 守 護"
"まもr 守 護 防"
"まみr 塗"
"まみe 見"
"まほうつかi 魔法使"
"まぶs 眩 塗"
"まびk 間引"
"まばゆi 目映 眩"
"まばたk 瞬"
"まばr 疎"
"まはs 回 廻"
"まのあt 目の当"
"まのb 間延"
"まねt 真似"
"まねr 真似"
"まねk 招"
"まねi 招"
"まぬがr 免"
"まぬかr 免"
"まぬk 間抜"
"まにあw 間に合"
"まにあu 間に合"
"まにあt 間に合"
"まにあi 間に合"
"まにあe 間に合"
"まなn 学 學 斈"
"まなb 学 學 斈"
"まどろm 微睡"
"まどがk 窓掛"
"まどかk 窓掛"
"まどw 惑"
"まどu 惑 悗"
"まどh 惑"
"まとu 纏 繚"
"まとt 纏"
"まとm 纏 纒"
"まとh 纏"
"まづi 不味"
"まつまえづk 松前漬"
"まつw 纏"
"まつr 祭 奉 祀"
"まつh 纏"
"まっぷたt 真っ二"
"まっとu 全"
"まったk 全"
"まっすg 真っ直"
"まちのr 街乗"
"まちどおs 待ち遠"
"まちづくr 町作"
"まちっがt 間違"
"まちこg 待ち焦"
"まちがw 間違"
"まちがu 間違"
"まちがt 間違"
"まちがi 間違"
"まちがe 間違"
"まちかまe 待ち構"
"まちかt 間違"
"まちあわs 待ち合わ 待合"
"まちあw 待合 待ち合"
"まちあk 待ち明"
"またたk 瞬"
"またたi 瞬"
"またぎk 又聞"
"またi 跨"
"またh 又"
"またg 跨"
"まぜがk 交ぜ書"
"まずs 貧"
"まずi 不味"
"まじろg 瞬"
"まじめすg 真面目過"
"まじなi 呪"
"まじきr 間仕切"
"まじw 交"
"まじt 混"
"まじk 間近"
"まじh 交 雑"
"まじe 交 雑"
"まざりあu 混ざり合"
"まざりあt 混ざり合"
"まさt 勝 優"
"まさs 正"
"まさr 勝 優"
"まさn 正"
"まことn 誠"
"まけつづk 負け続"
"まくr 捲"
"まぎれこn 紛れ込"
"まぎれこm 紛れ込"
"まぎr 紛"
"まきもどs 巻戻 巻き戻"
"まきつk 巻き付"
"まきこn 巻き込"
"まきこm 巻き込"
"まきかえs 巻き返"
"まきおこs 巻き起"
"まきあg 巻き上"
"まがまがs 禍禍 兇々 禍々"
"まがu 紛 擬"
"まがt 曲"
"まがr 曲 間借 彎 弯 枉"
"まがi 擬 紛"
"まがh 紛"
"まかなw 賄"
"まかなu 賄"
"まかなh 賄"
"まかなe 賄"
"まかs 任 委"
"まかr 罷"
"まえむk 前向"
"まえふr 前振"
"まえづk 前付"
"まえがk 前書"
"まえおk 前置"
"まえうr 前売"
"まえいわi 前祝"
"まうs 申"
"まうk 設 儲"
"まうd 詣"
"まいこn 舞い込"
"まいこm 舞い込"
"まいあg 舞上"
"まいt 参 參"
"まいr 参 詣 參"
"まあたらs 真新 目新"
"まあi 間合"
"まz 混 先 交"
"まu 舞"
"まt 待 舞 俟"
"まs 増 摩 益 坐 在"
"まn 間"
"まk 負 巻 蒔 撒 敗 卷 捲 撤 播"
"まj 交 混 雑"
"まi 舞 蒔 巻 散 撒"
"まh 舞"
"まg 曲"
"まd 未"
"まc 待"
"ぼんおどr 盆踊"
"ぼんあk 盆明"
"ぼっs 没"
"ぼうえいs 防衛"
"ぼk 呆 惚 暈"
"ほんみょうおなj 本名同"
"ほんどおr 本通"
"ほんとb 本飛"
"ほんづかi 本使"
"ほんすべr 本滑"
"ほろよi 微酔"
"ほろn 滅"
"ほろb 滅 亡"
"ほれこn 惚れ込"
"ほれこm 惚れ込"
"ほりぬk 掘り抜"
"ほりだs 掘り出"
"ほりさg 掘り下"
"ほりかえs 掘り返"
"ほめそやs 褒称 誉称"
"ほまれおおk 誉大"
"ほまr 誉 譽"
"ほほばr 頬張"
"ほほえn 微笑"
"ほほえm 微笑 頬笑"
"ほふr 屠"
"ほのぐらi 仄暗"
"ほのm 仄"
"ほのk 仄"
"ほねやすm 骨休"
"ほねぐm 骨組"
"ほねおr 骨折"
"ほどよk 程良"
"ほどよi 程良"
"ほどとおk 程遠"
"ほどとおi 程遠"
"ほどこs 施"
"ほどk 解"
"ほとんd 殆"
"ほとばしt 迸"
"ほとばしr 迸"
"ほとn 殆"
"ほてt 火照"
"ほてr 火照"
"ほっs 欲"
"ほだs 絆"
"ほそながk 細長"
"ほそながi 細長"
"ほそぎr 細切"
"ほそs 細"
"ほそm 細"
"ほそk 細"
"ほそi 細"
"ほじr 穿"
"ほしふr 星降"
"ほしi 欲し 欲"
"ほころb 綻"
"ほこt 誇"
"ほこr 誇"
"ほぐr 解"
"ほがr 朗 朖"
"ほかn 他"
"ほおばr 頬張"
"ほおt 放"
"ほうりだs 放り出"
"ほうりこn 放り込"
"ほうりこm 放り込"
"ほうむr 葬"
"ほうふn 豊富"
"ほうっt 放"
"ほうこくいたs 報告致"
"ほうz 焙 報"
"ほうw 方"
"ほうt 放"
"ほうs 焙"
"ほうr 放 抛"
"ほうk 呆"
"ほうj 報 焙"
"ほうg 方"
"ほt 掘 放 彫"
"ほs 欲 乾 干"
"ほr 掘 惣 惚 堀 彫 恍 愡"
"ほm 誉 褒 賞 襃 譽"
"ほe 吠 咆 哮"
"べんj 弁"
"べつずr 別刷"
"べつあつかi 別扱"
"べつn 別"
"べいこくぎらi 米国嫌"
"べs 可"
"べk 可"
"へんにゅうs 編入"
"へんそうくだs 返送下"
"へんじくだs 返事下"
"へんこういたs 変更致"
"へんかんふくm 返還含"
"へんかんg 変換"
"へんかs 変化"
"へんn 変 變"
"へんd 変"
"へりくだr 謙 遜"
"へらs 減ら"
"へつらu 諛 諂"
"へつらh 諛 諂"
"へだt 隔"
"へたn 下手"
"へこm 凹"
"へいわn 平和"
"へz 経 經"
"へt 減 経 經"
"へr 減 経 經 歴"
"へn 経 經"
"ぶんせつくぎr 文節区切"
"ぶひんとr 部品取"
"ぶどまr 歩留"
"ぶじうごk 無事動"
"ぶじうごi 無事動"
"ぶかk 深"
"ぶかi 深"
"ぶあつk ぶ厚"
"ぶあつi 分厚 部厚"
"ぶt 撃 打 撲"
"ぶr 振"
"ふんばt 踏ん張"
"ふんばr 踏ん張"
"ふんちがi 分遅"
"ふんいきつたw 雰囲気伝"
"ふんいきつたe 雰囲気伝"
"ふんいきだs 雰囲気出"
"ふんs 扮"
"ふわたr 不渡"
"ふろあg 風呂上"
"ふれこn 触れ込"
"ふれこm 触れ込"
"ふるまu 振舞 振る舞"
"ふるまt 振る舞"
"ふるまi 振舞 振る舞"
"ふるまh 振舞"
"ふるまe 振舞"
"ふるすg 古過"
"ふるさとh 故郷"
"ふるくさi 古臭"
"ふるw 震"
"ふるu 奮 揮 振 震 篩"
"ふるt 奮"
"ふるs 古"
"ふるm 古"
"ふるk 古"
"ふるi 古 旧 震 舊 故 奮 振"
"ふるh 揮 振 震 奮 篩"
"ふるe 震 顫"
"ふるb 古"
"ふりわk 振り分"
"ふりむk 振り向"
"ふりむi 振り向"
"ふりまわs 振り回"
"ふりはらu 振り払"
"ふりつk 振り付"
"ふりだs 振り出 降り出"
"ふりこn 振り込 降り込"
"ふりこm 振り込 振込 降り込"
"ふりかえt 振り返 振返"
"ふりかえr 振り返"
"ふりかe 振り替"
"ふゆやすm 冬休"
"ふやs 殖や"
"ふむk 不向"
"ふみたおs 踏み倒"
"ふみこn 踏み込"
"ふみこm 踏み込"
"ふみきt 踏み切"
"ふみきr 踏み切"
"ふみいr 踏み入"
"ふなr 不慣"
"ふとどk 不届"
"ふとt 太"
"ふとs 太"
"ふとr 太"
"ふとm 太"
"ふとk 太"
"ふとi 太"
"ふてくさr ふて腐"
"ふつかよi 二日酔"
"ふつうn 普通"
"ふっとn 吹っ飛"
"ふっとb 吹っ飛"
"ふちどr 縁取"
"ふだんつかu 普段使"
"ふだんつかt 普段使"
"ふだんつかo 普段使"
"ふだんつかi 普段使"
"ふだんつかe 普段使"
"ふたとおr 二通"
"ふたたb 再"
"ふたしk 不確"
"ふたt 二 弍"
"ふぞろi 不揃"
"ふせi 防"
"ふせg 防 拒"
"ふしまわs 節回"
"ふしぜんn 不自然"
"ふしぎn 不思議"
"ふざけr 巫山戯"
"ふさわs 相応"
"ふさi 塞"
"ふさg 塞 鬱"
"ふけt 耽"
"ふけr 耽"
"ふくざつすg 複雑過"
"ふくs 服"
"ふくr 膨 脹"
"ふくn 含"
"ふくm 含"
"ふきぬk 吹き抜"
"ふきながs 吹き流"
"ふきとおs 吹き通"
"ふきとb 吹き飛"
"ふきつづk 吹き続"
"ふきつk 吹き付"
"ふきだs 噴き出 吹き出"
"ふきこn 吹き込"
"ふきこm 吹き込"
"ふきかe 吹替"
"ふきあg 吹き上"
"ふがひなi 腑甲斐無"
"ふがいなi 腑甲斐無"
"ふかよm 深読"
"ふかすg 深過"
"ふかおi 深追"
"ふかいr 深入"
"ふかs 深 更 蒸"
"ふかm 深"
"ふかk 深"
"ふかi 深 潭"
"ふえふk 笛吹"
"ふうじこm 封じ込"
"ふうしゃがたm 風車固"
"ふうぎt 封切"
"ふうがわr 風変"
"ふうz 封"
"ふうs 諷"
"ふうj 封"
"ふあんていd 不安定"
"ふy 増 殖"
"ふt 振 降"
"ふs 伏 付 臥 附 匐"
"ふr 振 降 触 経 經 觝 觸"
"ふn 踏 蹈 履"
"ふm 踏 践 履 蹈"
"ふk 吹 更 老 拭 深 葺 噴"
"ふi 吹 拭"
"ふe 増 殖"
"びんじょうねあg 便乗値上"
"びょううc 鋲打"
"びみょうn 微妙"
"びk 引"
"ひんs 瀕"
"ひろせどおr 広瀬通"
"ひろすg 広過"
"ひろいだs 拾い出"
"ひろいあつm 拾い集"
"ひろいあg 拾い上"
"ひろw 拾"
"ひろu 拾 広"
"ひろt 拾"
"ひろs 広 廣"
"ひろo 拾"
"ひろm 広 廣"
"ひろk 広 廣"
"ひろi 広 拾 弘 廣"
"ひろg 広 拡 廣 擴 展"
"ひろe 拾"
"ひるやすm 昼休"
"ひるすg 昼過"
"ひるさg 昼下"
"ひるがえt 翻"
"ひるがえs 飜 翻"
"ひるがえr 飜 翻"
"ひるm 怯"
"ひらめk 閃"
"ひらきなおt 開き直"
"ひらきなおr 開き直"
"ひらt 平"
"ひらk 開 拓"
"ひらi 開"
"ひょうへんs 豹変"
"ひょうばんわるk 評判悪"
"ひょうばんわるi 評判悪"
"ひょうばんよk 評判良"
"ひょうばんよi 評判良"
"ひょうばんどおr 評判通"
"ひょうじょうゆたk 表情豊"
"ひょうじs 表示"
"ひょうしぬk 拍子抜"
"ひょうぐm 表組"
"ひょうs 表 評"
"ひやかs 素見"
"ひやs 冷"
"ひやk 日焼"
"ひゃっぽゆずr 百歩譲"
"ひもとk 紐解 繙"
"ひまつぶs 暇潰"
"ひまs 日増"
"ひびわr 罅割"
"ひびk 響"
"ひびi 響"
"ひねt 捻"
"ひねr 捻 撚 拈 捫 陳"
"ひにくr 皮肉"
"ひなb 鄙"
"ひどr 日取"
"ひどk 非道"
"ひどi 酷 非道"
"ひとりじm 一人占"
"ひとりぐr 一人暮"
"ひとりあるk 一人歩"
"ひとよs 人寄"
"ひとみしr 人見知"
"ひとにぎr 一握"
"ひとどおr 人通"
"ひととおr 一通 一通り"
"ひととうr 一通"
"ひとづきあi 人付き合"
"ひとつづk 一続"
"ひとちがi 人違"
"ひとたたきk 一叩"
"ひとしr 人知"
"ひとさわg 一騒 人騒"
"ひとさがs 人捜 人探"
"ひとごろs 人殺"
"ひとごm 人込 人混"
"ひとくi 人喰"
"ひとくg 一区切"
"ひとかかe 一抱"
"ひとt 一 １ 壱 弌 壹"
"ひとs 等 均 斉"
"ひとr 独 獨 孤"
"ひとm 一"
"ひでr 日照"
"ひづk 日付"
"ひつようn 必要"
"ひっぱりだs 引っぱり出"
"ひっぱりこn 引っ張り込"
"ひっぱりこm 引っ張り込"
"ひっぱt 引っ張"
"ひっぱr 引っ張 引張"
"ひったくr 引っ手繰"
"ひっこぬi 引っこ抜"
"ひっこしづかr 引越疲"
"ひっこs 引越 引っ越"
"ひっこn 引っ込"
"ひっこm 引込 引っ込"
"ひっかかt 引掛"
"ひっかかr 引掛"
"ひっかk 引っ掛 引っ掻"
"ひだりまわr 左回"
"ひだりきk 左利 左効"
"ひたはしr 直走"
"ひたかくs 直隠"
"ひたs 浸 漬"
"ひたr 浸"
"ひそy 秘"
"ひそn 潜 潛 濳"
"ひそm 潜 潛 濳 顰"
"ひそk 秘 密 祕"
"ひずn 歪"
"ひずm 歪"
"ひじょうn 非常"
"ひしゃg 拉"
"ひしめk 犇"
"ひしm 犇"
"ひしg 柆"
"ひざまづk 跪"
"ひざまづi 跪"
"ひざまずk 跪"
"ひざs 日射 日差"
"ひさしぶr 久し振"
"ひさs 久 尚"
"ひさg 販 鬻 拉"
"ひぐr 日暮"
"ひくすg 低過"
"ひくs 低"
"ひくm 低"
"ひくk 低"
"ひくi 低"
"ひきわたs 引き渡"
"ひきわk 引き分"
"ひきもどs 引き戻"
"ひきまわs 引き回"
"ひきぬk 引き抜"
"ひきぬi 引き抜"
"ひきとおs 引き通"
"ひきとt 引き取"
"ひきとr 引き取 引取"
"ひきつづk 引き続 引続"
"ひきつづi 引き続"
"ひきつr 引き攣 引き連"
"ひきつk 引き付"
"ひきつi 引き継 引継"
"ひきつg 引き継 引継"
"ひきだs 引出 引き出"
"ひきたt 引き立"
"ひきずりこn 引きずり込"
"ひきずりこm 引きずり込"
"ひきしめr 引き締め"
"ひきしm 引締"
"ひきさr 引き去"
"ひきさk 引き裂"
"ひきさg 引き下"
"ひきこn 引き込"
"ひきこm 引き込"
"ひきかe 引き換"
"ひきおとs 引き落"
"ひきおk 引き起 惹き起"
"ひきうk 引き受"
"ひきあt 引き当"
"ひきあg 引き上"
"ひきw 率"
"ひきi 率"
"ひがえr 日帰"
"ひがw 日替 日変"
"ひがm 僻"
"ひからb 乾涸 干涸"
"ひかくてきあたらs 比較的新"
"ひかt 光"
"ひかr 光"
"ひかe 控"
"ひえこn 冷え込"
"ひえこm 冷え込"
"ひいd 秀"
"ひあg 干上 乾上"
"ひy 冷"
"ひt 引"
"ひs 比 秘"
"ひp 引"
"ひm 秘 祕"
"ひk 引 弾 挽 魅 曳 惹 彈 牽 索 退 碾 轢"
"ひi 引 弾 挽 彈 索"
"ひe 冷"
"ぱt 張"
"ぱr 張"
"ばんごうづk 番号付"
"ばんくるw 番狂"
"ばらi 払 拂"
"ばやi 早"
"ばなr 離"
"ばつぐんd 抜群"
"ばっすいおわt 抜粋終"
"ばっすいおわr 抜粋終"
"ばちがi 場違"
"ばたらk 働"
"ばしt 走"
"ばかよb 馬鹿呼"
"ばかs 魅"
"ばかr 許"
"ばいちかk 倍近"
"ばいちかi 倍近"
"ばあいわk 場合分"
"ばあt 場当"
"ばr 化"
"ばk 化"
"ばi 這"
"はんとしちかk 半年近"
"はんとしちかi 半年近"
"はんていがc 判定勝"
"はんだづk 半田付"
"はんそくまk 反則負"
"はんぐm 版組"
"はんs 反"
"はれわたt 晴れ渡"
"はれわたr 晴れ渡"
"はるやすm 春休"
"はるk 遥 遼 遙"
"はりめぐr 張り巡"
"はりつけr 貼り付け"
"はりつk 貼り付 張り付"
"はりつi 張り付"
"はりだs 張り出"
"はりこn 張り込 はり込 貼り込"
"はりこm 張り込 はり込 貼り込"
"はりかe 貼り替"
"はりあわs 貼り合"
"はりあw 貼り合"
"はりあu 張り合"
"はらへt 腹減"
"はらへr 腹減"
"はらばi 腹這"
"はらだt 腹立"
"はらたt 腹立"
"はらぐろi 腹黒"
"はらいもどs 払戻"
"はらいさg 払い下"
"はらいこn 払い込"
"はらいこm 払込 払い込"
"はらw 払 拂"
"はらu 払 拂 祓 禳 掃"
"はらt 払 拂"
"はらo 払 拂"
"はらm 孕"
"はらi 払 拂 祓"
"はらh 掃 払 拂 祓"
"はらe 払 拂"
"はよu 早"
"はゆs 映"
"はゆi 映"
"はやすg 早過 速過"
"はやがわr 早変"
"はやがえr 早帰"
"はやおくr 早送"
"はやおk 早起"
"はやt 流行"
"はやs 速 早 囃"
"はやr 流行 逸 早"
"はやm 早 速"
"はやk 早 速 疾"
"はやi 早 速 疾 捷"
"はめこm 嵌め込"
"はみでr はみ出"
"はみだs はみ出"
"はみがk 歯磨"
"はまべちかk 浜辺近"
"はまべちかi 浜辺近"
"はまちかk 浜近"
"はまちかi 浜近"
"はまt 嵌"
"はまr 填 嵌"
"はべr 侍"
"はぶr 羽振"
"はぶk 省 羽振"
"はぶi 省"
"はびこr 蔓延"
"はばよs 幅寄"
"はばひろk 幅広"
"はばひろi 幅広"
"はばかr 憚"
"はばn 阻"
"はばm 阻 難"
"はねかえs 跳ね返"
"はねかえr 跳ね返"
"はねあg 跳ね上"
"はなもt 鼻持"
"はなびe 花冷"
"はなばなs 華々 花々 華華"
"はなはだs 甚"
"はなはd 甚 堪"
"はなつまm 鼻抓"
"はなしだs 話出"
"はなしこn 話し込"
"はなしこm 話し込"
"はなしがi 放し飼"
"はなしあw 話し合"
"はなしあu 話し合"
"はなしあt 話し合"
"はなしあo 話し合"
"はなしあi 話し合"
"はなしあe 話し合"
"はなy 華 花"
"はなt 放"
"はなs 話 離 放"
"はなr 離 放"
"はづs 外"
"はづr 外"
"はづm 勢 弾 彈"
"はづk 辱 恥"
"はつすべr 初滑"
"はっぴょうもうs 発表申"
"はっこうs 発行"
"はっs 発 發"
"はちあw 鉢合"
"はだざむk 肌寒"
"はだざむi 肌寒"
"はださむi 肌寒"
"はだk 開"
"はたらk 働"
"はたらi 働"
"はたたk 羽撃"
"はたs 果"
"はたk 叩"
"はせいs 派生"
"はずかs 恥ずか"
"はずs 外"
"はずr 外"
"はずn 弾"
"はずm 弾 彈 勢 機"
"はずk 辱 恥"
"はすうきりあg 端数切上"
"はじm 始 初 甫 創"
"はじk 弾"
"はじi 弾"
"はしをr 端折"
"はしわたs 橋渡"
"はしりだs 走り出"
"はしりこn 走り込"
"はしりこm 走り込"
"はしょr 端折"
"はしおr 端折"
"はしt 走 赱 奔"
"はしr 走 奔 赱 迸"
"はさみこn 挟み込"
"はさみこm 挟み込"
"はさn 狭 挟 夾 挾"
"はさm 挟 夾 挾"
"はこびこn 運び込"
"はこびこm 運び込"
"はこn 運"
"はこb 運"
"はげまs 励ま"
"はげs 激 烈 劇"
"はげn 励 勵"
"はげm 励 勵"
"はぐくm 育 毓"
"はぐr 逸"
"はくs 博"
"はきだs 掃き出 吐き出 はき出"
"はきだi 掃き出"
"はがゆi 齒痒"
"はがs 剥"
"はがr 剥"
"はかりしr 計り知"
"はかりうr 量り売"
"はかばかs 捗々"
"はかなm 果無"
"はかなi 儚 果敢無 果無"
"はかどr 捗"
"はかt 計 図 測 圖"
"はかr 計 図 測 企 量 謀 圖 諮"
"はおt 羽織"
"はおr 羽織"
"はいりこn 入り込"
"はいりこm 入り込"
"はいちがe 配置換"
"はいしゃてつづk 廃車手続"
"はいt 入 這入"
"はいs 排 廃 拝 配"
"はいr 入 這入"
"はいn 入"
"はあくd 把握"
"はz 恥 耻 爆"
"はy 生 映 榮"
"はw 歯 齒 這"
"はu 這 匍"
"はt 果 張 貼 這"
"はs 発 馳 發"
"はr 晴 張 貼 腫 膨 脹"
"はn 跳 食 撥"
"はm 食 嵌"
"はk 吐 掃除 履 掃 帚 菷 刷 捌 穿 着 佩 帶"
"はj 恥 羞 耻"
"はi 吐 履 這 掃"
"はg 剥 禿"
"はe 生 映 暎 榮"
"はd 恥 耻 愧 慙 羞"
"はb 羽"
"のろけr 惚気"
"のろw 呪"
"のろu 呪 咒 詛"
"のろt 呪"
"のろi 呪 鈍"
"のりづk 糊付"
"のりつg 乗り継"
"のりだs 乗り出"
"のりこn 乗り込"
"のりこm 乗り込"
"のりこe 乗り越"
"のりくn 乗り組"
"のりきt 乗り切"
"のりきr 乗り切"
"のりかe 乗り換 乗換"
"のりいr 乗り入"
"のみほs 飲み干"
"のみすg 飲み過"
"のみこn 飲み込"
"のみこm 飲込 飲み込"
"のみあk 飲む明"
"のぼt 登 昇 上"
"のぼs 逆上 上"
"のぼr 登 昇 上 騰"
"のびなやn 伸び悩"
"のばなs 野放"
"のばs 延"
"ののしr 罵"
"ののs 罵"
"のっとt 乗っ取 則"
"のっとr 乗っ取 則"
"のちn 後"
"のたまu 宣"
"のたまh 宣 曰"
"のぞn 望 臨"
"のぞm 望 臨"
"のぞk 除 覗 覘 臨"
"のぞi 除 覗"
"のこt 残 殘"
"のこs 残 遺 殘"
"のこr 残 殘 遺"
"のこn 残"
"のこc 残"
"のがs 逃 迯"
"のがr 逃 迯 逸 遁"
"のt 載 乗 乘"
"のs 載 乗 乘 熨 伸"
"のr 乗 載 乘 伸"
"のn 飲 呑 飮"
"のm 飲 呑 飮 嚥"
"のk 乗 退 載"
"のg 逃 迯"
"のb 述 延 伸 陳"
"ねんごr 懇"
"ねんj 念"
"ねりこm 練り込"
"ねらw 狙"
"ねらu 狙"
"ねらt 狙"
"ねらo 狙"
"ねらi 狙"
"ねらe 狙"
"ねむりこn 眠り込"
"ねむりこm 眠り込"
"ねむt 眠"
"ねむs 眠"
"ねむr 眠 睡"
"ねむk 眠"
"ねむi 眠"
"ねまわs 根回"
"ねぼk 寝惚 寝呆"
"ねぶかk 根深"
"ねぶかi 根深"
"ねぶr 舐"
"ねびk 値引"
"ねばりづよi 粘り強"
"ねばt 粘"
"ねばr 粘"
"ねばk 粘"
"ねづよk 根強"
"ねづよi 根強"
"ねづk 根付"
"ねっしんd 熱心"
"ねっs 熱"
"ねちがe 寝違"
"ねだr 強請"
"ねたm 妬"
"ねずみとr 鼠取"
"ねすごs 寝過"
"ねすg 寝過"
"ねじふs 捻じ伏"
"ねじr 捻 捩"
"ねじk 拗"
"ねさg 値下"
"ねころg 寝転"
"ねころb 寝転"
"ねこずk 猫好"
"ねこn 寝込"
"ねこm 寝込"
"ねぐるs 寝苦"
"ねくずr 値崩"
"ねぎらu 犒"
"ねぎらi 犒"
"ねぎt 値切"
"ねぎr 値切"
"ねがえt 寝返"
"ねがえr 寝返"
"ねがいでt 願い出"
"ねがいさg 願い下"
"ねがw 願"
"ねがu 願"
"ねがt 願"
"ねがi 願"
"ねがh 願"
"ねがe 願"
"ねえs 姉"
"ねうc 値打"
"ねいr 寝入"
"ねあがr 値上"
"ねあk 寝明"
"ねあg 値上"
"ねz 寝 寢"
"ねy 寝 寢"
"ねt 寝 練 寢"
"ねs 寝"
"ねr 寝 練 錬 寢 粘 煉"
"ねn 寝 寢"
"ねm 寝 寢 睨"
"ねk 寝 根"
"ねj 捻 捩"
"ねc 寝"
"ぬるm 微温"
"ぬるi 微温 温"
"ぬりつぶs 塗り潰"
"ぬりこn 塗り込"
"ぬりこm 塗り込"
"ぬめr 滑"
"ぬすn 盗 盜"
"ぬすm 盗 盜"
"ぬけだs 抜け出"
"ぬぐu 拭"
"ぬぐt 拭"
"ぬぐo 拭"
"ぬぐi 拭"
"ぬくm 温"
"ぬくi 温"
"ぬきとおs 貫き通"
"ぬきでt 抜き出"
"ぬきだs 抜き出"
"ぬきずr 抜き刷"
"ぬきさs 抜き差"
"ぬきうt 抜き打 抜き撃"
"ぬきn 抽 擢"
"ぬかr 泥濘"
"ぬw 抜"
"ぬu 縫"
"ぬt 塗 縫"
"ぬr 塗 濡"
"ぬk 抜 脱 拔 貫"
"ぬi 抜 脱 縫 拔 貫"
"ぬg 脱"
"にんきうすk 人気薄"
"にんきうすi 人気薄"
"にわk 俄"
"にらn 睨"
"にらm 眈 睨"
"にゅうりょくまt 入力待"
"にゅうりょくまc 入力待"
"にゅうしゅつりょくh 入出力"
"にほんじんずk 日本人好"
"にほんじんごのm 日本人好"
"にほんごまz 日本語混"
"にほんごまj 日本語混"
"にほんごふきかe 日本語吹替"
"にほんごうc 日本語打"
"にぶt 鈍"
"にぶr 鈍"
"にぶk 鈍"
"にぶi 鈍"
"になw 担"
"になu 担 擔"
"になt 担 擔"
"になi 担 擔"
"になe 担"
"にとおr 二通"
"につm 煮詰"
"にちしゅくやすm 日祝休"
"にじr 躙"
"にじn 滲"
"にじm 滲"
"にごt 濁"
"にごs 濁"
"にごr 濁"
"にこy 柔 和"
"にこn 煮込"
"にこm 煮込"
"にげまわt 逃げ回"
"にげまわr 逃げ回"
"にげまどu 逃げ惑"
"にげまどt 逃げ惑"
"にげだs 逃げ出"
"にげさr 逃げ去"
"にげこn 逃げ込"
"にげこm 逃げ込"
"にげきt 逃げ切"
"にげきr 逃げ切"
"にげかくr 逃げ隠"
"にげかえt 逃げ帰"
"にげかえr 逃げ帰"
"にげおくr 逃げ遅"
"にげおt 逃げ落"
"にげうs 逃げ失"
"にくにくs 憎々"
"にくづk 肉付"
"にくおどr 肉踊"
"にくt 憎"
"にくs 難 憎"
"にくn 憎"
"にくm 憎"
"にくk 難 憎"
"にくi 難 憎"
"にぎわu 賑"
"にぎはh 賑"
"にぎy 賑"
"にぎw 賑"
"にぎt 握"
"にぎr 握"
"にがs 逃 苦"
"にがk 苦"
"にがi 苦"
"にかよu 似通"
"にかよt 似通"
"におw 匂 臭"
"におu 匂 臭"
"におi 匂 臭"
"におe 匂"
"にえきr 煮え切"
"にいt 兄"
"にいs 兄"
"にあw 似合"
"にあu 似合"
"にあt 似合"
"にあi 似合"
"にy 煮"
"にt 似 煮"
"にs 似"
"にr 煮 似"
"にn 似"
"にk 煮 似"
"にg 逃 迯"
"にe 煮"
"なんばんづk 南蛮漬"
"なんなn 垂"
"なんなk 難無"
"なんとおr 何通"
"なんt 何"
"なんr 何"
"なんk 何"
"なんd 何"
"なれなれs 馴々"
"なりふr 形振"
"なりたt 成り立 成立"
"なりかw 成り変 成り代"
"ならべかe 並べ変 並べ替 並べ換"
"ならびかe 並び換"
"ならづk 奈良漬"
"ならw 習"
"ならu 習 倣 肄"
"ならt 習 倣"
"ならs 均"
"ならn 並 竝"
"ならi 習 倣"
"ならh 習"
"ならe 習"
"ならb 並 竝 列"
"なやn 悩 惱"
"なやm 悩 惱"
"なめらk 滑"
"なめs 鞣"
"なめr 滑"
"なみはずr 並み外"
"なみのr 波乗"
"なみうt 波打"
"なまやさs 生易"
"なまやk 生焼"
"なまめかしk 艶かし"
"なまめかしi 艶かし"
"なまめk 艶"
"なまめi 艶"
"なまぬるi 生温"
"なまにe 生煮"
"なまなまs 生生 生々"
"なまじろs 生白"
"なまじろk 生白"
"なまじろi 生白"
"なまじi 憖"
"なまじh 憖"
"なまぐさk 生臭"
"なまぐさi 生臭 腥"
"なまがわk 生乾"
"なまえまk 名前負"
"なまえつk 名前付"
"なまあたたk 生暖"
"なまt 訛"
"なまr 鈍 訛 譌"
"なまm 生"
"なまk 怠 懶"
"なほs 治 直"
"なぶr 嬲 嫐"
"なびk 靡"
"なはs 話"
"なのt 名乗"
"なのr 名乗 名告 名宣"
"なにひとt 何一"
"なにげなi 何気無"
"なにげn 何気"
"なにかんがe 何考"
"なにw 何"
"なにm 何"
"なにk 何"
"なにg 何"
"ななt 七"
"ななm 斜"
"なづけt 名付け"
"なづm 泥"
"なづk 名付"
"なつやすm 夏休"
"なつむk 夏向"
"なつまつr 夏祭"
"なつかs 懐 懷"
"なつk 懐 懷"
"なっとくいただk 納得頂"
"なっとくいただi 納得頂"
"なっとくいk 納得行"
"なだかk 名高"
"なだかi 名高"
"なだt 名立"
"なだr 傾 雪崩"
"なだm 宥"
"なぞらu 擬 准 凖"
"なぞらh 擬 准 凖"
"なぞらe 擬 准 準"
"なぞとk 謎解"
"なずらu 擬 准 凖"
"なずらh 擬 准 凖"
"なずm 泥"
"なすr 擦"
"なじr 詰"
"なじn 馴染"
"なじm 馴染"
"なしとg 成し遂"
"なざs 名指"
"なさけなs 情無"
"なさけなi 情無 情け無"
"なさk 情"
"なごy 和"
"なごr 名残"
"なごn 和"
"なごm 和"
"なげやr 投げ遣"
"なげつk 投げ付"
"なげだs 投げ出"
"なげこn 投げ込"
"なげこm 投げ込"
"なげうt 抛 擲"
"なげいr 投げ入"
"なげあg 投げ上"
"なげk 嘆 歎 慨"
"なげi 嘆 慨"
"なぐりこn 殴り込"
"なぐりこm 殴り込"
"なぐさm 慰"
"なぐt 殴 毆 撲"
"なぐr 殴 毆 擲 撲"
"なきだs 泣き出"
"なきあk 泣き明"
"ながれだs 流れ出"
"ながれこn 流れ込"
"ながれこm 流れ込"
"ながれあるk 流れ歩"
"ながらh 存"
"ながもt 長持"
"ながもc 長持"
"ながびk 長引"
"ながびi 長引"
"ながつづk 長続"
"ながすぎr 長過"
"ながすg 長過"
"ながしこn 流し込"
"ながしこm 流し込"
"ながいこうえんどおr 長居公園通"
"ながいk 長生"
"ながs 流 長"
"ながr 流 長 乍 永 存"
"ながm 眺 長"
"ながk 長 永"
"ながi 長 永"
"ながb 長"
"なかよs 仲良"
"なかよk 仲良"
"なかまはずr 仲間外"
"なかまいr 仲間入"
"なかぬk 中抜"
"なかr 勿"
"なかn 中"
"なかb 半"
"なおっt 直"
"なおt 直 治"
"なおs 直 治 癒"
"なおr 直 治"
"ないまz 綯い交"
"なz 撫"
"なu 綯"
"なt 鳴 成"
"なs 無 成 為 做 爲 生"
"なr 慣 鳴 成 馴 生 爲 為"
"なo 綯"
"なm 並 嘗 竝 舐"
"なk 泣 無 亡 鳴 失 成 哭 啾 啼 嚶 涕"
"なi 無 泣 鳴 綯 凪 亡 啼"
"なh 綯"
"なg 投 薙 凪"
"なe 萎 痿"
"なd 撫 名"
"どろくさk 泥臭"
"どろくさi 泥臭"
"どもr 吃"
"どなりこn 怒鳴り込"
"どなりこm 怒鳴り込"
"どなt 怒鳴"
"どなr 怒鳴"
"どしゃぶr 土砂降"
"どしゃくづr 土砂崩"
"どくづk 毒突"
"どくけs 毒消"
"どおs 遠"
"どおr 通"
"どうせきs 同席"
"どうじn 同時"
"どうきづk 動機付"
"どうあg 胴上"
"どうz 動"
"どうr 通"
"どうj 動"
"どあi 度合"
"どr 取り 録"
"どm 止"
"とんがr 尖"
"とろk 蕩 盪"
"とりわすr 取り忘"
"とりわk 取り分"
"とりよs 取り寄"
"とりやm 取り止"
"とりもなおs 取りも直"
"とりもどs 取り戻"
"とりむすn 取り結"
"とりむすb 取り結"
"とりみだs 取り乱"
"とりまわs 取り回"
"とりまz 取り混"
"とりまk 取り巻"
"とりまi 取り巻"
"とりひk 取引 取り引"
"とりはらw 取り払"
"とりはらu 取り払"
"とりはらt 取り払"
"とりはらo 取り払"
"とりはらi 取り払"
"とりはらe 取り払"
"とりはずs 取り外"
"とりはこn 取り運"
"とりはこb 取り運"
"とりはかr 取り計"
"とりのぞk 取り除 取除"
"とりのぞi 取り除"
"とりのこs 取り残"
"とりにg 取り逃"
"とりなおs 取り直"
"とりなs 取り成 執り成"
"とりつくろu 取り繕"
"とりつくろt 取り繕"
"とりつくs 取り尽"
"とりつk 取り付 取付"
"とりつi 取り付 取り次"
"とりつg 取り次"
"とりちがe 取り違"
"とりちr 取り散"
"とりだs 取り出 取出"
"とりたt 取り立"
"とりそろe 取り揃"
"とりそこn 取り損"
"とりすm 取り澄"
"とりしらb 取調 取り調"
"とりしまr 取り締ま"
"とりしきt 取り仕切"
"とりしきr 取り仕切"
"とりしm 取り締 取締"
"とりさt 取り去"
"とりさr 取り去"
"とりさg 取り下"
"とりこわs 取り壊"
"とりこs 取り越"
"とりこn 取り込"
"とりこm 取り込"
"とりけs 取り消 取消"
"とりくずs 取り崩"
"とりくn 取り組"
"とりくm 取り組 取組"
"とりきm 取り決"
"とりかたm 取り固"
"とりかこn 取り囲"
"とりかこm 取り囲"
"とりかえs 取り返"
"とりかk 取り掛"
"とりかe 取り換 取り替"
"とりおさe 取り抑"
"とりおこなw 執り行"
"とりおこなu 執り行"
"とりおこなt 執り行"
"とりおこなo 執り行"
"とりおこなi 執り行"
"とりおこなe 執り行"
"とりおk 取り置"
"とりおi 取り置"
"とりうr 取り得"
"とりいそi 取り急"
"とりいそg 取り急"
"とりいr 取り入 取入"
"とりあらそu 取り争"
"とりあらそt 取り争"
"とりあつかw 取り扱"
"とりあつかu 取り扱 取扱"
"とりあつかt 取り扱"
"とりあつかo 取り扱"
"とりあつかi 取り扱 取扱"
"とりあつかe 取り扱"
"とりあつm 取り集"
"とりあw 取り合"
"とりあu 取り合"
"とりあt 取り合"
"とりあo 取り合"
"とりあi 取り合"
"とりあg 取り上"
"とりあe 取り敢 取り合"
"とらw 捕 囚"
"とらh 囚 捉 捕"
"とらe 捉 捕 把"
"ともばたらk 共働"
"ともなw 伴"
"ともなu 伴"
"ともなt 伴"
"ともなi 伴"
"ともなh 伴"
"ともえなg 巴投"
"ともs 灯 燈 点"
"ともr 燈 灯 点"
"ともn 共 伴"
"とむらu 弔 訪"
"とまりこn 泊まり込"
"とまりこm 泊まり込"
"とまどu 戸惑"
"とまどt 戸惑 戸迷"
"とまどi 戸惑"
"とまt 止 泊 佇"
"とまr 泊 止 停 留"
"とぼs 乏"
"とぼk 惚 恍"
"とほのk 遠退"
"とほs 通 徹"
"とほi 遠"
"とぶらh 弔 訪"
"とびのk 飛び退"
"とびぬk 飛び抜"
"とびでt 飛び出"
"とびでr 飛び出"
"とびちt 飛び散"
"とびちr 飛び散"
"とびだs 飛び出"
"とびこs 飛び越"
"とびこn 飛び込"
"とびこm 飛び込"
"とびかu 飛び交"
"とびかt 飛び交"
"とびいr 飛び入"
"となりあw 隣合"
"となりあu 隣合"
"となりあt 隣り合"
"となr 隣 鄰"
"となh 唱 称"
"となe 唱 称 稱"
"とどろk 轟 軣"
"とどまt 滞"
"とどこおt 滞 滯"
"とどこおr 滞 滯"
"とどm 留 止 畄 停"
"とどk 届 屆"
"とどi 届 屆"
"ととのえr 整"
"ととのw 整"
"ととのu 整"
"ととのt 整"
"ととのi 整"
"ととのh 整 斉 調"
"ととのe 整 調"
"とつi 嫁"
"とつg 嫁"
"とってかえs 取って返"
"とっしんs 突進"
"とっかe 取っ替"
"とだe 途絶"
"とじこn 綴じ込"
"とじこm 閉じ込 綴じ込"
"とじm 戸締"
"としよr 年寄"
"としこs 年越"
"としあk 年明"
"とざs 鎖 閉"
"とげとげs 刺刺"
"とけこn 溶け込"
"とけこm 溶け込"
"とくべつあつかi 特別扱"
"とくべつn 特別"
"とくばらi 特払"
"とくちょうづk 特徴付"
"とくn 特"
"とぎれr 途切れ"
"とぎr 途切"
"ときあk 説き明 解き明"
"ときn 時"
"とがt 尖"
"とがr 尖"
"とがm 咎"
"とおりぬk 通り抜"
"とおまわr 遠回"
"とおまk 遠巻"
"とおぼe 遠吠"
"とおのk 遠の 遠退"
"とおすg 遠過"
"とおざかt 遠ざか"
"とおz 遠"
"とおt 通"
"とおs 通 遠 徹"
"とおr 通"
"とおn 遠"
"とおk 遠"
"とおi 遠"
"とおc 通"
"とうひょうてつづk 投票手続"
"とうとs 尊"
"とうとi 貴 尊"
"とうとb 尊 貴"
"とうぜんn 当然"
"とうすg 遠過"
"とうじつうr 当日売"
"とうじすでn 当時既"
"とうこういたs 投稿致"
"とうきょううm 東京生"
"とうz 投"
"とうt 通"
"とうs 通 父"
"とうr 通"
"とうj 投"
"といなおs 問直"
"といあわs 問合 問い合わ"
"といあw 問い合 問合"
"とz 閉 閇 綴"
"とw 問"
"とu 問"
"とt 取 撮 採 録 盗 脱 捕"
"とr 取 撮 採 捕 録 執 摂 秉 脱 盗"
"とp 取"
"とn 飛 富 冨 翔 跳"
"とm 止 泊 留 停 富 冨 畄"
"とk 解 溶 説 觧 疾 融 熔 鎔"
"とj 閉 綴 閇"
"とi 問 解 説 觧 研"
"とh 問"
"とg 遂 研 磨 砥"
"とe 問"
"とd 綴 閉"
"とb 飛 跳 翔"
"でんちぎr 電池切"
"でんげんぬk 電源抜"
"でんげんぎr 電源切"
"でんげんいr 電源入"
"でんきさらあらi 電気皿洗"
"でやすk 出易"
"でやすi 出易"
"でむかe 出迎"
"でむk 出向"
"でむi 出向"
"でまわt 出回"
"でまわr 出回"
"でばらu 出払"
"でばらt 出払"
"でばらi 出払"
"ではじm 出始"
"ではいr 出入"
"でにくk 出難"
"でなおs 出直"
"でてゆk 出て行"
"でてきt 出て来"
"でつづk 出続"
"でつくs 出尽"
"でっぱt 出張"
"でたt 出立"
"でそろu 出揃"
"でそろt 出揃"
"でそろi 出揃"
"ですg 出過"
"でくw 出喰 出食"
"できなi 出来無"
"できあg 出来上"
"できz 出来"
"できt 出来"
"できs 出来"
"できr 出来"
"できn 出来"
"できm 出来"
"でかせg 出稼"
"でかk 出掛"
"でおくr 出遅"
"でいr 出入"
"であるk 出歩"
"であるi 出歩"
"であw 出逢 出合 出会"
"であu 出逢 出会 出合"
"であt 出逢 出会"
"であi 出会 出逢"
"であe 出会 出逢 出合"
"でz 出"
"でy 出"
"でt 出"
"でs 出"
"でr 出"
"でn 出"
"でm 出"
"でk 出"
"でd 出"
"でa 出"
"てんぷいたs 添付致"
"てんとr 点取"
"てんじもうs 展示申"
"てんj 転"
"てをだs 手を出"
"てわたs 手渡"
"てりこn 照り込"
"てりこm 照り込"
"てりかえs 照り返"
"てらu 衒"
"てらs 照"
"てらh 衒"
"てやわらk 手柔"
"てもどr 手戻"
"てもt 手持"
"てもc 手持"
"てまわs 手回"
"てまどt 手間取"
"てまどr 手間取"
"てぶr 手振"
"てびk 手引"
"てばやk 手早"
"てばやi 手早"
"てばなs 手放 手離"
"てはじm 手始"
"てぬk 手抜"
"てにはいr 手に入"
"てにいr 手に入"
"てなおs 手直"
"てどr 手取"
"てとりあしとr 手取り足取"
"てとr 手取"
"てづくr 手作"
"てづm 手詰"
"てつやあk 徹夜明"
"てつづk 手続"
"てつだw 手伝"
"てつだu 手伝"
"てつだt 手伝"
"てつだo 手伝"
"てつだi 手伝"
"てつだe 手伝"
"てっとりばやk 手っ取り早"
"てっとりばやi 手っ取り早"
"てっs 徹"
"てぢかn 手近"
"てちがi 手違"
"てだすk 手助"
"てだt 手立 手出"
"てだr 手練"
"てざわr 手触"
"てざs 手差"
"てさぐr 手探"
"てさs 手差"
"てごわs 手強"
"てごわi 手強"
"てごたh 手應"
"てごたe 手應"
"てこずr 梃摺"
"てきびs 手厳"
"てきとうn 適当"
"てきs 適"
"てきn 的"
"てがたk 手堅"
"てがたi 手堅"
"てがかr 手掛"
"てがk 手書 手掛 手懸"
"ておくr 手遅"
"ておs 手押"
"ていせいいたs 訂正致"
"ていしいたs 停止致"
"ていぎづk 定義付"
"ていs 呈 挺 締 訂"
"ていr 手入"
"てあらk 手粗"
"てあらi 手洗"
"てあつk 手厚"
"てあつi 手厚"
"てあt 手当"
"てあi 手合"
"てあg 手上"
"てr 照"
"てn 手"
"てg 手"
"てd 手"
"づらi 辛"
"づよk 強"
"づよi 強"
"づたi 伝"
"づくr 作 造 做"
"づかi 遣 使"
"づr 連"
"づm 積"
"づk 付 漬 突"
"つんざk 劈"
"つれもどs 連れ戻"
"つれてきt 連れて来"
"つれだt 連れ立"
"つれだs 連れ出"
"つれこn 連れ込"
"つれこm 連れ込"
"つるs 吊"
"つるm 連"
"つりこn 釣り込"
"つりこm 釣り込"
"つりあw 釣合"
"つりあu 釣合 釣り合"
"つりあi 釣合"
"つりあg 釣上 釣り上"
"つりあe 釣合"
"つらぬきとおs 貫き通"
"つらぬk 貫"
"つらぬi 貫"
"つらs 辛"
"つらn 連 列"
"つらk 辛"
"つらi 辛"
"つよs 強"
"つよm 強"
"つよk 強"
"つよi 強"
"つよg 強"
"つもt 積"
"つもr 積"
"つめたi 冷"
"つめこn 詰め込"
"つめこm 詰め込"
"つめあw 詰め合"
"つめt 冷"
"つめr 詰"
"つむg 紡"
"つみぶかk 罪深"
"つみこn 積み込"
"つみこm 積み込"
"つみかさn 積み重 積重"
"つみあg 積上 積み上"
"つまびk 爪弾"
"つまづk 躓"
"つまt 詰"
"つまs 約"
"つまm 撮 摘 抓"
"つぼm 窄 蕾"
"つぶやk 呟"
"つぶやi 呟"
"つぶひとt 粒一"
"つぶs 潰"
"つぶr 潰 瞑"
"つひe 潰 費 幣"
"つのt 募"
"つのr 募"
"つねr 抓"
"つねn 常"
"つなぎこm 繋ぎ込"
"つなぎかe 継ぎ換"
"つなi 継 繋 繼"
"つなg 繋 継 繼"
"つどu 集"
"つどt 集"
"つどi 集"
"つどh 集"
"つとn 夙"
"つとm 勤 務 努 勉"
"つづt 綴"
"つづr 綴"
"つづm 約"
"つづk 続 續"
"つづi 続 續"
"つつみこn 包み込"
"つつみこm 包み込"
"つつぬk 筒抜"
"つつしn 謹 慎 愼"
"つつしm 慎 鎮 謹 愼 鎭"
"つつs 謹 慎"
"つつn 包"
"つつm 包"
"つつk 突 突突"
"つっぷs 突っ伏"
"つっぱしt 突っ走"
"つっぱしr 突っ走"
"つっぱt 突っ張"
"つっぱr 突っ張 突張"
"つっぱn 突っ撥"
"つっつk 突っ突"
"つったt 突っ立"
"つっこn 突込 突っ込 突っこ"
"つっこm 突っ込"
"つっきr 突っ切"
"つっかk 突っ掛"
"つっかh 支 閊"
"つっかe 支 閊"
"つちかw 培"
"つちかu 培"
"つちかt 培"
"つだu 伝 傳"
"つだi 伝 傳"
"つたなi 拙"
"つたw 伝 傳"
"つたu 伝 傳"
"つたt 伝 傳"
"つたi 伝"
"つたh 伝 傳"
"つたe 伝 傳"
"つずr 綴"
"つこうまつr 仕"
"つこu 使"
"つけわすr 付け忘"
"つけたs 付け足"
"つけこn 付け込 漬け込"
"つけこm 付け込 漬け込"
"つけくわe 付け加"
"つけかe 付け替"
"つけあg 付け上"
"つぐなu 償"
"つぐなi 償"
"つぐm 噤"
"つくろu 繕"
"つくろh 繕"
"つくりなおs 作り直"
"つくりだs 作り出"
"つくりこn 作り込"
"つくりあg 作り上"
"つくらh 繕"
"つくt 作 做 創 造"
"つくs 尽 殲 殱 盡"
"つくr 作 創 造 做"
"つくn 捏"
"つぎこn つぎ込"
"つぎこm つぎ込"
"つぎn 次"
"つきまとu 付き纏"
"つきはじm 月始 月初"
"つきとおs 突き通"
"つきとb 突き飛"
"つきつk 突き付"
"つきだs 突き出"
"つきそt 付き添"
"つきおとs 突き落"
"つきおくr 月遅"
"つきあw 突き合 付き合"
"つきあu 付き合 付合"
"つきあt 付き合 突き当"
"つきあi 付き合"
"つきあg 突き上"
"つがu 番"
"つがi 番"
"つがh 番"
"つかまつr 仕"
"つかさどt 司"
"つかさどr 司 掌"
"つかうまつr 仕"
"つかいわk 使い分"
"つかいやすs 使い易"
"つかいやすi 使い易"
"つかいはじm 使い始"
"つかいはt 使い果"
"つかいにくi 使い難"
"つかいづらi 使い辛"
"つかいつk 使い尽"
"つかいだs 使い出"
"つかいすt 使い捨"
"つかいこn 使い込"
"つかいこm 使い込"
"つかいおw 使い終"
"つかいおe 使い終"
"つかw 使 遣"
"つかu 使 遣"
"つかt 使 遣"
"つかr 疲"
"つかo 使"
"つかn 掴 把 束"
"つかm 捕 掴 把 捉 攫"
"つかi 使 遣 遺"
"つかh 遣 仕 使 支 閊"
"つかe 使 仕 支 障 閊"
"つかc 使"
"つうほうs 通報"
"つうz 通"
"つうj 通"
"ついやs 費 費や"
"ついy 費"
"ついn 対 遂"
"ついe 潰 費 幣"
"つt 突 釣 吊"
"つr 連 釣 吊 攣 貫"
"つn 積 詰 接 摘"
"つm 詰 積 摘"
"つk 付 着 尽 突 漬 点 使 尾 衝 憑 就 附 盡 點 築 撞 搗"
"つi 着 付 突 継 憑 次 就 附 繼 支 点"
"つg 告 継 次 接 嗣 椄 繼"
"ぢs 持"
"ちんがs 賃貸"
"ちりばm 鏤"
"ちょくせんみとおs 直線見通"
"ちょくせついk 直接行"
"ちょうどよk 丁度良"
"ちょうどよi 丁度良"
"ちょうしわるk 調子悪"
"ちょうしわるi 調子悪"
"ちょうしよk 調子良"
"ちょうしよi 調子良"
"ちょうしおt 調子落"
"ちょうしおc 調子落"
"ちょうけs 帳消"
"ちょうz 長"
"ちゅうもんとr 注文取"
"ちゅうしs 中止"
"ちゅうこうr 中古売"
"ちゅうがえr 宙返"
"ちゅうかんあたr 中間辺"
"ちゅうおうよs 中央寄"
"ちゅうおうどおr 中央通"
"ちゅういぶかk 注意深"
"ちゅういぶかi 注意深"
"ちゅうs 沖 注 註 冲"
"ちゃづk 茶漬"
"ちゃくばらi 着払"
"ちゃくm 茶汲"
"ちゃかs 茶化 茶加"
"ちまよu 血迷"
"ちまよt 血迷"
"ちばしt 血走"
"ちばしr 血走"
"ちぬr 血塗"
"ちなn 因"
"ちなm 因"
"ちぢみこn 縮み込"
"ちぢみこm 縮み込"
"ちぢみあg 縮み上"
"ちぢr 縮"
"ちぢn 縮"
"ちぢm 縮"
"ちちおやごろs 父親殺"
"ちじm 縮"
"ちこu 近"
"ちぎr 契 千切"
"ちがw 違"
"ちがu 違 交"
"ちがt 違"
"ちがi 違"
"ちがh 違 交"
"ちがe 違"
"ちからもc 力持"
"ちからまかs 力任"
"ちからづよk 力強"
"ちからづよi 力強"
"ちからつk 力尽"
"ちからぞe 力添"
"ちかよt 近寄"
"ちかよr 近寄"
"ちかづk 近付"
"ちかづi 近付"
"ちかu 誓 盟"
"ちかt 誓"
"ちかs 近 親"
"ちかk 近"
"ちかi 近 誓"
"ちかh 誓 盟"
"ちかg 近"
"ちかe 誓"
"ちかd 近"
"ちいさk 小"
"ちいs 小"
"ちt 散"
"ちr 散"
"ちg 血"
"ちb 禿"
"だんどr 段取"
"だんとr 段取"
"だんちがi 段違"
"だんせいむk 男性向"
"だんぐm 段組"
"だんくm 段組"
"だんz 断"
"だんj 断"
"だれm 誰"
"だれk 誰"
"だれg 誰"
"だるi 怠"
"だよr 便"
"だまりこn 黙り込"
"だまりこm 黙り込"
"だまt 黙 默"
"だまs 騙"
"だまr 黙 默"
"だぶr ダブ"
"だっs 脱"
"だしあu 出し合"
"だしあt 出し合"
"だきこn 抱き込"
"だきこm 抱き込"
"だきあt 抱き合"
"だおs 倒"
"だいめいわすr 題名忘"
"だいめいどおr 題名通"
"だいぶちがu 大分違"
"だいびk 代引"
"だいひょうてきn 代表的"
"だいたいおなj 大体同"
"だいすk 大好"
"だいきらi 大嫌"
"だいがくがえr 大学帰"
"だいs 題"
"だt 立 建"
"だs 出 堕"
"だm 溜 澑"
"だk 抱"
"だi 抱"
"だc 立"
"たんじゅんn 単純"
"たんいじかんあt 単位時間当"
"たんn 単 單"
"たをr 手折"
"たをm 撓"
"たわむr 戯 戲"
"たわm 撓"
"たわk 戯"
"たれながs 垂れ流"
"たれこn 垂れ込"
"たれこm 垂れ込"
"たるm 弛"
"たらs 誑"
"たよt 頼"
"たよr 頼 便"
"たゆたu 揺蕩"
"たゆたh 揺蕩"
"たゆm 弛"
"たやすi 容易"
"たもt 保"
"たもc 保"
"ためらu 躊躇 猶豫"
"ためらh 躊躇 猶豫"
"ためしずr 試し刷"
"ためこn 溜め込"
"ためs 試"
"ためn 為 爲"
"ためd 為"
"たむろs 屯"
"たむk 手向"
"たまわr 賜 承"
"たまつk 玉突"
"たまだs 玉出"
"たまげr 魂消"
"たまぎr 弾切 魂消"
"たまきt 玉木"
"たまw 賜"
"たまu 給 賜"
"たまt 溜 澑"
"たまr 溜 堪 澑"
"たまh 給 賜"
"たまe 給"
"たべつくs 食べ尽"
"たべかk 食べ掛"
"たべt 食べ"
"たぶらk 誑"
"たふとi 貴 尊"
"たふs 倒"
"たふr 倒 斃"
"たびなr 旅慣"
"たびだt 旅立"
"たびかさn 度重"
"たばなs 手放"
"たばさm 手挾"
"たばかr 謀"
"たばn 束"
"たはむr 戲"
"たのみこn 頼み込"
"たのみこm 頼み込"
"たのしm 楽"
"たのs 楽 愉 樂"
"たのn 頼"
"たのm 頼 恃"
"たにまわr 谷回"
"たどりつk たどり付"
"たどりつi たどり付"
"たどt 辿 到"
"たどr 辿 到"
"たとh 喩 譬"
"たとe 例 喩 譬"
"たでくu 蓼食"
"たてまつr 奉"
"たてなおs 立て直"
"たてとおs 立て通"
"たてつづk 立て続"
"たてつk 盾突 楯突"
"たてぐm 縦組"
"たてがk 縦書"
"たてかk 立て掛"
"たてかe 立て替"
"たづさh 攜 携"
"たづn 尋 訊 訪"
"たっとi 貴"
"たっとb 貴 尊"
"たっs 達 逹"
"たちよt 立寄 立ち寄"
"たちよr 立寄"
"たちよm 立ち読"
"たちなおt 立ち直"
"たちなおr 立ち直"
"たちどおs 立ち通"
"たちどm 立ち止"
"たちとおs 立ち通"
"たちさr 立ち去"
"たちさg 立ち下"
"たちこm 立ち籠"
"たちきt 断ち切 裁ち切"
"たちきr 断ち切 裁ち切"
"たちうt 太刀打"
"たちいr 立ち入"
"たちあw 立会"
"たちあu 立合 立ち会 立ち合"
"たちあt 立ち合"
"たちあi 立合"
"たちあg 立ち上 起ち上 立上"
"ただよw 漂"
"ただよu 漂"
"ただよt 漂"
"ただよi 漂"
"ただよh 漂"
"ただたんn 只単"
"ただt 直"
"ただs 正 但 匡 質 糺"
"ただr 爛 糜"
"ただc 直"
"たたみこn 畳み込"
"たたみこm 畳み込"
"たたづm 佇"
"たたずm 侘 佇"
"たたきつk 叩きつ"
"たたきだs 叩き出"
"たたきこm 叩き込"
"たたかw 戦 闘 戰 鬪"
"たたかu 闘 戦 斗 戰 鬪"
"たたかt 闘 戦 戰 鬪"
"たたかi 戦 闘 戰 鬪"
"たたかh 戰 鬪"
"たたかe 戦 戰"
"たたえr 湛"
"たたt 祟"
"たたr 祟 崇"
"たたm 疊 畳 疉 疂"
"たたk 叩 敲"
"たたi 叩"
"たたh 称 湛"
"たたe 讃 賛 称 湛"
"たそがr 黄昏"
"たずさわt 携"
"たずさわr 携"
"たずさw 携 攜"
"たずさe 携 攜"
"たずn 尋 訪 訊"
"たすk 助 扶"
"たしょうちがu 多少違"
"たしょうちがt 多少違"
"たしょうちがi 多少違"
"たしょうちがe 多少違"
"たしょうたかk 多少高"
"たしょうたかi 多少高"
"たしょうおくr 多少遅"
"たしなm 嗜 窘"
"たしあw 足し合"
"たしk 確 慥"
"たけなわn 闌 酣"
"たけしたどおr 竹下通"
"たけs 猛"
"たけr 猛 哮"
"たけk 猛"
"たぐu 比 類"
"たぐt 手繰"
"たぐr 手繰"
"たぐi 類"
"たぐh 比 類"
"たくわe 蓄 畜 貯"
"たくらn 企"
"たくらm 企"
"たくまs 逞"
"たくはh 蓄 貯"
"たくs 託"
"たくr 綰"
"たくm 巧"
"たぎr 滾"
"たがやs 耕 畊 畉"
"たがu 違"
"たがi 互"
"たがh 違"
"たがe 違"
"たかぶr 昂ぶ 亢ぶ 昂"
"たかなt 高鳴"
"たかなr 高鳴"
"たかすg 高過"
"たかs 高"
"たかr 集"
"たかn 高"
"たかm 高"
"たかk 高"
"たかi 高"
"たおれr 殕"
"たおしこm 倒し込"
"たおy 嫋"
"たおs 倒"
"たおr 倒 斃 手折"
"たえがたi 耐え難"
"たうe 田植"
"たいへんよk 大変良"
"たいへんよi 大変良"
"たいへんもうs 大変申"
"たいへんおそk 大変遅"
"たいへんおそi 大変遅"
"たいさくしr 対策知"
"たいおうづk 対応付"
"たいおうしきr 対応仕切"
"たいあたr 体当"
"たいあt 体当"
"たいs 対 大 對"
"たいr 平"
"たy 絶"
"たt 立 経 建 断 起 発 絶 斷 發 經 裁"
"たs 足 達 逹"
"たr 足 垂 埀"
"たn 他"
"たm 溜 貯 矯 澑"
"たk 炊 焚 長 闌"
"たi 炊"
"たh 他 堪 耐"
"たe 耐 絶 堪"
"たc 立 断 斷 経 建"
"たb 食"
"ぞんじあg 存じ上"
"ぞんz 存"
"ぞんj 存"
"ぞろe 揃"
"ぞくs 属"
"ぞくn 俗"
"ぞi 沿"
"そんz 損"
"そんs 存"
"そんj 損"
"そろw 揃"
"そろu 揃"
"そろt 揃"
"そろi 揃"
"そろh 揃"
"そろe 揃"
"そろc 揃"
"そらんj 諳"
"そめこn 染め込"
"そめこm 染め込"
"そむk 背 叛"
"そむi 背"
"そぼt 濡"
"そぶr 素振"
"そびe 聳"
"そばだt 峙"
"そねm 嫉 妬 猜"
"そなえつk 備え付"
"そなw 備"
"そなh 供 具 備"
"そなe 備 供 具"
"そとむk 外向"
"そとまわr 外回"
"そとづk 外付"
"そとつk 外付"
"そだt 育 毓"
"そだc 育 毓"
"そそのかs 唆 嗾"
"そそぎこn 注ぎ込"
"そそぎこm 注ぎ込"
"そそi 注"
"そそg 注 灌"
"そしr 詆 謗 讒 誹"
"そこなw 損"
"そこなu 損 害"
"そこなt 損"
"そこなh 損"
"そこしr 底知"
"そこn 損 害"
"そぐu 似"
"そくs 則 即 促"
"そうりょうちゃくばらi 送料着払"
"そうめいd 聡明"
"そうふいただk 送付頂"
"そうふいたs 送付致"
"そうとうn 相当"
"そうていs 想定"
"そうだんくだs 相談下"
"そうぞうs 騒々"
"そうs 奏"
"そうj 総"
"そあくn 粗悪"
"そw 沿 添"
"そu 沿 添 副"
"そt 沿 添 剃"
"そr 剃 反 逸 其"
"そn 其 素"
"そm 初 染"
"そi 沿 添"
"そh 沿 添 副"
"そg 削 殺"
"そe 添 沿 副"
"ぜんぶもt 全部持"
"ぜんぜんよn 全然読"
"ぜんぜんよm 全然読"
"ぜんぜんみt 全然見"
"ぜんきょくとおs 全曲通"
"ぜんk 前"
"ぜひきk 是非聞"
"ぜにうしなi 銭失"
"ぜったいよk 絶対良"
"ぜったいいk 絶対行"
"ぜっs 絶"
"ぜいこm 税込"
"せんもんかむk 専門家向"
"せんまいどおs 千枚通"
"せんまいづk 千枚漬"
"せんびk 線引"
"せんなi 詮無"
"せんたくばさm 洗濯挟"
"せんたくs 選択"
"せんぞがえr 先祖帰"
"せんさいn 繊細"
"せんかたなi 詮方無"
"せんz 煎"
"せんs 僭"
"せんj 煎"
"せわずk 世話好"
"せわs 忙"
"せめこn 攻め込"
"せめこm 攻め込"
"せめg 鬩"
"せますg 狭過"
"せまt 迫"
"せまs 狭 狹"
"せまr 迫 逼"
"せまk 狭 狹"
"せまi 狭 狹"
"せばm 狭 狹"
"せはs 忙"
"せつめいしょどおr 説明書通"
"せつめいs 説明"
"せつぞくs 接続"
"せつn 切"
"せつk 責付"
"せっていまちがi 設定間違"
"せっつk 責付"
"せっしょくs 接触"
"せっきんs 接近"
"せっきょくてきn 積極的"
"せっきょうたr 説教垂"
"せっきょうくさk 説教臭"
"せっきょうくさi 説教臭"
"せっs 接"
"せせらわらu 嘲笑"
"せきにんもt 責任持"
"せきにんとt 責任取"
"せきにんとr 責任取"
"せきとm せき止"
"せきたt 急き立"
"せきがe 席替"
"せおいこn 背負い込"
"せおいこm 背負込 背負い込"
"せおu 背負"
"せおt 背負"
"せおi 背負"
"せおe 背負"
"せうs 抄"
"せいりけんとr 整理券取"
"せいちょうs 成長"
"せいせいs 生成"
"せいげんつk 制限付"
"せいかくs 正確"
"せいかくn 正確"
"せいs 制"
"せt 競"
"せs 接"
"せr 競 迫 糶"
"せm 責 攻"
"せk 急 堰 塞"
"せi 急"
"せg 背"
"ずるi 狡"
"ずぶとk 図太"
"ずぶとi 図太"
"ずつk 頭突"
"ずうずうs 図々"
"ずいぶんふるi 随分古"
"ずr 刷"
"ずm 済 濟"
"ずk 好 付"
"すんぶんちがw 寸分違"
"すわりこn 座り込"
"すわりこm 座り込"
"すわt 座 坐"
"すわr 座 坐"
"すれちがu 擦れ違"
"するどs 鋭"
"するどk 鋭"
"するどi 鋭"
"すりよr 擦り寄 摩り寄"
"すりむk 擦り剥 擦剥"
"すりむi 擦剥"
"すりへr 磨り減"
"すりぬk 擦り拔"
"すりつぶs 摺り潰 磨り潰"
"すりこn 刷り込"
"すりこm 摺り込 摩り込 刷り込"
"すりくだk 擂り碎"
"すりきr 摺り切 摩り切"
"すりかe すり替 摩り替"
"すもぐr 素潜"
"すみこn 住み込"
"すみこm 住み込"
"すみy 速"
"すまh 住ま"
"すぼm 窄"
"すべりこn 滑り込"
"すべりこm 滑り込"
"すべt 全 滑 総 總"
"すべr 滑 辷"
"すばらs 素晴"
"すばやs 素早"
"すばやk 素早 素速"
"すばやi 素早"
"すばr 素晴"
"すなわt 即 則"
"すなわc 即"
"すなどr 漁"
"すどまr 素泊"
"すどおs 素通"
"すどおr 素通"
"すでn 既"
"すてさt 捨て去"
"すてさr 捨て去"
"すてきr 捨て切"
"すてきd 素敵"
"すてがたi 捨て難"
"すづk 酢漬"
"すだt 巣立"
"すたr 廃 頽 廢"
"すずs 涼 凉"
"すずn 涼"
"すずm 涼 凉"
"すすr 啜"
"すすn 進"
"すすm 進 勧 薦 勸"
"すすk 煤"
"すすg 啌 漱 濯 雪"
"すじちがi 筋違"
"すじr 捩"
"すさm 凄 荒 進 遊"
"すさb 荒 進 遊"
"すごもr 巣篭"
"すごすg 凄過"
"すごs 過 凄"
"すごm 凄"
"すごk 凄"
"すごi 凄"
"すこぶr 頗"
"すこy 健"
"すこs 少"
"すぐr 優 秀 勝 選"
"すぐn 直"
"すくなk 少 少な"
"すくなi 少 少な 寡"
"すくいだs 救い出"
"すくw 救 掬"
"すくu 救 掬 匡 抄 巣喰 済 巣く"
"すくt 救 掬"
"すくo 救"
"すくn 少 竦"
"すくm 竦 窘"
"すくi 救 掬"
"すくh 掬 救 済 抄"
"すくe 救"
"すぎn 過ぎ"
"すきとおt 透き通"
"すきとおr 透き通"
"すきこn 漉き込"
"すきこm 漉き込"
"すがすがs 清々"
"すがr 縋"
"すかs 賺 透"
"すえながk 末長 末永"
"すえおk 据置 据え置"
"すうねんたt 数年経"
"すうねんたc 数年経"
"すいだs 吸い出"
"すいこn 吸い込"
"すいこm 吸い込"
"すいあg 吸い上"
"すw 吸 喫 据"
"すu 吸 喫"
"すt 捨 吸 刷 棄 喫"
"すr 刷 擦 摺 擂 為 剃 摩 磨 掏 爲"
"すp 酸"
"すn 済 住 棲 澄 拗 濟"
"すm 済 住 澄 棲 栖 澂 濟 清"
"すk 好 透 梳 耡 空 漉 鋤 抄 剥"
"すi 吸 済 空 透 喫 酸 濟 好"
"すg 過 直"
"すe 据 吸 饐"
"すb 総 統 總"
"じょうほうくだs 情報下"
"じょうせきどおr 定石通"
"じょうけんづk 条件付"
"じょうz 乗 乘"
"じょうs 城"
"じょうn 上 状"
"じょうj 乗 乘"
"じゆうd 自由"
"じゅんばんまc 順番待"
"じゅんz 準 殉 凖"
"じゅんn 順"
"じゅんj 準 凖"
"じゅつごよb 述語呼"
"じゅくs 熟"
"じゅうらいどおr 従来通"
"じゅうぶんn 十分"
"じゅうぶんd 十分"
"じゅうなんn 柔軟"
"じゅうだいn 重大"
"じゅうじがたm 十字固"
"じゅn 得"
"じゃらs 戯"
"じゃっかんことn 若干異"
"じむてづづk 事務手続"
"じばk 字化"
"じてんしゃのr 自転車乗"
"じてんd 時点"
"じつn 実"
"じつh 実"
"じだいおくr 時代遅"
"じしょひk 辞書引"
"じさg 字下"
"じこm 仕込"
"じきはずr 時期外"
"じかんぎr 時間切"
"じかんおくr 時間遅"
"じs 辞 侍 持"
"じr 焦"
"じn 死"
"じg 字"
"しんぴてきn 神秘的"
"しんぴてきd 神秘的"
"しんぱいなs 心配無"
"しんぱいなi 心配無"
"しんじんぶかk 信心深"
"しんじんぶかi 信心深"
"しんじゅくどおr 新宿通"
"しんしんぶかk 信心深"
"しんしんぶかi 信心深"
"しんしんともn 心身共"
"しんけんd 真剣"
"しんきくさk 神気臭"
"しんきくさi 神気臭 心気臭 辛気臭"
"しんz 信"
"しんj 信 死ん"
"しをr 萎"
"しわがr 嗄"
"しわk 仕分"
"しわi 吝"
"しろうとかんがe 素人考"
"しろk 白"
"しろi 白"
"しるs 記 著 示 印 誌 徴 標"
"しりぞk 退 斥"
"しりぞi 退"
"しりあu 知り合"
"しりあt 知り合"
"しりあi 知り合"
"しりあe 知り合"
"しらじらs 白々"
"しらs 報"
"しらm 白"
"しらk 白"
"しらb 調"
"しようくだs 使用下"
"しようs 使用"
"しようd 使用"
"しょっきあらi 食器洗"
"しょじs 所持"
"しょしんしゃむk 初心者向"
"しょげr 悄気"
"しょくs 食"
"しょきばらi 暑気払"
"しょきかs 初期化"
"しょうめいずm 証明済"
"しょうめいs 証明"
"しょうぶづよi 勝負強"
"しょうぶつよk 勝負強"
"しょうだt 章立"
"しょうじょまんがずk 少女漫画好"
"しょうぎだおs 将棋倒"
"しょうがつやすm 正月休"
"しょうかいいただk 紹介頂"
"しょうかいいたs 紹介致"
"しょうz 生"
"しょうs 称 抄 証"
"しょうj 生"
"しょu 背負"
"しょt 背負"
"しょs 処"
"しょh 背負"
"しゅくs 祝"
"しゅうりがk 修理書"
"しゅうはすうg 周波数"
"しゅうかんおくr 週間遅"
"しゅうあk 週明"
"しゅt 主"
"しゃれt 洒落"
"しゃべt 喋"
"しゃべr 喋 諜"
"しゃちほこばr 鯱張"
"しゃこいr 車庫入"
"しゃがr 嗄"
"しめだs 締め出"
"しめくくr 締め括"
"しめきt 締め切"
"しめきr 締切 締め切"
"しめt 湿"
"しめs 示 湿 濕"
"しめr 湿 濕"
"しめp 湿 濕"
"しむk 仕向"
"しみこn 染み込"
"しみこm 染み込"
"しみいt 染み入"
"しみいr 染み入"
"しみr 沁"
"しまu 仕舞 終 了"
"しまt 了 仕舞"
"しまr 閉"
"しまi 終"
"しぼりこm 絞り込"
"しぼt 絞"
"しぼr 絞 搾"
"しぼm 萎 凋"
"しぶt 渋 澁 澀"
"しぶs 渋"
"しぶr 渋 澁"
"しぶk 渋 澁 澀"
"しぶi 渋 澁 澀"
"しびr 痺"
"しばらk 暫"
"しばたk 瞬"
"しばt 縛"
"しばs 暫"
"しばr 縛 暫 凍"
"しはらw 支払"
"しはらu 支払"
"しはらt 支払"
"しはらi 支払"
"しはらe 支払"
"しのびこn 忍び込"
"しのびこm 忍び込"
"しのばずどおr 不忍通"
"しのn 忍"
"しのi 凌"
"しのg 凌"
"しのb 偲 忍"
"しにくi 為難 爲難"
"しなぞろi 品揃"
"しなぞろe 品揃"
"しなぎr 品切"
"しなおs 仕直"
"しなu 撓"
"しなr 撓"
"しなh 撓"
"しなb 萎"
"しとm 仕留 爲留"
"してきどおr 指摘通"
"してきs 指摘"
"していs 指定"
"しづr 垂 埀"
"しづm 沈 鎭 靜"
"しつりょうあたr 質量当"
"しつけr 躾"
"しっとぶかi 嫉妬深"
"しっかr 確"
"しちめんどうくさi 七面倒臭"
"しだr 垂"
"したよs 下寄"
"したまわr 下回"
"したばたらk 下働"
"したどr 下取"
"したとr 下取"
"したつk 下付"
"したたt 滴"
"したたr 舌足 滴"
"したたm 認"
"したしm 親し 親"
"したざわr 舌触"
"したがw 従 从 從"
"したがu 従 順 从 啝 從 随"
"したがt 従 从 從 順"
"したがk 下書"
"したがi 従 从 從 順"
"したがh 従 順 随 從"
"したがe 従 从 從 随"
"したうt 舌打"
"したうk 下請け 下請"
"したw 慕"
"したu 慕"
"したt 仕立 慕"
"したs 親"
"したn 下"
"したk 下"
"したh 慕"
"しぜんn 自然"
"しずみこn 沈み込"
"しずみこm 沈み込"
"しずけs 靜け"
"しずr 垂"
"しずn 沈"
"しずm 沈 静 鎮 靜 沒 鎭"
"しずk 静 靜"
"しじょうむk 市場向"
"しじどおr 指示通"
"ししんかえs 私信返"
"しさs 示唆"
"しごk 扱"
"しこr 凝 痼"
"しこn 仕込"
"しこm 仕込"
"しげt 茂 楙"
"しげr 茂 繁 楙"
"しげm 茂"
"しけr 湿気"
"しぐr 時雨"
"しくn 仕組"
"しくm 仕組"
"しきわm 爲極"
"しきりなおs 仕切り直"
"しきはm 爲極"
"しきt 仕切"
"しきr 仕切 頻"
"しからしm 然らし"
"しかたなk 仕方無"
"しかたなi 仕方無"
"しかしながr 乍"
"しかくi 四角"
"しかえs 仕返"
"しかt 叱"
"しかs 而 然 併"
"しかr 叱 然"
"しかn 爲兼"
"しかm 顰"
"しかk 仕掛"
"しおほs 爲果"
"しおづk 塩漬"
"しおくr 仕送 爲送"
"しおおs 爲果"
"しおr 萎"
"しおk 仕置 爲置"
"しいれr 仕入れ"
"しいたg 虐"
"しいs 弑"
"しいr 仕入"
"しあわs 幸 倖 仕合"
"しあがt 仕上が"
"しあいおw 試合終"
"しあu 為合 爲合"
"しあg 仕上"
"しt 知"
"しs 死 資 執 失 悉 齒"
"しr 知 調"
"しn 死 知"
"しm 占 締 閉 染 絞 〆 沁 閇 緊 浸 凍 滲"
"しk 敷 如 及 若"
"しi 強 敷 誣"
"しh 強 誣"
"ざいせきs 在籍"
"ざr 戯"
"さんびょうしそろt 三拍子揃"
"さんはいしこm 山廃仕込"
"さんせいいたs 賛成致"
"さんしょうくだs 参照下"
"さんしゅうくだs 参集下"
"さんかてつづk 参加手続"
"さんかくだs 参加下"
"さんかいたs 参加致"
"さんs 産"
"さんj 参"
"さわぎだs 騒ぎ出"
"さわy 爽"
"さわt 触 障 觸"
"さわr 触 障 觸"
"さわi 騒 騷"
"さわg 騒 騷"
"さらあらi 皿洗"
"さらu 濬 復習 攫 浚 渫"
"さらs 晒 曝"
"さらn 更"
"さらk 曝"
"さらh 浚 復習 渫"
"さらe 渫 浚"
"さめr 寤"
"さむs 寒"
"さむk 寒"
"さむi 寒"
"さむg 寒"
"さみs 淋 寂"
"さまよu 彷 さ迷"
"さまたg 妨 防 碍"
"さまざまn 様々"
"さまがw 様変"
"さまs 冷 醒 覺す"
"さぼt サボ"
"さぶらu 候"
"さびs 寂 淋 寞 寥"
"さびr 寂"
"さばk 捌 裁"
"さばi 裁"
"さとがえr 里帰"
"さとうづk 砂糖漬"
"さとt 悟"
"さとs 悟 説 諭 訓"
"さとr 悟"
"さとi 慧"
"さっちs 察知"
"さっそくためs 早速試"
"さっs 察"
"さだm 定"
"さだk 定"
"さそいこn 誘い込"
"さそいこm 誘い込"
"さそw 誘"
"さそu 誘 哘"
"さそt 誘"
"さそo 誘"
"さそi 誘"
"さそe 誘"
"さずk 授"
"さすらu 流離"
"さしもどs 差し戻"
"さしむk 差し向"
"さしまわs 差し回"
"さしひかe 差し控 差控"
"さしひk 差し引"
"さしひi 差し引"
"さしはさn 差し挟"
"さしはさm 差し挟"
"さしのぼt 差し上 差し昇"
"さしのぼr 差し上 差し昇"
"さしのb 差し延"
"さしぬi 刺し縫"
"さしとおs 刺し通"
"さしとm 差し止"
"さしでg 差し出"
"さしづm 差し詰"
"さしつかw 差し遣"
"さしつかe 差し支 差支"
"さしちがe 差し違 刺し違"
"さしだs 差出 指し出 差し出"
"さしたt 差し立"
"さしせまt 差し迫"
"さしせまr 差し迫"
"さしずm 差し詰"
"さししめs 指し示"
"さしさわt 差し障"
"さしさわr 差障 差し障"
"さしころs 刺し殺"
"さしこn 差し込 射し込"
"さしこm 差し込 射し込"
"さしかw 差し交"
"さしかk 差し掛"
"さしかe 差し替 挿し替"
"さしおs 差し押"
"さしおk 差し置"
"さしおi 差し置"
"さしいそg 差し急"
"さしいr 差し入 挿し入"
"さしあw 差し合"
"さしあt 差し当"
"さしあg 差し上"
"ささやk 囁"
"ささy 細"
"ささg 捧"
"ささe 支"
"さげすm 蔑 貶"
"さけずk 酒好"
"さけn 叫"
"さけb 叫"
"さぐりあi 探り合"
"さぐt 探"
"さぐr 探"
"さくづk 作付"
"さくせいてつづk 作成手続"
"さくせいいたs 作成致"
"さきよm 先読"
"さきものがi 先物買"
"さきまわr 先回"
"さきばらi 先払"
"さきばしr 先走"
"さきのb 先延"
"さきどr 先取"
"さきだt 先立"
"さきだc 先立"
"さきがk 先駆"
"さきおくr 先送"
"さきうt 先打"
"さきn 先"
"さきg 先"
"さがしまわr 探し回"
"さがしだs 探し出"
"さがt 下"
"さがs 探 捜 搜"
"さがr 下"
"さかもr 酒盛"
"さかまk 逆巻"
"さかのぼt 遡"
"さかのぼr 遡 逆昇 逆のぼ 泝 溯"
"さかなy 魚"
"さかだt 逆立"
"さかs 逆 賢"
"さかr 逆 盛"
"さかn 盛"
"さかe 栄 盛 榮"
"さえわたr さえ渡 冴え渡"
"さえずr 哢 囀"
"さえぎt 遮"
"さえぎr 峺 遮"
"さいわi 幸"
"さいはt 最果"
"さいなm 呵 嘖"
"さいこうn 最高"
"さいげんs 再現"
"さいきんいそがs 最近忙"
"さいs 際"
"さいn 際"
"さt 去"
"さs 差 指 刺 察 射 剌 溂 螫 鎖 挿 注 点 捺 插"
"さr 去 然"
"さm 覚 醒 冷 覺 褪"
"さk 避 咲 裂 割"
"さi 咲 裂 割 削"
"さg 下 差 提"
"さe 冴 冱"
"さb 錆 荒 寂"
"ごろうz 御覧"
"ごろうj 御覧"
"ごろn 頃"
"ごれんらくねがu 御連絡願"
"ごれんらくねがi 御連絡願"
"ごれんらくいただk 御連絡戴 御連絡頂"
"ごれんらくいただi 御連絡戴 御連絡頂"
"ごりようくだs 御利用下 ご利用下"
"ごりかいくだs 御理解下"
"ごりかいいただk 御理解頂"
"ごりおs ゴリ押"
"ごらんくだs 御覧下"
"ごようしゃくだs 御容赦下"
"ごまかs 胡麻化 誤魔化"
"ごのm 好"
"ごとうひょうくだs 御投票下"
"ごとs 若 如"
"ごとn 毎"
"ごとk 如"
"ごちゅういくだs 御注意下"
"ごぞんz 御存"
"ごぞんj 御存"
"ごしようくだs 御使用下"
"ごしどうねがi 御指導願"
"ごしどうくだs 御指導下"
"ごしてきくだs 御指摘下"
"ござi 御座"
"ごさんしょうくだs 御参照下"
"ごさんかくだs 御参加下"
"ごきょうりょくくだs 御協力下"
"ごきょうじゅねがi 御教授願"
"ごきょうじゅくだs 御教授下"
"ごきょうじねがi 御教示願"
"ごきょうじくだs 御教示下"
"ごきょうじいただk 御教示頂"
"ごきょうじいただi 御教示頂"
"ごきたいくだs 御期待下"
"ごかつようくだs 御活用下"
"ごかくにんくだs 御確認下"
"ごえんりょくだs 御遠慮下"
"ごうじょっぱr 強情っ張"
"ごいっぽうねがu 御一報願"
"ごいっぽうねがi 御一報願"
"ごいっぽうくだs 御一報下"
"ごいちどくくだs 御一読下"
"ごあんないもうs 御案内申"
"ごあんしんくだs 御安心下"
"ごs 越 期 伍"
"ごk 極"
"こんぽんてきn 根本的"
"こんねんどかぎr 今年度限"
"こんにちh 今日"
"こんかいはじm 今回初"
"こわばr 強張"
"こわs 壊 怖 毀 壞"
"こわr 壊 毀 壞"
"こわk 恐 怖 小分"
"こわi 恐 怖 強"
"こわg 怖 恐"
"こわb 硬"
"ころしあi 殺し合"
"ころげこn 転げ込"
"ころげこm 転げ込"
"ころがりこn 転がり込"
"ころがりこm 転がり込"
"ころs 殺"
"ころn 転 轉"
"ころg 転 轉"
"ころb 転 轉"
"こりかたm 凝り固"
"こらe 怺 堪"
"こもt 籠"
"こもr 籠 隠 篭 子守"
"こみだs 小見出"
"こみいt 混み入"
"こまわr 小回"
"こまねk 拱"
"こまぎr 細切 小間切"
"こまt 困"
"こまr 困"
"こまn 困"
"こまk 細"
"こまi 細"
"こまc 困"
"こぼt 毀"
"こぼs 零 毀"
"こぼr 溢 零"
"こほr 凍 氷"
"こぶr 小降 小振"
"こばしr 小走"
"こばn 拒"
"こばm 拒"
"このn 好"
"このm 好"
"こどもむk 子供向"
"こどもづr 子供連"
"ことわt 断 斷"
"ことわr 断 斷"
"ことほg 言祝 寿"
"ことばどおr 言葉通"
"ことばづかi 言葉遣 言葉使"
"ことばあそb 言葉遊"
"ことなt 異"
"ことなr 異"
"こととh 言問"
"ことづt 言伝 言傳"
"ことづk 託 言付"
"ことたr 言葉足 事足"
"ことずk 託"
"ことごとk 尽 盡 悉"
"ことかk 事欠"
"ことw 断 斷"
"ことn 異 殊"
"こづかi 小遣"
"こづr 子連"
"こづk 小突"
"こづi 小突"
"こだわt 拘"
"こだわr 拘"
"こだかi 小高"
"こたh 堪 答 應"
"こたe 答 応 堪 應"
"こぞt 挙"
"こぞr 挙"
"こそだt 子育"
"こそg 刮"
"こすからi 狡辛"
"こすt 擦"
"こすr 擦 錯"
"こすi 狡"
"こじんてきn 個人的"
"こじs 誇示"
"こじr 抉 拗"
"こしらh 拵"
"こしらe 拵"
"こしづk 腰付"
"こしくだk 腰砕"
"こしかk 腰掛"
"こざかs 小賢"
"こごろs 子殺"
"こごr 凝"
"こごm 屈"
"こごe 凍"
"こころよk 快"
"こころよi 快"
"こころゆるs 心許"
"こころやさs 心優"
"こころもとなi 心許無"
"こころもc 心持"
"こころまt 心待"
"こころまc 心待"
"こころぼそk 心細"
"こころぼそi 心細"
"こころひk 心魅"
"こころのこr 心残"
"こころづよk 心強"
"こころづよi 心強"
"こころづかi 心遺 心使 心遣"
"こころざs 志"
"こころぐるs 心苦"
"こころがまe 心構"
"こころがk 心掛"
"こころおだy 心穏"
"こころあたたm 心温"
"こころあたr 心辺"
"こころあt 心当"
"こころm 試"
"こころh 心"
"こころg 心"
"ここのt 九"
"ここちよs 心地良"
"ここちよk 心地良"
"ここちよi 心地良 心地好"
"ここn 個々"
"こきょうさがs 故郷探"
"こきみよi 小気味良"
"こきざm 小刻"
"こきおr 扱き下"
"こがらs 木枯"
"こがs 焦"
"こがr 焦"
"こかs 転 倒"
"こおりつi 凍り付"
"こおりけずr 氷削"
"こおt 凍"
"こおr 凍 氷"
"こえだs 声出"
"こえかk 声掛"
"こえt 超"
"こうりょs 考慮"
"こうむt 蒙 被"
"こうむr 被 蒙"
"こうべそだc 神戸育"
"こうべうm 神戸生"
"こうねんはなr 光年離"
"こうにゅういたs 購入致"
"こうだいn 広大"
"こうそくなr 高速慣"
"こうそくn 高速"
"こうせいn 公正"
"こうごうs 神々"
"こうきゅうとr 高給取"
"こうz 高 構 嵩 考"
"こうj 講 高 効 構 效 嵩"
"こいねがはk 希"
"こいs 恋 戀"
"こz 来"
"こy 来 來 徠 肥"
"こw 請"
"こu 乞 請 買 斯 戀"
"こt 凝"
"こs 越 漉 濃 濾 鼓 超"
"こr 来 凝 懲 來 徠 樵 此"
"こn 込 来 混 此 來 徠 捏"
"こm 込 混 籠 篭"
"こk 濃 扱 痩 放"
"こi 濃 来 漕 來 徠 乞 請"
"こh 乞 請 戀"
"こg 焦 漕 扱"
"こe 越 超 肥 踰"
"こd 子 小"
"こb 媚"
"げんつk 原付"
"げんだいかなづかi 現代仮名遣"
"げんさくどおr 原作通"
"げんz 減"
"げんs 減"
"げんn 現"
"げんj 減"
"げぎらi 毛嫌"
"げきs 激"
"げs 解 觧"
"けんとうちがi 見当違"
"けんとうs 検討"
"けんしょうずm 検証済"
"けんいづk 権威付"
"けんz 献"
"けわu 化粧"
"けわs 険 峻 險"
"けりとb 蹴飛"
"けむt 煙"
"けむr 煙 烟"
"けみs 閲"
"けぶかk 毛深"
"けぶかi 毛深"
"けぶr 煙 烟"
"けぶi 煙"
"けはh 化粧"
"けなs 貶"
"けどr 気取"
"けとb 蹴飛"
"けづr 削 梳"
"けっていてきn 決定的"
"けっていづk 決定付"
"けっていいたs 決定致"
"けっていs 決定"
"けっこうおおk 結構大"
"けっs 決"
"けちr 蹴散"
"けだるi 気怠"
"けだかk 気高"
"けだかi 気高"
"けたちがi 桁違"
"けたちがh 桁違"
"けずt 削"
"けずr 削 梳"
"けしかr 怪しか"
"けしかk 嗾"
"けがs 汚 涜 穢"
"けがr 汚 穢"
"けおs 気圧"
"けいこくs 警告"
"けいけんゆたk 経験豊"
"けいきづk 景気付"
"けいかいn 軽快"
"けいえいs 経営"
"けあg 蹴上"
"けt 蹴"
"けs 消 決"
"けr 蹴"
"ぐるs 苦"
"ぐちr 愚痴"
"ぐずr 愚図"
"ぐさr 腐"
"ぐあi 具合"
"ぐm 組"
"ぐi 食"
"くんよm 訓読"
"くんづk 君付"
"くわだt 企"
"くわw 加"
"くわs 詳 加"
"くわk 区分"
"くわe 加 咥 銜"
"くろすg 黒過"
"くろk 黒"
"くろi 黒 梍 玄"
"くれなずm 暮れ泥"
"くるめk 眩"
"くるしまぎr 苦し紛"
"くるw 狂"
"くるu 狂"
"くるt 狂"
"くるs 苦"
"くるm 包"
"くるi 狂"
"くるh 狂"
"くりひろg 繰り広"
"くりのb 繰延"
"くりだs 繰り出"
"くりこs 繰り越"
"くりこn 繰り込"
"くりこm 繰り込"
"くりかえs 繰り返 繰返"
"くりあw 繰り合"
"くりあg 繰上 繰り上"
"くらすg 暗過"
"くらいどr 位取"
"くらいづk 位付"
"くらいつk 食らい付"
"くらいつi 食らい付"
"くらいこn 食らい込"
"くらいこm 食らい込"
"くらいs 位"
"くらu 喰ら"
"くらt 食"
"くらs 暮 暗"
"くらm 晦 眩 暗"
"くらk 暗"
"くらi 暗 位 暝 眛 昏 冥"
"くらe 喰ら"
"くらb 比 較 競"
"くゆr 燻"
"くやs 悔 口惜"
"くやm 悔"
"くもゆk 雲行"
"くもt 曇"
"くもr 曇"
"くみとr 汲み取"
"くみたてr 組み立て"
"くみたt 組み立 組立"
"くみこn 組み込"
"くみこm 組込 組み込"
"くみかw 酌み交"
"くみかe 組替"
"くみあわs 組合 組み合わ 組み合"
"くみあw 組み合 組合"
"くみs 与 與"
"くぼn 窪"
"くぼm 窪 凹"
"くびがたm 首固"
"くびr 縊 括"
"くばt 配"
"くばr 配"
"くはh 加 銜"
"くどk 口説"
"くどi 口説 諄"
"くづほr 頽"
"くづs 崩"
"くつろg 寛"
"くつがへs 覆"
"くつがへr 覆"
"くつがえs 覆"
"くつがえr 覆"
"くっt 食"
"くっs 屈"
"くちをs 口惜"
"くちばしt 口走"
"くちばしr 口走"
"くちどr 口取"
"くちだs 口出"
"くちずさm 口遊"
"くちごm 口籠"
"くちぎたなi 口穢"
"くちおs 口惜"
"くちあt 口当"
"くだt 下"
"くだs 下 降"
"くだr 下 降"
"くだk 砕 碎"
"くだi 砕"
"くずおr 頽"
"くずs 崩"
"くずr 崩"
"くすりづk 薬漬"
"くすぶr 燻ぶ 燻"
"くすぐt 擽"
"くすぐr 擽"
"くすg 擽"
"くじk 挫"
"くしざs 串刺"
"くしけづr 梳"
"くしけずr 梳"
"くさふかk 草深"
"くさふかi 草深"
"くさかr 草刈"
"くさt 腐"
"くさs 臭"
"くさr 腐 鏈"
"くさk 臭"
"くさi 臭"
"くぐt 潜"
"くぐr 潛 潜"
"くくt 括"
"くくr 括"
"くぎづk 釘付"
"くぎt 区切"
"くぎr 区切"
"くうきいr 空気入"
"くいちがu 食い違"
"くいちがt 食い違"
"くいちがi 喰い違 食い違"
"くいちr 食い散"
"くいたr 食い足"
"くいこn 食い込 喰い込"
"くいこm 喰い込 食い込"
"くいあらたm 悔い改"
"くいあr 食い荒"
"くy 悔"
"くw 食 喰"
"くu 食 喰"
"くt 食 喰 朽"
"くs 屈"
"くr 来 繰 暮 食 喰 呉 來 徠 眩"
"くo 食"
"くn 組 苦 汲"
"くm 組 汲 酌"
"くi 食 悔 喰"
"くh 食"
"くg 絎"
"くe 喰 食"
"くc 朽 喰"
"ぎんz 吟"
"ぎろんずk 議論好"
"ぎらi 嫌"
"ぎょうぎょうs 仰々 仰仰"
"ぎゅうじr 牛耳"
"ぎゃっこうs 逆行"
"ぎゃくもどr 逆戻"
"ぎゃくむk 逆向"
"ぎゃくまわr 逆回"
"ぎゃくびk 逆引"
"ぎゃくじょうs 逆上"
"ぎゃくじゅうじがたm 逆十字固"
"ぎゃくn 逆"
"ぎむづk 義務付"
"ぎs 擬"
"ぎr 切"
"きんちょうs 緊張"
"きんz 禁"
"きんj 禁"
"きをつk 気を付"
"きわどi 際疾"
"きわだt 極立 際立"
"きわm 極 究"
"きわd 際"
"きれこn 切れ込"
"きれこm 切れ込"
"きりんかんどおr 希林館通"
"きりわk 切り分"
"きりひらk 切開"
"きりはなs 切離 切り離"
"きりはr 切り貼"
"きりぬk 切り抜"
"きりぬi 切り抜"
"きりなおs 切り直"
"きりどおs 切り通"
"きりとおs 切り通"
"きりとt 切り取"
"きりとr 切取 切り取"
"きりづk 切り漬"
"きりつm 切り詰"
"きりだs 切り出"
"きりすt 切り捨 切捨"
"きりさk 切り裂 斬り裂"
"きりかえs 切り返"
"きりかえr 切り換え"
"きりかw 切り替 切替"
"きりかe 切り替 切り換 切替 切換"
"きりおとs 切り落"
"きりうr 切り売"
"きりあg 切り上"
"きらめk 煌"
"きらw 嫌"
"きらu 嫌"
"きらt 嫌"
"きらm 煌"
"きらi 嫌"
"きらh 嫌"
"きらb 燦"
"きよらかn 清らか"
"きよs 清"
"きよr 清"
"きよm 浄 清"
"きよk 清"
"きよi 清"
"きょくりょくさk 極力避"
"きょうりょくたまわr 協力賜"
"きょうりょくくだs 協力下"
"きょうみぶかk 興味深"
"きょうみぶかi 興味深"
"きょうだいn 強大"
"きょうじゅくだs 教授下"
"きょうじくだs 教示下"
"きょうかしょどおr 教科書通"
"きょうs 供"
"きょうj 興"
"きょうh 今日"
"きゅうしょげr 急所蹴"
"きゅうしゅうs 吸収"
"きゅうs 窮"
"きゅうn 急"
"きやすm 気休"
"きやすk 気安"
"きやすi 気安"
"きゃくあつかi 客扱"
"きもちわるs 気持ち悪"
"きもちわるi 気持ち悪 気持悪"
"きもちよi 気持ち良"
"きもだめs 肝試"
"きもいr 肝煎"
"きもt 気持"
"きもc 気持"
"きめつk 決め付"
"きめこn 決め込"
"きめこm 木目込 決め込"
"きむづかs 気難"
"きむずかs 気難"
"きみわるi 気味悪"
"きまぐr 気紛"
"きまt 決"
"きまr 極 決"
"きぼういたs 希望致"
"きぶくr 着脹"
"きふよm 棋譜読"
"きびs 厳 嚴"
"きばr 気張 気晴"
"きはどi 際疾"
"きはz 気恥"
"きはm 窮"
"きのうs 機能"
"きのr 気乗"
"きにいt 気に入"
"きにいr 気に入"
"きなr 着慣"
"きどおs 着通"
"きどうs 起動"
"きどt 気取"
"きどr 気取"
"きていどおr 規定通"
"きづかu 気遣"
"きづかi 気遣"
"きづk 気付 築 気附"
"きづi 気付 築"
"きつk 気付"
"きっs 喫"
"きちがi 気違"
"きたなs 汚"
"きたなk 汚"
"きたなi 汚 穢"
"きたいどおr 期待通"
"きたいくだs 期待下"
"きたいs 期待"
"きたs 来 來"
"きたr 来 來"
"きたn 汚"
"きたe 鍛"
"きそづk 基礎付"
"きそくただs 規則正"
"きそいあu 競い合"
"きそw 競"
"きそu 競 竸"
"きそt 競"
"きそo 競"
"きそi 競"
"きそh 競"
"きそe 競"
"きずつk 傷付"
"きずt 傷"
"きずk 気付 築"
"きずi 築"
"きじよm 記事読"
"きしょくわるk 気色悪"
"きしょくわるi 気色悪"
"きしょうむずかs 気性難"
"きしちかk 岸近"
"きしr 軋 轢"
"きしn 軋"
"きしm 軋"
"きざs 兆"
"きざn 刻"
"きざm 刻"
"きさいs 記載"
"きこn 着込"
"きこm 着込"
"きけんn 危険"
"きくばr 気配"
"ききわk 聞き分"
"ききよi 聴き良"
"ききやすi 聞き易"
"ききのg 聞き逃"
"ききにくi 聞き難"
"ききとおs 聞き通"
"ききとt 聞き取"
"ききとr 聞き取"
"ききだs 聞き出 効き出"
"ききこn 聞き込"
"ききこm 聞き込"
"ききぐるs 聞き苦"
"ききおぼe 聞き覚"
"ききいt 聞き入 聴き入"
"ききいr 聞き入"
"きがまe 気構"
"きがつk 気が附 気が付"
"きがつi 気が付 気が附"
"きがかr 気掛"
"きがn 気兼"
"きがe 着替"
"きかざt 着飾"
"きかざr 着飾"
"きかe 着換"
"きおくちがi 記憶違"
"きおくr 気遅"
"きおw 気負"
"きおu 気負"
"きえさt 消え去"
"きえさr 消え去"
"きいろk 黄色"
"きいろi 黄色"
"きあいはいr 気合入"
"きあいいr 気合入"
"きあi 気合"
"きz 着 気 氣"
"きy 消"
"きw 気 氣"
"きt 来 切 着 斬 來 徠 著"
"きs 来 記 着 期 帰 來 徠 歸 皈"
"きr 切 着 斬 鑽 著"
"きn 気 来 着 機 氣 著"
"きm 決 来 気 來 决 徠 氣 窮 極 着"
"きk 聞 効 聴 訊 利 尋 着 切 效 聽"
"きi 聞 効 聴 尋 訊 效 聽 利"
"きh 気 氣"
"きg 気 氣"
"きe 消"
"きd 気 氣"
"きc 切 来"
"がんばっt 頑張"
"がんばt 頑張"
"がんばr 頑張"
"がらi 辛"
"がまんできn 我慢出来"
"がまんづよk 我慢強"
"がまんづよi 我慢強"
"がとu 難"
"がっしょうづくr 合掌造"
"がっこうがえr 学校帰"
"がっきつなg 楽器繋"
"がたs 難"
"がたk 難"
"がたi 難"
"がぞうとr 画像取"
"がさn 重"
"がけくずr 崖崩"
"がかr 係"
"がえんj 肯"
"がえs 返"
"がえr 帰 歸 皈"
"がえn 肯"
"がいじんえらb 外人選"
"がいs 害 概"
"がw 代"
"がt 勝"
"がr 刈"
"がk 書"
"がi 買"
"がe 替 換"
"かんれんづk 関連付"
"かんれんz 関連"
"かんれんs 関連"
"かんれんd 関連"
"かんりょういたs 完了致"
"かんべんねがu 勘弁願"
"かんべんねがi 勘弁願"
"かんばt 頑張"
"かんばs 芳"
"かんねんs 観念"
"かんとくはじm 監督始"
"かんづm 缶詰"
"かんちがi 勘違 感違"
"かんだかk 甲高"
"かんだかi 甲高 疳高"
"かんたんすg 簡単過"
"かんせいs 完成"
"かんすうよb 関数呼"
"かんじょうてきすg 感情的過"
"かんじまz 漢字混"
"かんじとr 感じ取"
"かんしゃいたs 感謝致"
"かんしゃs 感謝"
"かんしちどおr 環七通"
"かんげいいたs 歓迎致"
"かんけいs 関係"
"かんぐt 勘繰"
"かんぐr 勘繰"
"かんきわm 感極"
"かんがみr 鑑み"
"かんがえだs 考え出"
"かんがえすg 考え過"
"かんがえこn 考え込"
"かんがえこm 考え込"
"かんがえあw 考え合"
"かんがm 鑑 鑒"
"かんがh 考"
"かんがe 考 攷"
"かんいr 缶入"
"かんz 感"
"かんs 関 冠 關"
"かんj 感"
"かんg 勘"
"かんd 勘"
"かわばたどおr 川端通"
"かわぞi 川沿"
"かわくだr 川下"
"かわきr 皮切"
"かわいs 可愛 可哀"
"かわいr 可愛"
"かわいk 可愛"
"かわいi 可愛"
"かわいg 可愛"
"かわt 変 變"
"かわs 交 躱"
"かわr 代 変 換 替 變"
"かわk 乾 喝 渇"
"かわi 可愛 乾 喝"
"かろy 輕"
"かろu 辛"
"かろn 軽"
"かれんn 可憐"
"かれr 彼 涸"
"かれh 彼"
"かるがるs 軽々"
"かるいざわおよb 軽井沢及"
"かるs 軽 輕"
"かるk 軽 輕"
"かるi 軽 輕"
"かりとt 刈り取"
"かりとr 刈取 刈り取"
"かりだs 狩り出 借り出 駆り出"
"かりたt 駆り立"
"かりずm 借り住 仮住"
"かりこn 狩り込 刈り込"
"かりこm 狩り込 刈り込"
"かりきt 借り切"
"かりきr 借り切"
"かりうk 借り受"
"かりいr 借り入 刈り入"
"かりあつm 駆り集"
"かりあg 借り上 刈り上"
"かりn 仮"
"からまわr 空回"
"からs 辛"
"からn 絡"
"からm 絡 辛 搦"
"からk 辛"
"からi 辛 鹹"
"からg 絡 紮"
"かよw 通"
"かよu 通"
"かよt 通"
"かよo 通"
"かよi 通"
"かよe 通"
"かゆs 痒"
"かゆm 痒"
"かゆk 痒"
"かゆi 痒 癢"
"かゆg 痒"
"かもs 醸 釀"
"かむr 被"
"かみあt 噛み合"
"かまびすs 喧"
"かまw 構"
"かまu 構"
"かまt 構"
"かまi 構"
"かまh 構"
"かまe 構"
"かへr 歸 皈"
"かぶt 被"
"かぶs 被"
"かぶr 被"
"かばu 庇"
"かはs 交"
"かのうn 可能"
"かねもうk 金儲"
"かねもt 金持"
"かねもc 金持"
"かねばらi 金払"
"かねづかi 金遣"
"かねそなe 兼ね備"
"かねあi 兼ね合 兼合"
"かねt 予"
"かねr 兼"
"かならz 必"
"かなづかi 仮名遣"
"かなしばr 金縛"
"かなぎr 金切"
"かなきr 金切"
"かなw 叶 敵 適"
"かなu 叶 敵 適"
"かなt 叶 適"
"かなs 悲 哀 愛"
"かなe 叶"
"かなd 奏"
"かていs 仮定"
"かつt 嘗"
"かつi 担"
"かつg 担 擔"
"かつe 餓"
"かっこうよk 格好良"
"かちこs 勝ち越"
"かたわr 傍"
"かたりあk 語り明"
"かたよt 偏"
"かたよr 偏 片寄"
"かたむk 傾"
"かたむi 傾"
"かたべr 片減"
"かたどおr 型通"
"かたどt 象"
"かたどr 象 模"
"かたづくr 形作"
"かたづk 片付 型付"
"かたづi 片付"
"かたつk 型付"
"かたたたk 肩叩"
"かたすg 硬過"
"かたじけなi 忝 辱"
"かたこr 肩凝"
"かたくるs 堅苦"
"かたがw 肩代"
"かたかk 肩掛"
"かたおもi 片想 片思"
"かたえびがたm 片海老固"
"かたいr 肩入"
"かたt 語"
"かたs 固 堅 難 硬"
"かたr 語 騙"
"かたm 固 傾 硬"
"かたk 固 堅 難 硬"
"かたi 固 難 堅 硬"
"かたd 片"
"かぞくづr 家族連"
"かぞえいr 数え入"
"かぞえあg 数え上"
"かぞe 数 數"
"かぜとおs 風通"
"かぜあt 風当"
"かせi 稼"
"かせg 稼"
"かずすくn 数少"
"かずしr 数知"
"かずかぎりなk 数限り無"
"かずおおk 数多"
"かずおおi 数多"
"かずあt 数当"
"かずk 被"
"かすがどおr 春日通"
"かすt 掠"
"かすr 擦 掠"
"かすn 霞"
"かすm 霞 掠"
"かすk 微 幽"
"かじょうがk 箇条書"
"かじt 齧 噛"
"かじr 噛 囓 齧"
"かしまs 姦"
"かしづk 傳"
"かしつk 貸し付"
"かしだs 貸し出 貸出"
"かしずk 侍"
"かしこs 賢"
"かしこm 畏"
"かしこk 賢"
"かしこi 賢"
"かしきt 貸し切"
"かしきr 貸し切"
"かしかr 貸し借"
"かしi 傾"
"かしg 傾"
"かざりたt 飾り立"
"かざt 飾 餝"
"かざs 翳"
"かざr 飾 錺 餝"
"かさねあw 重ね合"
"かさなりあt 重なり合"
"かさなt 重な"
"かさn 重"
"かさm 嵩"
"かこつk 託"
"かこくn 苛酷"
"かこいこn 囲い込"
"かこいこm 囲い込"
"かこw 囲"
"かこu 囲 圍"
"かこt 喞 囲"
"かこn 囲 圍"
"かこm 囲 圍"
"かこi 囲"
"かこe 囲 圍"
"かげきすg 過激過"
"かげr 翳 陰"
"かけめぐt 駆け巡"
"かけまわr 駆け回"
"かけひk 駆引"
"かけどおs 駆け通"
"かけつけt 駆け付け"
"かけだs 駆けだ"
"かけこn 駆け込"
"かけこm 駆け込"
"かけr 翔"
"かぐわs 馨 香"
"かくのごとk 斯くの如"
"かくにんねがi 確認願"
"かくにんくだs 確認下"
"かくにんおよb 確認及"
"かくにんs 確認"
"かくていs 確定"
"かくづk 格付"
"かくちょうたかk 格調高"
"かくちょうたかi 格調高"
"かくs 隠 隱 匿 画"
"かくr 隠 隱"
"かぎt 限"
"かぎr 限"
"かきわすr 書き忘"
"かきわk かき分 掻き分 書き分"
"かきよごs 書き汚"
"かきやすk 書き易"
"かきやすi 書き易"
"かきもどs 書き戻 書戻"
"かきもうs 下記申"
"かきもr 書き漏"
"かきまz かき混 掻き混"
"かきはじm 書き始"
"かきのこs 書き残"
"かきぬk 書き抜"
"かきぬi 書き抜"
"かきならb 書き並"
"かきなおs 書き直"
"かきなr かき鳴 掻き鳴"
"かきとどm 書き留"
"かきとt 書き取"
"かきとr 書き取"
"かきとb 書き飛"
"かきつらn 書き連"
"かきつづt 書き綴"
"かきつづr 書き綴"
"かきつづk 書き続"
"かきつたe 書き伝"
"かきつくs 書き尽"
"かきつk 書き尽 書き付"
"かきちr 書き散"
"かきだs 書き出 書出 かき出 掻き出"
"かきたt 書き立"
"かきたs 書き足"
"かきぞm 書き初"
"かきそんz 書き損"
"かきそんj 書き損"
"かきそこn 書き損"
"かきそe 書き添"
"かきすt 書き捨 かき捨 掻き捨"
"かきしるs 書き記"
"かきこn 書き込 書込"
"かきこm 書き込 書込"
"かきけs かき消 掻き消"
"かきくわe 書き加"
"かきくだs 書き下"
"かきくずs 書き崩"
"かきかえr 書き換え"
"かきかe 書換 書き換 書き替 書き変"
"かきおろs 書下 描き下ろ"
"かきおよn 書き及"
"かきおよb 書き及"
"かきおさm 書き納"
"かきおくt 書き送"
"かきおくr 書き送"
"かきおt 書き落"
"かきおr 書き下"
"かきおk 書き起 書き置"
"かきうつs 書き写"
"かきいr 書き入"
"かきあらわs 書き表"
"かきあらたm 書き改"
"かきあやまt 書き誤"
"かきあやまr 書き誤"
"かきあつm かき集 掻き集"
"かきあg 書き上"
"かがやk 輝 耀"
"かがやi 輝"
"かがn 屈"
"かがm 屈"
"かかわt 拘"
"かかわr 拘 関 係"
"かかりつk 掛かり付"
"かかりすg 掛り過"
"かかえこn 抱え込"
"かかえこm 抱え込"
"かかw 関 係 關"
"かかt 掛 係"
"かかr 係 掛 罹"
"かかg 掲"
"かかe 抱"
"かおみしr 顔見知"
"かおまk 顔負"
"かおつk 顔付"
"かおだt 顔立"
"かおあわs 顔合"
"かおあw 顔合"
"かおt 薫"
"かおr 香 薫"
"かえりざk 返り咲"
"かえりm 省 顧"
"かえt 帰 返 変 却 卻 變 歸 皈"
"かえs 返 帰 還 孵 歸 皈"
"かえr 帰 返 換 替 歸 皈 還"
"かえn 帰"
"かえc 帰 歸 皈"
"かいまみy 垣間見"
"かいまみt 垣間見"
"かいまみr 垣間見"
"かいまみn 垣間見"
"かいまみm 垣間見"
"かいなおs 買い直"
"かいどくd 買い得"
"かいとういただk 回答頂"
"かいとういただi 回答頂"
"かいとt 買い取"
"かいとr 買取 買い取"
"かいだs 買い出"
"かいたs 買い足"
"かいせんたt 回線断"
"かいせつs 開設"
"かいせいてつづk 改姓手続"
"かいじょうえらb 会場選"
"かいしゃがえr 会社帰"
"かいしm 買占"
"かいさいいたs 開催致"
"かいこn 買い込"
"かいこm 買い込"
"かいぐi 買い食"
"かいがんまわr 海岸回"
"かいがんちかk 海岸近"
"かいがんちかi 海岸近"
"かいかe 買い換"
"かいt 解 觧"
"かいs 介 解 会 會 觧"
"かあs 母"
"かw 変 買 代 換 替 交 變 飼"
"かu 買 飼 交 書 支"
"かt 買 勝 掛 飼 且 駆 苅 刈 交 驅 克"
"かs 貸 課 化 加 科 淅"
"かr 借 苅 刈 枯 狩 仮 駆 嗄 涸 驅"
"かo 買 飼"
"かn 兼 噛 彼"
"かm 噛 咬 嚼"
"かk 書 掛 欠 描 駆 賭 掻 架 画 駈 懸 買 畫 缺 翔 驅 繋 斯 闕 舁"
"かi 書 買 描 飼 画 欠 掻 畫 缺 交 嗅"
"かh 替 換 交 支 飼 代 買 變"
"かg 嗅"
"かe 変 換 替 買 代 帰 飼 變 歸 皈 易"
"かc 勝 買"
"おんよm 音読"
"おんなだいすk 女大好"
"おんがえs 恩返"
"おわたs お渡"
"おわすr お忘"
"おわかr お別"
"おわかi お若"
"おわt 終"
"おわs 御座 在"
"おわr 終"
"おろそk 疎"
"おろs 卸 下"
"おろk 愚"
"おれまがr 折れ曲"
"おれいもうs 御礼申"
"おりまg 折り曲"
"おりなs 織り成"
"おりたたn 折畳"
"おりたたm 折畳 折り畳"
"おりこn 折り込 織り込"
"おりこm 折込 織込 折り込 織り込"
"おりかえs 折り返 折返"
"おりs 折"
"およろこb お慶"
"およぎこn 泳ぎ込"
"およぎこm 泳ぎ込"
"およn 及"
"およm 御読"
"およi 泳"
"およg 泳 游"
"およb 及"
"おやすm お休"
"おもんばかr 慮"
"おもむk 赴 趣"
"おもむi 赴"
"おもみづk 重み付"
"おもはy 面映"
"おもねr 阿"
"おもてむk 表向"
"おもてどおr 表通"
"おもてだt 表立"
"おもすぎr 重過ぎ"
"おもすg 重過"
"おもしろu 面白"
"おもしろs 面白"
"おもしろk 面白"
"おもしろi 面白"
"おもしろg 面白"
"おもぐるs 重苦"
"おもくるs 重苦"
"おもおもs 重々"
"おもいつk 思い付"
"おもいつi 思い付"
"おもいだs 思い出"
"おもいたt 思い立"
"おもいしr 思い知"
"おもいこn 思い込"
"おもいこm 思い込"
"おもいきt 思い切"
"おもいきr 思い切"
"おもいおk 思い起"
"おもいうk 思い浮"
"おもいあg 思い上"
"おもw 思"
"おもu 思 想"
"おもt 思 重"
"おもs 重"
"おもr 重"
"おもo 思"
"おもn 主 重"
"おもm 重"
"おもk 重"
"おもi 思 重 想"
"おもh 思 想"
"おもe 思 想"
"おもc 御持 思 お持"
"おめn 御目"
"おまt お待"
"おぼしめs 思召"
"おぼえなおs 覚え直"
"おぼえこn 覚え込"
"おぼえこm 覚え込"
"おぼw 憶"
"おぼt 覚"
"おぼs 覚 思"
"おぼr 溺"
"おぼe 覚 憶 覺"
"おほh 被 覆"
"おぶu 負"
"おびやk 脅"
"おびただs 夥"
"おびe 怯 脅"
"おひとよs 御人好"
"おひさs 御久 お久"
"おののk 戦"
"おのずかr 自"
"おのずt 自"
"おのずk 自"
"おのz 自"
"おのr 己"
"おねがi お願 御願"
"おなz 同"
"おなj 同"
"おどろk 驚"
"おどろi 驚"
"おどりこn 踊り込"
"おどりこm 踊り込"
"おどりあk 踊り明"
"おどt 踊 踴"
"おどs 脅 縅"
"おどr 踊 躍 踴"
"おどk 脅"
"おとろe 衰"
"おとなu 訪"
"おとなs 大人"
"おとどk 御届"
"おとだs 音出"
"おとずr 訪"
"おとしいr 陥 陷"
"おとしm 貶"
"おとぎr 音切"
"おとz 訪"
"おとt 劣"
"おとs 落"
"おとr 劣"
"おてあg お手上"
"おつかr お疲"
"おつかi お使"
"おっしゃr 仰"
"おっしゃi 仰"
"おちつk 落着 落ち着"
"おちつi 落ち着 落着"
"おちこn 落ち込"
"おちこm 落ち込"
"おちいt 陥"
"おちいr 陥 陷"
"おちあu 落ち合"
"おちあt 落ち合"
"おちあo 落ち合"
"おちr 落 堕ち 墜ち 落ち"
"おちi 陥"
"おだやk 穏"
"おだy 穏 穩"
"おだt 煽"
"おたずn お尋"
"おたけb 雄叫"
"おたがi 御互 お互"
"おぞまs 悍ま"
"おそろs 恐"
"おそれいr 恐れ入"
"おそれr 怐"
"おそw 教 襲"
"おそu 襲"
"おそt 襲"
"おそs 遅 遲"
"おそr 恐 畏 怖 臆 憶 惧 虞"
"おそm 遅"
"おそk 遅 遲"
"おそi 遅 襲 遲"
"おそh 襲"
"おしよs 押し寄"
"おしとおs 押し通"
"おしつk 押し付"
"おしだs 押し出"
"おしたおs 押し倒"
"おしすすm 推し進"
"おしこn 押し込"
"おしこm 押し込"
"おしえこn 教え込"
"おしえこm 教え込"
"おしうr 押し売"
"おしあk 押し開"
"おしr 御知 お知"
"おしe 教"
"おさなs 幼"
"おさなk 幼"
"おさなi 幼"
"おさっs 御察"
"おさえこn 押さえ込"
"おさえこm 押さえ込"
"おさm 収 治 納 修 收"
"おさe 抑 押 圧 壓"
"おごそk 厳 嚴"
"おごr 傲 奢 驕"
"おこのm お好"
"おこなw 行"
"おこなu 行"
"おこなt 行"
"おこなo 行"
"おこなi 行"
"おこなh 行"
"おこなe 行"
"おこたt 怠"
"おこたr 怠"
"おこがましk 烏滸がまし"
"おこがましi 烏滸がまし"
"おこt 怒 起"
"おこs 起 遣 起こ"
"おこr 怒 起 興"
"おこn 行 怒"
"おこc 怒"
"おくりとどk 送り届"
"おくりだs 送り出"
"おくりこm 送り込"
"おくりかえs 送り返"
"おくゆk 奥行"
"おくふかk 奥深"
"おくふかi 奥深"
"おくt 送 贈"
"おくs 臆"
"おくr 送 遅 贈 遲"
"おぎなw 補"
"おぎなu 補"
"おぎなt 補"
"おぎなo 補"
"おぎなi 補"
"おぎなe 補"
"おきわすr 置き忘"
"おきびk 置き引"
"おきぬk 起き抜"
"おきにいr お気に入"
"おきなおs 起き直"
"おきてやぶr 掟破"
"おきだs 起き出"
"おきたt 起き立"
"おきざr 置き去"
"おきがk 置き掛"
"おきかえt 置き換え"
"おきかえr 置き換え"
"おきかw 置き換 置き変"
"おきかe 置き換 置換"
"おきあg 起き上"
"おきk 御聞 お聞"
"おがn 拝"
"おがm 拝 拜"
"おかえr お帰"
"おかs 犯 可笑 冒 侵 奇"
"おおわらi 大笑"
"おおよろこb 大喜"
"おおよs 凡"
"おおもうk 大儲"
"おおむn 概"
"おおみだs 大見出"
"おおまわr 大回"
"おおまちがi 大間違"
"おおばんぶるまi 大判振る舞"
"おおどおr 大通"
"おおちがi 大違"
"おおすぎt 大過ぎ"
"おおすg 多過"
"おおしe 御教 お教"
"おおさわg 大騒"
"おおぐi 大食"
"おおくr 御送 お送"
"おおきすg 大き過"
"おおがk 大掛"
"おおうk 大受"
"おおいそがs 大忙"
"おおいそg 大急"
"おおあばr 大暴"
"おおあt 大当"
"おおz 大"
"おおw 覆"
"おおu 覆 奄 多 被 蔽"
"おおt 覆 被"
"おおs 多 仰 夛"
"おおr 大"
"おおm 多 大 夛"
"おおk 大 多 夛"
"おおj 応 應"
"おおi 多 大 覆 夛"
"おおh 被 覆"
"おおg 大"
"おうぼくだs 応募下"
"おうz 応 應"
"おうj 応 應"
"おいわi お祝"
"おいはらu 追い払"
"おいはらt 追い払"
"おいはらi 追い払"
"おいぬk 追い抜"
"おいぬi 追い抜"
"おいつm 追い詰"
"おいつk 追い付"
"おいつi 追い付"
"おいだs 追い出 追出"
"おいたt 生い立 追い立"
"おいしげt 生い茂"
"おいしげr 生い茂"
"おいこs 追い越"
"おいこn 追い込 老い込"
"おいこm 追い込 老い込"
"おいかk 追い掛"
"おいt 於"
"おいs 美味"
"おあi 御会"
"おz 怖"
"おw 終 追 負"
"おu 追 負"
"おt 落 追 折 負 堕 墜 墮 織 居"
"おs 押 推 惜 圧 壓"
"おr 降 折 居 下 織"
"おp 追"
"おo 追"
"おm 追"
"おk 起 置 於 追 落 惜 怒 擱"
"おj 怖"
"おi 置 追 負 於 老 生"
"おh 負 追"
"おe 終 負 追"
"おd 怖"
"おc 落"
"おb 帯 帶"
"えんりょねがいi 遠慮願"
"えんりょくだs 遠慮下"
"えんむすb 縁結"
"えんばらi 円払"
"えんどおk 縁遠"
"えんきr 縁切"
"えんz 演"
"えんj 演"
"えらびだs 選び出"
"えらs 偉"
"えらn 選"
"えらk 偉"
"えらi 偉"
"えらb 選"
"えびがたm 海老固"
"えづk 餌付"
"えつk 絵付"
"えだわかr 枝分"
"えだわk 枝分"
"えだがr 枝刈"
"えだかr 枝刈"
"えぐt 抉"
"えぐr 刔 抉"
"えがたi 得難"
"えがk 描"
"えがi 描"
"えかk 絵描"
"えいきょうあたe 影響与"
"えいz 映"
"えz 得"
"えy 得"
"えt 得"
"えs 得"
"えr 得 選 獲"
"えn 得"
"えm 得 笑"
"うんわるk 運悪"
"うんわるi 運悪"
"うわむk 上向"
"うわまわt 上回"
"うわまわr 上回"
"うわのs 上乗"
"うわづm 上積"
"うわさどおr 噂通"
"うわがk 上書"
"うわかk 上書"
"うわt 浮"
"うろおぼe 空覚"
"うれえr 慯"
"うれu 愁 憂"
"うれs 嬉"
"うれi 愁 憂"
"うれe 憂"
"うるわs 麗"
"うるさi 五月蝿 煩 騒"
"うるおu 潤"
"うるm 潤"
"うりとb 売り飛"
"うりだs 売り出"
"うりこn 売り込"
"うりこm 売り込"
"うりきr 売り切"
"うりあg 売上"
"うらやm 羨"
"うらなu 占 卜"
"うらなt 占"
"うらなi 占 卜"
"うらなg 裏投"
"うらなe 占"
"うらどおr 裏通"
"うらどr 裏取"
"うらづk 裏付"
"うらぎt 裏切"
"うらぎr 裏切"
"うらがえt 裏返"
"うらがえs 裏返"
"うらかえs 裏返"
"うらうc 裏打"
"うらn 恨"
"うらm 恨 怨"
"うらd 裏"
"うやまu 敬"
"うやうやs 恭"
"うめこn 埋め込"
"うめこm 埋め込 埋込"
"うめk 呻"
"うみだs 生み出"
"うみd 生み出"
"うまれつk 生まれ付"
"うまれつi 生まれ付"
"うまれかw 生まれ変"
"うまれおt 生まれ落"
"うまのr 馬乗"
"うまs 旨 巧"
"うまr 生"
"うまk 上手 旨 巧"
"うまi 旨 上手 巧 美味"
"うばいさr 奪い去"
"うばw 奪"
"うばu 奪"
"うばt 奪"
"うばo 奪"
"うばi 奪"
"うばe 奪"
"うのm う飲 鵜飲 鵜呑"
"うぬぼr 己惚 自惚"
"うなだr 項垂"
"うなずk 頷"
"うなずi 頷"
"うながs 促"
"うなt 唸"
"うなs 魘"
"うなr 唸"
"うとm 疎"
"うとk 疎 踈"
"うとi 疎 踈"
"うでがたm 腕固"
"うつむk 俯"
"うつぶs 俯"
"うつくs 美"
"うつt 移 写 映 遷 冩 寫 暎"
"うつs 移 写 映 冩 寫 暎"
"うつr 移 写 映 遷 伝染 冩 寫 暎 虚"
"うっとうs 欝陶 鬱陶"
"うったe 訴"
"うちよs 打ち寄"
"うちやぶt 打ち破 討ち破"
"うちやぶr 打ち破 討ち破"
"うちほろb 討ち滅"
"うちはらu 打ち払"
"うちはらt 打ち払"
"うちはなs 打ち放"
"うちぬk 打ち抜"
"うちぬi 打ち抜"
"うちながm 打ち眺"
"うちなおs 打ち直"
"うちなr 打ち鳴"
"うちどm 打ち止"
"うちとおs 打ち通"
"うちとt 打ち取"
"うちとr 打ち取"
"うちとk 打ち解"
"うちつk 打ち付"
"うちだs 打ち出"
"うちたt 打ち立"
"うちじn 討ち死"
"うちこわs 打ち壊"
"うちころs 打ち殺"
"うちこn 打ち込"
"うちこm 打込 打ち込"
"うちけs 打ち消"
"うちくだk 打ち砕"
"うちくだi 打ち砕"
"うちくずs 打ち崩"
"うちきt 打ち切"
"うちきr 打ち切"
"うちかt 打ち勝"
"うちかk 打ち掛"
"うちおt 打ち落"
"うちおr 打ち下"
"うちいr 討ち入"
"うちあわs 打合"
"うちあw 打ち合 打合"
"うちあk 打ち明"
"うちあg 打ち上"
"うたがw 疑"
"うたがu 疑"
"うたがt 疑"
"うたがi 疑"
"うたがe 疑"
"うたいだs 歌い出"
"うたいあk 歌い明"
"うたw 歌 謳 唄 謡"
"うたu 歌 唄 唱 謌 謳 謠 謡"
"うたt 歌 唄 唱 謌 謡"
"うたo 唄 歌 謳 謡"
"うたi 歌 謌 謳 唄 謡"
"うたe 歌 謌 唄 謡"
"うそぶk 嘯"
"うせつまc 右折待"
"うずたかk 堆"
"うずたかi 堆"
"うずくまr 踞 蹲"
"うずくm 蹲"
"うずk 疼"
"うすわらi 薄笑"
"うすよごr 薄汚"
"うすぐらk 薄暗"
"うすぐらi 薄暗"
"うすぎたなi 薄汚"
"うすきみわるk 薄気味悪"
"うすきみわるi 薄気味悪"
"うすs 薄"
"うすr 薄"
"うすm 薄"
"うすk 薄"
"うすi 薄"
"うしろむk 後向 後ろ向"
"うしろづk 後ろ付"
"うしなw 失"
"うしなu 失"
"うしなt 失"
"うしなi 失"
"うしおi 牛追"
"うしr 後"
"うしn 失"
"うさんくさi 胡散臭"
"うごめk 蠢 蠕"
"うごきはじm 動き始"
"うごきだs 動き出"
"うごk 動"
"うごi 動"
"うけわたs 受渡 受け渡"
"うけもどs 受け戻"
"うけもt 受け持 受持"
"うけながs 受け流"
"うけとt 受け取 受取"
"うけとr 受け取 受取"
"うけとm 受け止"
"うけつk 受け付 受付"
"うけつi 受け継"
"うけつg 受け継"
"うけたまわt 承"
"うけたまわr 承"
"うけたまw 受け賜"
"うけおw 請け負"
"うけおu 請け負 請負"
"うけおt 請け負"
"うけおo 請け負"
"うけおi 請け負"
"うけおe 請け負"
"うけうr 請け売 受け売"
"うけいr 受け入 受入"
"うけあw 請け合 受け合"
"うけあu 請け合 受け合"
"うけあt 請け合 受け合"
"うけあo 請け合 受け合"
"うけあi 請合 請け合 受け合"
"うけあe 請け合 受け合"
"うきぼr 浮き彫"
"うきだs 浮き出"
"うきたt 浮き立"
"うきしずm 浮き沈"
"うきがs 浮貸"
"うきうk 浮き浮"
"うきあしだt 浮足立"
"うきあg 浮き上"
"うががi 伺"
"うがt 穿 窄 鑿"
"うかがw 伺 窺"
"うかがu 伺 窺 覘"
"うかがt 伺 窺"
"うかがo 伺"
"うかがi 伺 覘"
"うかがe 伺 窺"
"うかr 合格"
"うかn 浮"
"うかb 浮"
"うえよs 上寄"
"うえつk 植え付 上付"
"うえこn 植え込"
"うえこm 植え込"
"うえd 上"
"うz 埋"
"うw 植"
"うt 打 売 撃 射 討 撲 搏 攴 攵 賣"
"うs 失 憂"
"うr 売 得 熟 賣"
"うn 産 生 膿"
"うm 埋 生 産 倦 膿"
"うk 受 浮 請 憂"
"うi 浮 憂"
"うe 飢 植"
"うc 打 射 討 撃 売"
"いんしょうぶかk 印象深"
"いんしょうぶかi 印象深"
"いわu 祝"
"いわt 祝"
"いわr 謂"
"いわk 曰"
"いわi 祝"
"いろわk 色分"
"いろどr 彩"
"いろづかi 色使"
"いろづk 色付"
"いろづi 色付"
"いろちがi 色違"
"いろだs 色出"
"いろこk 色濃"
"いろあs 色褪"
"いろあi 色合"
"いれわすr 入れ忘"
"いれなおs 入れ直"
"いれこn 入れ込"
"いれこm 入れ込"
"いれかw 入れ替 入れ換"
"いれかe 入れ替 入れ換"
"いりみだr 入り乱"
"いりこn 入り込"
"いりこm 入り込"
"いりくn 入り組"
"いりくm 入り組"
"いらだたしi 苛立たし"
"いらだt 苛立"
"いらだc 苛立"
"いらいらしi 苛苛し"
"いらu 苛 弄"
"いらh 苛 弄"
"いらd 苛"
"いやしm 卑し"
"いやs 卑 癒"
"いやn 嫌"
"いやg 嫌"
"いやd 嫌"
"いみぶかk 意味深"
"いみぶかi 意味深"
"いみづk 意味付"
"いみきらu 忌み嫌"
"いまわs 忌"
"いましばらk 今暫"
"いましm 戒 誡"
"いまいまs 忌々"
"いまd 未"
"いぶかs 訝"
"いぶかr 訝"
"いぶs 燻"
"いぶr 燻"
"いばt 威張"
"いばr 威張"
"いのちもe 命燃"
"いのちとr 命取"
"いのちごi 命乞"
"いのこr 居残"
"いのt 祈"
"いのr 祈"
"いねむr 居眠"
"いならn 居並"
"いならb 居並"
"いななk 嘶"
"いなおt 居直"
"いなおr 居直"
"いなm 否"
"いなk 否"
"いどn 挑"
"いどm 挑"
"いとなn 営 營"
"いとなm 営 營"
"いとw 厭"
"いとu 厭"
"いとs 愛"
"いとi 厭"
"いでたt 出で立"
"いてつk 凍てつ 凍て付"
"いつわr 偽 僞"
"いつづk 居続"
"いつくしm 慈"
"いつくs 慈"
"いつt 五"
"いつk 居着"
"いっぱんn 一般"
"いっそうおいs 一層美味"
"いっしょn 一緒"
"いっしむくi 一矢報"
"いっかつs 一括"
"いっt 言 行"
"いっs 逸"
"いちりんざs 一輪挿"
"いちやづk 一夜漬"
"いちばんちかk 一番近"
"いちばんちかi 一番近"
"いちばんすk 一番好"
"いちはやk 一早"
"いちとr 位置取"
"いちづk 位置付"
"いちずk 位置付"
"いちじるs 著"
"いちぎm 位置決"
"いだk 抱"
"いだi 抱"
"いたわr 労"
"いただk 頂 戴"
"いただi 頂 戴"
"いたずらn 徒"
"いたいたs 痛々"
"いたw 労"
"いたt 至 到"
"いたs 致 痛"
"いたr 至 到 致"
"いたn 痛 悼 傷"
"いたm 痛 炒 傷 悼 愴 慯"
"いたk 痛"
"いたi 痛"
"いたg 痛"
"いそがs 忙"
"いそi 急"
"いそg 急 忙"
"いずr 何"
"いすわt 居座"
"いすわr 居座"
"いじわるk 意地悪"
"いじわるi 意地悪"
"いじょうn 異常"
"いじっぱr 意地っ張"
"いじt 弄"
"いじs 維持"
"いじr 弄"
"いじm 苛"
"いじk 弄"
"いしなg 石投"
"いしとr 石取"
"いしづくr 石造"
"いしぐm 石組"
"いざなu 誘"
"いざなt 誘"
"いざなi 誘"
"いざr 躄"
"いさぎよk 潔"
"いさぎよi 潔"
"いさかi 諍"
"いさn 勇"
"いさm 諌 勇"
"いこu 憩 憇"
"いこn 鋳込"
"いこm 鋳込"
"いこi 憩 憇"
"いけn 不可"
"いくとおr 幾通"
"いくt 幾"
"いくr 幾"
"いぎもうs 異義申"
"いぎぶかi 意義深"
"いきわたt 行き渡"
"いきわたr 行き渡"
"いきわかr 生き別"
"いきまk 息巻"
"いきまi 息巻"
"いきのこt 生き残"
"いきのこr 生き残"
"いきのb 生き延"
"いきぬk 息抜"
"いきなやn 行き悩"
"いきなやm 行き悩"
"いきながr 生き長"
"いきどおr 憤"
"いきどm 行き止"
"いきとどk 行き届"
"いきとどi 行き届"
"いきづかi 息使 息遣"
"いきづm 息詰 行き詰"
"いきつづk 生き続"
"いきつk 行き付"
"いきつi 行き付"
"いきちがu 行き違"
"いきちがi 行き違"
"いきだおr 行き倒"
"いきすg 行き過"
"いきごn 意気込"
"いきごm 意気込"
"いきぐるs 息苦"
"いきぎr 息切"
"いきがk 行き掛"
"いきかよu 行き通"
"いきかえt 生き返"
"いきかえr 生き返 行き帰"
"いきかu 行き交"
"いきかt 行き交"
"いきおいづk 勢い付"
"いきおいづi 勢い付"
"いきおいこn 勢い込"
"いきおいこm 勢い込"
"いきおi 勢"
"いきうつs 生き写"
"いきうm 生き埋"
"いきいk 生き生"
"いきあu 行き合"
"いきあt 行き当 行き合"
"いがいn 意外"
"いがいd 意外"
"いかおなj 以下同"
"いかt 怒"
"いかr 怒 忿"
"いかn 以下 何如 如何"
"いかg 如何"
"いえどm 雖"
"いいわたs 言い渡"
"いいわすr 言い忘"
"いいわk 言い分"
"いいよt 言い寄"
"いいよr 言い寄"
"いいもr 言い漏"
"いいまわs 言い回"
"いいまぎr 言い紛"
"いいまk 言い負"
"いいふるs 言い古"
"いいふくm 言い含"
"いいふr 言い触"
"いいひろm 言い広"
"いいひらk 言い開"
"いいはなt 言い放"
"いいはt 言い張"
"いいはr 言い張"
"いいのこs 言い残"
"いいのがr 言い逃"
"いいぬk 言い抜"
"いいならw 言い習"
"いいなおs 言い直"
"いいとおs 言い通"
"いいつたe 言い伝"
"いいつくs 言い尽"
"いいつk 言い付"
"いいだs 言い出"
"いいそこn 言い損"
"いいそe 言い添"
"いいすg 言い過"
"いいしr 言い知"
"いいこm 言い籠"
"いいけs 言い消"
"いいきt 言い切"
"いいきr 言い切"
"いいきk 言い聞"
"いいがたi 言い難"
"いいかえs 言い返"
"いいかえr 言い替え"
"いいかk 言い掛"
"いいかe 言い換 言い替"
"いいおよn 言い及"
"いいおよb 言い及"
"いいおとs 言い落"
"いいおくt 言い送"
"いいおくr 言い送"
"いいおk 言い置"
"いいおi 言い置"
"いいあるk 言い歩"
"いいあるi 言い歩"
"いいあらわs 言い表"
"いいあらたm 言い改"
"いいあらそw 言い争"
"いいあらそu 言い争"
"いいあらそt 言い争"
"いいあらそo 言い争"
"いいあらそe 言い争"
"いいあやまt 言い誤"
"いいあやまr 言い誤"
"いいあu 言い合"
"いいあt 言い当 言い合"
"いいあo 言い合"
"いいあi 言い合"
"いいあe 言い合"
"いあわs 居合"
"いあw 居合"
"いあu 居合"
"いz 居"
"いy 癒"
"いw 言 云"
"いu 言 云 謂"
"いt 言 行 入 居 射 云 炒 煎 凍 要"
"いs 逸"
"いr 入 居 要 煎 射 容 炒 鑄 淹 言"
"いo 言"
"いn 居 要 言"
"いm 居 忌"
"いk 行 生 活 逝 言"
"いi 言 良 云 可"
"いh 云 言"
"いe 言 癒 云"
"いd 出"
"いc 言 行"
"あんないもうs 案内申"
"あんないいたs 案内致"
"あんぜんd 安全"
"あんしんくだs 安心下"
"あんしんs 安心"
"あんz 案"
"あんj 案"
"あんd 編ん"
"あわれm 憐"
"あわだt 泡立 粟立"
"あわおどr 阿波踊"
"あわt 慌"
"あわs 合 併"
"あわr 憐 哀 閔"
"あわk 淡"
"あわi 淡"
"あるきまわr 歩き回"
"あるきだs 歩き出"
"あるk 歩"
"あるi 歩 或"
"ありがとu 有難"
"ありがたk 有難"
"ありがたi 有難"
"あらわs 表 現"
"あらわr 現 表"
"あらたn 新"
"あらたm 改 更"
"あらそu 争 爭"
"あらそt 争 爭"
"あらそi 争 爭"
"あらすg 粗過"
"あらけずr 荒削"
"あらがu 抗 爭"
"あらがi 抗"
"あらがe 抗"
"あらかじm 予 豫"
"あらいだs 洗い出"
"あらあらs 荒々 荒ゝ"
"あらz 非"
"あらw 表 現 洗"
"あらu 洗"
"あらt 新 洗"
"あらs 粗"
"あらp 荒"
"あらo 洗"
"あらk 荒 粗"
"あらj 非"
"あらi 洗 荒 粗 麁"
"あらe 洗"
"あらb 荒"
"あゆみよr 歩み寄"
"あゆn 歩"
"あゆm 歩"
"あやまt 誤 謝 過"
"あやまr 誤 謝"
"あやまc 過 誤"
"あやつt 操"
"あやつr 操"
"あやu 危"
"あやs 怪 妖 恠"
"あやb 危"
"あめふr 雨降"
"あみかk 網掛"
"あみあg 編み上"
"あまやどr 雨宿"
"あまもr 雨漏"
"あまねk 遍 普"
"あまっさe 剰"
"あまくだr 天下"
"あまぎごe 天城越"
"あまy 甘"
"あまt 余 餘 甘"
"あまs 甘 余 餘"
"あまr 余 餘"
"あまn 甘"
"あまk 甘"
"あまi 甘"
"あまe 甘"
"あぶなs 危"
"あぶなk 危"
"あぶなi 危"
"あぶなg 危"
"あぶt 焙"
"あぶr 炙 炮 焙 溢"
"あぶn 危"
"あふr 溢"
"あびs 浴"
"あばr 暴"
"あばk 暴"
"あばi 暴"
"あなねらi 穴狙"
"あなどt 侮"
"あなどr 侮"
"あなうm 穴埋"
"あともどr 後戻"
"あとまわs 後回"
"あとばらi 後払"
"あとづk 後付"
"あとすこs 後少"
"あとおs 後押"
"あとd 後"
"あてはまr 当て嵌"
"あてはm 当て嵌"
"あてこn 当て込"
"あてこm 当て込"
"あつらh 誂"
"あつらe 誂"
"あつまr 集 集ま"
"あつぐるs 暑苦"
"あつくるs 暑苦"
"あつぎr 厚切"
"あつかw 扱"
"あつかu 扱"
"あつかt 扱"
"あつかo 扱"
"あつかi 扱"
"あつかe 扱"
"あつs 暑 厚 熱"
"あつm 集 厚 纂 蒐 輯 聚"
"あつk 厚 暑 熱 篤"
"あつi 厚 暑 熱"
"あつg 暑"
"あったk 暖"
"あだうt 仇打"
"あたらs 新"
"あたまがk 頭書"
"あたまうt 頭打"
"あたたかi 暖"
"あたたm 暖 温"
"あたたk 暖 温"
"あたu 能"
"あたt 当 中 辺"
"あたr 辺 当 新 中 邊 邉"
"あたh 与"
"あたe 与 與"
"あそんd 遊ん"
"あそびほうk 遊び惚"
"あそびあk 遊び明"
"あそn 遊"
"あそb 遊 游"
"あせにぎr 汗握"
"あせt 焦"
"あせr 焦"
"あずかt 与"
"あずk 預"
"あじちがi 味違"
"あじだs 味出"
"あじけs 味消"
"あじw 味"
"あしまわs 足回"
"あしまわr 足回"
"あしぶm 足踏"
"あしふm 足踏"
"あしなr 足慣"
"あしどr 足取"
"あしとr 足取"
"あししげk 足繁"
"あしk 悪 惡"
"あざやk 鮮"
"あざむk 欺"
"あざけr 嘲"
"あざy 鮮"
"あさはやk 朝早"
"あさはやi 朝早"
"あさづk 浅漬"
"あさすg 浅過"
"あさぐろi 浅黒"
"あさがえr 朝帰"
"あさおk 朝起"
"あさいr 浅煎"
"あさt 漁"
"あさs 浅"
"あさr 漁"
"あさk 浅 淺"
"あさi 浅 淺"
"あこがr 憧"
"あこu 赤"
"あげt 上"
"あけくれr 明け暮れ"
"あぐm 倦"
"あくめいたかk 悪名高"
"あくめいたかi 悪名高"
"あくみょうだかi 悪名高"
"あきらm 諦"
"あきらk 明"
"あきやすm 秋休"
"あきばr 秋晴"
"あきなu 賈 商"
"あきr 明 呆 煥 顕"
"あがりこn 上がり込"
"あがりこm 上がり込"
"あがなu 購 贖"
"あがなi 贖 購"
"あがt 上"
"あがr 上"
"あがm 崇"
"あかるi 明"
"あからm 赧"
"あかs 證 赤"
"あかr 明 灯"
"あかp 赤"
"あかn 赤"
"あかk 赤 紅"
"あかi 赤 紅 赫"
"あおむk 仰向"
"あおばどおr 青葉通"
"あおじろs 青白"
"あおじろk 青白"
"あおじろi 青白"
"あおt 煽"
"あおr 煽"
"あおp 青"
"あおk 青 蒼"
"あおi 青 蒼 碧 仰"
"あおg 仰"
"あえt 敢"
"あえg 喘"
"あいまt 相俟"
"あいはんs 相反"
"あいのr 相乗"
"あいなr 相成"
"あいつらn 相連"
"あいつi 相次"
"あいつg 相次"
"あいたいs 相対"
"あいしあw 愛し合"
"あいしあu 愛し合"
"あいしあt 愛し合"
"あいしあo 愛し合"
"あいしあi 愛し合"
"あいしあe 愛し合"
"あいさつがわr 挨拶代"
"あいことn 相異"
"あいかわr 相変"
"あいかw 相変"
"あいうt 相討"
"あいいr 相容"
"あいs 愛"
"あいi 相"
"あw 合 会 併 逢 會"
"あu 合 会 逢 遭 遇 會"
"あt 当 会 合 有 宛 挙 蓬 逢 遭 會 當 充 該"
"あs 悪 褪 惡"
"あr 有 荒 在 或"
"あo 合 会 會"
"あn 編"
"あm 編"
"あk 空 開 明 飽 厭 倦 飫"
"あi 合 会 空 悪 開 逢 遭 相 會"
"あh 合 會"
"あg 上 挙 揚 擧"
"あe 会 合 逢 敢 遭 會 和"
"あb 浴"
)

;; Setting postfix entries.
(skkdic-set-postfix
"いき 行"
"がかり 係"
"がく 学"
"がわ 川"
"しゃ 社"
"しゅう 集"
"しょう 賞 城"
"じょう 城"
"せん 線"
"だけ 岳"
"ちゃく 着"
"てん 店"
"とうげ 峠"
"どおり 通り"
"やま 山"
"ばし 橋"
"はつ 発"
"もく 目"
"ゆき 行"
"い 位"
"えん えん 円"
"おうふく 往復"
"おく 億"
"おくねんまえ 億年前"
"か 価 日"
"かい Ｆ 階 回"
"かいせい 回生"
"かいせん 回戦 回線"
"かいはつ 開発"
"かいめ 回目"
"かかん 日間"
"かげつ カ月 ヶ月"
"かこく カ国"
"かしょ カ所 個所 ヶ所 箇所"
"かじょう カ条"
"かねん カ年"
"かめ 日目"
"からむ カラム"
"かん 巻"
"がい 階"
"がつ 月"
"がつごう 月号"
"がつちゅう 月中"
"がつまつ 月末"
"がめん 画面"
"き 機 期"
"きょく 曲"
"きろ ｋ Ｋ kg kbyte Km キロ"
"きろばいと kbytes kb"
"きん 金"
"ぎが Ｇ"
"ぎょう 行"
"ぎょうめ 行目"
"ぐらむ グラム"
"けいとう 系統"
"けた 桁"
"けん 間 軒 件"
"こ 個"
"こう 校 項"
"こうかんけい 項関係"
"こま コマ"
"ご 語"
"ごう 號 号"
"ごうかん 号館"
"ごうき 号機"
"ごうしつ 号室"
"ごうせん 号線"
"さい 才 歳"
"さつ 冊"
"さつめ 冊目"
"し 氏"
"しあい 試合"
"しつ 室"
"しゅ 種"
"しゅう 週"
"しゅうかん 週間"
"しゅうかんご 週間後"
"しゅうねん 周年"
"しゅるい 種類"
"しょう 章"
"しょく 色"
"しん 進"
"しんすう 進数"
"しんほう 進法"
"しんぽう 進法"
"じ 字 次 時"
"じかい 次会"
"じかん 時間"
"じかんはん 時間半"
"じげん 次元"
"じごろ 時頃"
"じはん 時半"
"じみゃく 次脈"
"じゅう 重"
"じょ 女"
"じょう 乗 条 畳"
"すう 数"
"すうか 数花"
"すうせい 数性"
"すてっぷ ステップ"
"すん 寸"
"せいき 世紀"
"せいりょく 勢力"
"せだい 世代"
"せだいめ 世代目"
"せっと セット"
"せつ 節"
"せん 千"
"せんえん 千円"
"せんち センチ cm"
"せんまん 千万"
"そう 相 層 漕"
"そうさ 走査"
"ぞく 属"
"だい 題 代 台"
"だいめ 台目"
"だん 段"
"だんぐみ 段組み"
"だんめ 段目"
"ち 値"
"ちっぷ チップ"
"ちょうめ 丁目"
"つ つ"
"つう 通"
"つうめ 通目"
"つき 月"
"つぼ 坪"
"てん 点"
"とう 頭 等"
"とうしん 頭身"
"とおり 通り"
"ど 度"
"どめ 度目"
"にち 日"
"にちかん 日間"
"にん 人"
"にんぐみ 人組"
"にんぶん 人分"
"にんめ 人目"
"ねん 年"
"ねんかん 年間"
"ねんご 年後"
"ねんせい 年生"
"ねんど 年度"
"ねんはん 年半"
"ねんまえ 年前"
"ねんめ 年目"
"はいめ 杯目"
"はく 拍 (j-stay) 泊"
"はこ 箱"
"ばい 杯 倍"
"ばいすう 倍数"
"ばいと バイト"
"ばん 番 晩"
"ばんだい 番台"
"ばんち 番地"
"ばんめ 番目"
"ぱーせんと ％"
"ぱく 泊 拍"
"ひき 匹"
"ひゃくねん 百年"
"びっと ビット"
"びょう 秒"
"びょうし 拍子"
"びん 便"
"ふくろ 袋"
"ふん 分"
"ぶ 部"
"ぶもん 部門"
"ぶんや 分野"
"ぷん 分"
"へるつ Hz"
"へん 辺 片 編"
"ぺーじ ページ"
"ほん 本"
"ほんだて 本立て"
"ぼん 本"
"ぽん 本"
"まい 枚"
"まいぶん 枚分"
"まいめ 枚目"
"まん 万"
"まんえん 万円"
"まんねん 万年"
"めーとる メートル"
"めい 名"
"めが メガ Mbyte"
"めん 面"
"もじ 文字"
"もじめ 文字目"
"り 人"
"りーる リール"
"りん 輪"
"りんか 輪花"
"れつ 列 裂"
"れつめ 列目"
"れん 連"
"れんぱい 連敗"
"わり 割"
"わりびき 割引 割り引き"
"か 化 課"
"がた 型"
"く 区"
"くん 君"
"けん 県"
"ご 後"
"さま 様"
"し 氏 市"
"しつ 室"
"すう 数"
"せい 製 性"
"せん 線"
"せんせい 先生"
"てい 邸"
"てき 的"
"てん 点"
"と 都"
"どの 殿"
"は 派"
"はい 杯"
"ばん 版"
"ふ 府"
"ぶ 部"
"ぶん 文"
"まち 町"
"めい 名"
"よう 用"
"いき 域"
"いち 市"
"いろ 色"
"いん 員"
"えき 駅"
"えん 園"
"おん 音"
"か 可 課 科 化 下"
"かい 会 界 回"
"かく 核"
"かた 方 型"
"かん 官 観 館 艦 間 感"
"が 画 絵"
"がい 外 街"
"がた 型"
"がわ 側"
"き 機 器"
"きゅう 級"
"きょく 局"
"く 区"
"くみ 組"
"くん 君"
"ぐみ 組み 組"
"ぐん 群 郡"
"け 家"
"けい 型 系"
"けん 圏 権 県 研"
"こ 個"
"こく 国"
"ご 語 後"
"ごう 号"
"さ 差"
"さき 先"
"さく 策"
"さま 様"
"ざい 剤"
"し 師 誌 氏 市"
"しき 式"
"しつ 室"
"しゃ 者"
"しょ 所 書"
"しょう 証 症"
"じ 時"
"じてん 辞典"
"じゅう 中"
"じゅつ 術"
"じょう 場 状 上"
"じん 陣"
"すう 数"
"ず 図"
"せい 生 性 制"
"せん 線"
"せんせい 先生"
"ぜんたい 全体"
"そく 則"
"ぞく 族"
"たい 隊 帯"
"たち 達"
"だい 代 大 台"
"だいがく 大学"
"だん 団 談"
"ち 地 値"
"ちゅう 注 中"
"ちょう 調 長 町"
"つい 対"
"つう 通"
"つき 付き"
"てい 邸"
"てき 的"
"てん 点"
"とう 等"
"ど 度"
"どう 道"
"どうし 同士"
"どの 殿"
"ない 内"
"など 等"
"は 派"
"はば 幅"
"はん 半 藩"
"ばい 倍"
"ばん 盤 版"
"ひょう 票 表"
"ひん 品"
"び 日"
"ふう 風"
"ぶ 部"
"ぶつ 物"
"ぶん 文 分"
"べつ 別"
"べん 弁"
"ほう 法"
"まい 枚"
"まえ 前"
"まち 町"
"むら 村"
"め 目"
"めい 名"
"めん 面"
"もと 元"
"や 屋"
"やく 訳"
"よう 用"
"よく 翼"
"らん 欄"
"りつ 率"
"りょう 量 料"
"りょく 力"
"るい 類"
"れい 例"
"れき 歴"
"ろく 録"
"ろん 論"
"わ 羽"
"わき 脇"
"か 課 科 化"
"かい 回 会"
"かん 感"
"く 区"
"こ 個"
"ご 語 後"
"さ 差"
"さき 先"
"し 氏 市 子"
"しゃ 者"
"しょ 書"
"じ 時"
"じん 人"
"せい 性"
"ちゅう 中"
"てき 的"
"てん 点"
"ない 内"
"はん 版"
"ひ 比"
"ひん 品"
"ぶ 部"
"めい 名"
"もと 元"
"や 屋"
"よう 用"
)

;; Setting prefix entries.
(skkdic-set-prefix
"い 異"
"いち 一"
"うき 浮"
"うら 裏"
"お 御"
"おお 大"
"おん 御"
"か 可"
"かい 改 開"
"かく 各"
"かく 各"
"から 空"
"かり 仮"
"かん 間"
"かん 間"
"き 貴"
"きゅう 旧"
"ぎゃく 逆"
"けい 計"
"げき 激"
"げん 元 現"
"こ 仔"
"こう 広 高"
"こん 今"
"ご 御"
"ご 誤 御"
"ご 誤"
"さい 歳 再"
"さい 最 再"
"さい 再"
"しゅ 主"
"しょ 諸"
"しょう 症 小"
"しん 新"
"しん 真 新"
"しん 新"
"じ 次"
"じゅう 重"
"じゅん 準"
"じょう 上"
"すう 数"
"せい 正 性"
"ぜつ 絶"
"ぜん 全"
"ぜん 全 前"
"そう 総"
"そう 双 総"
"た 他 多"
"た 他"
"たい 耐"
"たい 対"
"たん 短"
"だい 第"
"だい 大 第"
"だい 第"
"だん 団"
"ちゅう 中"
"ちゅう 中"
"ちょう 超"
"ちょう 超"
"てい 低"
"とう 当"
"とう 当"
"ど 度"
"どう 同"
"なん 何"
"はつ 初"
"はん 半 反"
"ひ 非"
"ひ 非 被"
"ひ 非"
"び 微"
"ふ 不"
"ふ 負 不"
"ふ 不"
"ふく 複 副"
"へい 閉"
"ほん 本"
"ほん 本"
"ぼう 某"
"ま 真"
"まい 毎"
"まい 毎"
"み 未"
"み 未"
"む 無"
"めい 名"
"めい 名"
"もと 元"
"やく 約"
"やく 約"
"よう 要"
"らい 来"
"りょう 両"
)

;; Setting okuri-nasi entries.
(skkdic-set-okuri-nasi
"あ 唖 襾 痾 椏 婀 嗚 哇 亞 明 安 亜 娃 阿"
"あーかいぶ アーカイブ"
"あーく アーク"
"あーす アース"
"あーち アーチ"
"あーてぃすと アーティスト"
"あーびとれーしょん アービトレーション"
"ああ 噫 嗚呼"
"あい 靉 阨 藹 穢 瞹 欸 埃 噫 饗 会 娃 隘 曖 藍 亜衣 挨 姶 合 哀 相 愛"
"あいあいがさ 相合い傘"
"あいあん アイアン"
"あいいく 愛育"
"あいいちろう 愛一郎"
"あいいん 合印 愛飲"
"あいうら 相浦"
"あいえん 愛煙"
"あいえんか 愛煙家"
"あいおい 相生"
"あいか 哀歌"
"あいかぎ 合鍵"
"あいかた 相方 合方"
"あいかわ 合川 愛川 相川"
"あいかわらず 相変わらず"
"あいかん 哀歓"
"あいが 相賀"
"あいがん 愛玩 哀願"
"あいがんけん 愛玩犬"
"あいき 愛機"
"あいきどう 合気道"
"あいきゃく 相客"
"あいきょう 愛郷 愛嬌 愛敬"
"あいくち 匕首"
"あいけん 愛犬"
"あいこ 藍子 アイ子 愛顧 愛子"
"あいこう 愛甲 愛好 愛校"
"あいこうか 愛好家"
"あいこうしん 愛校心"
"あいこうだいめいでん 愛工大名電"
"あいこく 愛国"
"あいこくしん 愛国心"
"あいことば 合言葉"
"あいご 愛護"
"あいごま 合駒 合い駒"
"あいさい 愛妻"
"あいさいか 愛妻家"
"あいさつ 挨拶"
"あいさわ 相沢"
"あいざわ 相澤 相沢 会沢"
"あいしかた 愛し方"
"あいしゃ 愛車"
"あいしゃせいしん 愛社精神"
"あいしゅう 哀愁"
"あいしょ 愛書"
"あいしょう 愛唱 愛誦 愛称 相性"
"あいしょうか 愛唱歌"
"あいしょか 愛書家"
"あいしんせいき アイシン精機"
"あいじ 愛児"
"あいじょう 哀情 愛情"
"あいじん 愛人"
"あいす アイス"
"あいすみちょう 愛住町"
"あいず 会津 合図"
"あいずみ 藍住"
"あいせき 愛惜 哀惜 相席"
"あいせつ 哀切"
"あいそ 愛相 相曽 相磯 愛想"
"あいそう 愛想"
"あいぞう 愛蔵 愛憎"
"あいたい 相対"
"あいだ 愛田 英田 合田 会田 相田 藍田 間"
"あいだい 愛大"
"あいだがら 間柄"
"あいだじゅう 間中"
"あいち 相知 愛知"
"あいちがくせんだい 愛知学泉大"
"あいちゃく 合着 愛着"
"あいちょう 哀調 愛鳥 愛聴"
"あいつぎ 相次"
"あいづ 会津"
"あいづき 相築"
"あいづち 相槌 相づち"
"あいづま 逢妻"
"あいて 相手"
"あいてがた 相手方"
"あいてやく 相手役"
"あいであ アイデア"
"あいでぃあ アイディア"
"あいでんてぃてぃー アイデンティティー"
"あいとう 哀悼"
"あいどく 愛読"
"あいどりんぐ アイドリング"
"あいどる アイドル"
"あいにく 生憎"
"あいの 愛野"
"あいのり 相乗り"
"あいはら 愛原 合原 相原"
"あいはん 相判 合判"
"あいば 相羽 相庭 愛馬 相場 饗場"
"あいばら 相原 合原"
"あいびき 合挽 逢引"
"あいふく 合服 間服"
"あいぶ 愛撫"
"あいべ 相部"
"あいべつ 愛別 哀別"
"あいべつりく 愛別離苦"
"あいぼ 愛慕"
"あいぼう 相棒"
"あいま 合い間 合間"
"あいまい 愛昧 曖昧"
"あいまって 相俟って"
"あいみ 亜衣実"
"あいもと 相本"
"あいやぐら 相矢倉"
"あいやど 相宿"
"あいやま 相山"
"あいよう 愛用"
"あいよく 愛欲"
"あいよし 相吉"
"あいら 吾平 姶良"
"あいらく 哀楽"
"あいりん 愛輪"
"あいるらんど 愛蘭"
"あいれん 愛憐 哀憐"
"あいろ 隘路"
"あいろん アイロン"
"あいわ 哀話"
"あう 櫻 媼 奧 桜 奥 央"
"あうすとろばいれやか アウストロバイレヤ科"
"あうと アウト"
"あうとさいだー アウトサイダー"
"あうん 呵吽 阿吽"
"あえ 阿江"
"あえぎ 喘ぎ"
"あえもの 和え物"
"あえり 愛絵理"
"あえん 亜鉛"
"あお 靜 碧 蒼 青"
"あおあお 青々"
"あおい 碧 青井 葵"
"あおいきといき 青息吐息"
"あおいけ 青池"
"あおいっしょく 青一色"
"あおいめ 青い目"
"あおいもく アオイ目"
"あおいろ 青色"
"あおえ 青江"
"あおえきしょう 青液晶"
"あおおに 青鬼"
"あおがき 青垣"
"あおがく 青山学院大学 青学"
"あおがしま 青ヶ島"
"あおき 青木"
"あおきいさお 青木功"
"あおきこ 青木湖"
"あおきっぷ 青切符"
"あおぎいろ 青黄色"
"あおぎり 榮 青桐"
"あおくさ 青草"
"あおけいとう 青系統"
"あおしか 青鹿"
"あおしま 青嶋 青島"
"あおしんごう 青信号"
"あおじ 青地"
"あおじゃしん 青写真"
"あおぞら 蒼空 青空"
"あおた 青田"
"あおたがり 青田刈"
"あおたけ 青竹"
"あおたん 青丹"
"あおだいしょう 青大将"
"あおだま 青玉"
"あおてんじょう 青天井"
"あおでんわ 青電話"
"あおと 青砥 青戸"
"あおに 青二"
"あおぬま 青沼"
"あおねぎ 青葱"
"あおの 青野"
"あおのはら 青野原"
"あおのり 青海苔"
"あおはた 青旗"
"あおば 青葉"
"あおばどおり 青葉通"
"あおばん 青盤 青版"
"あおぼうず 青坊主"
"あおみどり 青緑"
"あおむし 青虫"
"あおむらさき 青紫"
"あおもと 青本"
"あおもの 青物"
"あおもり 青森"
"あおもりうんてんじょ 青森運転所"
"あおもん 青門"
"あおや 青谷"
"あおやき 青焼"
"あおやぎ 青柳"
"あおやま 青山"
"あおんそく 亜音速"
"あか 絳 閼伽 亜科 垢 赤"
"あかあお 赤青"
"あかあおみどり 赤青緑"
"あかあか 明々 赤々"
"あかい 赤井"
"あかいくつ 赤い靴"
"あかいけ 赤池"
"あかいし 赤石"
"あかいっしょく 赤一色"
"あかいろ 赤色"
"あかいわ 赤岩 赤磐"
"あかいわし 赤鰯"
"あかうんと アカウント"
"あかえだ 赤枝"
"あかお 赤尾"
"あかおか 赤岡"
"あかおすぎ 赤尾杉"
"あかおに 赤鬼"
"あかかげ 赤影"
"あかがい 赤貝"
"あかがね 銅"
"あかがみ 赤紙"
"あかがり 赤狩"
"あかがわ 赤川"
"あかきっぷ 赤切符"
"あかぎ 赤木 赤城"
"あかぎいろ 赤黄色"
"あかくら 赤倉"
"あかくろ 赤黒"
"あかぐみ 紅組"
"あかけいとう 赤系統"
"あかげ 赤毛"
"あかご 赤子"
"あかさか 赤坂"
"あかさき 赤崎 赤碕"
"あかざ 藜"
"あかざか アカザ科"
"あかざき 赤崎"
"あかざわ 赤澤 赤沢"
"あかし 灯 絳し 證 赤司 証 明石"
"あかしお 赤潮"
"あかしこう 明石港"
"あかしな 明科"
"あかしば 赤芝"
"あかしや 明石家"
"あかしやき 明石焼"
"あかしろ 赤白"
"あかしんごう 赤信号"
"あかしんぶんか 赤新聞化"
"あかじ 赤字"
"あかすいしょう 赤水晶"
"あかずきん 赤頭巾"
"あかせがわ 赤瀬川"
"あかせがわげんぺい 赤瀬川原平"
"あかせん 赤線"
"あかたにせん 赤谷線"
"あかたん 赤丹"
"あかだな 閼伽棚"
"あかだま 赤玉"
"あかちゃ 赤茶"
"あかちゃん 赤ちゃん"
"あかつか 赤塚"
"あかつき 曉 暁"
"あかつち 赭 赤土"
"あかつつみ 赤堤"
"あかてん 赤点"
"あかでん 赤電"
"あかでんわ 赤電話"
"あかどう 赤胴"
"あかどまり 赤泊"
"あかな 赤名"
"あかにんじゃ 赤忍者"
"あかぬま 赤沼"
"あかね 朱子 茜"
"あかねか アカネ科"
"あかねもく アカネ目"
"あかはた 旃 赤旗"
"あかはな 赤鼻"
"あかはに 赤埴"
"あかはね 赤羽"
"あかばこ 赤箱"
"あかばね 赤羽根 赤羽"
"あかばん 赤盤"
"あかひら 赤平"
"あかびょうし 赤表紙"
"あかびら 赤平"
"あかふく 赤福"
"あかふだ 赤札"
"あかほ 赤穂"
"あかほり 赤堀"
"あかほん 赤本"
"あかぼう 赤帽"
"あかぼし 赤星"
"あかぼり 赤堀"
"あかま 赤間"
"あかまつ 赤松"
"あかまど 赤窓"
"あかまる 赤丸"
"あかみそ 赤味噌"
"あかむし 赤虫"
"あかむらさき 赤紫"
"あかめ 赤目"
"あかめぐち 赤目口"
"あかもん 赤門"
"あかゆ 赤湯"
"あかり 明り 灯り 燈 明かり 灯"
"あかるみ 明るみ"
"あかん 阿寒"
"あかんこ 阿寒湖"
"あかんぼう 赤ん坊"
"あがおか 阿賀岡"
"あがつま 我妻 吾妻"
"あがの 阿賀野"
"あがほ 英賀保"
"あがり 上り"
"あがりかた 上がり方"
"あがりがまち 上がり框"
"あがりた 揚田"
"あがわ 阿川 吾川"
"あき 晶紀 亜希 安岐 空き 龝 璋 朖 晢 晄 彬 哲 光 顕 暁 亜樹 朗 亮 彰 晃 晶 安芸 亜季 晰 亜紀 昭 章 穐 空 明 秋"
"あきあじ 秋味"
"あきいこう 秋以降"
"あきう 秋保"
"あきうみ 明生"
"あきえ 秋江 亜紀恵 明恵 昭江 晃枝 章江 秋絵"
"あきお 明央 亜希夫 彬生 彰夫 暁生 晶夫 明夫 明男 昭夫 昭男 秋雄 秋夫 秋男 晃夫 章夫 明雄 昭雄"
"あきおか 秋岡"
"あきおみ 明臣"
"あきかず 彰一"
"あきかぜ 秋風"
"あきかわ 秋川"
"あきかん 空缶 空き罐 空き缶"
"あきがわ 秋川"
"あきぐち 秋口"
"あきけいば 秋競馬"
"あきこ 亜季子 朱子 暁子 昭子 彰子 朗子 亜樹子 亜紀子 晃子 顕子 晶子 章子 明子 亜希子"
"あきごう 秋号"
"あきごろ 秋頃"
"あきさと 穐里"
"あきさめ 秋雨"
"あきさわ 秋澤"
"あきしの 秋篠"
"あきしのでら 秋篠寺"
"あきしののみや 秋篠宮"
"あきしま 安芸島 昭島"
"あきしょせん 秋初戦"
"あきじかん 空時間"
"あきすえ 秋末"
"あきせき 空き席"
"あきた 飽田 秋田"
"あきたに 秋谷"
"あきだい 秋大"
"あきち 空地"
"あきつ 安芸津 蜻蛉 秋津"
"あきつぐ 明二"
"あきづき 秋月"
"あきと 彰人"
"あきとし 晃年 彰俊 明敏 秋利"
"あきとも 秋友"
"あきな 明菜"
"あきない 商い"
"あきなが 秋永"
"あきなぎ 秋奈祇"
"あきなす 秋茄子"
"あきなり 章成"
"あきなる 秋成"
"あきの 秋野 昭乃"
"あきのり 昭憲 明徳 昭徳 晃紀 昭則 晧則 明紀 彰則 明憲"
"あきは 秋葉"
"あきはばら 秋葉原"
"あきば 秋庭 秋場 秋葉"
"あきばこ 空箱"
"あきばれ 秋晴れ"
"あきひこ 祥彦 秋彦 暁彦 晶彦 彰彦 明彦 昭彦"
"あきひさ 彰久 顕尚"
"あきひで 彰英"
"あきひと 明仁 昭仁 祥仁"
"あきひろ 明裕 章弘 明広 章宏 晃宏 明浩 哲裕 碩宏 章裕 昭宏 晃弘 暁宏 章浩 彰広 彰宏 明弘 昭浩 章博 昭弘 明宏 晃広 昭博"
"あきびより 秋日和"
"あきびん 空瓶"
"あきふく 秋服"
"あきふみ 晶文 明文 章文"
"あきふゆ 秋冬"
"あきぶもん 空部門"
"あきべや 空部屋"
"あきほ 秋穂 明穂"
"あきま 秋間 空き間"
"あきまで 秋迄"
"あきまる 秋丸"
"あきみ 秋生"
"あきみず 秋水"
"あきみち 明倫"
"あきみつ 章充"
"あきむら 秋村"
"あきもと 秋本 秋元"
"あきもの 秋物"
"あきものがたり 秋物語"
"あきや 空家 空き家"
"あきやす 彰康"
"あきやま 秋山"
"あきゅう 秋保"
"あきゅうせい 亜急性"
"あきゆき 昭如"
"あきよ 明代 晃代"
"あきようりょう 空容量"
"あきよし 昭良 彰芳 昭義 明良 秋吉 明吉"
"あきら 日明 鑑 晧 顕 顯 滉 洸 朖 曉 晄 昜 聡 啓 彬 暁 亮 陽 昭 光 旭 晶 輝 章 璋 朗 彰 晃 明"
"あきらか 明らか 昿 曠 明か"
"あきりょういき 空領域"
"あきんど 商人"
"あぎ 阿木 亜木"
"あぎと 顎"
"あぎょう ア行"
"あく 灰汁 齷 軛 惡 幄 堊 空 阿久 渥 握 悪"
"あくい 悪意"
"あくいんしょう 悪印象"
"あくうかん 亜空間"
"あくうん 悪運"
"あくえいきょう 悪影響"
"あくえき 悪疫"
"あくえん 悪縁"
"あくかんきょう 悪環境"
"あくかんじょう 悪感情"
"あくぎ 悪戯"
"あくぎゃく 悪虐"
"あくぎょう 悪行 悪業"
"あくこうか 悪効果"
"あくごう 悪業"
"あくさい 悪妻"
"あくざいりょう 悪材料"
"あくしつ 悪質"
"あくしでんと アクシデント"
"あくしゃ 幄舎"
"あくしゅ 悪趣 悪手 握手"
"あくしゅう 悪臭 悪習"
"あくしゅけん 握手券"
"あくしゅみ 悪趣味"
"あくしょ 悪書 悪所"
"あくしょん アクション"
"あくしん 悪心"
"あくじ 悪事"
"あくじき 悪食"
"あくじゅんかん 悪循環"
"あくじょ 悪女"
"あくじょうけん 悪条件"
"あくせい 悪声 悪政 悪性"
"あくせさり アクセサリ"
"あくせす アクセス"
"あくせぷと アクセプト"
"あくせる アクセル"
"あくせん 悪銭 悪戦"
"あくせんと アクセント"
"あくぜい 悪税"
"あくた 芥"
"あくたい 悪態"
"あくたがわ 芥川"
"あくだいかん 悪代官"
"あくだま 悪玉"
"あくつ 圷 阿久津"
"あくてん 悪天"
"あくてんこう 悪天候"
"あくとう 悪党"
"あくとく 悪徳"
"あくどい 悪どい"
"あくどう 悪道 悪童"
"あくにん 悪人"
"あくね 阿久根"
"あくねんぴ 悪燃費"
"あくば 悪罵"
"あくひつ 悪筆"
"あくひょう 悪評"
"あくひょうばん 悪評判"
"あくび 欠伸"
"あくびょう 悪病"
"あくふう 悪風"
"あくぶん 悪文"
"あくへい 悪弊"
"あくへき 悪癖"
"あくほう 悪法"
"あくま 悪魔"
"あくみ 飽海"
"あくみょう 悪名"
"あくむ 悪夢"
"あくめい 悪名"
"あくもん 悪問"
"あくやく 悪役"
"あくゆう 阿久悠 悪友"
"あくよう 悪用"
"あくらつ 悪辣"
"あくりょう 悪霊"
"あくりょく 握力"
"あくりる アクリル"
"あくれい 悪例"
"あくろ 悪路"
"あぐい 阿久比 安食"
"あぐさ 阿草"
"あぐに 粟国"
"あぐら 趺坐 胡座"
"あぐり 亜久里"
"あぐん 亜群"
"あけ 明 曉 朱 暁"
"あけお 暁生"
"あけがた 明け方"
"あけこ 朱子"
"あけち 明智"
"あけちこごろう 明智小五郎"
"あけの 明野"
"あけはま 明浜"
"あけびか アケビ科"
"あけぼの 曙"
"あけぼのばし 曙橋"
"あけみ 明珠 暁美 朱美 朱実 明海 明美"
"あげ 安芸 揚 上"
"あげあし 挙げ足 揚足 揚げ足"
"あげお 上尾"
"あげく 揚句 上げ句 挙げ句 挙句"
"あげくのはて 挙げ句の果て"
"あげぞこ 上げ底"
"あげだま 揚げ玉"
"あげの 揚野"
"あげはば 上げ幅"
"あげはましきえんでん 揚浜式塩田"
"あげば 揚げ場 揚場"
"あげもの 揚げ物"
"あこ 亜子 亜古"
"あこう 亜綱 赤穂"
"あこうそく 亜光速"
"あこぎ 阿漕"
"あこめ 袙 衵"
"あご 阿児 顎"
"あごかんせつ 顎関節"
"あごしゅうへん 顎周辺"
"あごひげ 鬚"
"あごひも 顎紐"
"あさ 厚狭 淺 安佐 阿佐 麻 浅 朝"
"あさい 朝井 淺井 浅井"
"あさいち 朝市 朝一"
"あさいと 麻絲 麻糸"
"あさえだ 朝枝 浅枝"
"あさお 朝雄 浅尾 麻生"
"あさおか 朝丘 朝岡 浅丘 麻丘"
"あさか 朝加 安積 朝霞 浅香"
"あさかぜ 朝風"
"あさかわ 浅川"
"あさが 浅賀"
"あさがえり 朝帰り"
"あさがお 蕣 朝顔"
"あさがけ 朝駆"
"あさがた 朝型 朝方"
"あさがみ 麻上"
"あさがや 阿佐々谷 阿佐ヶ谷 阿佐谷"
"あさき 麻木"
"あさきた 安佐北"
"あさぎ 浅葱"
"あさぎり 朝霧"
"あさくさ 浅草"
"あさくち 浅口"
"あさくら 麻倉 朝倉 浅倉"
"あさげ 朝餉"
"あさこ あさ子 朝子 麻子 亜抄子 浅子"
"あさご 朝来"
"あさごはん 朝ごはん"
"あさざけ 朝酒"
"あさしお 朝潮"
"あさしな 浅科"
"あさしろ 麻城"
"あさじ 浅茅 朝地"
"あさじえ 浅知恵"
"あさせ 浅瀬"
"あさだ 朝田 麻田 阿佐田 浅田"
"あさだあきら 浅田彰"
"あさだあめ 浅田飴"
"あさぢえ 浅知恵"
"あさって 明後日"
"あさづけ 浅漬"
"あさてい 朝定"
"あさと 麻人"
"あさとうちゃくぶん 朝到着分"
"あさどら 朝ドラ"
"あさぬま 浅沼"
"あさね 朝寝"
"あさねぼう 朝寝坊"
"あさの 浅野"
"あさのぶ 朝信"
"あさはか 浅はか"
"あさはら 麻原 浅原"
"あさば 浅羽"
"あさばん 朝晩"
"あさひ 朝陽 アサヒ 旭 朝日"
"あさひかせい 旭化成"
"あさひかわ 旭川"
"あさひがおか 朝日々丘 旭が丘 旭ケ丘 旭ヶ丘"
"あさひがらす 旭硝子"
"あさひがわ 旭川"
"あさひく 旭区"
"あさひこうよう 朝日航洋"
"あさひそのらま 朝日ソノラマ"
"あさひだい 旭台"
"あさひだけ 旭岳"
"あさひつうしんしゃ 旭通信社"
"あさひな 朝日奈 朝比奈"
"あさひなたかし 朝比奈隆"
"あさひまち 旭町"
"あさひや 旭屋"
"あさひる 朝昼"
"あさびん 朝便"
"あさふく 浅福"
"あさぶ 麻布 麻生"
"あさぶき 麻吹"
"あさほうそう 朝放送"
"あさま 浅間"
"あさました 浅間下"
"あさまつ 朝松"
"あさみ 亜沙美 亜左美 麻見 朝美 麻美 浅見 あさ美"
"あさみぞ 麻溝"
"あさみなみ 安佐南"
"あさみや 麻宮"
"あさむし 浅虫"
"あさめし 朝メシ 朝飯"
"あさもや 朝靄"
"あさやけ 朝焼け"
"あさやま 浅山"
"あさゆ 朝湯"
"あさゆう 朝夕"
"あさり 朝里 蜊 浅蜊 浅利 鯏"
"あされん 朝練"
"あざ 痣 字"
"あざい 浅井"
"あざな 字"
"あざぶ 麻布"
"あざみ 薊"
"あざやか 鮮か"
"あざわらい 嘲笑い"
"あし 躄 蹙 跫 蘆 脚 蹇 葦 芦 足"
"あしあと 足跡"
"あしいろ 足色"
"あしうら 足裏"
"あしお 足尾"
"あしおざん 足尾山"
"あしおと 跫 脚音 足音"
"あしおり 足折"
"あしかが 足利"
"あしかけ 足掛 足掛け"
"あしかせ 鐐 桎 足枷"
"あしかり 芦刈"
"あしかわ 芦川"
"あしがかり 足掛り 足掛かり"
"あしがた 足型"
"あしがため 足固め"
"あしがら 足柄"
"あしがらかみ 足柄上"
"あしがらしも 足柄下"
"あしがる 足軽"
"あしがわ 芦川"
"あしきた 芦北 葦北"
"あしきょう 芦響"
"あしくび 足首"
"あしげ 足蹴 芦毛"
"あしこし 脚腰 足腰"
"あしさき 足先"
"あしざわ 芦澤 芦沢"
"あしすたんと アシスタント"
"あしずり 足摺"
"あしずりみさき 足摺岬"
"あしそこ 足底"
"あしぞこばん 足底板"
"あした 朝 明日"
"あしたか 愛鷹"
"あしだ 芦田"
"あしだい 足代"
"あしつき 足付"
"あしづけ 足付"
"あしとり 足取り"
"あしどめ 足止 足止め"
"あしどり 足鳥 足取り"
"あしな 足名 芦名 芦品"
"あしなが 足長"
"あしなみ 足並み 足並"
"あしはら 蘆原 芦原"
"あしば 足場"
"あしばや 足早"
"あしひっさつわざ 足必殺技"
"あしび 馬酔木"
"あしびょうし 足拍子"
"あしぶみ 足踏 足踏み"
"あしべ 芦辺 芦部"
"あしべつ 芦別"
"あしまえ 足前"
"あしめ 走目"
"あしもと 足許 脚元 足下 足元"
"あしもり 足守"
"あしや 芦谷 芦屋"
"あしやす 芦安"
"あしゅ 亜種"
"あしゅら 阿修羅"
"あしゅらぞう 阿修羅像"
"あしゆび 趾 足指"
"あしょうさん 亜硝酸"
"あしょうさんえんのうど 亜硝酸塩濃度"
"あしょろ 足寄"
"あしろ 安代"
"あしわざ 足技"
"あしわだ 足和田"
"あじ 庵治 鰺 鯵 味"
"あじあ 亞細亞 亜細亜"
"あじおう 味皇"
"あじおか 味岡"
"あじおんち 味音痴"
"あじか 簣"
"あじから 味方"
"あじがさわ 鯵ヶ沢"
"あじがわ 安治川"
"あじきこう 味紀行"
"あじけ 味気"
"あじさい 紫陽花"
"あじさか 鯵坂"
"あじじまん 味自慢"
"あじす 阿知須"
"あじつけ 味付 味付け"
"あじとみ 安次富"
"あじな 阿品 芦品"
"あじのもと 味の素"
"あじふめい 味不明"
"あじみ 味見"
"あじむ 安心院"
"あじゃり 阿闍梨"
"あじろ 安代 網代"
"あす 明日"
"あすか 明日香 飛鳥"
"あすかい 飛鳥井"
"あすかじ 飛鳥路"
"あすけ 足助"
"あすたりすく アスタリスク"
"あすぢゅう 明日中"
"あすぱらがす アスパラガス"
"あすら 阿修羅"
"あすわ 足羽"
"あずかりきん 預かり金"
"あずかりしょう 預かり証"
"あずき 小豆"
"あずけきん 預け金"
"あずさ 梓"
"あずさがわ 梓川"
"あずち 堋 安土"
"あずま 吾嬬 吾妻 東"
"あずまふじ 東富士"
"あずまや 四阿 阿亭"
"あずみ 杏美 安住 安曇"
"あずみの 安曇野"
"あせ 阿瀬 汗"
"あせみず 汗水"
"あせり 焦り"
"あぜ 畔 畦"
"あぜりあ アゼリア"
"あぜん 唖然"
"あそ 安蘇 阿蘇 阿曽"
"あそう 麻生"
"あそうぎ 阿僧祇"
"あそさん 阿蘇山"
"あそしぇいつ アソシェイツ"
"あそしえーしょん アソシエーション"
"あそび 遊び"
"あそびごころ 遊び心"
"あそびにん 遊人"
"あそびば 遊び場"
"あそびめ 遊女 遊び女"
"あたい 値い 價 価 値"
"あたいていぎ 値定義"
"あたいひょう 値表"
"あたいよび 値呼び"
"あたえかた 与え方"
"あたか 恰 宛"
"あたかも 宛"
"あたがわ 熱川"
"あたく 安宅"
"あたご 愛宕"
"あたっく アタック"
"あたっちめんと アタッチメント"
"あたま アタマ 頭"
"あたまいがい 頭以外"
"あたまかず 頭数"
"あたまがわ 頭側"
"あたまきん 頭金"
"あたまだし 頭出し"
"あたまわり 頭割り"
"あたみ 熱海"
"あたらし 新子"
"あたり 当たり 邉 邊 辺り 当り 辺"
"あたりやく 当役"
"あたる 中 鼎"
"あだ 讐 讎 徒 仇"
"あだい 亜大"
"あだうち 仇討 仇討ち"
"あだしの 化野"
"あだたら 安達太良"
"あだたらこうげん 安達良高原"
"あだたらやま 阿達太良山"
"あだち 足達 安達 足立"
"あだっきゅう 亜脱臼"
"あだな 渾名 綽名 仇名"
"あだばな 徒花"
"あち 窪地 阿智 閼"
"あちわ 阿知波"
"あっか 悪貨 悪化"
"あっかい 圧潰"
"あっかく 圧覚"
"あっかん 圧巻 悪漢"
"あっかんども 悪漢共"
"あっき 悪鬼"
"あっけ 呆気"
"あっけし 厚岸"
"あっこう 悪口"
"あっさく 圧搾"
"あっさつ 圧殺"
"あっさぶ 厚沢部"
"あっし 圧死"
"あっしゅく 圧縮"
"あっしょう 圧勝"
"あっせい 圧制 圧政"
"あっせつ 圧雪"
"あっせつしゃ 圧雪車"
"あっせん 斡旋"
"あっそう 圧送"
"あっちゃく 圧着"
"あっつう 圧痛"
"あっと ＠"
"あっとう 圧到 圧倒"
"あっとこ 厚床"
"あっぱい 圧排"
"あっぱく 圧迫"
"あっぱれ 遖 天晴れ 天晴"
"あっぴ 安比"
"あっぷ アップ"
"あっぷく 圧服"
"あっぷる アップル"
"あつ 閼 遏 軋 乢 壓 淳 熱 惇 暑 敦 篤 厚 斡 圧"
"あつあつ 熱々"
"あついた 圧板"
"あつえん 圧延"
"あつお 厚雄 敦夫 淳夫"
"あつかい 扱い"
"あつかいさき 扱先"
"あつかいだか 扱い高"
"あつかいてん 扱店"
"あつかん 熱燗 熱澗"
"あつがま 厚釜"
"あつがみ 厚紙"
"あつぎ 厚着 厚木"
"あつぎしつまだ 厚木市妻田"
"あつぎり 厚切り"
"あつけし 厚岸"
"あつげしょう 厚化粧"
"あつこ 惇子 亜都子 篤子 淳子 厚子 敦子 あつ子 温子"
"あつさ 厚さ 暑さ"
"あつし 淳史 篤司 敦志 敦司 篤史 敦史 厚 篤 充史 淳 厚志 敦 篤志"
"あつじ 厚地"
"あつた 熱田 厚田"
"あつたか 篤孝"
"あつつぐ 淳嗣"
"あつで 厚手"
"あつでん 圧電"
"あつでんざい 圧電材"
"あつでんたい 圧電体"
"あつにゅう 圧入"
"あつぬり 厚塗"
"あつのぶ 篤信"
"あつひこ 敦彦 篤彦 淳彦"
"あつひと 厚人"
"あつひろ 敦弘 淳裕 厚宏"
"あつへいこお 圧平衡"
"あつま 厚真"
"あつまり 集り 集まり"
"あつみ 厚み 温海 厚見 厚味 淳美 渥美"
"あつめ 厚目"
"あつもの 羹"
"あつもり 敦盛"
"あつや 篤哉"
"あつゆき 敦之 淳之 篤幸"
"あつりょく 壓力 圧力"
"あつりょくがま 圧力釜"
"あつりょくけい 圧力計"
"あつりょくなべ 圧力鍋"
"あつりょくは 圧力波"
"あつれき 軋轢"
"あつろう 淳良"
"あづかりきん 預かり金"
"あづち 安土"
"あづま 東 吾妻 我妻"
"あづまや 東谷"
"あて 宛"
"あてさき 宛て先 宛先"
"あてさきじゅん 宛先順"
"あてじ あて字 宛字"
"あてつ 阿哲"
"あてな 宛て名 宛名"
"あてね 雅典"
"あてみ 当て身"
"あてらざわ 左沢"
"あで 艶"
"あと 踪 蹟 痕 跡 後"
"あとあし 後足"
"あとあじ 後味"
"あとあと 後々"
"あといっこ 後一個"
"あといっぽ 後一歩"
"あとう 阿東"
"あとうだ 阿刀田"
"あとおい 後追"
"あとおし 後押し"
"あとかいぎ 後会議"
"あとかた 跡かた 跡形"
"あとかたづけ 後片付 後かたづけ"
"あとがき 後書"
"あとがま 後釜"
"あときん 後金"
"あとくされ 後腐れ"
"あとくち 後口"
"あとこうてい 後工程"
"あとさき 後先"
"あとざん 後産"
"あとしまつ 後始末"
"あとしょり 後処理"
"あとすうねん 後数年"
"あとち 跡地"
"あとつぎ 跡継ぎ"
"あとのり 後ノリ"
"あとばらい 後払い"
"あとばんぐみ 後番組"
"あとべ 跡部"
"あとまわし 後回し"
"あとみ 跡見"
"あとみや 後宮"
"あともどり 後戻り"
"あとやく 後厄"
"あとりえ アトリエ"
"あど 亜土"
"あどがわ 安雲川 安曇川"
"あどばいす アドバイス"
"あどほっく アドホック"
"あどれす アドレス"
"あどれなりん アドレナリン"
"あな 孔 坑 穴"
"あない 穴井"
"あなうま 穴馬"
"あなうめ 穴埋め"
"あなうんさ アナウンサ"
"あなうんさー アナウンサー"
"あなうんす アナウンス"
"あながち 強ち"
"あながわ 穴川"
"あなぐま 穴熊"
"あなぐら 穴蔵"
"あなご 穴子"
"あなし 阿梨"
"あなた 貴女 貴方"
"あなだ 穴田"
"あなとう 穴党"
"あなにんき 穴人気"
"あなば 穴馬 穴場"
"あなぶき 穴吹"
"あなほり 穴堀り"
"あなみず 穴水"
"あなやま 穴山"
"あなよそう 穴予想"
"あなろぐ アナログ"
"あなろじー アナロジー"
"あなん 阿南"
"あに 阿仁 豈 兄"
"あにうえ 兄上"
"あにき 兄貴"
"あにでし 兄弟子"
"あにめ アニメ"
"あにめーしょん アニメーション"
"あにや 安仁屋"
"あによめ 嫂 兄嫁"
"あね 姐 姉"
"あねがさき 姉ヶ崎"
"あねき 姉貴"
"あねご 姉御 姐御"
"あねさき 姉崎"
"あねざき 姉崎"
"あねったい 亜熱帯"
"あのう 穴太 安濃"
"あのくたら 阿耨多羅"
"あのこ あの娘"
"あはなち 畔放"
"あば 阿波"
"あばしり 網走"
"あばしりこ 網走湖"
"あばら 肋"
"あばらぼね 肋骨"
"あばれんぼう 暴れん坊"
"あぱーと アパート"
"あぱれる アパレル"
"あひかけ 足腰"
"あひる 阿比留 鶩 家鴨"
"あび 阿鼻"
"あびーむ アビーム"
"あびこ 安彦 我孫子"
"あびせたおし 浴びせ倒し"
"あびる 阿比留"
"あぴーる アピール"
"あぴお アピオ"
"あふ 押 凹"
"あふりか 阿弗利加"
"あふりかぞう アフリカ象"
"あぶ 阿武 虻"
"あぶくま 阿武隈"
"あぶくまがわていぼう 阿武隈川堤防"
"あぶすとらくしょん アブストラクション"
"あぶすとらくと アブストラクト"
"あぶた 虻田"
"あぶみ 鐙"
"あぶら 脂 油"
"あぶらあげ 油揚"
"あぶらあせ 油汗"
"あぶらえ 油絵"
"あぶらかわ 油川"
"あぶらげ 油揚"
"あぶらぜみ 油蝉"
"あぶらつぼ 油壷"
"あぶらな 薹"
"あぶらなか アブラナ科"
"あぶらひ 油日"
"あぶらぶん 油分"
"あぶらみ 油身 脂身"
"あぶらむし 蜚"
"あぶらや 油屋"
"あぷろーち アプローチ"
"あへん 阿片"
"あべ 阿倍 安倍 安部 阿部"
"あべかわ 安倍川"
"あべた 安部田"
"あべっく アベック"
"あべの 阿部野 阿倍野"
"あべれーじ アベレージ"
"あほ アホ 阿呆"
"あほう 阿房 阿呆"
"あほうどり 信天翁"
"あぼ 英保 安保"
"あぼう 安房"
"あぼし 網干"
"あま 海士 蜑 塰 海女 亜麻 海人 雨 尼 天 甘"
"あまあし 雨足"
"あまいけ 雨池 天池"
"あまいた 天板"
"あまえ 甘え"
"あまえび 甘海老 甘エビ 甘えび"
"あまお 雨尾"
"あまおと 雨音"
"あまかす 甘粕"
"あまかぜ 雨風"
"あまがい 雨海 天海"
"あまがえる 雨蛙"
"あまがさ 雨傘 雨ガサ 雨がさ"
"あまがさき 尼崎"
"あまがせ 天瀬 天ケ瀬"
"あまき 天木"
"あまぎ 亜麻木 甘木 天城"
"あまくさ 天草"
"あまくだり 天下り"
"あまくち 甘口"
"あまくぼ 天久保"
"あまぐ 雨具"
"あまぐも 雨雲"
"あまぐり 甘栗"
"あまこ 尼子"
"あまごい 雨乞い"
"あまさ 甘さ"
"あまざけ 甘酒"
"あまし 蔗"
"あまた 数多 天田"
"あまだ 天田"
"あまだれ 雨だれ"
"あまち 天池 天地"
"あまちゅあ アマチュア"
"あまつ 天津"
"あまつかぜ 天津風"
"あまつかみ 天津神"
"あまつくに 天津国"
"あまつじ 天辻"
"あまつつみ 天津罪"
"あまつぶ 雨粒"
"あまづ 天津"
"あまでら 尼寺"
"あまとう 甘党"
"あまど 雨戸"
"あまどり 天鳥"
"あまどりのみこと 天鳥命"
"あまなっとう 甘納豆"
"あまなつ 甘夏"
"あまぬま 天沼"
"あまね 周"
"あまの 雨野 天野"
"あまのいわと 天の磐戸"
"あまのがわ 天の河"
"あまのじゃく 天の邪鬼 天邪鬼"
"あまのはしだて 天橋立 天の橋立"
"あまべ 海部"
"あまみ 甘味 奄美"
"あまみず 雨水"
"あまみや 天宮 雨宮"
"あまもと 天本"
"あまもよい 雨催"
"あまもり 雨森 雨漏 雨漏り"
"あまやどり 雨宿り"
"あまり 余り 甘利"
"あまるべ 余部 餘部"
"あまるめ 余目"
"あまんざ 甘座"
"あみ 罔 网 阿見 亜美 網"
"あみうち 網打ち"
"あみえ 網江"
"あみかけ 網掛け 網掛 網かけ"
"あみき 編み機"
"あみこ 安見子"
"あみしま 網島"
"あみじょう 網状"
"あみせいぎょ 網制御"
"あみせつぞく 網接続"
"あみたいつ 網タイツ"
"あみだ 阿弥陀"
"あみだな 網棚"
"あみだぶつ 阿弥陀仏"
"あみど 網戸"
"あみなか 網中"
"あみの 網野"
"あみのさん アミノ酸"
"あみのめ 網の目"
"あみはま 網浜"
"あみはり 網張"
"あみぼし 網干"
"あみめ 編目 網目"
"あみもの 編物"
"あみや 網屋"
"あみやき 網焼"
"あみわたり 網渡"
"あむろ 安室"
"あめ 天 飴 雨"
"あめあがり 雨上がり"
"あめあられ 雨霰"
"あめいろ 飴色"
"あめおとこ 雨男"
"あめおんな 雨女"
"あめかぜ 雨風"
"あめたいさく 雨対策"
"あめだま 飴玉"
"あめつゆ 雨露"
"あめのもり 雨森"
"あめふり 雨降り 雨ふり"
"あめふりょうばば 雨不良馬場"
"あめみや 雨宮"
"あめもよう 雨模様"
"あめよこ アメ横"
"あめよほう 雨予報"
"あめりか 米 亞米利加 亜米利加 アメリカ"
"あめりかん アメリカン"
"あもい 厦門 廈門"
"あもく 亜目"
"あもん 亜門"
"あや 亜弥 亜矢 禮 彪 亜也 礼 彩 絢 綾 文"
"あやうた 綾歌"
"あやか 彩香 綾香"
"あやかみ 綾上"
"あやがみ 綾上"
"あやぎく 綾菊"
"あやぎぬ 綺"
"あやこ 操子 章子 文子 亜弥子 絢子 亜也子 綾子 彩子 亜矢子"
"あやし 愛子"
"あやしろ 綾城"
"あやせ 綾世 綾瀬"
"あやせま 綾瀬間"
"あやつか 綾塚"
"あやつじ 綾辻"
"あやつり 操"
"あやつりにんぎょう 操人形"
"あやとも 文友"
"あやね 綾音"
"あやの 綾野 綾乃"
"あやのこうじ 綾小路"
"あやのみや 礼宮"
"あやはな 彩花"
"あやふみ 礼史"
"あやべ 綾部"
"あやべししゅっしん 綾部市出身"
"あやま 阿山"
"あやまち 誤ち 過ち"
"あやまり 誤り"
"あやめ 文目"
"あやめいけ あやめ池"
"あやめか アヤメ科"
"あやめもく アヤメ目"
"あゆ 阿諛 鮎"
"あゆかわ 鮎川"
"あゆこ 亜佑子"
"あゆさわ 鮎澤"
"あゆざわ 鮎澤"
"あゆつり 鮎釣り"
"あゆづり 鮎釣り"
"あゆみ アユミ 亜弓 歩美 歩 歩み 亜由美 彩友美"
"あゆむ 渉"
"あら 新 荒"
"あらい 新井 新居 荒井"
"あらいじゅく 新井宿"
"あらいそ 荒磯"
"あらいだし 洗い出し"
"あらいど 荒井戸"
"あらいもの 洗い物"
"あらいわ 荒岩"
"あらお 荒生 荒尾"
"あらかじめ 豫め 豫 予 予め"
"あらかると アラカルト"
"あらかわ 荒川"
"あらかわおき 荒川沖"
"あらがき 荒書き 新垣"
"あらがね 荒金"
"あらき 荒木"
"あらきの 新木野"
"あらくれ 荒くれ"
"あらけ 有明"
"あらこ 荒子"
"あらごと 荒事"
"あらごなし 荒ごなし"
"あらさき 荒崎"
"あらさわ 荒沢 荒澤"
"あらし 嵐"
"あらしがおか 嵐ヶ丘"
"あらしね 荒稲"
"あらしやま 嵐山"
"あらすじ 粗筋"
"あらず 韮 韲 齏 韭"
"あらぜき 荒関"
"あらそい 争い"
"あらた 新田 新た 新"
"あらたけ 荒武"
"あらたに 新たに 荒谷"
"あらたま 新田間"
"あらて 新手"
"あらなみ 荒波"
"あらの 荒野"
"あらはた 荒畑"
"あらはま 荒浜"
"あらひとがみ 現人神"
"あらびあ 亞剌比亞"
"あらびあせきゆ アラビア石油"
"あらびき 粗引き"
"あらふか 荒深"
"あらふね 荒船"
"あらまき 新巻 荒牧 荒巻"
"あらまた 荒俣"
"あらまち 荒町"
"あらまつ 荒松"
"あらむしゃ 荒武者"
"あらめ 荒目"
"あらもと 荒本"
"あらものや 荒物屋"
"あらや 新谷 新屋"
"あらゆる 凡"
"あらり 粗利"
"あらりえき 粗利益"
"あらりょうじ 荒療治"
"あらりょうち 荒療治"
"あられ 霰"
"あらわ 表 現"
"あらわざ 荒業 荒技"
"あらわしかた 表し方"
"あらん 亜欄 亜蘭"
"あり 袵 衽 阿梨 蟻 有"
"ありあけ 有明"
"ありあけかい 有明海"
"ありあけころしあむ 有明コロシアム"
"ありあわせ 有り合わせ"
"ありえ 有家"
"ありか 在処 亜里香"
"ありかた 有り方 あり方"
"ありかべ 有壁"
"ありかわ 有川"
"ありが 有賀"
"ありがたみ 有難味 ありがた味"
"ありがとう 有難う 有り難う"
"ありき 有木"
"ありくい 食蟻獣"
"ありくら 有倉"
"ありさ 亜利沙 亜理佐 アリサ 亜里沙"
"ありさか 有坂"
"ありさま 有り様 有様"
"ありさわ 有沢 有澤"
"ありざ 有座"
"ありしゃかい 蟻社会"
"ありじごく 蟻地獄"
"ありす 有栖"
"ありた 有田"
"ありたま 有玉"
"ありだ 有田"
"ありつぎ 有次"
"ありつね 有恒"
"ありづか 蟻塚"
"ありてい 有態 有体"
"ありとう 有藤"
"ありとも 有朋"
"ありなが 有永"
"ありのとうぐさもく アリノトウグサ目"
"ありはた 有畠"
"ありはら 有原"
"ありま 有馬"
"ありまぐち 有馬口"
"ありまさ 有正"
"ありみ 有里巳"
"ありむら 有村"
"ありもと 有本"
"ありもり 有森"
"ありや 有家"
"ありやま 有山"
"ありゅう 亜流"
"ありゅうさん 亜硫酸"
"ありよし 有吉"
"ある 亜留 或"
"あるいは 或は"
"あるかり アルカリ"
"あるが 有賀"
"あるきかた 歩き方"
"あるこーる アルコール"
"あるごん アルゴン"
"あるしゅ 或る種"
"あるじ 主"
"あるぜんちん 亞爾然丁"
"あるたみらどうくつ アルタミラ洞窟"
"あるばいと アルバイト"
"あるばむ アルバム"
"あるふぁ α"
"あるふぁせん α線"
"あるふぁは α波"
"あるふぁべっと アルファベット"
"あるふぃー アルフィー"
"あるぷすでんき アルプス電気"
"あるぺん アルペン"
"あるまいと アルマイト"
"あるみ アルミ"
"あるみにうむ アルミニウム"
"あれち 荒れ地 荒地"
"あれるぎ アレルギ"
"あれんじ アレンジ"
"あわ 慌 安房 阿波 粟 泡"
"あわこうぞう 泡構造"
"あわさ 粟佐"
"あわさか 泡坂"
"あわじ 淡路"
"あわじしま 淡路島"
"あわず 粟津"
"あわせ 袷"
"あわせいれつ 泡整列"
"あわせわざ 合わせ技"
"あわた 粟田"
"あわたてき 泡立て器"
"あわだち 泡立"
"あわだてき 泡立て器"
"あわつ 粟津"
"あわづ 粟津"
"あわづはら 粟津原"
"あわの 粟野 阿波野"
"あわばこ 泡箱"
"あわび 鰒 蚫 鮑"
"あわもり 泡盛"
"あわや 粟谷 粟屋 淡谷"
"あわゆき 淡雪"
"あわら 芦原"
"あわれむ 恤れむ"
"あん 黯 鮟 餡 閼 諳 菴 晏 罨 行 按 庵 杏 闇 鞍 安 暗 案"
"あんい 安易"
"あんいつ 安佚 安逸"
"あんうつ 暗鬱"
"あんうん 暗雲"
"あんえい 暗影"
"あんか 行火 安価"
"あんかん 安閑 暗槓"
"あんがい 案外"
"あんき 暗鬼 暗記"
"あんきょ 暗渠 安居"
"あんぎゃ 行脚"
"あんぐう 行宮"
"あんけーと アンケート"
"あんけん 案件"
"あんこ 暗刻"
"あんこーる アンコール"
"あんこう 鱇 鮟 安康 鮟鱇"
"あんこうなべ 鮟鱇鍋"
"あんこく 暗黒"
"あんこくじ 安国寺"
"あんご 安吾"
"あんごう 暗合 暗号"
"あんごうちょう 暗号帳"
"あんさつ 暗殺"
"あんざい 安齋 安齊 安在 安斉 安斎 安西"
"あんざん 暗算 安産"
"あんざんがん 安山岩"
"あんし 暗視"
"あんしつ 暗室"
"あんしゅつ 案出"
"あんしょう 諳誦 暗誦 暗唱 暗礁 暗証"
"あんしん 安心"
"あんじ 暗示"
"あんじゅ 杏樹"
"あんじゅう 安住"
"あんじょう 鞍上 安生 安城"
"あんじんりゅうみょう 安心立命"
"あんじんりょうみょう 安心立命"
"あんず 杏子 杏"
"あんせい 安政 安静"
"あんせきしょく 暗赤色"
"あんぜん 暗然 安全"
"あんぜんぐつ 安全靴"
"あんぜんとう 安全燈"
"あんぜんぱい 安全牌"
"あんそうおん 暗騒音"
"あんそく 安息"
"あんそくこうさん 安息香酸"
"あんたい 安泰"
"あんたく 安宅"
"あんたん 暗澹"
"あんだ 安打"
"あんだー アンダー"
"あんち 安地 庵地 安置"
"あんちゃく 安着"
"あんちゅう 闇中 暗中"
"あんちょく 安直"
"あんちょくか 安直過"
"あんちん 安珍"
"あんてい 安定"
"あんてな アンテナ"
"あんてん 暗転 鞍点"
"あんでんりゅう 暗電流"
"あんとう 暗闘 安東"
"あんとく 安徳"
"あんど 安堵"
"あんどう 安東 安藤"
"あんどく 暗読"
"あんどん 闇鈍 行燈 行灯"
"あんな 杏奈 アンナ"
"あんない 案内"
"あんないじょ 案内所"
"あんないばん 案内板"
"あんなか 安中"
"あんに 暗に"
"あんにん 杏仁"
"あんねい 安寧"
"あんねん 安念"
"あんの 安野 庵野"
"あんのじょう 案の上 案の定"
"あんのん 安穏"
"あんばい 塩梅 案配 按排"
"あんばらんす アンバランス"
"あんぱち 安八"
"あんひつ 安謐"
"あんぴ 安否"
"あんぶ 暗部 鞍部"
"あんぶん 案分 案文 按分"
"あんぷ 暗譜"
"あんぺあ アンペア"
"あんぼれらか アンボレラ科"
"あんぽ 安保"
"あんぽう 罨法"
"あんぽり 安保理"
"あんま 按摩"
"あんまく 暗幕"
"あんみん 安眠"
"あんもく 暗黙"
"あんもち 餡餅"
"あんもにあ アンモニア"
"あんや 暗夜"
"あんやく 暗躍"
"あんゆ 暗喩"
"あんらく 安楽"
"あんらくし 安楽死"
"あんり 杏里"
"あんろくざん 安禄山"
"い 揖 鮪 斐 胆 詑 莞 堰 蔚 矮 猗 忌 鰄 饐 頤 鑄 醫 逶 貽 詒 苡 肄 矣 痿 痍 爲 熨 渭 洟 懿 恚 怡 彜 彝 幃 帷 已 姨 圍 囗 噫 僞 倚 射 五 韋 鋳 偽 ゐ 夷 尉 威 惟 依 緯 猪 慰 畏 椅 以 易 囲 維 如 委 萎 唯 居 移 謂 亥 伊 衣 違 医 遺 偉 為 胃 異 彙 意 井 位"
"いーすと ＥＡＳＴ"
"いあ 依阿"
"いあい 居合"
"いあく 帷幄"
"いあつ 威壓 威圧"
"いあん 慰安"
"いあんじょ 慰安所"
"いあんふ 慰安婦"
"いい 猪井 依違 依倚 依依 井伊 謂 伊井 猪 飯"
"いいあい 言い合い"
"いいあらそい 言い争い"
"いいうり 言売"
"いいおか 飯岡"
"いいかげん いい加減"
"いいかた 言い方"
"いいくら 飯倉"
"いいぐさ 言い草"
"いいさか 飯坂"
"いいざか 飯坂"
"いいざわ 飯沢"
"いいし 飯石"
"いいじま 飯嶋 飯島"
"いいずか 飯塚"
"いいたか 飯高"
"いいたがわ 飯田川"
"いいたて 飯館"
"いいだ 飯田"
"いいだか 飯高"
"いいだしっぺ 言い出しっぺ"
"いいつたえ 言い伝え"
"いいづか 飯塚"
"いいづな 飯綱"
"いいで 飯豊"
"いいなずけ 許嫁"
"いいなん 飯南"
"いいぬま 飯沼"
"いいね 言い値"
"いいの 飯野"
"いいはま 飯浜"
"いいはん 一翻"
"いいぶん 言い分"
"いいぼし 飯干"
"いいま 飯間"
"いいまわし 言い回し"
"いいむら 飯村"
"いいもり 飯盛 飯森"
"いいやま 飯山"
"いいわけ 言訳 言い訳"
"いいん 医院 委員"
"いいんかいあん 委員会案"
"いいんちょうあて 委員長宛"
"いうち 井内"
"いうら 井浦"
"いぇん 円 ￥"
"いえ 伊江 彌 家"
"いえい 遺影"
"いえいえ 家々"
"いえいがい 家以外"
"いえがた 家型"
"いえがら 家柄"
"いえき 胃液"
"いえしま 家島"
"いえじ 家路"
"いえじゅう 家中"
"いえだ 家田"
"いえつき 家付"
"いえで 家出"
"いえども 雖"
"いえなが 家永"
"いえなみ 家並み"
"いえふきん 家付近"
"いえみつ 家光"
"いえもち 家茂"
"いえもと 家元"
"いえやす 家康"
"いえやま 家山"
"いえらいしゃん 夜来香"
"いえろー イエロー"
"いえん 以遠 胃炎"
"いおう 硫 硫黄"
"いおうしゅう 硫黄臭"
"いおうじま 硫黄島 伊王島"
"いおか 井岡"
"いおち 庵地"
"いおの 魚野"
"いおり 菴 庵 伊織"
"いおん 異音 イオン"
"いか イカ 位下 伊香 烏賊 異化 ≦ 如何 医科 以下"
"いかい 伊貝 猪飼 異界 位階"
"いかいよう 胃かいよう 胃潰瘍"
"いかが 如何"
"いかく 威赫 居角 威嚇"
"いかけ 鋳掛"
"いかざき 五十崎"
"いかずち 雷 霹 霆"
"いかた 伊方"
"いかだ 筏"
"いかだい 筏井"
"いかづち 雷"
"いかてん イカ天"
"いかなる 如何なる"
"いかひか 異花被花"
"いかほ 伊香保"
"いかむけ 医家向け"
"いからし 五十嵐"
"いかり 怒 碇 錨 怒り"
"いかりがせき 碇ヶ関"
"いかりど 錨戸"
"いかりゃく 以下略"
"いかる 鵤"
"いかるが 斑鳩"
"いかわ 居川 井河 井川"
"いかわだに 伊川谷"
"いかん 医官 衣冠 偉観 遺憾 遺感 如何 移管"
"いかんそく 維管束"
"いかんそくたい 衣冠束帯"
"いが 伊賀"
"いがい 遺骸 意外 以外"
"いがうえ 伊賀上"
"いがく 医学部 医学"
"いがぐり 毬栗"
"いがぐりあたま 毬栗頭"
"いがさてつどう 井笠鉄道"
"いがた 鎔 范 井形 鋳型"
"いがっか 医学科"
"いがみ 井上"
"いがや 井ヶ谷"
"いがらぎけんかつたし 茨城県勝田市"
"いがらし 五十嵐"
"いがり 猪狩"
"いがわ 居川 井川"
"いがん 胃癌 依願"
"いき 行 行き 粹 委棄 壱岐 生 遺棄 閾 囲気 粋 意気 域 息"
"いきあたりばったり 行き当たりばったり"
"いきいき イキイキ 生き生き"
"いきうま 生き馬"
"いきうめ 生き埋め"
"いきえ 生き餌"
"いきおい 勢い"
"いきかた 生き方"
"いきかん 異機間"
"いきがい 生き甲斐 域外 生きがい"
"いきがみ 生き神"
"いきき 一箕 往き来 行き来"
"いきぎも 生き肝"
"いきぎれ 息切れ"
"いきごみ 意気ごみ"
"いきさき 行先"
"いきさつ 経緯"
"いきさわ 生澤"
"いきざま 生き様"
"いきじごく 生き地獄"
"いきじびき 生き字引"
"いきす 伊岐須"
"いきち 生き血 生血 域値 閾値"
"いきつき 生月"
"いきつぎ 息継ぎ"
"いきづかい 息遣い"
"いきな 生名"
"いきない 域内"
"いきぬき 息抜き"
"いきのこり 生き残り"
"いきのね 息の根"
"いきはじ 生き恥"
"いきぼとけ 生き仏"
"いきもの 生物 生き物"
"いきょ 依拠"
"いきょう 井京 異郷 異教 異境"
"いきょく 異曲 医局"
"いきりょう 生き霊 生霊"
"いぎ 猪木 異義 威儀 異議 意義"
"いぎあり 異議有り"
"いぎす 伊岐須"
"いぎょう 医業 遺業 異形 偉業"
"いぎりす 英吉利 イギリス"
"いく 粥 鬻 礇 燠 毓 幾 育 郁"
"いくいっぷめんと イクイップメント"
"いくいな 生稲"
"いくえ 幾重 育江 郁恵"
"いくえい 育英"
"いくお 郁生 幾夫 郁夫 幾雄 育男 郁雄"
"いくこ 幾久子 郁久子 育子 以玖子 郁子"
"いくさ 戰 戦"
"いくさか 生坂"
"いくさち 生幸"
"いくしま 生島"
"いくしゅ 育種"
"いくしゅるい 幾種類"
"いくじ 意気地 育児"
"いくじひ 育児費"
"いくすじ 幾筋"
"いくせい 育成"
"いくせいそう 幾星霜"
"いくせん 幾千"
"いくそう 幾層"
"いくぞう 郁三 幾三"
"いくた 幾多 生田"
"いくたさい 生田祭"
"いくたはら 生田原"
"いくたび 幾度"
"いくつ 幾つ"
"いくつか 幾つか"
"いくつき 幾月"
"いくとしつき 幾年月"
"いくど 幾度"
"いくどうおん 異口同音"
"いくにち 幾日"
"いくにん 幾人"
"いくねん 幾年"
"いくの 生野"
"いくはら 幾原"
"いくばく 幾何 幾許"
"いくひと 生人"
"いくひろ 郁博"
"いくぶん いく分 幾分"
"いくま 伊玖磨"
"いくまん 幾万"
"いくみ 育巳"
"いくもうざい 育毛剤"
"いくや 郁哉 育也"
"いくゆう 育友"
"いくよ 郁代 育代"
"いくら 伊倉 居倉 幾ら"
"いくりん 育林"
"いくん 遺訓"
"いぐ 伊具"
"いぐさ 井草 伊草"
"いぐさもく イグサ目"
"いぐすり 胃薬"
"いぐち 井口"
"いぐるみ 弑 弋"
"いぐん 威軍"
"いけ 池"
"いけい 異形 医系 異型 畏敬"
"いけいちょう 衣掛町"
"いけいのねん 畏敬の念"
"いけいよう 異形葉"
"いけうち 池内"
"いけうら 池浦"
"いけえ 池江"
"いけお 池尾"
"いけがき 生垣 生け垣"
"いけがみ 池上"
"いけがめ 池亀"
"いけがや 池ケ谷 池谷"
"いけがわ 池川"
"いけざわ 池澤 生澤 池沢"
"いけした 池下"
"いけしょうじ 池庄司"
"いけじり 池尻"
"いけす 生け簀"
"いけた 井桁"
"いけたに 池谷"
"いけだ 池田"
"いけつき 池月"
"いけつつみ 池堤"
"いけど 池戸"
"いけなが 池永"
"いけなみ 池波"
"いけにえ 犠牲 犧 生贄 牲 犠"
"いけの 池乃 池野"
"いけのうえ 池ノ上"
"いけのはた 池の端"
"いけのはたもん 池の端門"
"いけのぼう 池の坊"
"いけはぎ 生剥"
"いけはら 池原"
"いけばな 生け花"
"いけぶくろ 池袋"
"いけぶくろぐち 池袋口"
"いけぶくろほんせん 池袋線本線"
"いけべ 池辺"
"いけみず 池水"
"いけみや 池宮"
"いけもと 池本"
"いけや 池谷"
"いけやま 池山"
"いけん 異見 違憲 意見"
"いげん 威嚴 威厳"
"いこ 依怙"
"いこーる ＝"
"いこい 憩 憩い"
"いこう 遺稿 威光 偉功 移項 意向 移行 以降"
"いこうあん 移行案"
"いこうずみ 移行済"
"いこく 異国"
"いこじ 依怙地 意固地"
"いこつ 遺骨"
"いこま 生駒"
"いこん 遺恨"
"いこんじあい 遺恨試合"
"いご 伊語 囲碁 以後"
"いごう 伊号"
"いごこち 居心地"
"いさ 諌 異差 伊佐"
"いさい 異才 偉才 異彩 委細"
"いさお 勳 勲男 勇雄 勇夫 功 勲"
"いさか 井坂 伊坂"
"いさかい 諍 諍い"
"いさく 遺作"
"いさこ いさ子"
"いささか 聊か"
"いさはや 諌早"
"いさはやわん 諫早湾"
"いさはら 井佐原"
"いさみ 勇"
"いさみあし 勇足 勇み足"
"いさむ 勳 勲 勇"
"いさやま 諌山"
"いさり 漁"
"いさりび 漁火"
"いさわ 石和 井澤 井沢 伊澤 伊沢"
"いさん 違算 胃散 胃酸 遺産"
"いざかや 居酒屋"
"いざき 伊崎 井崎"
"いざなぎ 伊邪那岐 伊弉諾"
"いざなぎのみこと 伊弉諾尊 伊邪那岐命"
"いざなみ 伊邪那美 伊弉冉"
"いざよい 十六夜"
"いざわ 伊澤 井沢 伊沢"
"いし 縊死 遺址 遺志 遺思 医師 意志 意思 石"
"いしあたま 石頭"
"いしい 石井"
"いしうち 石打"
"いしおか 石岡"
"いしおざん 石尾山"
"いしかべ 石壁"
"いしかめ 石亀"
"いしかり 石狩"
"いしかわ 石河 石川"
"いしかわじま 石川島"
"いしがき 石垣"
"いしがきじま 石垣島"
"いしがね 石金"
"いしがみ 石上 石神"
"いしがめ 石亀"
"いしき 伊敷 意識"
"いしくに 石國"
"いしくら 石倉"
"いしぐみ 石組み"
"いしぐろ 石黒"
"いしぐろけん 石黒賢"
"いしげ 石下 石毛"
"いしこし 石越"
"いしごう 石郷"
"いしごおり 石氷"
"いしざか 石坂"
"いしざき 石崎"
"いしざわ 石沢 石澤"
"いしした 石下"
"いしじま 石嶋 石島"
"いしずえ 礎"
"いしずか 石塚"
"いしずけ 石附"
"いしそね 石曽根"
"いしだ 石田"
"いしだたみ 甃 石畳"
"いしだりゅう 石田流"
"いしだん 石段"
"いしつ 遺失 異質"
"いしつか 石塚"
"いしづえ 礎"
"いしづか 石塚"
"いしづき 鐓"
"いしづくり 石造り"
"いしづけ 石附"
"いしとうろう 石燈篭"
"いしとび 石飛"
"いしどう 石堂"
"いしどりや 石鳥谷"
"いしなべ 石鍋"
"いしぬき 石貫"
"いしの 石野"
"いしのまき 石巻"
"いしのもり 石之森"
"いしはた 石畑"
"いしはま 石浜"
"いしはら 石原"
"いしはり 石播"
"いしば 石場"
"いしばし 石橋"
"いしぶみ 碑"
"いしべ 石部 石辺"
"いしま 石間"
"いしまき 石巻"
"いしまつ 石松"
"いしまる 石丸"
"いしみ 石見"
"いしみつ 石光"
"いしみね 石嶺"
"いしむら 石村"
"いしむれ 石牟礼"
"いしもた 石母田"
"いしもだ 石母田"
"いしもと 石元 石本"
"いしもり 石森"
"いしゃ 慰謝 医者"
"いしゃやく 医者役"
"いしや 石屋"
"いしやかわしゃこ 石屋川車庫"
"いしやき 石焼"
"いしやま 石山"
"いしやまざか 石山坂"
"いしやまでら 石山寺"
"いしゅ 異株 意趣 射手 異種"
"いしゅう 蝟集 異臭"
"いしゅかくとうぎせん 異種格闘技戦"
"いしゅく 蝟縮 畏縮 委縮 萎縮"
"いしゅつ 移出"
"いしゆみ 弩"
"いしょ 医書 遺書"
"いしょう 異称 意匠 衣装 衣裳"
"いしょうがえ 衣装替"
"いしょく 依嘱 衣食 異色 委嘱 移植"
"いしょくさく 異色作"
"いしょくじゅう 衣食住"
"いしょけんめい 一所懸命"
"いしわおんせん 石和温泉"
"いしわた 石渡 石綿"
"いしわたり 石渡"
"いしわら 石原"
"いしん 以深 維新 威信"
"いしんでんしん 以心伝心"
"いしんりき 維新力"
"いじ 依恃 依次 医事 遺児 意地 維持"
"いじち 伊地知"
"いじひ 維持費"
"いじゅう 移住"
"いじゅういん 伊集院"
"いじゅうけん 居住権"
"いじゅつ 医術"
"いじょう 移譲 移乗 異状 委譲 ≧ 異常 以上"
"いじょく 居職"
"いじら 伊自良"
"いじり 井尻"
"いじるし 井印"
"いじわる 意地悪"
"いじん 偉人 異人"
"いじんでん 偉人伝"
"いす 椅子"
"いすう 異数 位数"
"いすけ 伊介"
"いすず いすゞ"
"いすずがわ 五十鈴川"
"いすせき 椅子席"
"いすみ 夷隅"
"いすみぐんし 夷隅郡市"
"いず 伊津 伊豆"
"いずきゅう 伊豆急"
"いずくんぞ 焉"
"いずこ 何処"
"いずし 出石"
"いずしま 出島"
"いずた 泉田"
"いずつ 井筒"
"いずぬま 伊豆沼"
"いずまい 居ずまい"
"いずみ 偉津美 湶 五住 出水 和泉 泉"
"いずみおおつ 泉大津"
"いずみかわ 泉川"
"いずみがおか 泉ヶ丘"
"いずみがたけ 泉ヶ岳"
"いずみく 泉区"
"いずみさき 泉崎"
"いずみさの 泉佐野"
"いずみたに 泉谷"
"いずみだ 泉田"
"いずみちゅうおう 泉中央"
"いずみや イズミヤ 泉谷"
"いずも 出雲"
"いずもざき 出雲崎"
"いずものくに 出雲国"
"いずれ 何れ"
"いせ 伊勢"
"いせい 威勢 異星 以西 異性"
"いせいけん 遺生研"
"いせいしゃ 為政者"
"いせおきつ 伊勢奥津"
"いせき 井関 遺跡 移籍"
"いせきせつ 移籍説"
"いせきばなし 移籍話"
"いせさき 伊勢崎"
"いせざきいき 伊勢崎行"
"いせざきかん 伊勢崎間"
"いせざきせん 伊勢佐木線 伊勢崎線"
"いせざきちょう 伊勢崎町"
"いせざきほんせん 伊勢崎本線"
"いせたん 伊勢丹"
"いせだ 伊勢田"
"いせつ 異説 移設"
"いせはら 伊勢原"
"いせり 井芹"
"いせわん 伊勢湾"
"いせん 以浅 伊仙 緯線"
"いぜな 伊是名"
"いぜん 依然 以前"
"いそ 五十 磯"
"いそう 移相 位相 移送"
"いそうかく 位相角"
"いそうろう 居候"
"いそがい 磯貝"
"いそがみ 磯上"
"いそぎあし 急ぎ足"
"いそご 磯子"
"いそざお 磯竿"
"いそざき 磯崎"
"いそじまん 磯自慢"
"いそじん 磯陣"
"いそだ 磯田"
"いそていえん 磯庭園"
"いその 磯野"
"いそべ 磯辺 磯部"
"いそまつもく イソマツ目"
"いそみち 磯道"
"いそむら 磯村"
"いそや 磯谷"
"いそやま 礒山 磯山"
"いそん 依存"
"いぞう 以蔵 遺贈"
"いぞく 遺族"
"いぞり 居反り"
"いぞん 異存 依存"
"いぞんせき 依存積"
"いぞんわ 依存和"
"いた 分 至 致 板"
"いたあつ 板厚"
"いたい 板井 異体 遺体"
"いたがき 板垣"
"いたがね 鈑 板金"
"いたがみ 板紙"
"いたがらす 板硝子"
"いたきそえき 伊太祁曽駅"
"いたく 依託 委託"
"いたくら 板倉"
"いたけだか 居丈高"
"いたこ 板子 潮来"
"いたざい 板材"
"いたざき 板崎"
"いたしかた 致し方"
"いたしんどう 板振動"
"いたじき 板敷"
"いたじょう 板状"
"いたずら 徒ら 徒 悪戯"
"いたずらに 徒に"
"いただき 頂"
"いただきもの 頂き物"
"いたち 鼬"
"いたちょこ 板チョコ"
"いたづら 惡戲 悪戯"
"いたで 傷手 痛手"
"いたどり 板取"
"いたに 猪谷"
"いたの 板野"
"いたはし 板橋"
"いたばさみ 板挟み"
"いたばし 板橋"
"いたばり 板張り"
"いたひょうめん 板表面"
"いたべい 板塀"
"いたまえ 板前"
"いたみ 伊丹"
"いたみどめ 痛み止め"
"いため 板目"
"いためし イタ飯"
"いためん 板面"
"いたや 板矢 板谷"
"いたやなぎ 板柳"
"いたりー 伊太利"
"いたりあ 伊太利亜 伊太利屋"
"いたる 到 格 至"
"いたん 医療技術短期大学部 医短 異端"
"いたんし 異端視"
"いたんじ 異端児"
"いだ 委佗 伊田 井田"
"いだい 医大 偉大"
"いだいさ 偉大さ"
"いだてん 韋駄天"
"いち 依遅 壹 弌 伊知 1 １ 市 壱 位置 一"
"いちあん 一案"
"いちい 櫟 市井 一井 一位 一意"
"いちいち 一々"
"いちいん 一因 一員"
"いちう 一宇"
"いちえん 一円"
"いちおう 一応"
"いちおく 一億"
"いちおくえんきょう 一億円強"
"いちおし 一推し"
"いちおん 一音"
"いちかい 市貝"
"いちから 一から"
"いちかわ 市川"
"いちかわけおり 市川毛織"
"いちかわふさえ 市川房枝"
"いちがい 一概"
"いちがいに 一概に"
"いちがお 市ヶ尾"
"いちがくねんした 一学年下"
"いちがつ 睦月 一月 １月"
"いちがや 市谷 市ヶ谷 市ケ谷"
"いちがん 一丸 一眼"
"いちがんれふ 一眼レフ"
"いちき 市来 市來 一木"
"いちぎ 一義"
"いちぎょう １行 一行"
"いちく 移築"
"いちぐう 一隅 一遇"
"いちぐん 一軍 一群"
"いちけん 一研"
"いちげ 市毛"
"いちげい 一芸"
"いちげき 一撃"
"いちげん 一弦 一限 一元 一見 一言"
"いちこ 市子 一子"
"いちこう 一高"
"いちこし 市越"
"いちこつ 壱越"
"いちご 莓 一期 苺 一語"
"いちごいちえ 一期一会"
"いちごう 壱号 一合 一号"
"いちごん 一言"
"いちざ 一座"
"いちし 一志"
"いちしんきょう 一神教"
"いちじ 一児 伊知地 １次 １時 一字 一事 一次 一時"
"いちじく 無花果 一軸"
"いちじつせんしゅう 一日千秋"
"いちじへき 一次壁"
"いちじま 市島 市嶋"
"いちじゅう 一重"
"いちじゅん 一順 一巡"
"いちじょ 一女 一助"
"いちじょう 一畳 一城 一条"
"いちじょうじ 一乗寺 一条寺"
"いちじん 一陣"
"いちすぎ 一杉"
"いちず 一頭 一途"
"いちせ 一瀬"
"いちぞく 一族"
"いちぞん 一存"
"いちたいた 一対多"
"いちたに 市谷"
"いちたろう 市太郎"
"いちだ 一打 伊地田 市田"
"いちだい 一代 一大 一台"
"いちだん 一団 一段"
"いちだんうえ 一段上"
"いちだんした 一段下"
"いちぢ 伊知地"
"いちど 一度"
"いちどう 一堂 一同"
"いちどき 一時"
"いちどく 一読"
"いちなん 一難"
"いちに 一二"
"いちにち 一日"
"いちにちいちぜん 一日一善"
"いちにちけん 一日券"
"いちにん 一任"
"いちにんしゃ 一人者"
"いちねん 一念 一年"
"いちねんはんほどまえ 一年半程前"
"いちねんほど 一年程"
"いちの 市野"
"いちのう 一能"
"いちのき 一の樹"
"いちのぎく 市之菊 市乃菊"
"いちのくら 一ノ蔵 一ノ倉 一の倉"
"いちのせ 一の瀬 一瀬 一ノ瀬 市之瀬"
"いちのせき 一ノ関 一関"
"いちのちょう 一の町"
"いちのへ 一戸"
"いちのぼう 一の坊"
"いちのみや 一の宮 一宮 一ノ宮"
"いちのもと 檪本 櫟本"
"いちはさま 一迫"
"いちはざま 一迫"
"いちはし 市橋"
"いちはた 一畑"
"いちはやく いち早く"
"いちはら 市原"
"いちば 一馬 市場"
"いちばい 一倍"
"いちばた 一畑"
"いちばん 壱番 一番"
"いちばんいや 一番嫌"
"いちばんうえ 一番上"
"いちばんおく 一番奥"
"いちばんした 一番下"
"いちばんそこ 一番底"
"いちばんそと 一番外"
"いちばんとく 一番得"
"いちばんのり 一番乗"
"いちばんはし 一番端"
"いちばんひだり 一番左"
"いちばんみぎ 一番右"
"いちばんらく 一番楽"
"いちひめにたろう 一姫二太郎"
"いちびょう 一秒"
"いちびん 一便"
"いちぶ 一分 一部"
"いちぶりゃく 一部略"
"いちぶん 一分 一文"
"いちべつ 一別 一瞥"
"いちぼう 一望"
"いちまい 一枚"
"いちまいいた 一枚板"
"いちまいいわ 一枚岩"
"いちまいした 一枚下"
"いちまつ 市松 一抹 一松 一沫"
"いちまん 一萬 一万"
"いちまんえん 壱萬圓 壱万円"
"いちみ 一味"
"いちみゃく 一脈"
"いちむら 一村 市村"
"いちめい 一命 一名"
"いちめん 一面"
"いちもうさく 一毛作"
"いちもく 一目"
"いちもくさん 一目散"
"いちもじ １文字"
"いちもつ 一物"
"いちもん 一文 一門 一問"
"いちもんいっとう 一問一答"
"いちや 一夜"
"いちやく 一躍"
"いちやなぎ 一柳"
"いちゅう 移駐 意中"
"いちゆう 一揖"
"いちょ 遺著"
"いちょう 異聴 公孫樹 移牒 威張 銀杏 移調 胃腸"
"いちょうかん 胃腸管"
"いちょうこう イチョウ綱"
"いちょうびょう 胃腸病"
"いちょうやく 胃腸薬"
"いちよう 一葉 一様"
"いちようじゅうりょくば 一様重力場"
"いちよく 一翼"
"いちよし 市吉"
"いちらん 壹覽 一覧"
"いちらんせい 一卵性"
"いちり 一利 一里 一理"
"いちりき 一力"
"いちりつ 一率 市立 一律"
"いちりの 一里野"
"いちりゅう 一留 一流"
"いちりゅうば 一流馬"
"いちりょう 一両"
"いちりょうしゃ 一両車"
"いちりん 一輪"
"いちりんしゃ 一輪車"
"いちる 一縷"
"いちるい 一類 一塁"
"いちるいしゅ 一塁手"
"いちれい 一礼 一例"
"いちれつ 一列"
"いちれん 一蓮 一連"
"いちれんたくしょう 一蓮托生"
"いちろ 一路"
"いちろう 市郎 一朗 伊知郎 一浪 一郎"
"いちろうた 一朗太"
"いちろん 一論"
"いちわ 一話 一羽"
"いちわり 一割"
"いっ 逸"
"いっか 一過 一課 一家"
"いっかい １Ｆ 一塊 １回 一介 一階 一回"
"いっかいごと 一回毎"
"いっかいせき 一階席"
"いっかいせん 一回戦"
"いっかいてん 一回転"
"いっかく 一攫 一画 一獲 一角"
"いっかくじゅう 一角獣"
"いっかげつ 一カ月 １ヶ月 １か月 一ヶ月 一箇月"
"いっかげん 一家言"
"いっかごん 一家言"
"いっかしょ 一カ所 一ヶ所 一箇所"
"いっかつ 一喝 一括"
"いっかん 一巻 一環 一貫"
"いっき 一機 一輝 一揆 一期 一気"
"いっきいちゆう 一喜一憂"
"いっきうち 一騎打"
"いっきかせい 一気呵成"
"いっきに 一気に"
"いっきゃく 一脚"
"いっきゅう 一球 一休 一級"
"いっきょ 一挙"
"いっきょう 一興"
"いっきょく 一局 一極 一曲"
"いっきょしゅ 一挙手"
"いっきょりょうどく 一挙両得"
"いっきん 一金"
"いっく 一区 一句"
"いっけい 一景 一計"
"いっけつ 一決"
"いっけん 一軒 一件 一見"
"いっけんしき 一見識"
"いっけんや 一軒家"
"いっけんやど 一軒宿"
"いっこ 一ヶ 一戸 一顧 一個"
"いっこう 一鉤 溢口 一稿 一項 一幸 一考 一行 一向"
"いっこうしゅう 一向衆"
"いっこく 一国 一刻"
"いっこだて 一戸建て"
"いっこん 一献"
"いっさ 一茶"
"いっさい 一際 一済 一歳 一切"
"いっさく 一策 一昨 一作"
"いっさくじつ 一昨日"
"いっさつ 一冊"
"いっさんかたんそ 一酸化炭素"
"いっさんかちっそ 一酸化窒素"
"いっし 一志 逸史 一糸 一死 一指 一子 一矢"
"いっしあい 一試合"
"いっしき 一色 一式"
"いっしつ 一室"
"いっしどうじん 一視同仁"
"いっしゃ 一社"
"いっしゃせん 一車線"
"いっしゃせんり 一瀉千里"
"いっしゅ 一首 一種"
"いっしゅう 一週 一蹴 一周"
"いっしゅうかんほど 一週間程"
"いっしゅうき 一周忌"
"いっしゅうようぶん 一周要聞"
"いっしゅつ 逸出"
"いっしゅん 一瞬"
"いっしょ 一所 一緒"
"いっしょう 一笑 一章 一勝 一升 一生"
"いっしょうがい 一生涯"
"いっしょうせつ 一小節"
"いっしょうびん 一升瓶"
"いっしょく 一食 一色"
"いっしょくそくはつ 一触即発"
"いっしん 一審 一身 一心 一新"
"いっしんいったい 一進一退"
"いっしんきょう 一神教"
"いっしんとう 一親等"
"いっすい 溢水 一睡"
"いっすうか 一数花"
"いっすん 一寸"
"いっすんぼうし 一寸法師"
"いっせ 一瀬 一世"
"いっせい 一誠 一成 一生 一世 一斉"
"いっせいどう 一誠堂"
"いっせいに 一斉に"
"いっせき 一夕 一石 一席 一隻"
"いっせつ 一説 一節"
"いっせつな 一刹那"
"いっせん 一閃 一戦 一銭 一線 一千"
"いっそ 不如 一噌"
"いっそう 一掃 一層"
"いっそく 一足"
"いったい 一隊 一帯 一体"
"いったいいち 一対一"
"いったいけい 一体形"
"いったいだれ 一体誰"
"いったいなに 一体何"
"いったく 一卓"
"いったん 一たん 一反 一短 一端 一旦"
"いっち 一致"
"いっちゃく 一着"
"いっちゅうや 一昼夜"
"いっちょう 一聴 一張 一兆 一丁 一長 一朝"
"いっちょうめ １丁目"
"いっちょうら 一張羅"
"いっちょくせん 一直線"
"いっつい 一対"
"いっつう 一通"
"いっつうわ 一通話"
"いって 一手"
"いってい 一定"
"いっていかく 一定角"
"いっていがく 一定額"
"いってき 一擲 一滴"
"いってつ 一徹"
"いってん 一転 一点"
"いっと 一斗 一途"
"いっとう 一刀 一頭 一投 一党 一等"
"いっとうさい 一刀斉"
"いっとうしん 一等親"
"いっとうせい 一等星"
"いっとうそく 一投足"
"いっとうそつ 一等卒"
"いっとうへい 一等兵"
"いっとき 一時"
"いっぱ 一派"
"いっぱい 一敗 一杯"
"いっぱいほど 一杯程"
"いっぱく 一拍 一泊"
"いっぱつ 一髪 一発"
"いっぱつげい 一発芸"
"いっぱつどり 一発録り"
"いっぱん 一班 一半 一版 一般"
"いっぱんうけ 一般受け 一般受"
"いっぱんかい 一般解"
"いっぱんかく 一般角"
"いっぱんかばいあす 一般化バイアス"
"いっぱんきゃく 一般客"
"いっぱんけい 一般形"
"いっぱんざい 一般材"
"いっぱんしゃ 一般車"
"いっぱんしょく 一般職"
"いっぱんむき 一般向"
"いっぱんむけけいもうしょ 一般向啓蒙書"
"いっぱんりようしゃむき 一般利用者向"
"いっぱんろ 一般路"
"いっぴ １日"
"いっぴき 一匹"
"いっぴきおおかみ 一匹狼"
"いっぴつ 一筆"
"いっぴょう 一票"
"いっぴん 逸品 一品"
"いっぷう 一封 一風"
"いっぷく 一服"
"いっぷたさいせい 一夫多妻制"
"いっぷん 一分 １分"
"いっぷんはんていど 一分半程度"
"いっぺい 一平"
"いっぺき 一碧"
"いっぺん 一篇 一変 一片 一編 一辺 一遍"
"いっぺんとう 一辺倒"
"いっぽ 一歩"
"いっぽう 一法 一報 一方"
"いっぽうこう 一方行"
"いっぽうつうこうろ 一方通行路"
"いっぽん 一本"
"いっぽんあし 一本足"
"いっぽんさ 一本鎖"
"いっぽんすぎ 一本杉"
"いっぽんすじ 一本筋"
"いっぽんぜおい 一本背負い 一本背負"
"いっぽんだち 一本立ち"
"いっぽんまつ 一本松"
"いっぽんみち 一本道"
"いっぽんやり 一本槍"
"いつ 鴪 鎰 軼 聿 壹 佚 弌 伍 乙 壱 一 溢 逸 何時"
"いつう 胃痛"
"いつお 逸生"
"いつか 不知 五日 ５日"
"いつき 五月 五紀 樹 五木"
"いつきだ 五木田"
"いつくしま 厳島"
"いつこ 伊都子"
"いつごろ いつ頃"
"いつざい 逸材"
"いつだつ 逸脱"
"いつちょうら 一張羅"
"いつつ ５つ 五つ"
"いつつばし 五橋"
"いつはし 五橋"
"いつぶつ 逸物"
"いつみ 逸見 逸美"
"いつわ 五和 五輪 逸話"
"いづ 伊津"
"いづつ 井筒"
"いづはら 厳原 出原"
"いづぶち 出渕"
"いづれ 何れ 孰れ"
"いて 射手"
"いてき 夷狄"
"いてざ 射手座"
"いてん 移転"
"いで 出 井手 井出"
"いでおろぎー イデオロギー"
"いでぐち 井手口"
"いでさわ 出澤 出沢"
"いでみつ 出光"
"いでむら 出村"
"いでん 異伝 遺伝"
"いでんあるごりずむ 遺伝アルゴリズム"
"いでんびょう 遺伝病"
"いと 縷 絲 伊都 糸 意図"
"いとーよーかどう イトーヨーカ堂"
"いとい 糸井"
"いといがわ 糸魚川"
"いとう 依投 以東 伊東 伊藤"
"いとうちゅう 伊藤忠"
"いとうはむ 伊藤ハム"
"いとうまん 伊藤萬"
"いとが 糸賀"
"いとぐち 糸口"
"いとぐるま 糸車"
"いとこ 従姉妹 従兄弟"
"いとさき 糸崎"
"いとざき 糸崎"
"いとしま 糸島"
"いとたに 糸谷"
"いとだ 糸田"
"いとちゅう 伊藤忠"
"いとでんわ 糸電話"
"いとぬき 糸貫"
"いとのこぎり 糸鋸"
"いとま 暇"
"いとまき 糸巻"
"いとまん 糸満"
"いとめ 厭目 糸目"
"いとやま 糸山"
"いど 緯度 井戸"
"いどう 異同 異動 移動"
"いどうきゃく 移動客"
"いどうたい 移動体"
"いどうだな 移動棚"
"いどうとどけ 異動届"
"いどうはん 移動班"
"いどうひ 移動費"
"いどうもう 移動網"
"いどころ 拠所 居所"
"いどばた 井戸端"
"いな 伊南 稻 伊奈 伊那 稲 否"
"いない 稲井 以内"
"いなえ 稲枝"
"いなお 稲尾"
"いなおえき 稲生駅"
"いなおか 稲岡"
"いなか 田舎"
"いなかだて 田舎館"
"いなかみち 田舎道"
"いなかもの 田舎者"
"いなかわ 稲川"
"いながき 稲垣"
"いながわ 猪名川 稲川"
"いなき 稲木 稲城"
"いなぎ 稲木 稲城"
"いなげ 稲毛"
"いなご 蝗"
"いなさ 引佐"
"いなさく 稲作"
"いなさやま 稲佐山"
"いなざわ 稲沢"
"いなしき 稲敷"
"いなしろ 稲城"
"いなしろしがわ 稲城市側"
"いなずま 稲光 霆 稲妻"
"いなせ 粹"
"いなだ 鰍 稲田"
"いなち 稲地"
"いなつき 稲築"
"いなづま 稲妻"
"いなにわ 稲庭"
"いなの 稲野"
"いなば 因幡 稲葉 稲場"
"いなひさ 稲久"
"いなぶ 稲武"
"いなべ 員弁"
"いなほ 稲穂"
"いなみ 印南 稲美 井波 伊波"
"いなみね 稲嶺"
"いなむら 稲村"
"いなもと 稲元"
"いなもり 稲森 稲盛"
"いなよし 稲吉"
"いなり 稲荷"
"いなりだ 稲荷田"
"いなわしろ 猪苗代"
"いなわしろこ 猪苗代湖"
"いなん 以南"
"いにしえ 古え 古"
"いにしゃる イニシャル"
"いにゅう 移入"
"いにん 委任"
"いにんとうちりょう 委任統治領"
"いぬ 戌 狗 犬"
"いぬい 犬井 乾"
"いぬかい 犬飼"
"いぬかみ 犬上"
"いぬがみ 犬神"
"いぬがみぐん 犬上郡"
"いぬごや 犬小屋"
"いぬじに 犬死に"
"いぬぞり 犬橇"
"いぬつか 犬塚"
"いぬなき 犬鳴"
"いぬねこ 犬猫"
"いぬは 犬派"
"いぬぶえ 犬笛"
"いぬぼうさき 犬吠崎"
"いぬまる 犬丸"
"いぬやま 犬山"
"いね 禾 伊根 稻 稲"
"いねか イネ科"
"いねかり 稲刈 稲刈り"
"いねだ 稲田"
"いねなが 稲永"
"いねの 稲野"
"いねみつ 稲光"
"いねむり 居眠り"
"いねもく イネ目"
"いねん 為念"
"いの 井野 猪 伊野 猪野"
"いのうえ 井之上 井上"
"いのおか 猪岡"
"いのかしら 井の頭"
"いのがしら 井の頭"
"いのき 猪木"
"いのくち 井口"
"いのくま 猪熊"
"いのぐち 井ノ口 井口"
"いのさか 猪坂"
"いのしかちょう 猪鹿蝶"
"いのしし 豕 猯 猪"
"いのししなべ 猪鍋"
"いのした 井下"
"いのせ 猪瀬"
"いのだ 伊野田"
"いのち 生命 命"
"いのちづな 命綱"
"いのちとり 命取り"
"いのちびろい 命拾い"
"いのはら 猪原"
"いのべ 井ノ部"
"いのま 猪摩"
"いのまた 猪俣 猪股"
"いのり 祷"
"いのる 祷"
"いはい 位牌 違背"
"いはく 医博 曰く"
"いはつ 遺髪"
"いはら 井原 庵原 伊原"
"いはらだ 居原田"
"いはん 違反"
"いはんしゃ 違反車"
"いば 伊庭 井場"
"いばく 帷幕"
"いばしょ 居場所"
"いばら 棘 荊 茨"
"いばらき 茨城 茨木"
"いばらぎ 茨城"
"いばらぎえき 茨木駅"
"いばらぎし 茨木市"
"いばらぎてん 茨木店"
"いばらももく イバラモ目"
"いばん 異版"
"いぱっんじょうせい 一般情勢"
"いひょう 依憑 違表 意表"
"いひん 遺品"
"いび 依微 揖斐"
"いびき 鼾"
"いびしゃ 居飛車"
"いふ 依附 畏怖"
"いふう 遺風 威風"
"いふきょうだい 異父兄弟"
"いふく 衣服"
"いふくべ 伊福部"
"いふしん 畏怖心"
"いぶ 慰撫 伊武 ＥＶＥ"
"いぶか 井深"
"いぶき 伊吹 息吹"
"いぶくろ 胃袋"
"いぶしぎん 燻し銀"
"いぶすき 指宿"
"いぶせ 井伏"
"いぶつ 異物 遺物"
"いぶり 胆振"
"いぶん 遺文 異文"
"いぷしろん ε"
"いぷしろんせんい ε遷移"
"いへき 胃壁"
"いへや 伊平屋"
"いへん 異変"
"いべ 井部"
"いべんと イベント"
"いほう 彙報 異邦 異方 異法 違法"
"いほうし 違法視"
"いほく 以北"
"いほん 異本"
"いぼ 贅 肬 疣 異母 揖保"
"いぼう 依傍"
"いま 居間 今"
"いまい 今井"
"いまいけ 今池"
"いまいじょう 今以上"
"いまいずみ 今泉"
"いまいち 今市 今一"
"いまいっぽ 今一歩"
"いまいで 今出"
"いまがね 今金"
"いまがわ 今川"
"いまがわやき 今川焼"
"いまげんざい 今現在"
"いまころ 今頃"
"いまごろ 今ごろ 今頃"
"いまさき 今崎"
"いまさと 今里"
"いまさら 今さら 今更"
"いましがた 今し方"
"いましばらく 今暫く"
"いましま 今嶋"
"いましめ 戒め"
"いまじょう 今庄 今城"
"いまず 今津"
"いまぜき 今関"
"いまだ 未だ 今田 未"
"いまだて 今立"
"いまち 井街"
"いまづ 今津"
"いまで 今出"
"いまどき 今時"
"いまなか 今中 今仲"
"いまなが 今永"
"いまに 今仁"
"いまにし 今西"
"いまはし 今橋"
"いまはん 今半"
"いまばやし 今林"
"いまばり 今治"
"いまひと 今仁"
"いまひとつ 今一つ"
"いまふう 今風"
"いまふく 今福"
"いまべっぷ 今別府"
"いまべつ 今別"
"いままで 今まで 今迄"
"いまみや 今宮"
"いまむら 今村"
"いまや 今や"
"いまやま 今山"
"いまよう 今様"
"いまよし 今吉"
"いまり 伊万里"
"いまりゅう 今流"
"いまる 井丸"
"いまわだい 今話題"
"いまわの 忌野"
"いみ 意味"
"いみあい 意味合 意味合い"
"いみしん 意味深"
"いみず 射水"
"いみな 諱"
"いみなし 意味無"
"いみや 井宮"
"いみょう 異名"
"いみん 移民"
"いむ 異夢 諱 医務"
"いむた 伊牟田"
"いむら 井村"
"いめーじ イメージ"
"いめい 異名 依命 違名"
"いも 藷 薯 芋"
"いもうと 妹"
"いもうとふうふ 妹夫婦"
"いもうとやく 妹役"
"いもお 妹尾"
"いもづる 芋蔓"
"いもと 井本"
"いもに 芋煮"
"いもになべ 芋煮鍋"
"いもの 鋳物"
"いもむし 芋虫"
"いももと 芋本"
"いもようかん 芋羊羹"
"いもり 井森"
"いもん 慰問"
"いや 彌 祖谷 厭 嫌"
"いやいや 嫌々"
"いやおう 否応"
"いやがさこ 伊屋ヶ迫"
"いやがらせ 嫌がらせ"
"いやき 嫌気"
"いやく 依約 医薬 違約 意訳"
"いやけ 嫌気"
"いやけい 祖谷渓"
"いやし 鄙"
"いやなが 彌永"
"いやま 井山"
"いやみ 嫌み 厭み 嫌味 厭味"
"いゆう 畏友"
"いよ 伊予 伊代"
"いよいよ 愈 愈々"
"いよう 偉容 威容 医用 異様"
"いような 異様な"
"いよぎんこう 伊豫銀行"
"いよく 意欲"
"いよくさく 意欲作"
"いよこ 伊代子"
"いよじ 五代嗣"
"いよたに 伊豫谷"
"いよだ 伊與田"
"いよてつ 伊予鉄"
"いら 苛"
"いらい 以来 依頼"
"いらいしん 依頼心"
"いらいら 苛々 苛苛 イライラ"
"いらく イラク"
"いらくさ 蕁麻"
"いらくさもく イラクサ目"
"いらこ 伊良湖"
"いらここう 伊良湖港"
"いらこみさき 伊良湖岬"
"いらすと イラスト"
"いらぶ 伊良部"
"いらべ 伊良部"
"いらんくう 囲卵腔"
"いり 杁 圦 入 伊理"
"いりあい 入会"
"いりうち 入内"
"いりうちじま 入内島"
"いりえ 入り江 入江"
"いりおもて 西表"
"いりおもてじま 西表島"
"いりかさやま 入笠山"
"いりがい 入貝"
"いりき 入来"
"いりくち 入り口"
"いりぐち 入り口 入口"
"いりさ 入佐"
"いりさわ 入澤"
"いりた 入田"
"いりたはま 入田浜"
"いりなか 杁中"
"いりの 入野"
"いりひ 入り日"
"いりふね 入り船 入船"
"いりまじり 入交"
"いりまち 入り待ち"
"いりまめ 煎豆"
"いりもや 入母屋"
"いりや 入谷"
"いりやま 入山"
"いりゅう 移流 遺留 慰留"
"いりょう 衣糧 衣料 医療"
"いりょうせん 医療船"
"いりょうてきこうさつ 医療的考察"
"いりょうひ 医療費"
"いりょく 威力"
"いりよう 入用"
"いるーじょん イルージョン"
"いるい 異類 衣類"
"いるか 鯆 イルカ 海豚"
"いるす 居留守"
"いるま 入間"
"いれ 入れ"
"いれい 慰霊 異例"
"いれいさい 慰霊祭"
"いれいひ 慰霊碑"
"いれかえ 入換 入替 入れ換え"
"いれかえせん 入替戦"
"いれこ 入籠 入れ子"
"いれこみ 入込"
"いれずみ 刺青"
"いれぢえ 入れ知恵"
"いれば 入れ歯"
"いれもの 容れ物 入れ物"
"いろ 艷 色"
"いろあい 色相 色合 色合い"
"いろいがい 色以外"
"いろいろ 色色 色いろ 色々"
"いろう 遺漏 慰労"
"いろえんぴつ 色鉛筆"
"いろおち 色落ち"
"いろおとこ 色男"
"いろおんど 色温度"
"いろかず 色数"
"いろかわ 色川"
"いろかんけい 色関係"
"いろがみ 色紙"
"いろきろく 色記録"
"いろくうかん 色空間"
"いろぐろ 色黒"
"いろけ 色気"
"いろこい 色恋"
"いろこうじょうせい 色恒常性"
"いろさいげん 色再現"
"いろしきべつばんごう 色識別番号"
"いろしてい 色指定"
"いろしんごう 色信号"
"いろじょうほう 色情報"
"いろじろ 色白"
"いろすう 色数"
"いろずり 色刷り 色刷"
"いろたいおう 色対応"
"いろづけ 色付"
"いろどり 彩"
"いろはいち 色配置"
"いろはんてん 色反転"
"いろばんごう 色番号"
"いろひょうじ 色表示"
"いろふごう 色符号"
"いろぶんかい 色分解"
"いろほうしき 色方式"
"いろほせい 色補正"
"いろみほん 色見本"
"いろめ 色目"
"いろめい 色名"
"いろめがね 色眼鏡"
"いろもの 色物"
"いろり 鈩 鑪 囲炉裏"
"いろわけ 色分 色分け"
"いろん 異論"
"いろんな 色んな"
"いわ 巖 磐 違和 岩"
"いわい 岩韋 岩井 磐井 祝"
"いわいごと 祝事"
"いわいずみ 岩泉"
"いわいはら 岩井原"
"いわうち 岩内"
"いわお 岩生 岩尾 巖 磐 岩雄 岩夫 岩男 巌"
"いわおおじ 岩大路"
"いわおか 岩岡"
"いわかげ 岩陰"
"いわかみ 岩上"
"いわかめ 岩亀"
"いわかわ 岩川"
"いわかん 異和感"
"いわき 岩鬼 岩木 磐城 岩城"
"いわきさん 岩木山"
"いわきじ 磐城路"
"いわきり 岩切"
"いわぎ 岩城"
"いわく 曰く 曰"
"いわくに 岩国"
"いわくま 岩熊"
"いわくら 岩鞍 岩倉"
"いわさ 岩佐"
"いわさき 岩崎"
"いわさわ 岩沢"
"いわし 鰛 鰮 鰯"
"いわした 岩下"
"いわしみず 岩清水"
"いわしみづ 岩清水"
"いわしろ 岩代 岩城"
"いわせ 岩瀬"
"いわた 磐田 岩田"
"いわたき 岩滝"
"いわたけ 岩岳"
"いわたに 岩谷"
"いわだけ 岩岳"
"いわつう 岩通"
"いわつか 岩塚"
"いわつき 岩槻 岩月"
"いわて 岩手"
"いわてんじょう 岩天井"
"いわで 岩出"
"いわと 磐戸 岩戸"
"いわとくせん 岩徳線"
"いわど 岩戸"
"いわな 岩魚"
"いわない 岩内"
"いわないこう 岩内港"
"いわなみ 岩浪 岩波"
"いわにちきたせん 岩日北線"
"いわにちせん 岩日線"
"いわぬま 岩沼"
"いわね 岩根"
"いわの 岩野"
"いわはし 岩橋"
"いわはだ 岩肌"
"いわはら 岩原"
"いわば 言わば 謂わば 岩場"
"いわばやし 岩林"
"いわひろ 岩廣"
"いわふね 岩舟 岩船"
"いわぶち 岩淵 岩渕"
"いわほり 岩堀"
"いわま 岩間"
"いわまつ 岩松"
"いわみ 石見 岩美"
"いわみさわ 岩見沢"
"いわみざわ 岩見沢"
"いわみだ 岩見田"
"いわむら 岩村"
"いわむろ 岩室"
"いわもと 岩本"
"いわや 窟 岩谷 岩屋"
"いわやま 岩山"
"いわゆる 所謂"
"いん 韵 霪 隱 酳 贇 蚓 茵 湮 氤 殷 殞 飮 慇 廴 尹 婬 堙 咽 允 姻 淫 胤 蔭 隕 飲 隠 陰 因 韻 音 引 員 院 印"
"いんい 因依 陰萎"
"いんうつ 陰鬱"
"いんえい 陰翳 印影 陰影"
"いんおうご 印欧語"
"いんか 陰窩 引火 印加"
"いんかか 隠花果"
"いんかく 陰核"
"いんかしょくぶつ 隠花植物"
"いんかろん 因果論"
"いんかん 印鑑"
"いんが 陰画 印画 因果"
"いんがい 院外"
"いんがし 印画紙"
"いんがりつ 因果律"
"いんき 陰気"
"いんきょ 殷墟 隠居"
"いんきょく 陰極"
"いんきょくかん 陰極管"
"いんぎ 院議"
"いんぎゃく 淫虐"
"いんぎょう 隠形 印形"
"いんぎん 慇懃"
"いんく インク"
"いんぐらんど 英蘭"
"いんけい 陰茎"
"いんけん 隠顕 引見 陰険"
"いんげん 隠元"
"いんこ インコ 鸚哥"
"いんこう 淫荒 咽喉 淫行"
"いんご 隠語"
"いんごう 因業"
"いんさつ 印刷"
"いんさつじょ 印刷所"
"いんさつたい 印刷体"
"いんさつひ 印刷費"
"いんさん 陰惨"
"いんざい 印西"
"いんし 淫祀 淫祠 印紙 因子 院試"
"いんしぜい 印紙税"
"いんしつ 陰湿"
"いんしゅ 飲酒"
"いんしゅう 因習 因襲"
"いんしょう 印章 印象"
"いんしょく 飲食"
"いんしょくぎょう 飲食業"
"いんしん 殷賑 陰唇"
"いんじ 印字"
"いんじけーた インジケータ"
"いんじゃ 隠者"
"いんじゅう 陰獣"
"いんじゅん 因循"
"いんすう 員数 引数 因数"
"いんすたんと インスタント"
"いんずう 員数"
"いんせい 隠棲 院政 陰性 院生"
"いんせき 殞石 姻戚 引責 隕石"
"いんせん 隠線 陰線"
"いんぜい 印税"
"いんぜみ 院ゼミ"
"いんぜん 隠然"
"いんそつ 院卒 引率"
"いんたーせぷと インターセプト"
"いんたーちぇんじ インターチェンジ"
"いんたーばる インターバル"
"いんたい 隠退 引退"
"いんたいじあい 引退試合"
"いんたいずもう 引退相撲"
"いんたいせつ 引退説"
"いんたせぷと インタセプト"
"いんたびゅー インタビュー"
"いんだいせい 阪大生"
"いんだすとり インダストリ"
"いんち インチ 吋"
"いんちょう 院長"
"いんてりあ インテリア"
"いんでぃあん インディアン"
"いんでっくす インデックス"
"いんでんと インデント"
"いんとう 淫蕩 咽頭"
"いんとうえん 咽頭炎"
"いんとく 隠匿"
"いんとくざい 隠匿罪"
"いんとねーしょん イントネーション"
"いんとん 隠遁"
"いんど 印度"
"いんどう 引導"
"いんどよう インド洋"
"いんない 印内 院内"
"いんなみ 印南"
"いんに 因位 陰に"
"いんにく 印肉"
"いんにゅうし 院入試"
"いんねん 因縁"
"いんのう 陰嚢"
"いんのしま 因島"
"いんば 印旛"
"いんばい 淫売"
"いんばぬま 印旛沼"
"いんぱくと インパクト"
"いんぱるすおうとう インパルス応答"
"いんび 淫靡"
"いんびさ 淫靡さ"
"いんびせん 因美線"
"いんふるえんざ インフルエンザ"
"いんふれ インフレ"
"いんぶ 陰部"
"いんぶん 韻文"
"いんぷくかんすう 陰伏関数"
"いんぷっと インプット"
"いんぺい 隠蔽"
"いんぼう 陰謀"
"いんめい 因明"
"いんめつ 隠滅 湮滅"
"いんめん 隠面"
"いんもう 陰毛"
"いんゆ 隠喩"
"いんよう 陰陽 飲用 引用"
"いんようし 引用始"
"いんようじゅん 引用順"
"いんようすい 飲用水"
"いんようふ 引用符"
"いんらん 淫乱"
"いんりつ 韻律"
"いんりょう 飲料"
"いんりょうすい 飲料水"
"いんりょく 引力"
"いんれい 引例"
"いんれき 陰暦"
"いんれつ 陰裂"
"いんろう 印篭 印籠"
"いんわい 淫猥"
"う 得 菟 兎 胡 芋 齲 饂 紆 盂 挧 嫗 夘 傴 禹 生 于 烏 卯 羽 迂 宇 鵜 有 右 雨"
"うーはん 武漢"
"うーふぁ ウーファ"
"うーまん ウーマン"
"うーろん 烏龍"
"うーろんちゃ 烏龍茶"
"うぃーく ウィーク"
"うぃーん 維納"
"うぃじぇっと ウィジェット"
"うぃり 干莉"
"うぃるす ウィルス"
"うぃんど ウィンド"
"うい 宇井 有為 初"
"ういういしい 初々しい"
"ういきょう 茴香"
"ういざん 初産"
"ういじん 初陣"
"ういすきー ウイスキー"
"ういち 宇一"
"ういるす ウイルス"
"ういろう 外郎"
"ういんく ウインク"
"ういんぐす ウイングス"
"ううろんちゃ 烏龍茶"
"うぇい ウェイ"
"うぇるたーきゅう ウェルター級"
"うえ 飢え 植 ↑ 上"
"うええだ 上枝"
"うえおか 植岡"
"うえがはら 上ヶ原"
"うえがめん 上画面"
"うえがわ 上側"
"うえき 植え木 植木"
"うえきばち 植え木鉢 植木鉢"
"うえくさ 植草"
"うえくぼ 上窪"
"うえこみ 植え込み"
"うえさか 上坂"
"うえさま 上様"
"うえさんかく 上三角"
"うえさんかくぎょうれつ 上3角行列"
"うえしき 上式"
"うえした 上下"
"うえしば 植芝"
"うえしま 上島"
"うえじに 餓死"
"うえす 上須 上江洲"
"うえすぎ 上杉"
"うえすぎてるとら 上杉輝虎"
"うえすぎまさとら 上杉政虎"
"うえぞの 上園"
"うえた 植田"
"うえたけ 植竹"
"うえたに 上谷"
"うえだ 植田 上田"
"うえちゅうだん 上中段"
"うえつ 羽越"
"うえづけ 上付"
"うえなか 植中"
"うえにし 上西"
"うえの 植野 上野"
"うえのぐち 上野口"
"うえのはら 上野原"
"うえは ウエハ"
"うえはま 上浜"
"うえはら 植原 上原"
"うえはらせい 上原成"
"うえはんぶん 上半分"
"うえひら 植平"
"うえほうこう 上方向"
"うえほんまち 上本町"
"うえほんまちろくちょうめ 上本町六丁目"
"うえまち 上町"
"うえまつ 上松 植松"
"うえむき 上向き"
"うえむら 上村 植村"
"うえもと 植本"
"うえもり 上森"
"うえもん 右衛門"
"うえや ↑"
"うえやじるし 上矢印"
"うえやま 上山"
"うえろく 上本町六丁目"
"うえん 迂遠"
"うぉーみんぐ ウォーミング"
"うぉーむ ウォーム"
"うお 宇夫 魚"
"うおい 魚井"
"うおいちば 魚市場"
"うおうさおう 右往左往"
"うおがし 魚河岸"
"うおごころ 魚心"
"うおざ 魚座"
"うおざき 魚崎"
"うおざききたちょう 魚崎北町"
"うおしま 魚島"
"うおずみ 魚住"
"うおせ 魚瀬"
"うおっちんぐ ウオッチング"
"うおつか 魚塚"
"うおづ 魚津"
"うおぬま 魚沼"
"うおみ 魚見"
"うおみつ 魚光"
"うおや 魚屋"
"うか 羽化"
"うかい 鵜飼 迂回"
"うかいろ 迂回路"
"うかがい 窺 伺"
"うかじ 宇梶"
"うかつ 迂濶 迂闊"
"うかれめ 浮かれ女"
"うかん 有漢"
"うがい 嗽 鵜飼"
"うがん 右岸 右眼"
"うき 雨季 右記 浮 雨期"
"うきあし 浮足"
"うきえ 浮江"
"うきがや 浮ヶ谷"
"うきくさ 浮草"
"うきぐ 浮具"
"うきぐも 浮雲"
"うきしずみ 浮き沈み"
"うきしま 浮島"
"うきた 浮田"
"うきな 浮名"
"うきはし 浮橋"
"うきばし 浮橋"
"うきふね 浮船 浮舟"
"うきぶくろ 鰾 浮袋"
"うきぼり 浮き彫り"
"うきみ 憂き身 浮身 浮き身"
"うきめ 憂き目"
"うきょう 右京"
"うきよ 憂き世 浮世"
"うきよえ 浮世絵"
"うきわ 浮輪"
"うく 宇久"
"うくらいな 烏克蘭"
"うぐい 鯏"
"うぐいす 鴬 鶯"
"うぐいすざわ 鴬沢 鶯沢"
"うぐいすだに 鴬谷"
"うぐいすだにえき 鶯谷駅"
"うけい 右傾"
"うけいれ 受け入れ 受入"
"うけうり 受け売り"
"うけおい 請負"
"うけおいぎょう 請負業"
"うけかた 受け方"
"うけがわ 受け側"
"うけくち 受け口"
"うけぐち 受口 受け口"
"うけこたえ 受け答え"
"うけごし 受け腰"
"うけざら 受け皿"
"うけしょ 請書 受書"
"うけつけ 受け付け 受付"
"うけつけじょう 受付嬢"
"うけて 受け手"
"うけとり 受け取り 受取"
"うけとりて 受け取り手"
"うけにぬし 受荷主"
"うけにん 請人"
"うけはらい 受払い"
"うけばらい 受け払い"
"うけみ 受け身 受身"
"うける 受ける"
"うけわたし 受渡 受け渡し 受渡し"
"うけん 宇検"
"うげん 右舷 迂言"
"うこう 宇高"
"うこさべん 右顧左眄"
"うこん 鬱金"
"うご 雨後 羽後"
"うごう 烏合"
"うごき 動き"
"うさ 憂さ 右左 宇佐"
"うさぎ 莵 兔 菟 兎"
"うさぎごや 兎小屋"
"うさぎだいら 兎平"
"うさせつ 右左折"
"うさせつしゃ 右左折車"
"うさみ 宇沙美 宇佐美 宇佐見"
"うさわ 宇沢"
"うさん 胡散"
"うさんくさい 胡散臭い"
"うざき 宇崎"
"うざわ 鵜澤 鵜沢 宇沢"
"うし 丑 牛"
"うしお 牛尾 潮"
"うしおしゅっぱん 潮出版"
"うしおだ 潮田"
"うしおでんき ウシオ電機"
"うしかい 牛飼い"
"うしき 牛木"
"うしく 牛久"
"うしくぬま 牛久沼"
"うしごめ 牛込"
"うしじま 牛嶋 牛島"
"うしじろう 牛次郎"
"うした 牛田"
"うしづ 牛津"
"うしね 牛根"
"うしの 牛野"
"うしぶか 牛深"
"うしぼり 牛堀"
"うしまど 牛窓"
"うしみつ 丑三つ"
"うしょう 鵜匠"
"うしろ 後ろ 後"
"うしろあし 後ろ足"
"うしろかわ 後川"
"うしろがみ 後髪"
"うしろがわ 後側"
"うしろすがた 後姿 後ろ姿"
"うしろだて 後ろ盾 後ろだて"
"うしろで 後ろ手"
"うしろはんぶん 後半分"
"うしろほうこう 後方向"
"うしろみ 後見"
"うしろむき 後向き"
"うしろめ 後目"
"うしろゆび 後ろ指"
"うしわかまる 牛若丸"
"うしわた 牛渡"
"うしんしつ 右心室"
"うしんふぜん 右心不全"
"うじ 蛆 宇治 氏"
"うじいえ 氏家"
"うじさと 氏郷"
"うじすじょう 氏素性 氏素姓"
"うじな 宇品"
"うじはら 氏原"
"うじむし 蛆虫"
"うじょう 鵜匠 羽状 雨上"
"うじょうみゃく 羽状脈"
"うす 有珠 碓 臼 薄"
"うすあおいろ 薄青色"
"うすあじ 薄味"
"うすい 碓井 雨水 薄井 碓氷 臼井"
"うすいた 薄板"
"うすうす 薄々"
"うすがた 薄型"
"うすがみ 薄紙"
"うすき 臼杵 薄"
"うすきいろ 薄黄色"
"うすぎ 薄着"
"うすぎり 薄切り"
"うすくちしょうゆ 薄口醤油"
"うすぐもり うす曇り 薄曇"
"うすげしょう 薄化粧"
"うすじ 薄地"
"うすじお 薄塩"
"うすた 薄田"
"うすだ 臼田"
"うすちゃ 薄茶"
"うすで 薄手"
"うすば 薄葉"
"うすび 薄日"
"うすべに 薄紅"
"うすまく 薄膜"
"うすみどりいろ 薄緑色"
"うすめ 薄目"
"うすももいろ 薄桃色"
"うすやみ 薄闇"
"うすらばか 薄ら馬鹿"
"うず 右図 渦"
"うずい 渦位"
"うずき 宇津木"
"うずでんりゅう 渦電流"
"うずど 渦度"
"うずの 鶉野"
"うずまき 渦巻 渦巻き"
"うずら 鶉"
"うせつ 右折"
"うせつしゃ 右折車"
"うせんけい 右線形"
"うぜん 羽前"
"うそ 嘯 鷽 ウソ 嘘"
"うそうそ 嘘々"
"うそく 右側"
"うそつき 嘘つき"
"うそはっけんき 嘘発見機 嘘発見器"
"うそはっぴゃく 嘘八百"
"うぞうむぞう 有象無象"
"うた 謳 宇田 謌 詩 唄 歌"
"うたい 謠 謡"
"うたいかた 歌い方"
"うたいがい 歌以外"
"うたいもんく 謳文句 謡い文句 歌文句"
"うたいり 歌入り"
"うたえもん 歌右衛門"
"うたかい 歌会"
"うたかた 泡沫"
"うたがい 疑い"
"うたがわ 歌川"
"うたぐち 歌口"
"うたげ 宴"
"うたこ 詩子"
"うたごえ 歌声"
"うたごころ 歌心"
"うたしない 歌志内"
"うたしろ 歌代"
"うたた 転"
"うたたね 転寝"
"うたつ 歌津 宇多津"
"うたづ 宇多津"
"うたの 菟田野 宇多野 歌野"
"うたのかみ 雅楽頭"
"うたばん 歌伴"
"うたばんぐみ 歌番組"
"うたひめ 歌姫"
"うたほん 歌本"
"うたまろ 歌麿"
"うたよ 詩代"
"うたん 右端"
"うだ 宇田 宇陀"
"うだい 宇大"
"うだいじん 右大臣"
"うち 欝 鬱 中 家 内"
"うちあげ 打ち上げ"
"うちあわせ 打合せ 打ち合せ 打ち合わせ"
"うちい 内井"
"うちいけ 内池"
"うちいわい 内祝"
"うちうち 内々"
"うちうみ 内海"
"うちうら 内浦"
"うちかけ 裲襠 打掛け"
"うちかた 内潟 打ち方"
"うちかわ 内川"
"うちかんだ 内神田"
"うちがけ 内掛け"
"うちがわ 内側"
"うちき 内木 内気"
"うちきず 打傷"
"うちきば 内木場"
"うちきり 打切 打ち切り"
"うちきん 内金"
"うちぎ 袿"
"うちくび 打ち首"
"うちげば 内ゲバ"
"うちこ 内子"
"うちこば 内木場"
"うちこみ 打ち込み"
"うちこわし 打ち毀し"
"うちさいわい 内幸"
"うちざいこぶん 内在庫分"
"うちそで 内袖"
"うちた 打田"
"うちだ 内田"
"うちづま 内妻"
"うちで 打ち出"
"うちでし 内弟子"
"うちどめ 打ち止め 打止"
"うちなかはら 内中原"
"うちなだ 内灘"
"うちの 内野"
"うちのうら 内之浦"
"うちのみ 内海"
"うちのり 内法 内のり"
"うちはら 内原"
"うちばば 内馬場"
"うちひとり 内一人"
"うちひょうじ 内表示"
"うちひら 内平"
"うちぶくろ 内袋"
"うちべんけい 内弁慶"
"うちぼう 内房"
"うちぼり 内堀"
"うちまく 内幕"
"うちまた 内股"
"うちみ 打ち身"
"うちみず 打ち水"
"うちみや 内宮"
"うちむそう 内無双"
"うちむら 内村"
"うちやま 内山"
"うちやまだ 内山田"
"うちゅう 雨中 宇宙"
"うちゅういち 宇宙一"
"うちゅうかん 右中間"
"うちゅうしょく 宇宙食"
"うちゅうじん 宇宙塵"
"うちゅうせん 宇宙戦 宇宙船"
"うちゅうぜろねん 宇宙零年"
"うちゅうてい 宇宙挺"
"うちゅうふく 宇宙服"
"うちゅうれき 宇宙暦"
"うちゅうろんばたけ 宇宙論畑"
"うちゆ 内湯"
"うちょうてん 有頂天"
"うちょく 右直"
"うちら 内良"
"うちわ 団扇 内輪"
"うちわうけ 内輪受"
"うちわく 内枠"
"うちわけ 内訳"
"うちわたし 内渡し"
"うちわばなし 内輪話"
"うちわもめ 内輪揉め"
"うっき 鬱気"
"うっくつ 鬱屈"
"うっけつ 鬱結 うっ血 鬱血 欝血"
"うっこ 鬱乎"
"うっこん 鬱金"
"うっこんこう 鬱金香"
"うっせい 鬱生"
"うっせき 鬱積 欝積 うっ積"
"うっそう 鬱葱 鬱蒼 欝蒼"
"うっそく 鬱塞"
"うったい 鬱滞"
"うったえ 訴え"
"うっちゃり 打っ棄り"
"うっちょう 鬱鬯"
"うっとう 鬱陶 欝陶"
"うっとうしい 鬱陶しい 欝陶しい"
"うっぷん 欝憤 鬱憤"
"うつ 欝 鬱 蔚"
"うつい 鬱伊"
"うついく 鬱郁"
"うつう 鬱紆"
"うつうつ 鬱鬱"
"うつおう 鬱懊 鬱怏 鬱泱"
"うつき 宇津木 宇津喜"
"うつぎ 宇津木"
"うつぎみ 鬱気味"
"うつく 美"
"うつくしがはら 美ヶ原"
"うつし 写し 写"
"うつしよ 現世"
"うつじゅう 鬱情"
"うつせみ 空蝉"
"うつぜん 鬱然"
"うつのみや 宇都宮"
"うつびょう 鬱病"
"うつぼ 靱 笂 靭"
"うつぼつ 鬱勃"
"うつみ 宇都美 慈 内海"
"うつみや 宇津宮"
"うつも 鬱茂"
"うつもん 鬱悶"
"うつゆう 鬱邑 鬱悒"
"うつよう 鬱陶"
"うつよく 鬱抑"
"うつりつ 鬱律"
"うつろ 虚 虚ろ"
"うつわ 噐 器"
"うづ 宇津"
"うづき 宇津木 卯月"
"うづきゅうめいがん 宇津救命丸"
"うて 右手"
"うてき 雨滴"
"うてん 雨天"
"うで 腕"
"うでかざり 腕飾り"
"うできき 腕利き"
"うでくらべ 腕比べ"
"うでぐみ 腕組み"
"うでずく 腕尽く 腕ずく"
"うでずもう 腕相撲"
"うでたて 腕立"
"うでたてふせ 腕立伏せ"
"うでだめし 腕試し"
"うでづく 腕尽く"
"うでどけい 腕時計"
"うでまえ 腕前"
"うでまくら 腕枕"
"うでわ 腕輪"
"うと 宇土"
"うとう 宇藤 宇籐"
"うとく 宇徳"
"うとろ 宇登呂"
"うどの 鵜殿"
"うどり 羽鳥"
"うどん 饂飩"
"うない 宇内"
"うなかみ 海上"
"うなぎ 鰻"
"うなぎや 鰻屋"
"うなじ 項"
"うなづき 宇奈月"
"うなどん 鰻丼"
"うなばら 海原"
"うなり 唸り"
"うに 海胆 雲丹"
"うぬ 己"
"うぬぼれ 自惚れ"
"うね 有年 畴 疇 畆 宇根 畝 畦"
"うねおか 宇根岡"
"うねかわ 畝川"
"うねび 畝傍"
"うねめ 采女"
"うねもと 畝本"
"うの 鵜野 宇能 宇野"
"うのう 右脳"
"うのき 卯野木 宇野木"
"うのけ 宇ノ気"
"うのはな 卯の花"
"うのみ 鵜呑 鵜呑み"
"うは 右派"
"うば 姥 乳母"
"うばいあい 奪い合い"
"うばぐるま 乳母車"
"うばすて 姥捨"
"うびょう 宇廟"
"うふさま 右府様"
"うぶ 初 初心 産"
"うぶぎ 産着"
"うぶげ 産毛"
"うぶごえ 産声"
"うぶやま 産山"
"うぶゆ 産湯"
"うぷしろん Υ"
"うへん 右辺"
"うべ 宜 宇部"
"うべこう 宇部興"
"うほう 右方"
"うま 午 旨 馬"
"うまいり 馬入"
"うまこ 馬子"
"うまこし 馬越"
"うまごめ 馬込"
"うまごや 馬小屋"
"うまじ 馬路"
"うまじしん 馬自身"
"うまじたい 馬自体"
"うまじるし 馬標"
"うまずら 馬面"
"うまたち 馬達"
"うまに 甘煮"
"うまの 馬野"
"うまのすずくさか ウマノスズクサ科"
"うまのすずくさもく ウマノスズクサ目"
"うまのり 馬乗り"
"うまばん 馬番"
"うまふざい 馬不在"
"うまみ 旨味"
"うまみち 馬道"
"うまや 廏 廐 馬屋 厩"
"うまれ 生 生まれ"
"うまれつき 生まれつき"
"うまれどし 生まれ年"
"うまれん 馬連"
"うみ 宇美 生 膿 海"
"うみいちめん 海一面"
"うみかぜ 海風"
"うみがみ 海神"
"うみがめ 海亀"
"うみがわ 海側"
"うみしばうら 海芝浦"
"うみせんやません 海千山千"
"うみそだち 海育ち"
"うみぞい 海沿い"
"うみだし 海田市"
"うみづり 海釣"
"うみの 海野"
"うみのいえ 海の家"
"うみのなかみち 海の中道"
"うみべ 海辺"
"うむ 孳 有無"
"うむらうと ウムラウト"
"うめ 楳 梅"
"うめあわせ 埋め合わせ 埋め合せ"
"うめがえもち 梅枝餅"
"うめがおか 梅が丘"
"うめがき 梅垣"
"うめがしま 梅ヶ島"
"うめき 呻き"
"うめきごえ 呻き声"
"うめきち 梅吉"
"うめくさ 埋草 埋め草"
"うめこ 梅子"
"うめこうじ 梅小路"
"うめこぶちゃ 梅昆布茶"
"うめこみ 埋め込み"
"うめさお 梅棹"
"うめさわ 梅沢"
"うめざき 梅崎"
"うめざわ 梅澤 梅沢"
"うめしゅ 梅酒"
"うめず 梅酢 楳図 梅津 梅図"
"うめぞの 梅園"
"うめた 梅田"
"うめたて 埋立"
"うめたに 梅谷"
"うめだ 楳田 梅田"
"うめだがわぞい 梅田川沿"
"うめだきた 梅田北"
"うめつくし 埋め尽くし"
"うめづ 梅津"
"うめにしき 梅錦"
"うめの 梅野"
"うめはら 梅原"
"うめぼし 梅干 梅干し"
"うめみ 梅見"
"うめみや 梅宮"
"うめむら 梅村"
"うめむろ 梅室"
"うめもと 梅本"
"うめもり 梅森"
"うめやま 梅山"
"うめわかべや 梅若部屋"
"うもう 羽毛"
"うもうだ 羽毛田"
"うもうふく 羽毛服"
"うもん 宇門"
"うやま 宇山"
"うよ 紆餘 紆余"
"うよう 右葉"
"うよきょくせつ 迂余曲折"
"うよく 右翼"
"うら 占 浦 裏"
"うらあみ 裏編み"
"うらうす 浦臼"
"うらうち 裏打ち"
"うらえ 浦江"
"うらおもて 裏表"
"うらおもてがみ 裏表紙"
"うらかすみ 浦霞"
"うらかぜ 裏風"
"うらかた 裏方"
"うらかみ 浦上"
"うらかわ 浦河 浦川"
"うらが 浦賀"
"うらがお 裏顔"
"うらがき 裏書き 裏書"
"うらがすみ 浦霞"
"うらがすみぜん 浦霞禅"
"うらがね 裏金"
"うらがみ 浦上 裏紙"
"うらがわ 浦川 裏側"
"うらぎり 裏切り"
"うらぎりもの 裏切者"
"うらぐち 裏口"
"うらけん 裏拳"
"うらこう 浦港"
"うらさ 浦佐"
"うらさく 裏作"
"うらさわ 浦沢"
"うらしの 嬉野"
"うらしま 浦島"
"うらじ 裏地"
"うらじおすとっく 浦鹽斯徳"
"うらぜん 浦禅"
"うらそえ 浦添"
"うらた 浦田"
"うらち 浦地"
"うらづけ 裏付"
"うらて 裏手"
"うらどら 裏ドラ"
"うらない 卦 卜い 占い"
"うらにし 浦西"
"うらにわ 裏庭"
"うらの 浦野"
"うらはま 浦浜"
"うらはら 裏腹"
"うらばなし 裏話"
"うらばんだいねこま 裏磐梯猫摩"
"うらぶた 裏蓋"
"うらべ 裏部 占部 浦部 卜部"
"うらほろ 浦幌"
"うらぼん 盂蘭盆"
"うらまち 裏町"
"うらまど 裏窓"
"うらみごと 恨み言"
"うらみち 裏道"
"うらみぶし 怨み節"
"うらむ 怏"
"うらめ 裏目"
"うらめし 浦飯"
"うらめん 裏面"
"うらもと 浦本"
"うらもの 裏物"
"うらもん 裏門"
"うらやす 浦安"
"うらやま 浦山 裏山"
"うらら 麗"
"うらる 烏拉"
"うらわ 浦和"
"うらわざ 裏技"
"うらわせん 浦和戦"
"うらわみなみ 浦和南"
"うらん ウラン"
"うり 壷 壺 瓣 瓠 瓜"
"うりあげ 売り上げ 売上げ 売上"
"うりあげがく 売上額"
"うりあげぞう 売上増"
"うりあげだか 売上高"
"うりいえ 売り家"
"うりか ウリ科"
"うりかい 売り買い"
"うりかけ 売掛 売り掛け"
"うりきれ 売切 売り切れ"
"うりくち 売り口"
"うりこ 売子"
"うりことば 売り言葉"
"うりこみ 売り込み"
"うりごえ 売声"
"うりそうば 売相場"
"うりだし 売出し 売出 売り出し"
"うりづら 瓜連"
"うりて 売手 売り手"
"うりどき 売り時"
"うりぬし 売り主"
"うりね 売り値 売値"
"うりの 売野"
"うりば 売り場 売場"
"うりもく ウリ目"
"うりもの 売物 売り物"
"うりや 売り家"
"うりゅ 雨龍"
"うりゅう 瓜生 雨龍 雨竜"
"うりょう 雨量"
"うりょうけい 雨量計"
"うりん 雨林"
"うる 宇留"
"うるう 閏"
"うるうづき 閏月"
"うるうどし 閏年"
"うるうびょう 閏秒"
"うるき 売木"
"うるし 漆"
"うるしはら 漆原"
"うるしばた 漆畑"
"うるしま 漆島"
"うるしやま 漆山"
"うるた 粳田"
"うるち 粳"
"うるちまい 粳米"
"うれあし 売れ足"
"うれい 騷 恙 愁い 憂い"
"うれう 悄"
"うれえ 憂え 愁え"
"うれくち 売れ口"
"うれしの 嬉野"
"うれすじ 売れ筋"
"うれせん 売れ線"
"うれだか 売れ高"
"うれっこ 売れっ子"
"うれゆき 売れ行き 売行 売行き"
"うろ 空 空洞 迂路"
"うろう 傴僂"
"うろおぼえ うろ覚え"
"うろこ 鱗"
"うろん 胡乱"
"うわ 宇和 上"
"うわあご 上顎"
"うわがき 上書 上書き"
"うわがわ 上側"
"うわき 浮気"
"うわきごころ 浮気心"
"うわきしょう 浮気性"
"うわぎ 上衣 上着"
"うわくちびる 上唇"
"うわぐすり 釉薬"
"うわぐつ 上靴"
"うわごと 譫言 謔言"
"うわさ 噂"
"うわさばなし 噂話"
"うわざら 上皿"
"うわじま 宇和島"
"うわじまひがし 宇和島東"
"うわすべり 上滑り"
"うわずみ 上澄み 上住"
"うわぞこ 上底"
"うわつら 上面"
"うわづみ 上積み"
"うわて 上手"
"うわてだしなげ 上手出し投げ"
"うわてなげ 上手投げ"
"うわぬり 上塗り"
"うわね 上値"
"うわの 宇和野"
"うわのせ 上乗せ"
"うわのだい 上の台"
"うわのり 上乗り"
"うわばき 上履き"
"うわばみ 蠎蛇"
"うわぶたしき 上蓋式"
"うわべ 上辺"
"うわまえ 上前"
"うわみ 宇和海"
"うわみぞ 上溝"
"うわみの 上蓑"
"うわむき 上向き"
"うわめ 上目"
"うわや 上屋"
"うわやく 上役"
"うわん 右腕"
"うん 褞 蘊 薀 耘 繧 紜 暈 慍 吽 曇 雲 云 運"
"うんえい 運営"
"うんえいひ 運営費"
"うんか 雲霞"
"うんかい 雲海"
"うんが 運河"
"うんきゅう 運休"
"うんけいじょうぎ 雲型定規"
"うんげいせん 雲芸線"
"うんげん 繧繝"
"うんこう 運航 運行"
"うんこうまえてんけん 運行前点検"
"うんさん 雲散"
"うんざん 運算"
"うんし 運指"
"うんしだい 運次第"
"うんしん 雲身 運針"
"うんじゃく 雲雀"
"うんじゅ 琅珠"
"うんじょう 雲上"
"うんすい 雲水"
"うんせい 運勢"
"うんぜん 雲仙"
"うんそう 運送"
"うんそうぎょう 運送業"
"うんそうひ 運送費"
"うんだい 雲台"
"うんだめし 運試し"
"うんちく 薀蓄 蘊蓄"
"うんちょう 雲頂"
"うんちん 運賃"
"うんちんばこ 運賃箱"
"うんちんひょうじまく 運賃表示幕"
"うんてん 運転"
"うんてんし 運転士"
"うんてんしゃせき 運転者席"
"うんてんしゅ 運転手"
"うんてんせき 運転席"
"うんてんせきよこ 運転席横"
"うんでい 雲泥"
"うんどう 運動"
"うんどうかく 運動覚"
"うんどうぐつ 運動靴"
"うんどうたい 運動体"
"うんどうのう 運動能"
"うんどんりょう 運動量"
"うんなん 雲南"
"うんなんしょう 雲南省"
"うんぬん 云々"
"うんの 海野"
"うんのう 暈ノウ 雲衲 蘊奥"
"うんぱん 運搬"
"うんぱんぐ 運搬具"
"うんぴつ 運筆"
"うんぷう 雲風"
"うんめい 運命"
"うんも 雲母"
"うんゆ 運輸"
"うんゆしょう 運輸省"
"うんよう 運用"
"うんようえき 運用益"
"うんようがかり 運用掛"
"うんようひ 運用費"
"うんりょう 雲量"
"え 杖 依 猥 懷 衞 繪 畫 惠 囘 會 榎 衣 ヱ 画 慧 衛 笑 荏 枝 得 餌 恵 重 柄 回 江 会 絵"
"えーじぇんと エージェント"
"えーす エース"
"えーた η"
"えーてる エーテル"
"えあ エア"
"えあわせ 絵合わせ"
"えい 衡 頴娃 郢 贏 裔 衞 蠑 翳 纓 縊 睿 珱 瓔 瑩 瀛 潁 殪 楹 曵 暎 塋 營 咏 榮 曳 叡 盈 穎 洩 頴 泳 嬰 営 瑛 永 衛 詠 鋭 影 映 英 栄"
"えいい 栄位 営為 鋭意"
"えいいち 榮一 栄一 詠一 英一"
"えいいちろう 英一郎 栄一郎"
"えいえい 英英 営営 営々"
"えいえん 永遠"
"えいおうしつ 英王室"
"えいおおもじ 英大文字"
"えいおん 嬰音"
"えいか 穎果"
"えいかいわ 英会話"
"えいかく 鋭角"
"えいかん 栄冠"
"えいかんたい 英艦隊"
"えいが 栄画 栄華 映画"
"えいがかんけん 映画館券"
"えいがく 栄学"
"えいがさい 映画祭"
"えいがないえいが 映画内映画"
"えいき 英気 鋭気"
"えいきち 栄吉 永吉"
"えいきゅう 永久"
"えいきゅうし 永久歯"
"えいきょう 影響"
"えいぎょう 営業"
"えいぎょうしゃ 営業車"
"えいぎょうしょく 営業職"
"えいぎょうばたけ 営業畑"
"えいぐん 英軍"
"えいけい 鋭形"
"えいけん 英検"
"えいげん 永源"
"えいげんじ 永源寺"
"えいこ 映子 江威子 栄枯 暎子 瑛子 永子 栄子 英子"
"えいこう 栄幸 曳行 曳光 栄孝 曳航 栄光"
"えいこうだん 曳光彈 曳光弾"
"えいこく 英国"
"えいこくき 英国旗"
"えいこくこっきょうかい 英国国教会"
"えいこくしゃ 英国車"
"えいこくりゅう 英国流"
"えいこくりょう 英国領"
"えいこもじ 英小文字"
"えいご 英五 英語"
"えいごう 永劫"
"えいごげき 英語劇"
"えいさい 穎才 英才"
"えいさく 英作 栄策 栄作"
"えいさつ 縊殺"
"えいざぶろう 栄三郎"
"えいざん 叡山"
"えいしゃ 営舎 映写"
"えいしゅ 英主"
"えいしょ 英書"
"えいしょう 詠唱"
"えいしん 詠進 栄進"
"えいじ 英史 鋭二 英児 英志 嬰児 英次 英司 永二 栄二 栄治 栄次 英二 英治 英字"
"えいじゅ 衛戍"
"えいじゅう 永住"
"えいじろう 栄次郎"
"えいじん 英人"
"えいすう 英数"
"えいすけ 栄介 英輔 英介"
"えいず エイズ"
"えいせい 衞生 衞星 永逝 永世 衛星 衛生"
"えいせいこう 衛生工"
"えいせいし 衛生士"
"えいせいぞう 衛星像"
"えいせいだい 衛星第"
"えいせん 鋭尖 曳船"
"えいぜん 営繕"
"えいそう 営巣 営倉"
"えいぞう 影像 営造 英三 栄蔵 栄三 映像"
"えいぞうさい 映像祭"
"えいぞく 永続"
"えいた 英太"
"えいたい 永代"
"えいたつ 英達 栄達"
"えいたろう 英太郎 栄太郎 永太朗"
"えいたん 詠歎 詠嘆"
"えいたんご 英単語"
"えいだ 英田 栄田"
"えいだい 英題"
"えいだいさんぎょう 永大産業"
"えいだん 帝都高速度交通営団 英断 営団"
"えいだんしゃ 営団車"
"えいち 睿智 叡智 叡知 英知"
"えいてい 営庭"
"えいてん 栄典 栄転"
"えいでん 叡電"
"えいとう 衛陶"
"えいど エイド"
"えいどう 泳動 栄道"
"えいにち 英日"
"えいねん 永年"
"えいばん 英盤"
"えいびん 鋭敏"
"えいふく 永福"
"えいぶん 英文"
"えいぶんぽう 英文法"
"えいへい 衛兵"
"えいへいじ 永平寺"
"えいべい 英米"
"えいべいぐん 英米軍"
"えいべつてき 性別的"
"えいほう 泳法"
"えいみ 詠美"
"えいみん 永眠"
"えいめい 英名"
"えいめいかん 穎明館"
"えいもじ 英文字"
"えいもり 栄森"
"えいもん 営門"
"えいやく 英訳"
"えいゆう 英雄"
"えいよ 栄誉"
"えいよう 栄耀 栄養"
"えいようげん 栄養源"
"えいようし 栄養枝 栄養士"
"えいようしゅーと 栄養シュート"
"えいようしょく 栄養食"
"えいようそ 栄養素"
"えいらく 永楽"
"えいり 絵入り 鋭利 営利"
"えいりあん エイリアン"
"えいりょ 叡慮"
"えいりょう 英領"
"えいりん 英鈴 映倫 営林"
"えいりんしょ 営林署"
"えいれい 英霊"
"えいれんぽう 英連邦"
"えいろんぶん 英論文"
"えいわ 英和"
"えいわじてん 英和辞書"
"えうぽまちあか エウポマチア科"
"ええた Η η"
"えかき 絵書き 絵描き"
"えがお 笑顔"
"えがしら 江頭"
"えがみ 江上"
"えがら 絵柄"
"えがわ 江川"
"えがわすぐる 江川卓"
"えき 亦 依帰 驛 蜴 掖 懌 奕 腋 伯 繹 易 役 疫 液 益 駅"
"えきあんない 駅案内"
"えきいん 駅員"
"えきうら 駅裏"
"えきうり 駅売り"
"えきおん 液温"
"えきか 液果 腋窩 液化"
"えきかかりいん 駅係員"
"えきかん 駅間"
"えきが 腋芽"
"えきがく 疫学"
"えきがくてきちょうさ 疫学的調査"
"えきがわ 駅側"
"えききょう 易経"
"えききん 益金"
"えきげしゃ 駅下車"
"えきこうない 駅構内"
"えきごと 駅毎"
"えきしせつ 駅施設"
"えきしゃ 駅舎 易者"
"えきしゃあと 駅舎跡"
"えきしゅうへん 駅周辺"
"えきしょう 液晶"
"えきじたい 駅自体"
"えきじょう 液状"
"えきすう 駅数"
"えきすぱーと エキスパート"
"えきせい 液性"
"えきせいぎょそうち 駅制御装置"
"えきせん 易占"
"えきぜんぶ 駅全部"
"えきそんしつじかん 駅損失時間"
"えきたい 液体"
"えきだん 易断"
"えきちゅう 液中 益虫"
"えきちょう 益鳥 駅長"
"えきちょうあて 駅長宛"
"えきてき 液滴"
"えきでん 驛傳 駅伝"
"えきとう 駅頭"
"えきどめ 駅止め 駅止"
"えきない 駅内"
"えきね 駅寝"
"えきばいてん 駅売店"
"えきばしゃ 駅馬車"
"えきひょうじ 駅表示"
"えきびょう 疫病"
"えきびょうがみ 疫病神"
"えきびる 駅ビル"
"えきふきん 駅付近"
"えきべん 駅弁"
"えきほんや 駅本屋"
"えきまえ 駅前"
"えきむ 役務"
"えきめい 駅名"
"えきめいしょういん 駅名小印"
"えきめいばん 駅名板"
"えきめいひょう 駅名標"
"えきめいひょうきばん 駅名表記板"
"えきや 駅家"
"えきり 疫痢"
"えきりようしゃ 駅利用者"
"えきれい 液冷"
"えくぼ 靨 エクボ"
"えぐち 江口"
"えけい 恵瓊"
"えこ 依怙"
"えこー エコー"
"えこう 回向"
"えこじ 依怙地"
"えこだ 江古田"
"えこのみすと エコノミスト"
"えころじ エコロジ"
"えごいずむ エゴイズム"
"えごころ 絵心"
"えさ 餌"
"えさか 江坂"
"えさき 江崎"
"えさぎ 餌木"
"えさし 江指 枝幸 江刺 江差"
"えさだい 餌代"
"えさづり 餌釣り"
"えさば 餌場"
"えさばこ 餌箱"
"えさや 餌屋"
"えさん 恵山"
"えざき 江崎"
"えざきぐりこ 江崎グリコ"
"えざら 絵皿"
"えざわ 江澤 江沢"
"えし 絵師 画師 壊死"
"えしゃく 会釈"
"えじ 江地 衛士"
"えじき 餌食"
"えじぷと 埃及"
"えじま 江嶋 江島"
"えすえすせいやく エスエス製薬"
"えすかれーと エスカレート"
"えすがた 絵姿"
"えすせき Ｓ席"
"えすびーしょくひん ヱスビー食品"
"えすぺらんと エスペラント"
"えず 絵図"
"えずみ 江角"
"えずりこ 江釣子"
"えせ 似而非 似非"
"えそ 壊疽"
"えそらごと 絵空事"
"えぞ 蝦夷"
"えぞえ 江副"
"えぞら 江面"
"えた 穢多"
"えたい 得体"
"えたじま 江田島"
"えだ 荏田 江田 枝"
"えだおりとうげふきん 枝折峠付近"
"えだがり 枝刈り"
"えだげ 枝毛"
"えだじょう 枝状"
"えだずみ 枝炭"
"えだせん 枝線"
"えだなみ 枝並"
"えだは 枝葉"
"えだばり 枝針"
"えだばん 枝番"
"えだぶり 枝振り"
"えだまつ 枝松"
"えだまめ 枝豆"
"えだみち 枝道"
"えだわかれ 枝分かれ 枝わかれ"
"えち 乢"
"えちがわ 愛知川"
"えちけっと エチケット"
"えちご 越後"
"えちぜん 越前"
"えちぜんみさき 越前岬"
"えっきょう 越境"
"えっけん 謁見 越権"
"えっせい エッセイ"
"えっちゅう 越中"
"えっちゅうじま 越中島"
"えっとう 越冬"
"えっぺい 閲兵"
"えつ 鉞 粤 戉 噎 謁 閲 悦 越"
"えつお 悦夫"
"えつこ 絵津子 英津子 恵津子 えつ子 悦子"
"えつじ 悦次 悦司"
"えつたろう 悦太郎"
"えつねん 越年"
"えつや 悦也 悦哉"
"えつよ 悦代"
"えつらく 悦楽"
"えつらん 閲覧"
"えつろう 悦朗"
"えづくり 絵作り"
"えて 得手"
"えてき 絵的"
"えてこう 猿猴"
"えてして 得てして"
"えと 干支"
"えとう 恵藤 江頭 江藤 衛藤"
"えとく 会得"
"えとろふ 択捉"
"えど 穢土 江戸"
"えどくら 江戸蔵"
"えどさき 江戸崎"
"えどざき 江戸崎"
"えどっこ 江戸っ子"
"えどてん 江戸展"
"えどむらさき 江戸紫"
"えな 絵奈 恵那"
"えなざくら 恵那櫻"
"えなじー エナジー"
"えなつ 江夏"
"えなみ 榎並"
"えなり 江成"
"えにし 縁"
"えにっき 絵日記"
"えにわ 恵庭"
"えぬえちけいほーる ＮＨＫホール"
"えぬきょう Ｎ響"
"えぬこ Ｎ個"
"えぬじげん Ｎ次元"
"えぬま 江沼"
"えねるぎ エネルギ"
"えねるぎー エネルギー"
"えの 榎"
"えのき 榎木 榎"
"えのきだ 榎田"
"えのきど 榎戸"
"えのぐ 絵具 絵の具"
"えのしま 江ノ島 江の島"
"えのぞの 榎園"
"えのと 榎戸"
"えのもと 榎本"
"えはがき 絵はがき 絵葉書"
"えはた 江畑 江幡"
"えはら 荏原 江原"
"えばた 江端"
"えばら 江原"
"えばらこ 桧原湖"
"えひめ 愛媛"
"えび エビ 鰕 蝦 蛯 海老"
"えびさわ 海老澤 海老沢"
"えびす 胡 蛭子 ヱビス 貊 狄 戎 恵比須 夷 恵比寿"
"えびすがお 恵比寿顔"
"えびづか 海老塚"
"えびな 蝦名 海老名"
"えびね 恵比根"
"えびはら 海老原 蛯原"
"えぴそーど エピソード"
"えふだ 絵札"
"えふで 絵筆"
"えべつ 江別"
"えほん 絵本"
"えぼし 烏帽子"
"えぽ ＥＰＯ"
"えま 絵馬 絵麻"
"えまき 絵巻"
"えみ エミ 江民 笑み 笑 恵実 映見 絵美 栄美 恵美"
"えみか 恵美香"
"えみこ 江美子 栄美子 恵美子 絵美子 絵己子 英美子"
"えみり 恵美里"
"えむかえ 江迎"
"えむら 江村"
"えめらるど エメラルド"
"えもじ 絵文字"
"えもと 柄本 絵本 江本"
"えもの 得物 獲物"
"えもん 衛門 衣紋"
"えら 腮 江良 鰓"
"えらー エラー"
"えらさ 偉さ"
"えらびかた 選び方"
"えり 枝里 絵理 惠理 江利 衿 えり 絵莉 恵理 愛理 英理 衣理 エリ 恵里 恵利 絵里 襟"
"えりーと エリート"
"えりあ エリア"
"えりか 江利香 惠理香 絵里花 恵理香"
"えりくび 襟首"
"えりぐり 襟刳り"
"えりこ 江里子 江利子 恵理子 江梨子 絵梨子 英理子 えり子 絵理子 英里子"
"えりごのみ 選り好み"
"えりさ 恵利沙"
"えりしょう 襟章 衿章"
"えりな 江理奈"
"えりまき 襟巻"
"えりみ 恵里美"
"えりもと 襟元"
"えりもみさき 襟裳岬"
"えるなーど エルナード"
"えれくとろにくす エレクトロニクス"
"えれべーた エレベータ"
"えん 媛 鳶 垣 閼 黶 鹽 魘 閹 閻 轅 讌 覃 袁 蜿 蜒 艷 臙 簷 篶 筵 爰 烟 湲 渊 渕 淹 衍 櫞 檐 掾 捐 悁 寃 嫣 婉 圜 圓 嚥 冤 偃 焉 ￥ 堰 奄 怨 掩 厭 猿 燕 沿 焔 艶 薗 鴛 淵 宴 苑 炎 鉛 援 塩 遠 縁 煙 宛 演 延 園 円"
"えんい 遠位"
"えんいん 遠因"
"えんうんどう 円運動"
"えんえい 遠泳"
"えんえき 演繹"
"えんえきぎ 演繹木"
"えんえん 蜿々 蜿蜒 奄奄 延々"
"えんか 嚥下 怨歌 円貨 円価 塩化 演歌"
"えんかい 遠海 沿海 宴会"
"えんかいげい 宴会芸"
"えんかいしゅう 沿海州"
"えんかく 沿革 遠隔"
"えんかつ 円滑"
"えんかる 遠軽"
"えんかわせ 円為替"
"えんかん 煙管 円環 鉛管"
"えんかんさん 円換算"
"えんがい 鉛害 煙害 塩害 円外"
"えんがる 遠軽"
"えんがわ 縁側"
"えんがん 沿岸"
"えんき 塩基 延期"
"えんきごう 円記号"
"えんきどう 円軌道"
"えんきょう 円鏡 燕京"
"えんきょく 婉曲"
"えんきょり 遠距離"
"えんきり 縁切り"
"えんきりでら 縁切り寺"
"えんきん 遠近"
"えんぎ 縁起 演技"
"えんぎもの 縁起物"
"えんぐみ 縁組"
"えんぐん 援軍"
"えんけい 冤刑 遠景 円形"
"えんげ 嚥下"
"えんげい 園藝 演芸 園芸"
"えんげいか 園芸家"
"えんげき 演劇"
"えんげん 淵源"
"えんこ 縁故 円弧"
"えんこうるい 円口類"
"えんこく 遠国"
"えんこけい 円弧形"
"えんこん 怨恨"
"えんご 掩護 援護"
"えんさ 怨嗟"
"えんさん 演算 塩酸"
"えんざい 寃罪 冤罪"
"えんざん 塩山 演算"
"えんし 遠視"
"えんしつ 煙室"
"えんしゃ 演者"
"えんしゃっかん 円借款"
"えんしゅう 遠州 円周 演習"
"えんしゅうはまかいがん 遠州浜海岸"
"えんしゅつ 演出"
"えんしゅつか 演出家"
"えんしょ 炎暑"
"えんしょう 円生 艶笑 煙硝 延焼 炎症"
"えんしょうじ 円勝寺"
"えんしん 延伸 遠心力 遠心"
"えんじ 槐 臙脂 園児"
"えんじぇるす エンジェルス"
"えんじぇるず エンジェルズ"
"えんじつてん 遠日点"
"えんじにあ エンジニア"
"えんじゃ 演者 縁者"
"えんじゅく 円熟"
"えんじゅくみ 円熟味"
"えんじょ 援助"
"えんじょい エンジョイ"
"えんじょう 円状 炎上 遠城"
"えんじょうじ 円城寺"
"えんじょひ 援助費"
"えんじん 円陣 猿人 エンジン"
"えんすい 塩水 円錐"
"えんすいけい 円錐形"
"えんすいこう 塩水港"
"えんずい 延髄"
"えんずいぎり 延髄斬"
"えんせい 縁生 厭世 遠征"
"えんせいがい 袁世凱"
"えんせいひ 遠征費"
"えんせき 遠戚 宴席 縁石"
"えんせきがいせん 遠赤外線"
"えんせきがいせんばいせん 遠赤外線倍煎"
"えんせん 厭戦 沿線"
"えんせんず 円線図"
"えんぜつ 演舌 演説"
"えんぜん 嫣然 婉然 艶然"
"えんそ 塩素"
"えんそう 演奏"
"えんそうか 演奏家"
"えんそうちゅうどく 煙草中毒"
"えんそうば 円相場"
"えんそく 遠足"
"えんそさん 塩素酸"
"えんぞう 円蔵"
"えんた 苑田 遠田"
"えんたーていめんと エンターテイメント"
"えんたい 淹滞 掩体 延滞"
"えんたく 円卓"
"えんたんい 円単位"
"えんだ 遠田 苑田"
"えんだい 縁台 演台 円台 遠大 演題"
"えんだか 円高"
"えんだて 円建て"
"えんだま 円玉"
"えんだん 縁談 演壇"
"えんち 遠地"
"えんちくでんち 鉛蓄電池"
"えんちゃく 延着"
"えんちゅう 円柱"
"えんちょう 園長 延長"
"えんちょうきゅう 円頂丘"
"えんちょうせん 延長戦"
"えんちょく 鉛直"
"えんちん 遠沈"
"えんてい 堰堤 園丁"
"えんてつ 遠鉄"
"えんてん 炎天 遠点"
"えんでぃんぐ エンディング"
"えんでん 塩田"
"えんとう 遠投 円筒"
"えんとうけい 円筒形"
"えんとつ 煙突"
"えんとり エントリ"
"えんとりー エントリー"
"えんとろぴいさいだいりろん エントロピー最大理論"
"えんど 塩度 エンド"
"えんどーちぇーん エンドーチェーン"
"えんどう 豌豆 沿道 遠藤"
"えんどうまめ 豌豆豆"
"えんない 円内 園内"
"えんにち 縁日"
"えんねつ 炎熱"
"えんのした 縁の下"
"えんのすけ 猿之助"
"えんばん 円盤 円板"
"えんぱく 延泊"
"えんぱつ 延発"
"えんび 燕尾"
"えんびふく 燕尾服"
"えんぴつ 鉛筆"
"えんぶ 演武 円舞"
"えんぶん 艶聞 塩分"
"えんぶんれん 遠文連"
"えんへんこう 円偏光"
"えんべつ 遠別"
"えんべろーぷ エンベロープ"
"えんぺい 掩蔽"
"えんぺん 縁辺"
"えんぼう 遠望"
"えんぽう 演報 遠方"
"えんぽうば 遠方場"
"えんま 閻魔"
"えんまく 煙幕"
"えんまん 円満"
"えんみらい 遠未来"
"えんむすび 縁結び"
"えんめい 延命"
"えんもく 演目"
"えんやす 円安"
"えんゆうかい 宴遊会 園遊会"
"えんよう 遠洋 援用"
"えんらい 遠来 遠雷"
"えんらく 円楽 猿楽"
"えんり 厭離"
"えんりゃくじ 延暦寺"
"えんりょ 遠慮"
"えんろ 遠路"
"お 麻 苧 将 乎 悪 淤 塢 嗚 唹 郎 朗 勇 穂 桜 牡 央 緒 織 生 小 男 雄 於 御 汚 夫 尾"
"おーけすとら オーケストラ"
"おーすとらりあ 濠太剌利"
"おーすとりあ 墺太利"
"おーだー オーダー"
"おーでぃお オーディオ"
"おーとばい オートバイ"
"おーとめーしょん オートメーション"
"おーなー オーナー"
"おーばー オーバー"
"おーばーらっぷ オーバーラップ"
"おーぷん オープン"
"おーむ 王蟲 Ω"
"おーやんふぃふぃ 欧陽菲菲"
"おーる オール"
"おーれ ＯＲＥ"
"おあいそ お愛想"
"おあいて 御相手 お相手"
"おあしす オアシス"
"おあずけ お預け"
"おあふとう オアフ島"
"おあらため お改め"
"おい 老い 笈 及 追 甥"
"おいえ 尾家"
"おいえげい 御家藝 御家芸 お家芸"
"おいえそうどう 御家騒動"
"おいおい 追々"
"おいかぜ 追い風"
"おいかわ 生川 追川 及川"
"おいけ 御池"
"おいこし 追越し 追越 追い越し"
"おいこみ 追い込み"
"おいこん 追いコン"
"おいしゃ お医者"
"おいしんぼ 美味しんぼ"
"おいそがしい お忙しい"
"おいそぎ お急ぎ"
"おいた 置いた"
"おいたち 生い立ち"
"おいだし 追出"
"おいち 尾市"
"おいつ 老津"
"おいて 於て 於"
"おいのり お祈り"
"おいはま 生浜 追浜"
"おいべ 及部"
"おいまつ 老松"
"おいまわし 追廻"
"おいめ 負い目"
"おいめい 甥姪"
"おいらせ 奥入瀬"
"おいらん 花魁"
"おいる オイル"
"おいろなおし 御色直し お色直し"
"おいわい 御祝 御祝い お祝い"
"おいわけ 追分"
"おう 邑 鴨 姶 惶 悒 鸚 鞅 閘 鏖 謳 蓊 罌 秧 甌 瓮 澳 浤 泓 泱 汪 毆 殃 歐 櫻 枉 懊 怏 徃 媼 奧 墺 嚶 嘔 凰 應 奥 殴 凹 翁 押 央 襖 旺 皇 桜 鴎 往 鴬 黄 王 横 欧 応"
"おうあ 歐亞"
"おうい 王位"
"おういせん 王位戦"
"おういつ 汪溢 横溢"
"おういん 桜蔭 押印"
"おういんご 欧印語"
"おうう 奥羽"
"おうえん 応援"
"おうえんか 応援歌"
"おうえんせき 応援席"
"おうおう 往々"
"おうか 櫻花 応化 欧化 押下 謳歌 桜花"
"おうかく 旺角"
"おうかくまく 横膈膜 横隔膜"
"おうかしょうば 桜花賞馬"
"おうかん 往還 王冠"
"おうが 横臥"
"おうがい 鴎外"
"おうきゅう 王宮 応急"
"おうぎ 奥技 奥儀 扇"
"おうぎがた 扇形"
"おうぎがやつ 扇ヶ谷"
"おうぎさわ 扇沢"
"おうぎや 扇谷"
"おうけ 王家"
"おうけとり お受け取り"
"おうこう 王侯 往航 横行"
"おうこく 王国"
"おうご 朷"
"おうごん 黄金"
"おうごんちゅう 黄金虫"
"おうさか 逢坂 大坂"
"おうさだはる 王貞治"
"おうさつ 応札 殴殺 鏖殺"
"おうさま 王様"
"おうざ 王座"
"おうざせん 王座戦"
"おうし 雄牛 横死 牡牛"
"おうしざ 牡牛座"
"おうしつ 王室"
"おうしゃ 王者"
"おうしゅ 応手"
"おうしゅう 欧洲 歐洲 歐州 奥州 押収 欧州 応酬"
"おうしゅうしゃ 欧州車"
"おうしゅうぜい 欧州勢"
"おうしゅうなみ 欧州並"
"おうしょう 応召 王将"
"おうしょうせん 王将戦"
"おうしょく 黄色"
"おうしん 往診 往信"
"おうじ 王寺 欧字 皇子 往時 王子"
"おうじゃ 王者"
"おうじやまきゅうじょう 王子山球場"
"おうじょ 皇女 王女"
"おうじょう 王城 応情 往生"
"おうじょうぎわ 往生際"
"おうじょうけん 応用情報学研究センター"
"おうすい 王水"
"おうすう 応数"
"おうせ 逢瀬"
"おうせい 王制 王政 旺盛"
"おうせいもう 黄青盲"
"おうせつ 応接"
"おうせつま 応接間"
"おうせん 鏖戦 応戦"
"おうぜんじ 王禅寺"
"おうそ 応訴"
"おうそうじ 大掃除"
"おうそうだん 応相談"
"おうぞく 王族"
"おうた 桜多"
"おうたい 黄体 横隊 応待 応対"
"おうだ 殴打"
"おうだく 応諾"
"おうだん 黄疸 応談 黄胆 横断"
"おうだんきょう 横断橋"
"おうだんまく 横断幕"
"おうち 相知 欒 邑智 尾内"
"おうちゃく 横着"
"おうちゃくもの 横着者"
"おうちょう 王朝"
"おうて 王手"
"おうてい 奥底"
"おうてびしゃ 王手飛車"
"おうてん 横転"
"おうでん 応電"
"おうと 王都 嘔吐"
"おうとう 大塔 鴨東 櫻桃 桜桃 応答"
"おうとうや 応答野"
"おうとつ 凹凸"
"おうどいろ 黄土色"
"おうどう 横動 黄道 横道 王道"
"おうどうこう 黄道光 黄銅鉱"
"おうな 翁 嫗 媼"
"おうなつ 押捺"
"おうねつびょう 黄熱病"
"おうねん 往年"
"おうのう 懊悩"
"おうはん 凹版"
"おうばんが 凹版画"
"おうひ 王妃"
"おうびりん 桜美林"
"おうふう 欧風"
"おうふく 往復"
"おうふくぶんうんちん 往復分運賃"
"おうぶつ 応用物理 応物"
"おうぶん 応分 欧文"
"おうぶんしゃ 旺文社"
"おうへい 横柄"
"おうへん 応変"
"おうべい 欧米"
"おうべいば 欧米馬"
"おうほう 應報 応報"
"おうぼ 応募"
"おうぼう 横暴"
"おうぼけん 応募券"
"おうぼたすう 応募他数"
"おうぼばこ 応募箱"
"おうま 逢魔"
"おうまがとき 逢魔が刻"
"おうみ 青海 近江"
"おうみしおつ 近江塩津"
"おうみしおづ 近江塩津"
"おうみじ 近江路"
"おうみちょうしじょう 近江町市場"
"おうむ 王蟲 雄武 鸚鵡"
"おうむがえし おうむ返し"
"おうめ 青梅"
"おうめん 凹面"
"おうめんきょう 凹面鏡"
"おうもんきん 横紋筋"
"おうゆう 鴎友"
"おうよう 應用 鷹揚 応用"
"おうようでんしぶだい 応用電子部第"
"おうら 邑楽"
"おうらい 往来"
"おうりつがっかい 王立学会"
"おうりょう 横領"
"おうりょく 応力"
"おうりょくしょく 黄緑色"
"おうりん 黄燐"
"おうれつか 横裂果"
"おうれんあか オウレン亜科"
"おうろ 往路"
"おえかき お絵かき お絵描き お絵書き"
"おえつ 嗚咽"
"おえらがた お偉方"
"おお 夛 多 大"
"おおあかじ 大赤字"
"おおあさ 大朝"
"おおあざ 大字"
"おおあし 大足"
"おおあじ 大味"
"おおあせ 大汗"
"おおあたり 大当たり"
"おおあな 大穴"
"おおあばれ 大暴れ"
"おおあま 大甘"
"おおあみ 大網"
"おおあめ 大雨"
"おおあらい 大洗"
"おおあれ 大荒れ"
"おおい 大飯 大井"
"おおいけ 大池"
"おおいし 大石"
"おおいしだ 大石田"
"おおいずみ 大泉"
"おおいずみむらやくば 大泉村役場"
"おおいそ 大磯"
"おおいそがし 大忙し"
"おおいそぎ 大急ぎ"
"おおいた 大分"
"おおいち 大市"
"おおいちばん 大一番"
"おおいちょう 大銀杏 大堰町"
"おおいと 大糸"
"おおいに 大いに"
"おおいのかみ 大炊頭"
"おおいり 大入"
"おおいわ 大岩"
"おおう 奥羽"
"おおうえ 大上"
"おおうずまき 大渦巻"
"おおうせんけいゆう 奥羽線経由"
"おおうそ 大嘘"
"おおうだ 大宇陀"
"おおうち 大内"
"おおうちどおり 大内通"
"おおうら 大浦"
"おおうらわざ 大裏技"
"おおうりだし 大売り出し 大売出し"
"おおえ 大江"
"おおえど 大江戸"
"おおえどそうさもう 大江戸捜査網"
"おおえのき 大榎"
"おおえん 応援"
"おおおか 大岡"
"おおおかやまけいゆう 大岡山駅経由"
"おおおく 大奥"
"おおおとこ 大男"
"おおおやぶん 大親分"
"おおかじ 大火事"
"おおかぜ 大風"
"おおかた 大片 大方"
"おおかぶぬし 大株主"
"おおかみ 狼"
"おおかみおとこ 狼男"
"おおかみおんな 狼女"
"おおかみしょうねん 狼少年"
"おおかれ 多かれ"
"おおかわ 大河 大川"
"おおかわばた 大川畑"
"おおかわら 大河原"
"おおかんだ 大神田"
"おおが 大賀"
"おおがえし 大返し"
"おおがき 大柿 大書 大垣"
"おおがけ 大駆"
"おおがた 大方 大潟 大形 大型"
"おおがたぎょ 大型魚"
"おおがたけん 大型犬"
"おおがたしゃ 大型車"
"おおがたじゅう 大型獣"
"おおがたせん 大型船"
"おおがたば 大型馬"
"おおがたまど 大型窓"
"おおがね 大鐘 大金"
"おおがねもち 大金持"
"おおがめ 鰲"
"おおがら 大柄"
"おおがらす 大鴉"
"おおがわた 大河原"
"おおがわら 大河原"
"おおき 大城 大木"
"おおきかいがん 大岐海岸"
"おおきさ 大きさ"
"おおきた 大北"
"おおきに 大きに"
"おおきめ 大き目"
"おおぎ 青木 扇 仰木"
"おおぎがた 扇型"
"おおぎがはら 扇ヶ原"
"おおぎし 大岸"
"おおぎたに 扇谷"
"おおぎばし 扇橋"
"おおぎまち 扇町"
"おおぎみ 大宜味"
"おおぎょう 大仰"
"おおぎり 大喜利"
"おおくずれ 大崩れ"
"おおくち 大口"
"おおくにぬしのみこと 大国主命"
"おおくぼ 大窪 大久保"
"おおくま 逢隈 大隈 大熊"
"おおくまざ 大熊座"
"おおくら 大蔵 大倉"
"おおくらしょう 大蔵省"
"おおくり お送り"
"おおくわ 大桑"
"おおぐし 大串"
"おおぐす 大楠"
"おおぐち 大口"
"おおぐろ 大黒"
"おおけが 大怪我"
"おおげさ 大袈裟"
"おおげつひめのかみ 大宜津比売神 大気津比売神"
"おおげんか 大喧嘩"
"おおこうち 大河内"
"おおこし 大越"
"おおこめ 大米"
"おおご 大湖 大胡"
"おおごえ 大越 大声"
"おおごしょ 大御所"
"おおごと 大事"
"おおごま 大駒"
"おおごんはくぶつかん 黄金博物館"
"おおさ 大佐"
"おおさか 逢坂 大坂 大阪"
"おおさかおおしょう 大阪王将"
"おおさかこう 大阪港"
"おおさかさんだい 大阪産大"
"おおさかしょうちくざ 大阪松竹座"
"おおさかほか 大阪他"
"おおさき 大崎"
"おおさこ 大迫"
"おおさと 大郷 大里"
"おおさわ 大澤 大沢"
"おおさわぎ 大騒ぎ"
"おおさわの 大沢野"
"おおさんばし 大棧橋"
"おおざけのみ 大酒飲み"
"おおざっぱ 大雑把"
"おおざと 大里"
"おおざはた 大座畑"
"おおざら 大皿"
"おおしお 大潮"
"おおしか 大鹿"
"おおしげ 大重"
"おおしごと 大仕事"
"おおした 大下"
"おおしば 大柴 大芝"
"おおしま 大島 大嶋"
"おおしみず 大清水"
"おおしょうぎ 大将棋"
"おおしょうぶ 大勝負"
"おおしろ 大城"
"おおじ 王寺 大路"
"おおじだい 大時代"
"おおじぬし 大地主"
"おおじま 大島"
"おおじょたい 大世帯 大所帯"
"おおす 大須"
"おおすか 大須賀"
"おおすが 大須賀"
"おおすぎ 大杉"
"おおすじ 大筋"
"おおすみ 大角 大隈 大隅 大住"
"おおず 大洲"
"おおずもう 大相撲"
"おおずわ 大諏訪"
"おおせ 仰せ 大瀬"
"おおせざき 大瀬崎"
"おおせと 大瀬戸"
"おおぜい 多勢 大勢"
"おおぜき 大関"
"おおそうじ 大掃除"
"おおそうどう 大騒動"
"おおそが 大曽我"
"おおそとわく 大外枠"
"おおぞこ 大底"
"おおぞね 大曽根"
"おおぞら 大空"
"おおぞん 大損"
"おおた 大田 太田"
"おおたか 大高"
"おおたき 大多喜 王滝 大瀧 大滝"
"おおたくたいかい 太田区大会"
"おおたくひがしゆきがや 大田区東雪谷"
"おおたぐろ 太田黒"
"おおたけ 大武 大嶽 大丈 大竹"
"おおたけしのぶ 大竹しのぶ"
"おおたち 大立"
"おおたてもの 大立者"
"おおたに 大谷"
"おおたま 大玉"
"おおたわら 大田原"
"おおだ 大田"
"おおだい 大台"
"おおだいこ 大太鼓"
"おおだか 大高"
"おおだけ 大岳"
"おおだこ 大ダコ"
"おおだち 大館 大立"
"おおだて 大館"
"おおだま 大玉"
"おおだんえん 大団円"
"おおち 邑智"
"おおちがい 大違い"
"おおつ 大津"
"おおつか 大塚"
"おおつかあきら 大塚明"
"おおつが 大津賀"
"おおつき 大規 大附 大月 大槻"
"おおつこうしゅうへん 大津港周辺"
"おおつごもり 大晦 大晦日"
"おおつち 大槌"
"おおつちわん 大槌湾"
"おおつなみ 大津波"
"おおつの 大角"
"おおつぶ 大粒"
"おおつぼ 大坪"
"おおつま 大妻"
"おおつる 大鶴"
"おおづ 大津"
"おおづめ 大詰 大詰め"
"おおて 大手"
"おおてとしぎん 大手都市銀"
"おおてる 大照"
"おおで 大手"
"おおとう 大任 大塔"
"おおとかげ 大蜥蜴"
"おおとね 大利根"
"おおとのさま 大殿様"
"おおとも 大伴 大友"
"おおとよ 大豊"
"おおとり 鵬 鳳 鴻"
"おおとりい 大鳥居"
"おおとりじんじゃ 大鳥神社"
"おおどうぐ 大道具"
"おおどおり 大通 大通り"
"おおどけい 大時計"
"おおなえ 大苗"
"おおなき 大泣き"
"おおなべ 大鍋"
"おおなみ 大浪 大波"
"おおなんじ 大汝"
"おおにし 大西"
"おおにた 大仁田"
"おおにもつ 大荷物"
"おおにんずう 大人数 多人数"
"おおぬき 大貫"
"おおぬま 大沼"
"おおね 大根"
"おおねじめ 大根占"
"おおねだ 大根田"
"おおの 大野"
"おおのくに 大乃国"
"おおのみ 大野見"
"おおはさ 大迫"
"おおはざま 大間"
"おおはし 大橋"
"おおはじ 大恥"
"おおはた 大畠 大畑"
"おおはば 大幅"
"おおはま 大濱 大浜"
"おおはやり 大流行"
"おおはら 大原"
"おおはる 大治"
"おおば 大庭 大場"
"おおばか 大馬鹿"
"おおばかもの 大莫迦者 大馬鹿者"
"おおばけ 大化け"
"おおばこ 大箱"
"おおばたけ 大畠"
"おおばやし 大林"
"おおばん 大盤 大番 大版 大判"
"おおばんぶるまい 大盤振舞 大番振舞い"
"おおばんやき 大判焼"
"おおひさ 大久"
"おおひと 大仁"
"おおひら 大衡 大平"
"おおひろま 大広間"
"おおびけ 大引け"
"おおびん 大瓶 大壜"
"おおふか 大深"
"おおふく 大福"
"おおふな 大船"
"おおふなと 大船渡"
"おおふね 大舟"
"おおふろしき 大風呂敷"
"おおぶ 大府"
"おおぶくろ 大袋"
"おおぶち 大渕 大淵"
"おおぶね 大船"
"おおべや 大部屋"
"おおほ 大穂"
"おおほり 大濠 大堀"
"おおぼけ 大歩危 大ぼけ 大ボケ"
"おおま 大間"
"おおまえ 大前"
"おおまか 大まか"
"おおまがり 大曲"
"おおまき 大蒔"
"おおまじめ 大真面目"
"おおまた 大股"
"おおまち 大町"
"おおまつ 大松"
"おおまど 大窓"
"おおまぬけ 大間抜"
"おおまま 大間々"
"おおまめうだ 大豆生田"
"おおまわり 大回り"
"おおみ 大見"
"おおみか 大甕"
"おおみず 大水"
"おおみそか 大晦日"
"おおみぞ 大溝"
"おおみだし 大見出し"
"おおみつ 大光"
"おおみなと 大湊"
"おおみね 大峰"
"おおみや 大宮"
"おおむかし 大昔"
"おおむぎ 大麦"
"おおむた 大牟田"
"おおむね 概ね 大旨 概"
"おおむら 大村"
"おおむらわん 大村湾"
"おおむろ 大室"
"おおめ 多目 大目"
"おおめだま 大目玉"
"おおもじ 大文字"
"おおもと 大本 大元"
"おおもときょう 大本教"
"おおもの 大物"
"おおもも 大桃"
"おおもり 大盛 大盛り 大森"
"おおや 大宅 大屋 大家 大谷 大矢"
"おおやぎ 大八木 大谷木"
"おおやけ 公"
"おおやけど 大火傷"
"おおやす 大保"
"おおやすうり 大安売 大安売り"
"おおやち 大矢知"
"おおやの 大矢野"
"おおやま 大山"
"おおやまぐち 大山口"
"おおやまだ 大山田"
"おおやまやすはる 大山康晴"
"おおやん 欧陽"
"おおゆ 大湯"
"おおゆき 大雪"
"おおゆみ 大弓"
"おおよせ 大寄"
"おおよそ 凡そ 大凡"
"おおよど 大淀"
"おおよろこび 大喜び"
"おおよわり 大弱り"
"おおわき 大脇"
"おおわく 大和久 大枠"
"おおわざ 大技"
"おおわだ 大輪田 大和田"
"おおわだばく 大和田獏"
"おおわに 大鰐"
"おおわらい 大笑い"
"おおわらわ 大童"
"おか 阜 峻 陵 岳 丘 岡"
"おかあさま お母様 お母さま"
"おかあさん お母さん"
"おかい 汚怪 小粥"
"おかいあげ お買上"
"おかいどく お買い得"
"おかうち 岡内"
"おかえ 岡江"
"おかえし お返し"
"おかがき 岡垣"
"おかがみ 岡上"
"おかげ お陰 御蔭 お蔭 御陰"
"おかげん 御加減 お加減"
"おかさか 岡坂"
"おかさん 岡三"
"おかざき 丘咲 岡崎"
"おかざわ 岡澤"
"おかざわちょう 岡沢町"
"おかし お菓子"
"おかしい 可笑しい"
"おかしま 岡島"
"おかじま 岡嶋 岡島"
"おかぞえ 岡添"
"おかた お方 岡田"
"おかだ 岡田"
"おかだい 岡大"
"おかだせん 岡多線"
"おかだま 丘珠"
"おかちまち 御徒町"
"おかちめんこ オカチメンコ"
"おかって お勝手"
"おかつ 雄勝"
"おかと 岡登"
"おかどめ 岡留"
"おかね お金"
"おかの 岡野"
"おかはし 岡橋"
"おかはち 岡八"
"おかはら 岡原"
"おかはる 岡原"
"おかばやし 岡林"
"おかひさ 岡久"
"おかひら 岡平"
"おかふじ 岡藤"
"おかぶ 御株"
"おかべ 岡部"
"おかみ 女将 御上"
"おかむら 岡村"
"おかむろ 岡室"
"おかめ 傍目"
"おかめはちもく 傍目八目"
"おかもち 岡持"
"おかもと 岡元 岡本"
"おかや 岡谷"
"おかやす 岡安"
"おかやすこう 岡安高"
"おかやま 岡山"
"おかやまひがし 岡山東"
"おかゆ 小粥"
"おからだ お身体"
"おかりな オカリナ"
"おかわり お変り"
"おかん 惡寒 お燗 悪寒"
"おかんがえ お考え"
"おが 男鹿"
"おがい 小粥"
"おがくず 大鋸屑"
"おがさ 小笠"
"おがさか 小賀坂"
"おがさはら 小笠原"
"おがさわら 小笠原"
"おがた 緒形 緒方 尾形 小方"
"おがたけん 緒方拳 緒形拳"
"おがつ 雄勝"
"おがの 小鹿野"
"おがみ 尾上"
"おがゆ 小粥"
"おがら 麻幹"
"おがわ 尾河 緒川 尾川 小河 小川"
"おがわな 小川名"
"おき 熈 興 お気 煕 置き 隠岐 沖"
"おきあい 沖合 沖合い"
"おきあがりこぼし 起き上がり小法師"
"おきいし 置き石"
"おきかえ 置換え 置き換え"
"おきがさ 置き傘"
"おきがる 御気軽"
"おきくら 沖倉"
"おきこうぎょう 沖工業"
"おきごたつ 置き炬燵"
"おきざり 置き去り"
"おきそ 小木曽"
"おきた 小木田 沖田"
"おきつ 興津"
"おきつうしん 沖通信"
"おきつち 置き土"
"おきて 沖手 諚 掟"
"おきでんき 沖電気"
"おきとちょう 置戸町"
"おきな 奥菜 翁"
"おきなか 沖中"
"おきなかし 沖仲士"
"おきなわ 沖繩 沖縄"
"おきなわさん 沖縄産"
"おきなわもの 沖縄物"
"おきにいり お気に入り"
"おきのしま 隠岐島"
"おきば 置き場 置場"
"おきび 燠火"
"おきふじ 沖藤"
"おきまつしま 沖松島"
"おきまゆみ 沖まゆみ"
"おきまり お決まり"
"おきみ 沖美"
"おきめ 沖目"
"おきもち お気持"
"おきもと 沖本"
"おきもの 置物"
"おきゃく お客"
"おきゃくさま 御客様"
"おきゃくさん お客さん"
"おきゃん 御侠 お侠"
"おきょう お経"
"おきわたし 沖渡し"
"おぎ 蒹 尾木 小木 小城 荻"
"おぎくぼ 荻窪"
"おぎしま 荻島"
"おぎそ 小木曽"
"おぎた 荻田 小木田"
"おぎつ 荻津"
"おぎにしき 小城錦"
"おぎの 荻布 荻野"
"おぎのめ 萩野目 萩目"
"おぎはら 荻原"
"おぎゅうそらい 荻生徂徠"
"おぎわら 荻原"
"おく 尾久 檍 奧 邑久 屋 憶 臆 奥 億"
"おくい 奥居 奥井"
"おくいずも 奥出雲"
"おくいぶき 奥伊吹"
"おくえん 億円"
"おくかい 億回"
"おくかわ 奥川"
"おくがい 屋外"
"おくきょうと 奥京都"
"おくぎ 奥義"
"おくこ 億個"
"おくさがみ 奥相模"
"おくさき 奥崎"
"おくさま 奥様"
"おくさわ 奥澤 奥沢"
"おくさん 奥さん"
"おくしが 奥志賀"
"おくしり 奥尻"
"おくしりとう 奥尻島"
"おくじょう 屋上"
"おくじょうおく 屋上屋"
"おくせ 奥瀬"
"おくせつ 憶説"
"おくそく 臆測 憶測"
"おくそこ 奥底"
"おくただみ 奥只見"
"おくたに 奥谷"
"おくたま 奥多摩"
"おくたんい 億単位"
"おくだ 奥田"
"おくだて 奥立"
"おくち 奥地"
"おくつ 奥津"
"おくづけ 奥付"
"おくで 奥出"
"おくでら 奥寺"
"おくでん 奥伝"
"おくとね 奥利根"
"おくとみ 奥富"
"おくない 奥内 屋内"
"おくなが 奥永"
"おくにっかわ 奥新川"
"おくにっこう 奥日光"
"おくにん 億人"
"おくぬき 奥貫"
"おくねん 億年"
"おくの 奥乃 奥野"
"おくのて 奥の手"
"おくのと 奥能登"
"おくはら 奥原"
"おくば 奥歯"
"おくひえいがわ 奥比叡側"
"おくひだ 奥飛騨"
"おくびょう 臆病 憶病"
"おくびょうもの 臆病者"
"おくほ 奥穂"
"おくほうこう 奥方向"
"おくぼいん 奥母音"
"おくまつしま 奥松島"
"おくまんちょうじゃ 億万長者"
"おくみかわ 奥三河"
"おくみの 奥美濃"
"おくむら 奥村"
"おくめん 臆面 憶面"
"おくもと 奥本 納本"
"おくやま 奥山"
"おくやみ お悔やみ"
"おくゆき 奥行 奥行き"
"おくら 憶良"
"おくらいり お蔵入り"
"おくりかな 送り仮名"
"おくりがな 送り仮名"
"おくりさき 贈り先 送り先"
"おくりじょう 送り状"
"おくりたおし 送り倒し"
"おくりだし 送り出し"
"おくりて 送り手"
"おくりな 諡"
"おくりぬし 送主 贈り主 送り主"
"おくりび 送り火"
"おくりむかえ 送り迎え"
"おくりもの 饋 賻 贈物 贈り物"
"おくれ 遅れ"
"おくればせ 遅馳 遅れ馳せ"
"おくればせながら 遅ればせながら"
"おくわざ 奥技"
"おぐし 小串"
"おぐち 小口"
"おぐに 小国"
"おぐま 小熊"
"おぐら 小椋 小倉"
"おぐらけい 小椋佳"
"おぐり 小栗"
"おぐるま 小車"
"おぐろ 小黒"
"おけ 桶"
"おけいこ お稽古"
"おけがやぬま 桶ケ谷沼"
"おけがわ 桶川"
"おけと 置戸"
"おけはざま 桶狭間"
"おけや 桶屋"
"おけら 螻蛄"
"おげひん お下品"
"おげれつ お下劣"
"おげんき お元気 御元気"
"おこうでん 御香典"
"おこえ 御声"
"おこころ 御心"
"おこさま お子様"
"おこさん お子さん"
"おこし 小越 お越し"
"おこたえ 御答え お答え"
"おこたち 御子達"
"おこっぺ 興部"
"おことば 御言葉"
"おことわり お断り"
"おこない 行ない 行い"
"おこのぎ 小此木"
"おこのみ お好み"
"おこのみやき お好み焼き"
"おこめ お米 御米"
"おこり 瘧"
"おこりかた 怒り方"
"おごうりかん 小郡間"
"おごおり 小郡"
"おごせ 越生"
"おごと 雄琴"
"おごり 驕り 傲り 奢り"
"おさ 長"
"おさえかた 押え方"
"おさか 苧坂 尾坂 小坂"
"おさきに お先に"
"おさくひん 御作品"
"おさけ お酒"
"おさそい お誘い"
"おさだ 長田"
"おさと 長都"
"おさない 小内山 小山内 長内"
"おさないころ 幼い頃"
"おさないみえこ 小山内美江子"
"おさながお 幼顔"
"おさなご 幼子"
"おさなさ 幼さ"
"おさなづま 幼妻"
"おさななじみ 幼馴染み 幼なじみ"
"おさふね 長船"
"おさべ 長部"
"おさみ 修美"
"おさむ 納 理 収 治 治虫 修"
"おさめ 納め"
"おさめこみ 納込"
"おさわがせ お騒がせ"
"おざ 尾座"
"おざき 尾前 小崎 尾崎"
"おざきゆたか 尾崎豊"
"おざく 小作"
"おざさ 小笹"
"おざわ 尾沢 小澤 小沢"
"おざわりゅう 小沢流"
"おし 忍 鴛 押し 唖"
"おしあげ 押上"
"おしあわせ お幸せ"
"おしい 押井"
"おしいれ 押入"
"おしうり 押売"
"おしえ 押絵 教え"
"おしえご 教え子"
"おしお 押尾"
"おしか 牝鹿 牡鹿"
"おしかせん 男鹿線"
"おしかわ 押川"
"おしきせ 御仕着せ"
"おしきり 押切"
"おしくま 押熊"
"おしくも 惜しくも"
"おしごと お仕事"
"おしたおし 押し倒し"
"おしだ 押田"
"おしだし 押し出し"
"おしつけ 押し付け"
"おしどり 鴦 鴛鴦"
"おしの 忍野"
"おしばな 押し花"
"おしべ 雄蕊"
"おしま 小島"
"おしまはんとう 渡島半島"
"おしみず 押水"
"おしめ 襁 繦"
"おしゃか お釈迦"
"おしゃべり お喋り"
"おしゃまんべ 長万部"
"おしゃれ お洒落 おシャレ"
"おしょう 和尚"
"おしょうがつ お正月"
"おしょく 汚職"
"おしょくじ 御食事 お食事"
"おしらせ お知らせ"
"おしり お尻"
"おしろ お城"
"おしろい 白粉"
"おしん 悪心"
"おじ 小父 伯父 叔父"
"おじいさん お爺さん"
"おじか 小値賀 牝鹿 牡鹿"
"おじかせん 男鹿線"
"おじま 尾島 小島"
"おじゃま お邪魔 御邪魔"
"おじゃまむし お邪魔虫"
"おじょうさま お嬢様"
"おじょうさん お嬢さん"
"おじょく 汚辱"
"おじろ 尾白"
"おす 雄 牡 ♂"
"おすい 汚水"
"おすうし 雄牛"
"おすうま 牡馬"
"おすかぶ 雄株"
"おすがた 御姿"
"おすき お好き"
"おすごし お過ごし"
"おすし お寿司"
"おすすめ お薦め お勧め"
"おすたかやま 御巣鷹山"
"おすだ 小須田"
"おすとめす 雄と雌"
"おすねこ 雄猫"
"おすまい お住い"
"おすみ お済み"
"おすめす 牡牝 雄雌"
"おず 小津"
"おせ 尾瀬"
"おせいぼ 御歳暮"
"おせざき 大瀬崎"
"おせじ お世辞 御世辞"
"おせっかい 御節介 お節介"
"おせわ 御世話 お世話"
"おせん 汚染"
"おぜ 尾瀬"
"おぜき 尾関 小関"
"おぜぬま 尾瀬沼"
"おぜん お膳"
"おぜんだて お膳立て"
"おそ 遲 遅"
"おそうじ お掃除"
"おそくとも 遅くとも"
"おそざき 遅咲き"
"おそばん 遅版 遅番"
"おそまつ 御粗末"
"おそめ 遅目"
"おそらく 恐らく"
"おそる 惶"
"おそるべし 恐るべし"
"おそれ 畏れ 虞 恐れ"
"おそれざん 恐山"
"おそれる 惶"
"おそん 汚損"
"おた 織田"
"おたがい お互い"
"おたく オタク お宅"
"おたけび 雄叫び"
"おたじま 小田嶋 小田島"
"おたずね お尋ね"
"おたち お発ち"
"おたっし お達し"
"おたのしみ お楽しみ"
"おたのしみぶくろ お楽しみ袋"
"おたべ 小田部"
"おたま 御玉"
"おたまじゃくし 蝌蚪"
"おたまや 霊屋"
"おたまやした 霊屋下 御霊屋下"
"おたより お便り"
"おたり 小谷"
"おたる 小樽"
"おたんじょうび お誕生日"
"おだ 小田 織田"
"おだい お代 御題 お題 小田井"
"おだいとう 尾岱沼"
"おだか 尾高 小高"
"おだきゅう 小田原急行電鉄 小田急"
"おだぎ 小田木"
"おだぎり 小田桐 小田切"
"おだく 汚濁"
"おださかえちょう 小田栄町"
"おだしま 小田嶋"
"おだじま 小田嶋 小田島"
"おだて 煽て"
"おだなか 小田中"
"おだのぶひで 織田信秀"
"おだべ 小田部"
"おだまり お黙り"
"おだわら 小田原"
"おだわらがた 小田原方"
"おだん オ段"
"おち 越知 落ち 越智 落"
"おちあい 落合"
"おちいし 落石"
"おちえ 御知恵"
"おちかた 墜ち方"
"おちから 御力"
"おちこぼれ 落ちこぼれ"
"おちこみ 落ちこみ"
"おちど 越度 落度"
"おちば 落ち葉 落葉"
"おちみず 落ち水 落水"
"おちゃ 御茶 お茶"
"おちゃがし お茶菓子"
"おちゃづけ お茶漬"
"おちゃづけのり 御茶漬海苔"
"おちゃのま お茶の間 御茶乃間"
"おちゃのみず お茶の水 御茶ノ水 御茶の水"
"おちゃのみば お茶飲み場"
"おちゅうげん 御中元"
"おっかけ 追っかけ"
"おっきな 大っきな"
"おっくう 億劫"
"おって 追手 追っ手"
"おっと 夫"
"おっとせい 膃肭臍"
"おっぱま 追浜"
"おつ 膃 榲 乙"
"おつあん 乙案"
"おつかい お使い"
"おつかれさま お疲れ様"
"おつがわ 乙川"
"おつきさま お月様"
"おつげ 御告げ お告げ"
"おつざいよう 乙剤用"
"おつじ 尾辻"
"おつたえ お伝え"
"おつぼねさま お局様"
"おつや 御通夜"
"おつり お釣"
"おづ 小津"
"おづき 小月"
"おづつ 尾筒"
"おて お手"
"おてあげ お手あげ"
"おてあらい お手洗 御手洗"
"おてかず お手数"
"おてがみ 御手紙"
"おてがる お手軽"
"おてすう 御手数"
"おてつだい お手伝い"
"おてま お手間"
"おてまえ お点前"
"おてもり お手盛り"
"おてら お寺"
"おてん 汚点"
"おてんき お天気"
"おてんとうさま お天道様"
"おてんとさま 御天道様 お天道様"
"おてんば 御転婆 お転婆"
"おでい 汚泥"
"おでかけ お出かけ"
"おでし 御弟子"
"おでら 小寺"
"おでんわ お電話"
"おと 乙 音"
"おといあわせ お問い合わせ"
"おとうさん お父さん"
"おとうす 音薄"
"おとうと 弟"
"おとうとでし 弟弟子"
"おとうとぶん 弟分"
"おとおんかい 音音階"
"おとかず 音数"
"おとかわ 乙川"
"おとぎ 御伽"
"おとぎばなし 御伽話 お伽話"
"おとぎりそう 弟切草"
"おとぎりそうもく オトギリソウ目"
"おとくい お得意"
"おとくうかん 音空間"
"おとくに 乙訓"
"おとけんしゅつ 音検出"
"おとこ 男"
"おとこあいて 男相手"
"おとこうぞう 音構造"
"おとこおとこ 男男"
"おとこがみ 男神"
"おとこがわ 男側"
"おとこきょうだい 男兄弟"
"おとこぐみ 男組"
"おとこげいしゃ 男芸者"
"おとこことば 男言葉"
"おとこごころ 男心"
"おとこしゃかい 男社会"
"おとこじゅく 男塾"
"おとこたち 男達"
"おとこだて 男伊達"
"おとこで 男手"
"おとこどうし 男同士"
"おとこなまえ 男名前"
"おとこのこ 男の子"
"おとこのひと 男の人"
"おとこひとり 男一人"
"おとこべんじょ 男便所"
"おとこまさり 男勝"
"おとこみち 男道"
"おとこもの 男物"
"おとこやく 男役"
"おとこやま 男山"
"おとこゆ 男湯"
"おとさた 音沙汰"
"おとし お年"
"おとしあな 落とし穴 落し穴"
"おとしかた 落し方"
"おとしげき 音刺激"
"おとしだま おとし玉 お年玉"
"おとしなちょう 音更町"
"おとしもの 落とし物 落し物"
"おとしんごう 音信号"
"おとじたい 音自体"
"おとじょうほう 音情報"
"おとじろう 音二郎"
"おとせってい 音設定"
"おとそ お屠蘇"
"おとそしき 音組織"
"おとだ 音田"
"おとだし 音出し"
"おとつい 一昨日"
"おとてき 音的"
"おととい 一昨日"
"おととし 一昨年"
"おととり 音取 音取り"
"おとな 大人"
"おとなげ 大人気"
"おとなし 音無"
"おとなしく 大人しく"
"おとにゅうりょく 音入力"
"おとひめ 乙姫"
"おとふけ 音更"
"おとふじ 乙藤"
"おとべ 乙部"
"おとべつ 音別"
"おとめ 乙女"
"おとめざ 乙女座"
"おとめじゅく 乙女塾"
"おともだち お友達"
"おともれ 音洩れ"
"おとり 囮"
"おとりあつかい お取り扱い"
"おとりこみちゅう お取り込み中"
"おとりしらべ お取り調べ"
"おとりはからい お取り計らい"
"おとりひき お取り引き"
"おとろえ 衰え"
"おとわ 音羽"
"おどし 脅し 縅"
"おどり 踊り"
"おどりこ 踊り子"
"おどりば 踊り場"
"おどろき 驚き"
"おない 小内 尾内"
"おないどし 同い歳"
"おなか お腹"
"おなが 尾長 翁長"
"おながわ 女川"
"おなご 女子"
"おなじ ゝ 〃 々 同じ"
"おなじく 同じく 々"
"おなじみ お馴染"
"おなにー オナニー"
"おなはま 小名浜"
"おなまえ お名前 御名前"
"おなもみ 葹"
"おなりもん 御成門"
"おなれそめ 御馴染"
"おに 鬼"
"おにあい お似合い"
"おにいさん お兄さん"
"おにいちゃん お兄ちゃん"
"おにうだ 鬼生田"
"おにがわ 鬼皮"
"おにがわら 鬼瓦"
"おにけいじ 鬼刑事"
"おにこうべ 鬼首"
"おにざわ 鬼沢"
"おにし 鬼石"
"おにつか 鬼塚"
"おにづか 鬼塚"
"おにはは 鬼母"
"おにばば 鬼婆"
"おにび 鬼火"
"おにへい 鬼平"
"おにまろ 鬼磨呂"
"おにもつ お荷物"
"おぬま 小沼"
"おね 尾根"
"おねえさま お姉様 お姉さま"
"おねえさん お姉さん"
"おねがい お願い"
"おねがいいたします お願いいたします"
"おねだん お値段"
"おねみち 尾根道"
"おの 尾野 斧 小野"
"おのうえ 尾上"
"おのうえおんせんえき 小野上温泉駅"
"おのえ 尾上"
"おのおか 小野岡"
"おのおの 各々"
"おのかわ 小野川"
"おのがみ 小野上"
"おのがわこ 小野川湖"
"おのき 小野木"
"おのぎ 小野木"
"おのこ 男子"
"おのさと 小野里"
"おのざき 小野崎"
"おのざわ 小野沢"
"おのずから 自ずから 自ら"
"おのずと 自と"
"おのぞみ お望み"
"おのだ 小野田"
"おのだか 小野高"
"おのづか 小野塚"
"おのでら 小野寺"
"おのみち 尾道"
"おのれ 己"
"おはこ 十八番"
"おはし 御箸"
"おはせ 生長谷 小長谷"
"おはな お花"
"おはなし お話"
"おはなみ お花見"
"おはやめ お早め"
"おはら 尾原 小原"
"おはらい お赦い"
"おば 小場 小母 尾羽 叔母 伯母"
"おばあさん お婆さん"
"おばけ お化け オバケ"
"おばさん 小母さん"
"おばすて 姨捨"
"おばた 小俣 小畑 小幡"
"おばたりあん オバタリアン"
"おばな 雄花"
"おばなざわ 尾花沢"
"おばま 小浜"
"おばら 小原"
"おひきうけ お引受け"
"おひきたて お引き立て"
"おひさしぶり お久しぶり"
"おひざもと お膝元"
"おひつじ 牡羊"
"おひつじざ 牡羊座"
"おひま お暇 御暇"
"おひめさま お姫様"
"おひる お昼"
"おひるころ お昼頃"
"おひれ 尾ひれ"
"おひろめ 御披露目 お披露目"
"おび 飫肥 帶 小尾 帯"
"おびいた 帯板"
"おびえ 怯え"
"おびかわ 帯川"
"おびがき 帯書"
"おびがね 帯金"
"おびきおく 帯記憶"
"おびぎょうれつ 帯行列"
"おびこうこく 帯広告"
"おびじょう 帯状"
"おびつ 帯津"
"おびとけ 帯解"
"おびなた 大日方"
"おびなど 帯等"
"おびのこ 帯鋸"
"おびはば 帯幅"
"おびばんぐみ 帯番組"
"おびひろ 帯広"
"おびひろはくようこうこう 帯広柏葉高校"
"おびふう 帯封"
"おびら 小平"
"おびれ 尾鰭"
"おふ オフ"
"おふぃす オフィス"
"おふせ 御布施"
"おふたかた 御二方"
"おふたり 御二人 お二人"
"おふゆ 雄冬"
"おふる お古"
"おふれこ オフレコ"
"おふろ お風呂"
"おぶき 小吹"
"おぶじぇくと オブジェクト"
"おぶせ 小布施"
"おぶち 小渕"
"おぶちざわ 小淵沢"
"おぶつ 汚物"
"おぷしょん オプション"
"おへや お部屋"
"おへんじ 御返事 お返事"
"おべんきょう お勉強"
"おべんとう お弁当"
"おぺ 手術"
"おぺら オペラ"
"おぺれーしょん オペレーション"
"おぺれーた オペレータ"
"おぺれーたー オペレーター"
"おぼうさん お坊さん"
"おぼえ 憶え 覚え"
"おぼえがき 覚え書き 覚書"
"おぼろ 朧 朦"
"おぼろづき 朧月"
"おぼろづきよ 朧月夜"
"おぼん お盆"
"おまいり 御参り お参り"
"おまえ 御前 お前"
"おまえざき 御前崎"
"おまえざきおき 御前崎沖"
"おまごさん お孫さん"
"おまた 尾股 小俣"
"おまち お待ち"
"おまちがい お間違い"
"おまつり お祭り"
"おまもり 御守り お守り"
"おまわり お巡り"
"おみ 麻績 尾美 臣"
"おみあい お見合い"
"おみあし 御御足"
"おみおくり お見送り"
"おみがわ 小見川"
"おみき 御神酒"
"おみごと 御見事"
"おみず お水"
"おみせ 御店 お店"
"おみそれ 御見逸"
"おみつもり 御見積"
"おみなえし 女郎花"
"おみまい 御見舞 お見舞 御見舞い お見舞い"
"おみまいひ お見舞い費"
"おみやげ 御土産 お土産"
"おむつ 繦"
"おむにばす オムニバス"
"おむらいす オムライス"
"おむろ 御室"
"おめあて お目あて"
"おめい 汚名"
"おめいこう 御命講"
"おめいし お名刺"
"おめが ω Ω"
"おめがもう オメガ網"
"おめみえ 御目見得 お目見え"
"おめんじょう 御免状"
"おも 重 面 主"
"おもい 重茂 想い 思い 思"
"おもいきり 思い切り"
"おもいっきり 思いっきり"
"おもいで 想い出 思い出"
"おもいでばなし 思い出話"
"おもいやり 思いやり"
"おもうつぼ 思う壷"
"おもかげ 俤 面影"
"おもかじ 面舵"
"おもご 面河"
"おもさ 重さ"
"おもしろ 面白"
"おもしろい 面白い"
"おもしろさ 面白さ"
"おもしろみ 面白み 面白味"
"おもたに 面谷"
"おもだかもく オモダカ目"
"おもちゃ 玩具"
"おもて 面 表"
"おもてあみ 表編み"
"おもてうら 表裏"
"おもてかんばん 表看板"
"おもてがき 表書き"
"おもてがわ 表側"
"おもてぐち 表口"
"おもてぐみ 表組"
"おもてげんかん 表玄関"
"おもてごう 表郷"
"おもてさんどう 表参道"
"おもてざた 表沙汰 表ざた"
"おもてじ 表地"
"おもてせんけ 表千家"
"おもてどおり 表通り"
"おもてにほん 表日本"
"おもてぶた 表蓋"
"おもてぶたい 表舞台"
"おもてまんざ 表万座"
"おもてむき 表向 表向き"
"おもてろっこう 表六甲"
"おもな 主な"
"おもなが 面長"
"おもに 主に 重荷"
"おものがわ 雄物川"
"おもばば 重馬場"
"おもみ 重味 重み"
"おもむき 趣き 趣"
"おもむろ 徐"
"おももち 面持 面持ち"
"おもや 母屋"
"おもり お守り 錘 重り"
"おもわく 思惑"
"おもわず 思わず"
"おや 親"
"おやいず 小柳津"
"おやいづ 小柳津"
"おやいで 小柳出"
"おやかた お館 親方"
"おやかぶ 親株"
"おやがいしゃ 親会社"
"おやがめ 親亀"
"おやき 親機 親器"
"おやきじ 親記事"
"おやきゅうだん 親球団"
"おやく 御役"
"おやくそく 御約束 お約束"
"おやくそくどおり 御約束どおり お約束どおり"
"おやけ 小宅"
"おやこ 母子 親子"
"おやこうこう 親孝行"
"おやこたか 親子鷹"
"おやこどん 親子丼"
"おやこなべ 親子鍋"
"おやご 親御"
"おやごころ 親心"
"おやしお 親潮"
"おやしらず 親不知"
"おやじ 親爺 親字 親父"
"おやじしん 親自身"
"おやすみ お休み"
"おやたち 親達"
"おやだま 親玉"
"おやど 御宿"
"おやなぎ 小柳"
"おやばか 親馬鹿"
"おやひとりこひとり 親一人子一人"
"おやふこう 親不孝 親不幸"
"おやぶん 親分"
"おやぶんやく 親分役"
"おやべ 小矢部"
"おやま 雄山 女形 小山 尾山"
"おやまだ 小山田"
"おやむすめ 親娘"
"おやもと 親元"
"おやゆずり 親譲り"
"おやゆび 拇 親指"
"おゆ お湯"
"おゆずり 御譲り"
"おゆるし お許し"
"およそ 凡そ"
"および 及 及び"
"およびごし 及び腰"
"およめさん お嫁さん"
"およろこび お慶び お喜び"
"おらんうーたん オランウータン"
"おらんだ 和蘭"
"おり 檻 織 澱 折"
"おりお 折尾"
"おりおり 折々"
"おりかえし 折り返し"
"おりかさ 折笠"
"おりがみ 折り紙"
"おりくち 降り口"
"おりこみ 折込"
"おりしげ 折茂"
"おりしも 折しも"
"おりじなる オリジナル"
"おりた 織田"
"おりたて 折立"
"おりづめ 折詰 折り詰め"
"おりどしき 折戸式"
"おりはし 折橋"
"おりはら 織原 折原"
"おりばこ 折り箱"
"おりめ 折目 織り目 折り目"
"おりも 織茂"
"おりもの 織物"
"おりよく 折よく"
"おりんぴっく オリンピック"
"おれ 俺"
"おれい お礼 御礼"
"おれさま 俺様"
"おれせん 折れ線 折線"
"おれたち 俺達"
"おれめ 折れ目"
"おれんじ オレンジ"
"おろ 悪露"
"おろか 愚か"
"おろかもの 愚か者"
"おろし 颪 卸"
"おろしうり 卸売り 卸売"
"おろししょう 卸商"
"おろしそうば 卸相場"
"おろしどんや 卸問屋"
"おろしね 卸値"
"おろしまち 卸町"
"おろそか 疎か"
"おろち 大蛇"
"おわ 尾羽"
"おわい 汚穢 浄穢"
"おわかれかい お別れ会"
"おわせ 尾鷲"
"おわだ 小和田"
"おわび お詫び"
"おわらい お笑い"
"おわり 終り 尾張 終わり 終"
"おわりごろ 終頃"
"おわりね 終値"
"おん 隱 穩 瘟 怨 園 遠 オン 恩 穏 温 御 音"
"おんあい 恩愛"
"おんあつ 音圧"
"おんい 恩威"
"おんいき 音域"
"おんいん 音韻"
"おんえい 恩栄"
"おんか 恩暇 恩仮 恩化 音価"
"おんかい 音階"
"おんかた 御方"
"おんかん 音感"
"おんが 遠賀"
"おんがえし 恩返し"
"おんがく 音楽"
"おんがくいん 音楽院"
"おんがくか 音楽家"
"おんがくげき 音楽劇"
"おんがくさい 音楽祭"
"おんがくし 音楽史"
"おんがくしょせんもん 音楽書専門"
"おんがくどう 音楽堂"
"おんがくのとも 音樂之友 音楽之友"
"おんがくばたけ 音楽畑"
"おんがくへん 音楽篇"
"おんがっか 音学家"
"おんがっかい 音楽会"
"おんがっかん 音楽館"
"おんがん 温顔"
"おんき 恩紀"
"おんきごう 音記号"
"おんきゅう 恩給"
"おんきょう 音強 音響"
"おんきょうかん 音響管"
"おんぎ 音義 御義 恩誼 恩義"
"おんぎみしょう 音義未詳"
"おんくん 音訓"
"おんくんみしょう 音訓未詳"
"おんぐう 恩遇"
"おんぐん 音群"
"おんけい 音型 恩恵"
"おんけつ 温血"
"おんけん 穏健"
"おんげん 音源"
"おんげんがわ 音現側"
"おんこ 恩顧"
"おんこう 音効 恩幸 恩光 音高 温厚"
"おんこうろん 音講論"
"おんこちしん 温故知新"
"おんごく 遠国"
"おんさ 音叉"
"おんさいと オンサイト"
"おんさく 音作"
"おんさん 音産"
"おんし 恩私 恩旨 恩賜 恩師"
"おんしつ 温室 音質"
"おんしつど 温湿度"
"おんしつどけい 温湿度計"
"おんしゃ 音写 恩赦 御社"
"おんしゃく 恩借"
"おんしゅう 恩讎 恩讐"
"おんしょう 恩奨 恩詔 恩賞 温床"
"おんしょく 音色"
"おんしん 音信"
"おんじゅく 御宿"
"おんじゅつ 恩恤"
"おんじゅん 温順 音順"
"おんじょう 恩情 音場 温情 音情"
"おんじん 恩人"
"おんすい 温水"
"おんすう 音数"
"おんせい 音声"
"おんせいは 音声波"
"おんせき 恩錫"
"おんせつ 応接 音節"
"おんせん 音線 温泉"
"おんせんじるし 温泉印"
"おんせんやど 温泉宿"
"おんそ 音素"
"おんそく 音束 音速"
"おんぞう 音像"
"おんぞうし 御曹子 御曹司"
"おんぞん 温存"
"おんたい 恩貸 温帯 御大"
"おんたいしょう 御大将"
"おんたく 恩沢"
"おんたけ 御岳"
"おんたけさんえき 御嶽山駅"
"おんだ 音田 恩田"
"おんだい 音大"
"おんだいそつ 音大卒"
"おんだん 温暖"
"おんち 音痴"
"おんちく 音蓄"
"おんちけん 音知研"
"おんちゅう 御中"
"おんちょう 音調 音長 恩寵"
"おんてい 音程"
"おんてき 怨敵"
"おんてん 恩典"
"おんでこざ 鬼太鼓座"
"おんと 音吐"
"おんとう 穏当"
"おんど 音戸 音頭 温度"
"おんどく 音読"
"おんどけい 温度計"
"おんどり 雄鳥"
"おんどる 温突"
"おんな 恩名 恩納 ♀ 音奈 女"
"おんない 恩愛"
"おんながわ 女側"
"おんなきょうだい 女姉妹"
"おんなけいず 婦系図"
"おんなげいしゃ 女芸者"
"おんなことば 女言葉"
"おんなごころ 女心"
"おんなざちょう 女座長"
"おんなしまい 女姉妹"
"おんなしゃかい 女社会"
"おんなしゅじん 女主人"
"おんなじしん 女自身"
"おんなじゅうどうか 女柔道家"
"おんなずき 女好き"
"おんなずもう 女相撲"
"おんなせんし 女戦士"
"おんなそうばし 女相場師"
"おんなたち 女達"
"おんなたらし 女誑し 女誑"
"おんなっけ 女っ気"
"おんなともだち 女友達"
"おんなどうし 女同士"
"おんなのこ 女の子"
"おんなのひと 女の人"
"おんなばん 女版"
"おんなひとり 女一人"
"おんなべんごし 女弁護士"
"おんなもじ 女文字"
"おんなもの 女物"
"おんなゆ 女湯"
"おんにん 穏忍"
"おんねつ 温熱"
"おんねん 怨念"
"おんのじ 御の字 恩の字"
"おんはいすい 温排水"
"おんば 穏婆 音場"
"おんばん 音盤"
"おんぱ 恩波 音波"
"おんひ 音飛"
"おんび 音尾"
"おんびき ー"
"おんびん 音便 穏便"
"おんびんけい 音便形"
"おんぴょう 音表"
"おんぷ 音譜 ♪ 音符"
"おんぷう 温風"
"おんべつ 音別"
"おんみ 御身"
"おんみつ 隠密"
"おんみょう 陰陽"
"おんみょうじ 陰陽師"
"おんめい 恩名 恩命 音名"
"おんやく 音訳"
"おんやさい 温野菜"
"おんよう 恩養 温容 陰陽"
"おんようじ 陰陽師"
"おんよく 温浴"
"おんよみ 音読 音読み"
"おんり 厭離"
"おんりつ 音律"
"おんりょう 怨霊 音量"
"おんれい 恩礼 御礼"
"おんれつ 音列"
"おんわ 温和"
"か 个 耶 彼 袈 卦 掛 渦 ヵ 遐 軻 踝 跏 賈 譌 譁 謌 訶 蝌 萪 苟 舸 罅 笳 痂 珈 渮 柯 枷 戈 彁 廈 崋 夥 墟 堝 啝 哥 咼 呵 厦 價 假 馨 顆 蝸 窩 鹿 ヶ 伽 ケ 寡 嫁 禾 禍 苛 何 珂 架 賀 河 稼 茄 靴 嘉 蝦 菓 迦 価 箇 佳 嘩 霞 荷 華 貨 個 暇 香 科 花 仮 夏 蚊 過 歌 果 課 加 家 下 日 火 可 化"
"かー カー"
"かーとりっじ カートリッジ"
"かーど カード"
"かーにばる カーニバル"
"かーぶ カーブ"
"かーる カール"
"かあ 母"
"かあさん 母さん"
"かあちゃん 母ちゃん"
"かあつ 加圧"
"かい 醢 邂 迴 諧 誡 誨 詼 觧 褂 蠏 蛔 茴 繪 疥 畍 瑰 櫂 榿 槐 楷 椢 枴 揩 懈 懷 恠 廨 嵬 夬 壞 喙 咼 匯 囘 傀 偕 會 价 乖 丐 潰 飼 垣 徊 隗 塊 恢 灰 晦 械 拐 芥 廻 蟹 獪 悔 戒 快 絵 皆 魁 介 怪 甲斐 界 海 壊 懐 改 下位 貝 解 開 階 会 回"
"かいあく 改悪"
"かいい 会意 魁偉 怪異"
"かいいき 海域"
"かいいぬ 飼犬"
"かいいれさいむ 買入債務"
"かいいん 開院 海員 改印 会員"
"かいいんばぬし 会員馬主"
"かいいんぼ 会員簿"
"かいうん 開運 海運"
"かいうんしょう 海軍省"
"かいえいまえ 開映前"
"かいえだ 海江田"
"かいえん 快演 開宴 開園 開演"
"かいおうせい 海王星"
"かいおうまる 海王丸"
"かいおき 買い置き"
"かいおんじ 海音寺"
"かいか 開架 開果 階下 開化 開花"
"かいかい 恢恢 開会"
"かいかいいん 会会員"
"かいかえ 買換え"
"かいかく 開核 改革"
"かいかくあん 改革案"
"かいかけ 買掛"
"かいかた 買方"
"かいかつ 快活"
"かいかつどう 会活動"
"かいかわ 會川"
"かいかん 會舘 開館 開管 会舘 会館 快感"
"かいかんじ 怪幹事"
"かいが 繪畫 絵画"
"かいがい 海外"
"かいがいあて 海外宛"
"かいがいむけ 海外向 海外向け"
"かいがく 開学"
"かいがてん 絵画展"
"かいがもり 貝ヶ森 貝が森"
"かいがら 貝殻"
"かいがん 開眼 海岸"
"かいがんぞい 海岸沿"
"かいがんどおり 海岸通"
"かいき 回歸 買い気 改軌 皆既 回忌 会期 回帰 快気 怪奇"
"かいきしょく 皆既食"
"かいきゃく 開脚"
"かいきゅう 海丘 開球 懐旧 階級"
"かいきょ 快挙"
"かいきょう 懐郷 海峡 回教"
"かいきょく 開局"
"かいきん 開襟 皆勤 解禁"
"かいぎ 回議 懐疑 会議"
"かいぎじろく 会議事録"
"かいぎひ 会議費"
"かいぎゃく 詼謔 諧謔"
"かいぎょう 開業 改行"
"かいぎょうい 開業医"
"かいく 皆苦"
"かいくうかん 解空間"
"かいぐん 海軍"
"かいけい 塊茎 会稽 会計"
"かいけいざん 会稽山"
"かいけいし 会計士"
"かいけいのはじ 会稽の恥"
"かいけつ 怪傑 快傑 解決"
"かいけつあん 解決案"
"かいけつしきもんだい 解決式問題"
"かいけつびょう 壊血病"
"かいけつへん 解決篇"
"かいけつほう 解決方"
"かいけん 改憲 会見"
"かいげん 開眼 改元 戒厳"
"かいげんしょう 怪現象"
"かいげんれい 戒厳令"
"かいこ 廻顧 回雇 解顧 蠶 回顧 解雇 懐古 蚕"
"かいこう 開高 開項 回行 邂逅 開港 海溝 海港 回航 開口 改稿 開講 開校"
"かいこうしゃ 階行社"
"かいこうたけし 開高健"
"かいこうたん 開口端"
"かいこく 会告 開国 海国 戒告"
"かいことば 買い言葉"
"かいこま 甲斐駒"
"かいこん 塊根 悔恨 開墾 開梱"
"かいご 改悟 介護"
"かいごう 蟹螯 会合"
"かいごろし 飼い殺し"
"かいさ 海佐"
"かいさい 快哉 開催"
"かいさいと 下位サイト"
"かいさいようもう 開催要綱"
"かいさく 怪作 改作"
"かいさつ 改札"
"かいさつぐち 改札口"
"かいさん 海産 解散"
"かいさんせつ 解散説"
"かいざい 介在"
"かいざいく 貝細工"
"かいざん 改竄"
"かいし 壊死 海士 会誌 開始"
"かいしき 開式"
"かいしつ 開室"
"かいしめ 買占め"
"かいしゃ 膾炙 會社 会社"
"かいしゃがえり 会社帰り"
"かいしゃく 解釋 介錯 解釈"
"かいしゃもち 会社もち"
"かいしゅう 回收 改宗 会衆 改修 回収"
"かいしゅうしゃ 回収車"
"かいしゅうばこ 回収箱"
"かいしゅん 改悛 悔悛 回春"
"かいしょ 開所 楷書 会所"
"かいしょう 介紹 快勝 甲斐性 改称 解消"
"かいしょく 解職 会食"
"かいしん 快心 改心 回診 会心 改新"
"かいしんげき 快進撃"
"かいじ 怪事 甲斐路 解字 海事 快事 開示"
"かいじむきょく 会事務局"
"かいじゅ 解呪 槐樹"
"かいじゅう 海獣 晦渋 懐柔 怪獣"
"かいじゅうだいずかい 怪獣大図解"
"かいじゅんびかい 会準備会"
"かいじょ 介助 解除"
"かいじょう 階状 開城 回状 階上 開錠 開場 海上 階乗 会場"
"かいじょうひ 会場費"
"かいじょうほう 怪情報"
"かいじり 海尻"
"かいじん 灰燼 灰塵 怪人"
"かいすい 海水"
"かいすいおん 海水温"
"かいすいぎょ 海水魚"
"かいすいよく 海水浴"
"かいすう 階数 回数"
"かいすうけん 回数券"
"かいすうじゅん 回数順"
"かいず 海図 海津"
"かいずか 貝塚"
"かいせ 貝瀬"
"かいせい 海棲 海星 改姓 開成 回生 改正 快晴"
"かいせいあん 開盛庵 改正案"
"かいせいしゃ 階成社 偕成社"
"かいせき 懐石 会席 解析"
"かいせきかい 解析解"
"かいせきぎ 解析木"
"かいせつ 回折 開設 解説"
"かいせつぶさんしょう 解説部参照"
"かいせつりつ 会設立"
"かいせん 回船 海戦 疥癬 開戦 海鮮 改選 回旋 会戦 回戦 開栓 回線"
"かいせんだん 回線断"
"かいせんひ 回線費"
"かいせんもう 回線網"
"かいぜん 改善"
"かいぜんあん 改善案"
"かいそ 開祖 改組"
"かいそう 潰走 回漕 回走 海藻 快走 会葬 海草 回送 回想 改装 階層"
"かいそうがたねっとわあく 階層型ネットワーク"
"かいそうごと 階層毎"
"かいそうしゃ 回送車 改宗者"
"かいそうば 買相場"
"かいそうばなし 回想話"
"かいそうひ 改装費"
"かいそく 快足 会則 快速"
"かいそくば 快速馬"
"かいぞう 海三 解像 改造"
"かいぞうあん 改造案"
"かいぞうしゃ 改造車"
"かいぞうひ 改造費"
"かいぞえ 介添"
"かいぞく 海賊"
"かいぞくおとこ 海賊男"
"かいぞくせん 海賊船"
"かいぞん 買い損"
"かいた 海田 頴田"
"かいたい 解体"
"かいたく 開拓"
"かいたん 海単"
"かいだ 海田 開田 貝田 快打 改田"
"かいだい 改題 解題"
"かいだく 快諾"
"かいだし 買い出し"
"かいだて 階建"
"かいだめ 買いだめ 買い貯め"
"かいだん 戒壇 怪談 会談 階段"
"かいだんし 快男子"
"かいだんのぼり 階段登り"
"かいだんばなし 怪談話"
"かいだんよこ 階段横"
"かいち 嘉一"
"かいちく 改築"
"かいちくあん 改築案"
"かいちゅう 蛔蟲 懷中 蛔虫 界中 懐中 回虫 海中 壊中"
"かいちょう 回腸 諧調 開帳 怪鳥 階調 快調 会長"
"かいちん 開陳"
"かいつう 開通"
"かいつけ 買付 買付け"
"かいつぶり 鳰"
"かいづ 海津"
"かいづか 貝塚"
"かいて 買い手"
"かいてい 階梯 開廷 改定 海底 改訂"
"かいていにまんり 海底二万里"
"かいてき 会的 快適"
"かいてん 廻轉 廻転 廻天 開店 回転"
"かいてんあしばらい 回転足払い"
"かいてんかく 回転角"
"かいてんけい 回転計"
"かいてんじく 回転軸"
"かいてんじょ 回転所"
"かいてんすうけい 回転数計"
"かいてんそくせつ 回転足折"
"かいてんたい 回転体"
"かいてんとう 回転灯"
"かいてんば 回転場 回転刃"
"かいてんばん 回転板"
"かいてんやき 回転焼"
"かいでん 海田 皆伝"
"かいでんぱ 怪電波"
"かいとう 解糖 怪盗 会頭 快盗 解答 解凍 回答"
"かいとうあん 回答案"
"かいとうせき 解答席"
"かいとうほうしんあん 解答方針案"
"かいとうらんま 快刀乱麻"
"かいとくしながわいき 快特品川行"
"かいとくしながわゆき 快特品川行"
"かいとくていしゃ 快特停車"
"かいとり 買取り 貝取り 貝取 買い取り 買取"
"かいとりて 買取手"
"かいど 開度"
"かいどう 皆藤 海道 会堂 街道"
"かいどうあと 街道跡"
"かいどき 買い時"
"かいどく 回読 買得 解読"
"かいな 腕"
"かいなひねり 腕捻り"
"かいなん 海難 海南"
"かいなんとう 海南島"
"かいにゅう 介入"
"かいにん 懐妊 解任"
"かいぬし 買い主 飼い主"
"かいぬま 海沼"
"かいね 買値"
"かいのう 戒能"
"かいは 会派"
"かいはい 改廃"
"かいはくしつ 灰白質"
"かいはくしょく 灰白色"
"かいはつ 開発"
"かいはつしゃむきけ 開発者向け"
"かいはつしょく 開発職"
"かいはつぞう 開発像"
"かいはつひ 開発費"
"かいはつぶだい 開発部第"
"かいはら 開原"
"かいはん 改版"
"かいば 海馬"
"かいばしら 貝柱"
"かいばつ 皆伐 海抜"
"かいばら 柏原 海原 開原"
"かいばん 改番 改版"
"かいひ 廻避 会費 回避"
"かいひば 回避馬"
"かいひょう 解氷 回表 開票"
"かいひょうじょ 開票所"
"かいひん 海浜"
"かいびゃく 開闢"
"かいふ 回付 海部"
"かいふう 開封"
"かいふかい 快不快"
"かいふく 開腹 開福 恢復 快復 回復"
"かいふくそし 回復措置"
"かいぶったい 怪物体"
"かいぶつ 怪物"
"かいぶん 回分 回文"
"かいぶんしょ 怪文書"
"かいぶんだけ 開聞岳"
"かいへい 海兵 開閉"
"かいへん 壊変 拐騙 改編 改変"
"かいべくとる 解ベクトル"
"かいぺーじ 改頁"
"かいぺいじ 改頁"
"かいほう 快報 快方 介抱 会報 解法 開放 解放"
"かいほうぐん 解放軍 開放軍"
"かいほうげん 解放弦 開放弦"
"かいほうやく 介抱役"
"かいほうれい 解放令"
"かいぼう 海膨 海防 解剖"
"かいま 垣間"
"かいまく 開幕"
"かいまくせん 開幕戦"
"かいみょう 戒名"
"かいみん 快眠"
"かいむ 会務 皆無"
"かいめ 回目"
"かいめい 開明 晦暝 晦明 改名 解明"
"かいめいじゅう 開明獣"
"かいめつ 潰滅 壊滅"
"かいめん 海面 海綿 界面"
"かいめんたい 海綿体"
"かいめんは 界面波"
"かいもうぶ 回盲部"
"かいもく 皆目"
"かいもの 買いもの 買い物 買物"
"かいものぶくろ 買物袋"
"かいもん 階紋 開門"
"かいもんだけ 開聞岳"
"かいや 海谷"
"かいやく 改訳 解約"
"かいゆ 快癒"
"かいゆう 回游 回遊"
"かいゆうかん 海遊館"
"かいゆうぎょ 回遊魚"
"かいよう 海洋 潰瘍"
"かいらい 傀儡"
"かいらく 偕楽 皆楽 海楽 快楽"
"かいらん 介卵 潰乱 廻覽 解纜 回覧"
"かいらんじゅん 回覧順"
"かいらんばん 回覧板"
"かいり 解離 海里 乖離 浬"
"かいりき 怪力"
"かいりく 海陸"
"かいりつ 戒律"
"かいりゅう 海流"
"かいりょう 改良"
"かいりょくらんしん 怪力乱神"
"かいるい 貝類"
"かいれい 海嶺"
"かいれき 改暦"
"かいれつ 開裂"
"かいれつか 開裂果"
"かいろ 懐炉 海路 回路"
"かいろう 回廊"
"かいろもう 回路網"
"かいわ 會話 海和 会話"
"かいわい 界隈"
"かいわごえ 会話声"
"かいわたい 会話体"
"かいわれ 貝割"
"かいん 下院 課員"
"かう 斯う 買う"
"かうんた カウンタ"
"かうんと カウント"
"かえ 替え 華絵 佳枝 替"
"かえうた 替へ歌 替歌 替え歌"
"かえし 返し"
"かえしうた 返歌"
"かえしうま 返馬"
"かえしわざ 返し技"
"かえって 却って"
"かえつ 加越 嘉悦"
"かえつのうてつどう 加越能鉄道"
"かえで 楓"
"かえでぞく カエデ属"
"かえり 返り 帰り"
"かえりうち 返り討ち"
"かえりぎわ 帰り際"
"かえりぐるま 帰り車"
"かえりざき 返り咲き"
"かえりち 返値"
"かえりびと 帰り人 帰人"
"かえりみち 帰り路 帰り道"
"かえる 蛙"
"かえん 火炎 火焔"
"かえんざん 火焔山"
"かえんびん 火炎瓶"
"かお 貌 顏 顔"
"かおあわせ 顔合せ 顔合わせ"
"かおいろ 顔色"
"かおう 鹿央 花押 花王"
"かおかたち 顔容"
"かおく 家屋"
"かおこうげき 顔攻撃"
"かおじゃしん 顔写真"
"かおす カオス"
"かおだし 顔出し"
"かおだち 顔立ち"
"かおぢゅう 顔中"
"かおつき 顔付き"
"かおはんぶん 顔半分"
"かおぶれ 顔ぶれ"
"かおみ 顔見"
"かおみしり 顔見知り"
"かおむけ 顔向け"
"かおもじ 顔文字"
"かおやく 顔役"
"かおり 香り 薫理 歌織 香里 佳央里 佳央理 香 香織"
"かおる 香 カオル 薫 馨"
"かおるこ 薫子"
"かおん 加温"
"かか 仮果 窩家 嬶"
"かかあ 嬶 嚊"
"かかあてんか 嚊天下"
"かかい 科会 課会 下階 下界 可解"
"かかいこうい 破壊行為"
"かかく 過客 価格"
"かかくらんくうらん 価格欄空欄"
"かかし 案山子"
"かかたいしょう 呵々大笑"
"かかぢ 香々地"
"かかと 踵"
"かかとおとし 踵落し"
"かかみがはら 各務原"
"かかり 係り 掛 係"
"かかりいん 係員"
"かかりかん 係官"
"かかりじょし 係助詞"
"かかりちょう 掛長 係長"
"かかりなし 係無"
"かかん 花冠 可換 果敢 日間"
"かかんかん 可換環"
"かかんぜん 過完全"
"かが 鹿賀 花芽 加我 加賀"
"かがい 課外 加害"
"かがいみつせん 花外蜜腺"
"かがく 下顎 価額 化学 科学"
"かがくかいだい 科学会第"
"かがくかん 科学舘"
"かがくし 科学史"
"かがくてつがっかい 科学哲学会"
"かがくはく 科学博"
"かがくばたけ 科学畑"
"かがくもの 科学物"
"かがじ 加賀寺"
"かがたいりょうなべ 加賀大漁鍋"
"かがたけし 鹿賀丈史"
"かがっか 化学科 科学科"
"かがっかい 科学会"
"かがっかん 化学館"
"かがみ 各務 香我美 鏡味 鑒 加賀美 加賀見 鑑 鏡"
"かがみいし 鏡石"
"かがみじごく 鏡地獄"
"かがみぬま 鏡沼"
"かがみの 鏡野"
"かがみのくに 鏡の国"
"かがみやま 鏡山"
"かがや 加賀谷"
"かがやき 輝き"
"かがり 炬"
"かがりび 炬火 篝火"
"かがわ 嘉川 加川 香川"
"かき 蠣 硴 火器 夏記 堵 花器 火気 牡蠣 牡蛎 書き 夏季 夏期 蛎 垣 柿 書 下記"
"かきあじ 書き味"
"かきあて 下記宛"
"かきいれどき 書き入れ時 書入れ時"
"かきいろ 柿色"
"かきうち 垣内"
"かきお 柿生"
"かきおか 柿岡"
"かきおき 書置"
"かきおろし 描き下ろし 書下し 書き下ろし"
"かきかえ 書換 書換え 書き換え"
"かきからちょう 蛎殻町"
"かきぎ 柿木"
"かきこみ 書込 書きこみ"
"かきこむ 書き込む"
"かきごおり かき氷"
"かきざき 柿崎"
"かきした 柿下"
"かきじゅん 書き順"
"かきぞめ 書き初め 書初め"
"かきた 柿田"
"かきたかわ 柿田川"
"かきたに 柿谷 垣谷"
"かきだがわ 柿田川"
"かきだし 書き出し"
"かきちょう 蠣殻町"
"かきつけ 書付け"
"かきて 描き手 書き手"
"かきとめ 書留"
"かきとり 書取"
"かきぬま 柿沼"
"かきね 牆 墻 垣根"
"かきの 柿野"
"かきのうち 垣野内"
"かきのき 柿木"
"かきのもとひとまろ 柿本人麻呂"
"かきはちねん 柿八年"
"かきはら 柿原 垣原"
"かきはん 花押 書判"
"かきもく カキ目"
"かきもと 柿本"
"かきもの 書き物"
"かきやすさ 書き易さ"
"かきゅう 苛求 火球 加給 火急 下丘 過給 可及 下級"
"かきょ 火炬 科挙"
"かきょう 華僑 架橋 家教 佳境"
"かきょういん 花京院"
"かきょく 歌曲 佳曲"
"かきわき 垣脇"
"かきん 家禽 瑕瑾 課金"
"かきんど 火金土"
"かぎ 鉤 『』 「」 カギ 」 「 『 』 鈎 鍵"
"かぎあな 鍵穴"
"かぎかっこ 」 「 【 】 『"
"かぎかっことじ 』"
"かぎざき 鉤裂き"
"かぎじたい 鍵自体"
"かぎたんだい 科技短大"
"かぎだい 科技大 東京都立科学技術大学"
"かぎちょう 科学技術庁 科技庁"
"かぎづめ 鉤爪 鈎爪"
"かぎの 鍵野"
"かぎばり 鉤針"
"かぎほっく 鉤ホック"
"かぎもと 鍵本"
"かぎゃく 加虐 可逆"
"かぎゅう 蝸牛"
"かぎょう カ行 課業 家業 下行 稼業"
"かぎり 限り 限"
"かく 加来 恁く ∠ 骼 馘 霍 貉 覺 覈 蠖 茖 膕 膈 矍 癨 畫 狢 殼 槨 椁 攫 擴 擱 攪 挌 愨 恪 幗 寉 壑 埆 咯 喀 鶴 掴 斯く 賀来 拡 劃 撹 嚇 画 赫 穫 郭 殻 閣 客 較 廓 角 獲 核 隔 革 覚 確 格 各"
"かくあげ 格上げ"
"かくい 角井 各位"
"かくいえ 各家"
"かくいがく 核医学"
"かくいつ 劃一 画一"
"かくいん 客員 各員"
"かくう 架空"
"かくうえ 格上"
"かくうんどうりょう 角運動量"
"かくえい 角榮 角栄"
"かくえき 各駅"
"かくえきていしゃ 隔駅停車"
"かくおうざん 覚王山"
"かくおち 角落"
"かくおん 核音 各音"
"かくおんていごと 各音程毎"
"かくか 格下 角化 核果 各課"
"かくかい 各界 各階 各回"
"かくかく 赫々 赫赫 各々"
"かくかくさん 核拡散"
"かくかそくど 角加速度"
"かくかぞく 核家族"
"かくかん 各巻 各艦 各間"
"かくかんごと 各巻毎"
"かくがい 核外 格外"
"かくがた 角型"
"かくがり 角刈 角刈り"
"かくがわ 角川"
"かくがん 各眼"
"かくき 各機 各期"
"かくきょく 各曲"
"かくぎ 閣議"
"かくぎょう 角行 各行"
"かくぎょうごと 各行毎"
"かくく 各区"
"かくぐう 角隅"
"かくけい 角形"
"かくけん 各県 核研"
"かくげき 核撃"
"かくげっかん 隔月刊"
"かくげつ 隔月"
"かくげつかん 隔月刊"
"かくげん 確言 格言"
"かくこ 確固"
"かくこう 各校 各項"
"かくこうかん 角交換"
"かくこうぞう 核構造"
"かくご 各語 覚悟"
"かくごう 各号"
"かくごび 格語尾"
"かくさ 格差 隔差"
"かくさく 画策"
"かくさげ 格下げ"
"かくさん 核酸 拡散"
"かくざ 擱座 擱坐"
"かくざい 角材"
"かくざとう 角砂糖"
"かくし 隠し 核子 客死 各誌 各紙 各市 各氏"
"かくしき 格式"
"かくしげい 隠し芸"
"かくしごと 隠し事"
"かくしせつ 核施設"
"かくした 格下"
"かくしだま 隠し玉"
"かくしつ 革質 角質 確執 各室"
"かくして 斯くして"
"かくしどり 隠し撮り"
"かくしぬの 隠し布"
"かくしゃ 覚者 各車 各社"
"かくしゃかん 各者間"
"かくしゃく 矍鑠"
"かくしゅ 核種 鶴首 馘首 各種"
"かくしゅう 各週 隔週"
"かくしゅうかん 隔週刊"
"かくしゅうはすう 角周波数"
"かくしゅく 拡縮"
"かくしゅぼば 名種牡馬"
"かくしょ 角所 各署 各所"
"かくしょう 各省 各賞 各章 確証"
"かくしょく 各色"
"かくしん 確診 確心 核心 革新 確信"
"かくしんどうすう 角振動数"
"かくしんはん 確信犯"
"かくじ 覚治 各自"
"かくじく 各軸"
"かくじっけん 核実験"
"かくじつ 隔日 確実"
"かくじつし 確実視"
"かくじゅいん 鶴寿院"
"かくじゅう 拡充"
"かくじょし 格助詞"
"かくじん 核仁 各人"
"かくすい 角錐"
"かくすう 画数"
"かくすうじゅん 画数順"
"かくず 各図"
"かくせい 拡声 郭清 隔世 覚醒"
"かくせいぶんごと 各成分毎"
"かくせつ 各節"
"かくせん 各線"
"かくせんそう 核戦争"
"かくせんとう 角先頭"
"かくぜつ 隔絶"
"かくぜん 画然"
"かくそう 各層"
"かくそくど 角速度"
"かくぞう 覚三"
"かくた 角田"
"かくたい 各隊"
"かくたに 角谷"
"かくたん 喀痰"
"かくだ 角田"
"かくだい 拡大"
"かくだいきょう 拡大鏡"
"かくだん 各段 格段"
"かくだんとう 核弾頭"
"かくち 隔地 各地"
"かくちぶんり 廓地分利"
"かくちゅう 角柱"
"かくちょう 各町 格調 拡張"
"かくちょうあん 拡張案"
"かくちょうけい 拡張形"
"かくつう 格通"
"かくつき 各月 隔月"
"かくつけ 格付"
"かくづけ 格付け"
"かくてい 各停 確定"
"かくていずみ 確定済"
"かくてん 各店 各点"
"かくでーた 核データ"
"かくでん 各伝"
"かくでんききょうめい 核電気共鳴"
"かくとう 挌闘 各棟 確答 各党 格闘"
"かくとうか 格闘家"
"かくとうぎ 格闘技"
"かくとうせん 格闘戦"
"かくとうもの 格闘物"
"かくとか 殻斗果"
"かくとく 獲得"
"かくとくけい 獲得形"
"かくとくしょうきんがく 獲得賞金額"
"かくど 確度 角度"
"かくない 核内 閣内"
"かくに 角煮"
"かくにん 確認"
"かくにんずみ 確認済"
"かくねん 核燃 各年 隔年"
"かくの 角野"
"かくのう 格納"
"かくのうこ 格納庫"
"かくのうりょく 核能力"
"かくのだて 角館"
"かくは 各派"
"かくはいきぶつ 核廃棄物"
"かくはく 攫搏"
"かくはさい 核破砕"
"かくはん 攪拌 拡販 撹拌 各版 各般 各班"
"かくはんのう 核反応"
"かくば 各馬"
"かくばくだん 核爆弾"
"かくばくはつ 核爆発"
"かくばん 各晩"
"かくひつ 擱筆"
"かくひょう 各表"
"かくひょうしき 格標識"
"かくふ 角歩"
"かくふうとう 角封筒"
"かくふく 拡幅"
"かくぶ 各部"
"かくぶっしつ 核物質"
"かくぶつり 核物理"
"かくぶん 各文"
"かくぶんぽう 格文法"
"かくぶんやごと 各分野毎"
"かくぶんれつ 核分裂"
"かくへいき 核兵器"
"かくへき 隔壁"
"かくへん 各辺"
"かくへんか 格変化"
"かくべえじし 角兵衛獅子"
"かくべつ 各別 格別"
"かくほ 確保"
"かくほう 確報"
"かくほずみ 確保済"
"かくま 角間"
"かくまく 隔膜 角膜"
"かくまくえん 角膜炎"
"かくまち 各街"
"かくまる 革マル 角丸 核マル"
"かくむ 各務"
"かくめ 各目"
"かくめい 革命"
"かくめいか 革命家"
"かくめいじ 革命児"
"かくめん 各面"
"かくやく 核薬 確約"
"かくやす 格安"
"かくやすけん 格安券"
"かくゆうごう 核融合"
"かくゆうごうろ 核融合炉"
"かくよう 各様"
"かくよくし 核抑止"
"かくら 加倉"
"かくらい 加倉井"
"かくらん 霍乱 攪乱 撹乱 各欄"
"かくり 郭李 核理 隔離"
"かくりつ 格律 確率 確立"
"かくりょう 閣僚"
"かくれ 隠れ"
"かくれいわ 礁"
"かくれが 隠れ家"
"かくれつ 各列"
"かくろん 各論"
"かくわ 各話"
"かくん 家訓"
"かぐ 家具"
"かぐやひめ かぐや姫"
"かぐら 神楽"
"かぐらざか 神楽坂"
"かぐん 下郡 加群"
"かけ × 賭け 賭 掛"
"かけあし 駆け足"
"かけい 花形 火刑 家計 筧 家系"
"かけいひ 家計費"
"かけいぼ 家計簿"
"かけうり 掛売"
"かけおち 駆落 駆け落ち"
"かけかえ 掛替え"
"かけかわしがい 掛川市街"
"かけがえ 掛替 掛け替え"
"かけがね 掛け金"
"かけがわ 掛川"
"かけきん 賭金 掛け金 掛金"
"かけごえ 掛聲 掛け声 かけ声"
"かけごと 賭け事 賭事"
"かけざん 掛け算 かけ算"
"かけしょうぎ 賭将棋"
"かけじく 掛け軸 掛軸"
"かけず 掛け図 掛図"
"かけぞり 掛け反り"
"かけつ 可欠 可決"
"かけつかばし 掛塚橋"
"かけなげ 掛け投げ"
"かけはし 棧 懸け橋 架け橋"
"かけはた 欠端 欠畑"
"かけひ 筧"
"かけひき 駆引き 駆け引き"
"かけふ 掛布"
"かけぶとん 掛布団"
"かけまーじゃん 賭麻雀"
"かけまま 欠真間"
"かけもち 掛持ち"
"かけや 掛合"
"かけら 破片"
"かけりつ 掛率"
"かける ＊ ×"
"かけん 家憲 化研 科学計測研究所 科研"
"かけんひ 科学研究費 科研費"
"かげ 翳 鹿毛 蔭 景 影 陰"
"かげうら 影浦"
"かげえ 影絵"
"かげかつ 景勝"
"かげき 歌劇 過激"
"かげききょう 蔭桔梗"
"かげぐち 蔭口 陰口"
"かげさわ 影沢"
"かげぜん 陰膳"
"かげつ カ月 ケ月 荷月 花月 箇月 ヶ月"
"かげひこ 景彦"
"かげぼうし 影法師"
"かげぼし 陰干し"
"かげまる 影丸"
"かげむしゃ 影武者"
"かげもと 影本"
"かげやま 景山 陰山 影山 蔭山"
"かげろう 蜻蛉 蜉蝣 陽炎"
"かげん 仮言 ⊃ 下弦 下限 加減"
"かげんざん 加減算"
"かげんそく 加減速"
"かげんめいほう 仮言命法"
"かこ 苛湖 加古 過去"
"かこい 十六"
"かこう 河港 化工 火口 下降 河口 加工"
"かこうおんけい 下降音形"
"かこうがん 花崗岩"
"かこうげん 火口原"
"かこうこ 河口湖"
"かこうし 加工紙"
"かこうせき 河口堰"
"かこうぜき 河口堰"
"かこうちん 加工賃"
"かこうづけ 加工付"
"かこうなべ 加工鍋"
"かこうにく 加工肉"
"かこく カ国 苛刻 過酷 ヶ国 苛酷"
"かこくな 過酷な"
"かこけい 過去形"
"かこもん 過去問"
"かこん 禍根 過恨"
"かご 駕籠 花後 加護 過誤 籠 篭"
"かごう 化合"
"かごさか 籠坂"
"かごしま 鹿児島"
"かごしまこう 鹿児島港"
"かごしまわん 鹿児島湾"
"かごせ 籠瀬 篭瀬"
"かごたに 篭谷 籠谷"
"かごはら 篭原"
"かごん 過言"
"かさ 暈 瘡 疽 嵩 加佐 笠 傘"
"かさい 家栽 河西 加西 葛西 家裁 笠井 火災"
"かさいりゅう 火砕流"
"かさおか 笠岡"
"かさかけ 笠懸"
"かさぎ 笠置"
"かさく 企策 寡作 家作 佳作"
"かさくら 笠倉"
"かささ 笠沙"
"かささぎ 鵲"
"かさした 傘下"
"かさしま 笠島"
"かさじぞう 笠地蔵"
"かさじま 笠島"
"かさじょう 傘状"
"かさたて 傘立"
"かさだか 嵩高"
"かさつ 苛察"
"かさでら 笠寺"
"かさど 笠戸"
"かさなり 重なり"
"かさね 重ね"
"かさねあわせ 重ね合わせ"
"かさねうち 重ね打ち"
"かさねがき 重ね描き"
"かさねぎ 重ね着"
"かさねどり 重ね録り"
"かさはら 笠原"
"かさぶくろ 傘袋"
"かさま 笠間"
"かさまつ 笠松"
"かさみ 嵩"
"かさり 笠利"
"かさん 可算 加算"
"かさんか 過酸化"
"かさんかすいそすい 過酸化水素水"
"かざい 夏材 家財"
"かざかみ 風上"
"かざきり 風切り"
"かざぐるま 風車"
"かざごえ 風邪声"
"かざしも 風下"
"かざばな 風花"
"かざま 風間"
"かざまち 風街"
"かざまつり 風祭"
"かざみ 風見"
"かざみどり 風見鶏"
"かざむき 風向 風向き"
"かざりまど 飾窓 飾り窓"
"かざるすほーる カザルスホール"
"かざわ 鹿沢"
"かざん 加算 火山"
"かざんたい 火山体"
"かざんだん 火山弾"
"かざんばい 火山灰"
"かざんみゃく 火山脈"
"かざんむげん 可算無限"
"かし 花糸 槝 下賜 瑕疵 貸 河岸 下肢 華氏 仮死 貸し 樫 可視 橿 菓子 歌詞"
"かしい 香椎"
"かしいかえん 香椎花園"
"かしいきぜんたい 可視域全体"
"かしお 加塩"
"かしおか 柏岡"
"かしおけいさんき カシオ計算機"
"かしおり 菓子折り"
"かしかた 貸方"
"かしかぶ 貸株"
"かしかん 下士官"
"かしき 下式"
"かしきり 貸切 貸切り 貸し切り"
"かしこう 可視光"
"かしこし 貸越"
"かしこじまかん 賢島間"
"かししつ 貸室"
"かしせき 貸席"
"かしそうこ 貸倉庫"
"かしだ 樫田"
"かしだし 貸出 貸し出し"
"かしだしぼ 貸し出し簿"
"かしち 貸地"
"かしちん 貸賃"
"かしつ 呵叱 加湿 加執 過失"
"かしつけ 貸付"
"かして 貸手"
"かしてんぽ 貸店舗"
"かしの 柏野"
"かしはら 樫原 橿原"
"かしば 香芝"
"かしべっそう 貸別荘"
"かしほん 貸本"
"かしま 嘉島 加嶋 加島 貸間 鹿嶋 鹿島"
"かしまこう 鹿島港"
"かしません 鹿島戦"
"かしまだ 鹿島田"
"かしまやり 鹿島槍"
"かしみせ 貸し店"
"かしむら 鹿志村 樫村"
"かしも 加子母"
"かしもと 貸元"
"かしもり 樫森"
"かしゃ 火車 加者 貨車"
"かしゃく 仮借 呵責 苛責"
"かしや 貸家"
"かしやま 樫山"
"かしゅ 歌手"
"かしゅう 加州 歌集"
"かしゅく 可縮"
"かしょ カ所 ヶ所 箇所 個所"
"かしょう 花床 華宵 火傷 寡少 加商 過少 歌唱 過小 仮称"
"かしょうさんぜん 菓匠三全"
"かしょく 河蝕 華燭 過食"
"かしょくぶぶん 可食部分"
"かしら 頭"
"かしらもじ 頭文字"
"かしりょう 貸料"
"かしれこ 貸しレコ"
"かしろ 嘉代"
"かしわ 柏 栢"
"かしわぎ 柏木"
"かしわくら 柏倉"
"かしわざき 柏崎"
"かしわし 柏市"
"かしわしみん 柏市民"
"かしわば 柏葉"
"かしわばら 柏原"
"かしわぶち 柏渕"
"かしわほうめん 柏方面"
"かしわまち 柏町"
"かしわら 柏原"
"かしん 歌神 加振 家臣 過信"
"かじ 嘉事 加冶 加地 加治 加持 鍛治 舵 柁 鍛冶 火事 家事 梶"
"かじい 梶井"
"かじうら 梶浦"
"かじお 梶尾"
"かじか 鮖 鰍"
"かじかざわ 鰍沢"
"かじかわ 加冶川 舵川"
"かじがや 梶ケ谷"
"かじき 加治木 梶木"
"かじく 仮軸"
"かじせいけい 下自成蹊"
"かじた 梶田"
"かじたに 梶谷"
"かじつ 佳日 過日 果実"
"かじつあじ 果実味"
"かじの 梶野"
"かじはら 梶原"
"かじば 火事場"
"かじま 梶真 鹿嶋 鹿島"
"かじもと 梶本"
"かじゃ 冠者"
"かじやちょう 加治屋町"
"かじゅ 果樹"
"かじゅう 荷重 果汁 加重"
"かじゅうでん 過充電"
"かじゅうりょう 下重量"
"かじゅし 果樹試"
"かじょ 花序 加除"
"かじょう 箇条 過剰"
"かじょうがき 個条書き 箇条書"
"かじょうねつ 過剰熱"
"かじわら 梶原"
"かじわらいっき 梶原一騎"
"かじん 寡人 佳人 歌人 家人"
"かす 滓 粕 糟"
"かすい 加水 火水 河水 下垂"
"かすいたい 下垂体"
"かすいど 火水土"
"かすいもく 火水木"
"かすう 価数 仮数"
"かすかべ 春日部"
"かすかわ 粕川"
"かすが 春日"
"かすがい 春日居 鎹 春日井"
"かすがの 春日野"
"かすがのつぼね 春日局"
"かすがのみち 春日野道"
"かすがばる 春日原"
"かすじる 粕汁"
"かすじるじたて 粕汁仕立て"
"かすたに 糟谷"
"かすたむ カスタム"
"かすだ 粕田"
"かすてら カステラ"
"かすなべ 粕鍋"
"かすぴかい カスピ海"
"かすみ 香住 香純 香澄 霞"
"かすみがうら 霞浦"
"かすみがせき 霞ケ関 霞が関 霞ヶ関"
"かすみさい 霞祭"
"かすみのめ 霞目"
"かすや 糟谷 粕谷 粕屋"
"かすり 飛白 緕 纃 綛 絣"
"かすりきず かすり傷"
"かず 數 香鶴 一寿 下図 一 和 数"
"かずあき 和晃 和晶 一章 和昭 一明 一晃 和明"
"かずい 花蘂"
"かずえ 和恵 一枝 主計 一恵 和枝"
"かずえのかみ 主計頭"
"かずお 一生 和郎 和生 和雄 和男 一雄 一男 一夫 一穂 和夫"
"かずおおく 数多く"
"かずおか 数岡"
"かずおみ 和臣"
"かずかず 数々"
"かずき 和樹 和紀 一喜 一樹 一起 一機"
"かずこ 量子 数子 加寿子 佳寿子 加純子 和子"
"かずさ 上総"
"かずし 和司 数史 一至 和志 一志 和士 一司"
"かずしげ 一繁 一茂 和重 和茂"
"かずしれず 数知れず"
"かずじたい 数自体"
"かずすくない 数少ない"
"かずすけ 一助"
"かずたか 一隆 一貴 一任 和貴"
"かずてる 一晃 一輝"
"かずと 一人 和人"
"かずとし 和敏 数敏 和淑 一世 一寿 一敏 和利 一利"
"かずなり 一成"
"かずね 和音"
"かずの 数野"
"かずのこ 鯑"
"かずのみや 和宮"
"かずのり 和則 主紀 一孔 和徳 和典 一範 和憲 和紀 一憲"
"かずひこ 和比古 一彦 和彦"
"かずひさ 一寿 数久 一久 和久"
"かずひで 一秀 和英 一英 和秀"
"かずひと 一仁 一人 和仁 和人"
"かずひろ 一寛 和裕 一洋 一広 一裕 一宏 和弘 一弘 和博 和浩 一浩 和広 和宏 一博"
"かずふみ 一文 和史"
"かずほ 一穂"
"かずほど 数程"
"かずま 和馬 數間 一磨 和磨"
"かずまさ 和昌 一昌 数正 和政 一正 和正"
"かずまる 一丸"
"かずまろ 和麻呂"
"かずみ 香樹実 和実 一味 一三 和巳 一美 香津美 和美"
"かずみち 一路"
"かずもと 一元"
"かずや 和弥 数也 一弥 和哉 一也 一哉 和也"
"かずやす 一泰"
"かずゆき 和恭 数幸 和之 和幸 一之 一行 和行 一幸"
"かずよ 一代 和代 和世"
"かずよし 和由 和良 和好 和芳 和美 一義 和義"
"かずら 蔓 鬘 葛"
"かずわり 数割"
"かせ 加勢 綛 加世 枷 加瀬"
"かせい 苛性 苟性 家政 加勢 仮性 化成 火星"
"かせいがん 火成岩"
"かせいふ 家政婦"
"かせき 可積 化石"
"かせきさい 過積載"
"かせだ 加世田"
"かせっと カセット"
"かせつ 架設 仮設 仮説"
"かせつきょう 仮設橋"
"かせん 架線 化繊 河川 加線 寡占 下線"
"かせんしき 河川敷"
"かせんした 架線下"
"かせんじ 架線事"
"かせんじき 河川敷"
"かせんちゅう 架線柱"
"かせんよこ 河川横"
"かぜ 風 風邪"
"かぜあたり 風当たり"
"かぜい 課税"
"かぜいがく 課税額"
"かぜいたいしょうがく 課税対象額"
"かぜおき 風興"
"かぜきた 風北"
"かぜぐすり カゼ薬 風邪薬"
"かぜごえ 風邪声"
"かぜつかい 風使い"
"かぜとおし 風通し"
"かぜのたに 風の谷"
"かぜむき 風向き"
"かぜよけ 風よけ"
"かぜん 果然"
"かそ 過疎 可塑"
"かそう 価層 家相 火葬 仮装 下層 仮想"
"かそうせん 仮想戦"
"かそうば 火葬場"
"かそく 可測 加速"
"かぞ 數 加須 数"
"かぞう 家蔵"
"かぞえあげ 数え上げ"
"かぞえうた 数え歌"
"かぞえかた 数え方"
"かぞえやくまん 数え役満"
"かぞく 華族 家族"
"かた 沫 過多 潟 片 肩 形 型 方"
"かたあし 片足"
"かたあやまり 型誤り"
"かたい 下腿 難"
"かたいきん 過怠金"
"かたいっぽう 片一方"
"かたいと 片糸"
"かたいなか 片田舎"
"かたいれ 肩入 肩入れ"
"かたうで 片腕"
"かたうんてんだい 片運転台"
"かたお 片尾"
"かたおか 片岡"
"かたおもい 片想い 片思い"
"かたおや 片親"
"かたかいそう 型階層"
"かたかな 片假名 カタカナ 片仮名"
"かたかんせつ 肩関節"
"かたがい 片貝"
"かたがき 肩書き 肩書"
"かたがた 旁々 旁 方々"
"かたがみ 型紙"
"かたがみてつどう 片上鉄道"
"かたがわ 片側"
"かたがわり 肩代わり 肩代り"
"かたき 仇 敵"
"かたきうち 敵討 仇討ち"
"かたきやく 敵役"
"かたぎ 堅気 気質"
"かたぎし 片岸"
"かたぎのしゅう 堅気の衆"
"かたぎり 片桐"
"かたく 花托 火宅 家宅 仮託"
"かたくずれ 型くずれ"
"かたくな 頑 頑な"
"かたくら 片倉"
"かたくりこ 片栗粉"
"かたぐち 片口 肩口"
"かたぐるま 肩車"
"かたけんさ 型検査"
"かたげんご 型言語"
"かたこう 型項"
"かたこうせいし 型構成子"
"かたこと 片言"
"かたこり 肩凝り 肩こり"
"かたしき 型式"
"かたしすてむ 型システム"
"かたしていし 型指定子"
"かたしな 片品"
"かたじょうほう 型情報"
"かたすいろん 型推論"
"かたすかし 肩透し 肩透かし"
"かたすみ 片隅"
"かたず 固唾"
"かたせ 片瀬"
"かたせんげん 型宣言"
"かたそで 片袖"
"かたた 堅田"
"かたたいけい 型体系"
"かたたいすう 片対数"
"かたたがえ 方違え"
"かたたそう 型多相"
"かたたち 方達"
"かたち 貌 容 形"
"かたちじたい 形自体"
"かたちぜんたい 形全体"
"かたっぱし 片っ端"
"かたつ 可達 下達"
"かたつき 肩付 型つき 肩付き 型付"
"かたつけ 型付"
"かたつばさ 肩翼"
"かたつむり 蝸 蝸牛"
"かたづ 固唾"
"かたづけ 型付け 片付け"
"かたづけま 片付け魔"
"かたて 片手"
"かたていぎ 型定義"
"かたていすう 型定数"
"かたておち 片手落"
"かたてきようき 型適用基"
"かたてなべ 片手鍋"
"かたてま 片手間"
"かたとき 片時"
"かたな 刀"
"かたなや 刀屋"
"かたぬき 型抜"
"かたの 片野"
"かたはい 片肺"
"かたはし 片端"
"かたはじ 片端"
"かたはば 肩幅"
"かたはま 片浜"
"かたばかり 形許り"
"かたばみか カタバミ科"
"かたばん 型板 型版 型番"
"かたひがし 潟東"
"かたひも 肩紐"
"かたひら 片平"
"かたびら 帷子"
"かたびらのつじ 帷子ノ辻"
"かたぶつ 堅物"
"かたへんかん 型変換"
"かたへんすう 型変数"
"かたほう 片方"
"かたほうこう 片方向"
"かたぼう 片棒"
"かたまち 片町"
"かたまり 塊"
"かたみ 片見 肩見 形身 形見 肩身"
"かたみち 片道"
"かたみみ 片耳"
"かたみわけ 形見わけ"
"かたむき 傾き"
"かため 固め 片眼 片目"
"かためい 型名"
"かためん 片面"
"かたもと 片本"
"かたもみ 肩揉み"
"かたもり 容保"
"かたやま 片山"
"かたやまづ 片山津"
"かたよせ 片寄"
"かたり 騙り 語り"
"かたりくち 語り口"
"かたりぐさ 語り草"
"かたりべ 語り部"
"かたりろん 型理論"
"かたりん 片輪"
"かたる 拐"
"かたろぐ カタログ"
"かたわ 片輪"
"かたわら 旁 傍 傍ら"
"かたわれ 片割れ"
"かたん 可鍛 荷担 加胆 加担 下端"
"かだ 伽佗 伽陀"
"かだい 架台 荷台 仮題 過大 課題"
"かだん 歌壇 花壇 下段"
"かち 加地 徒 勝ち 可知 磆 勝 価値"
"かちいくさ 勝ち戦"
"かちうま 勝馬"
"かちうん 勝運"
"かちがいねん 価値観念"
"かちき 勝気"
"かちく 家蓄 家畜"
"かちこし 勝ち越し"
"かちすう 勝数"
"かちてん 勝点"
"かちどき 勝ちどき 勝鬨"
"かちぼし 勝ち星"
"かちめ 勝目"
"かちゅう 花柱 家中 火中 渦中"
"かちょう 課徴 花鳥 蚊帳 家長 科長 掛長 可聴 課長"
"かちょういん 課長印"
"かちょうせん 花蝶扇"
"かちょうづき 課長付"
"かぢ 鍛冶 加地 加治"
"かっ 渇"
"かっか 角化 閣下"
"かっかい 各界 各回"
"かっかく 赫々"
"かっかざん 活火山"
"かっかそうよう 隔靴掻痒"
"かっき 各期 画期 活気"
"かっきてき 劃期的"
"かっきゅう 割球"
"かっきょ 割拠"
"かっきょう 活況"
"かっきょく 各曲 各局"
"かっくう 滑空"
"かっけ 脚気"
"かっけた 各桁"
"かっけつ 喀血"
"かっこ “” ‘’ 【】 『』 「」 》 《》 《 〈〉 ｝ ｛｝ ｛ ［］ 〕 〔〕 〔 （） ” “ ’ ‘ 各個 」 「 カッコ 〈 〉 確固 ］ ［ ） （ 』 『 】 括弧 【"
"かっこう 郭公 恰好 滑降 滑行 格好"
"かっこく 各国"
"かっことじ 》 〉"
"かっこんとう 葛根湯"
"かっさい 葛西 喝采"
"かっしゃ 活写 滑車"
"かっしょう 滑翔"
"かっしょく 褐色"
"かっすい 活水 渇水"
"かっせい 活性"
"かっせいか 活生化"
"かっせいたん 活性炭"
"かっせん 合戰 活線 合戦"
"かっそう 滑走"
"かっそうろ 滑走路"
"かった 勝田 刈田"
"かったー カッター"
"かっちゃく 活着"
"かっちゅう 甲冑 甲胄"
"かって 勝手"
"かってつけ 勝手付"
"かっと カット"
"かっとう 葛藤"
"かっぱ Κ 川童 κ 合羽 喝破 河童"
"かっぱつ 活溌 活発"
"かっぱん 活版"
"かっぷ 割賦"
"かっぷく 割腹 恰幅"
"かっぷる カップル"
"かっぺい 勝平"
"かっぽ 闊歩 濶歩"
"かっぽう 割烹"
"かっぽうぎ 割烹着"
"かつ 且つ カツ 黠 鞨 濶 闊 豁 蠍 蝎 蛞 聒 羯 磆 瞎 猾 曷 戞 戛 劼 刮 捷 恰 喝 渇 褐 克 葛 勝 活 括 且 轄 滑 割"
"かつあい 割愛"
"かつあき 勝章 勝昭 克明"
"かついち 勝一"
"かつうら 勝浦"
"かつうらこう 勝浦港"
"かつえ 勝江 勝恵"
"かつお 勝生 克夫 勝雄 勝夫 勝男 鰹"
"かつおぶし 鰹節 鰹ぶし"
"かつかじゅう 活荷重"
"かつかつ 戛戛"
"かつかんれんじょうほう 活関連情報"
"かつき 香月 克己 勝木"
"かつきち 勝吉"
"かつぎひこうじょう 厚木飛行場"
"かつくら 勝倉 勝鞍"
"かつげき 活劇"
"かつこ 克子 勝子"
"かつさい 勝斉"
"かつし 勝志 克史 克 且 克志"
"かつしか 葛飾"
"かつしま 勝島"
"かつしろう 勝四郎"
"かつしんたろう 勝新太郎"
"かつじ 功至 勝治 勝次 活字"
"かつじたい 活字体"
"かつじょう 割譲"
"かつじょうほう 活情報"
"かつぜつ 活舌"
"かつぞう 勝三"
"かつた 勝田"
"かつたに 勝谷"
"かつたろう 勝太郎"
"かつだんそう 活断層"
"かつて 曽て 曾て 嘗て"
"かつとし 克敏 克年 勝俊 克俊 勝利 勝敏"
"かつどう 活動"
"かつどうか 活動家"
"かつどうげん 活動源"
"かつどうたい 活動体"
"かつどん カツ丼"
"かつなり 勝成"
"かつぬま 勝沼"
"かつの 勝野 鹿角"
"かつのぶ 克亘"
"かつのり 勝典 克典 克則"
"かつはた 勝畑"
"かつば 活馬"
"かつひこ 捷彦 勝彦 克彦"
"かつひさ 克久 勝久"
"かつひで 勝秀"
"かつひと 克仁"
"かつひら 勝平"
"かつひろ 勝浩 勝洋 勝宏 勝寛 勝弘 克弘 克洋 勝広 克裕 克博 克宏"
"かつふみ 克文"
"かつべ 勝部"
"かつぼう 渇望"
"かつま 勝間"
"かつまく 滑膜"
"かつまさ 勝正"
"かつまた 勝俣 勝股 勝間田 勝亦 勝又"
"かつみ 克実 勝己 勝巳 勝美 克巳 克美 克己 香津美"
"かつもく 割目 刮目"
"かつもと 勝本 勝元"
"かつや 勝弥 勝哉 克弥 勝也 勝谷 克也 克哉"
"かつやく 括約 活躍"
"かつやくきん 括約筋"
"かつやくば 活躍馬"
"かつやま 勝山"
"かつゆき 勝征 勝行 克之 勝幸 克行 勝之 克幸"
"かつよう 活用"
"かつようけい 活用形"
"かつようじゅ 闊葉樹"
"かつよし 克能 勝吉 克義 勝義"
"かつより 勝頼"
"かつら 蘰 桂"
"かつらお 葛尾"
"かつらか カツラ科"
"かつらかわ 桂川"
"かつらがわ 桂川"
"かつらぎ 桂木 葛城"
"かつらく 滑落"
"かつらさんし 桂三枝"
"かつらだ 桂田"
"かつらはま 桂浜"
"かつらばやし 桂林"
"かつらぶんちん 桂文珍"
"かつらゆみ 桂由美"
"かつらりきゅう 桂離宮"
"かつりょく 活力"
"かつりょくげん 活力源"
"かつれい 割礼"
"かつれん 勝連"
"かつろ 活路"
"かつろう 克朗"
"かづき 香月"
"かづけ 日付"
"かづさ 加津佐"
"かづの 鹿角"
"かづみ 香津美"
"かて 糧"
"かてい 家庭 課程 過程 仮定"
"かていつき 仮定付"
"かていむけ 家庭向け"
"かてきおう 過適応"
"かてつ 科哲"
"かてん 加点"
"かでな 嘉手納"
"かでん 瓜田 荷電 家伝 家電"
"かでんし 価電子"
"かと 加登 過渡"
"かとう 花筒 賀藤 加東 加登 果糖 寡頭 加糖 下等 加藤"
"かとうきょうそうか 過当競争下"
"かとうきょうそうじょうたい 過当競争状態"
"かとうぎ 加藤木"
"かとかい 過渡解"
"かときち 加ト吉"
"かとく 家督"
"かとくせい 可読性"
"かとくたい 科特隊"
"かとり 蚊取り 香取 鹿取"
"かとりせんこう 蚊取線香"
"かとりっく カトリック"
"かど 過渡 柧 加登 賀戸 門 └ ┌ ┐ ┘ 過度 角"
"かどいけ 門池"
"かどう 火道 可導 稼動 可動 華道 稼働"
"かどうかん 仮導管"
"かどおか 角岡"
"かどかり 下土狩"
"かどかわ 角川"
"かどがわ 門川"
"かどく 可読"
"かどくら 門倉"
"かどさき 門崎"
"かどさわ 門澤"
"かどた 門田 角田"
"かどち 角地"
"かどで 門出"
"かどなか 門仲"
"かどの 門野"
"かどばやし 門林"
"かどま 門真"
"かどまつ 門松 角松"
"かどみうむ カドミウム"
"かどわき 門脇"
"かな 香奈 華菜 佳奈 假名 金 哉 華奈 加奈 カナ 仮名"
"かなあしのう 金足農"
"かなあみ 金網"
"かない 科内 家内 課内 金井"
"かないけ 金池"
"かないし 金石"
"かなう 叶"
"かなえ 香苗 叶え 彜 彝 鼎 鬲"
"かなかん 仮名漢 仮名漢字変換プログラム かな漢"
"かながき 金垣 仮名書き カナ書き"
"かながた 金型"
"かながわ 金川 神奈川"
"かなぎ 金木 金城"
"かなくぎ 金釘"
"かなぐ 金具"
"かなこ 佳那子 香奈子 可奈子 佳奈子 嘉奈子 加奈子"
"かなさき 金崎"
"かなさし 金指"
"かなざき 加奈崎"
"かなざわ 金澤 金沢"
"かなざわだいり 金沢大理"
"かなしばり 金縛り"
"かなしま 金島"
"かなしみ 悲しみ"
"かなた 彼方"
"かなたに 金谷"
"かなだ 片田 カナダ 加奈陀 金田"
"かなちゅう 神奈中"
"かなつじ 金辻"
"かなづ 金津"
"かなづかい 仮名遣い"
"かなづち 金鎚 金槌"
"かなで 金出"
"かなでほん 仮名手本"
"かなぶつ 金仏"
"かなまじり 仮名混じり かな混じり かな交じり"
"かなまち 金町"
"かなまり 鋺"
"かなまる 金丸"
"かなまるしん 金丸信"
"かなみつ 金光"
"かなむら 金村"
"かなめ 要"
"かなめちょう 要町"
"かなもの 金物"
"かなもり 金森"
"かなや 金屋 金谷"
"かなやま 金山"
"かならず 必らず 必ず"
"かならずしも 必ずしも"
"かならずや 必ずや"
"かなり 可成 金成"
"かなん 伽南 華南 河南"
"かに 蠏 カニ 可児 蟹"
"かにえ 蟹江"
"かにく 果肉"
"かにざ 蟹座"
"かにた 蟹田"
"かにゅう 加入"
"かにゅうりょく 過入力"
"かぬき 香貫"
"かぬま 鹿沼"
"かね 鐘 兼 金"
"かねあい 兼合 兼ね合い"
"かねいがい 金以外"
"かねいし 金石"
"かねいそ 金磯"
"かねおか 兼岡 金岡"
"かねかし 金貸"
"かねかんじょう 金勘定"
"かねがさき 金ヶ崎"
"かねがふち 鐘淵"
"かねきち 兼吉"
"かねきよ 兼清"
"かねこ 兼子 金児 金子"
"かねざき 金崎"
"かねしたけんせつ 金下建設"
"かねしだい 金次第"
"かねしま 金嶋"
"かねしろちょう 金城町"
"かねじゃく 矩尺"
"かねずく 金ずく"
"かねぞう 兼蔵"
"かねた 兼太 金田"
"かねたか 兼貴"
"かねたに 金谷"
"かねだ 金田"
"かねつ 金津 火熱 過熱 加熱"
"かねづか 金塚"
"かねづかい 金遣い"
"かねて 予て"
"かねと 兼人"
"かねなし 金無し"
"かねなり 金成"
"かねはた 金畑"
"かねはま 金浜"
"かねはら 金原"
"かねひさ 金久"
"かねひと 兼人"
"かねぼう 鐘紡"
"かねまち 金町"
"かねまつ 兼松"
"かねまつごうしょう 兼松江商"
"かねまる 金丸"
"かねまわり 金回り"
"かねみつ 金光"
"かねめ 金目"
"かねもうけ 金儲け"
"かねもち 金持ち"
"かねもと 金本"
"かねもり 兼森"
"かねや 金谷"
"かねやま 兼山 金山"
"かねらか カネラ科"
"かねん 可燃"
"かの 彼の 鹿野 狩野 彼"
"かのあし 鹿足"
"かのい 鹿井"
"かのう 嘉納 納 加納 狩野 叶 化膿 可能"
"かのえ 庚"
"かのえいぬ 庚戌"
"かのえうま 庚午"
"かのえさる 庚申"
"かのえたつ 庚辰"
"かのえとら 庚寅"
"かのえね 庚子"
"かのじょ 彼女"
"かのじょら 彼女等"
"かのせ 鹿瀬"
"かのと 辛"
"かのとい 辛亥"
"かのとう 辛卯"
"かのとうし 辛丑"
"かのととり 辛酉"
"かのとひつじ 辛未"
"かのとみ 辛巳"
"かのや 鹿屋"
"かはい 加配"
"かはいじく 下胚軸"
"かはいらん 過排卵"
"かはらい 過払い"
"かはん 河畔 過半 可搬"
"かはんしん 下半身"
"かはんぶ 下半部"
"かば 河馬 蒲 椛 樺"
"かばー カバー"
"かばさん 加波山"
"かばしま 樺嶋"
"かばと 樺戸"
"かばね 屍"
"かばん 花盤状 花盤 鞄"
"かひ 下皮 痂皮 瑕疵 下卑 花被 果皮 下肥 可否"
"かひつ 加筆"
"かひょう 下表"
"かび 黴 華美 カビ"
"かびん 過敏 花瓶"
"かふ 寡婦 下付"
"かふう 家風"
"かふぇいん カフェイン"
"かふぇてりあ カフェテリア"
"かふか 過負荷"
"かふく 禍福 下腹"
"かふそく 過不足"
"かふちょうせい 家父長制"
"かふん 花紛 花粉"
"かぶ （株） 蕪 下部 株"
"かぶか 株価"
"かぶき 歌舞伎"
"かぶきざ 歌舞伎座"
"かぶけん 株券"
"かぶしき 株式"
"かぶしきがいしゃ 株式會社"
"かぶそく 過不足"
"かぶだん 歌舞団"
"かぶと 加太 甲 兜"
"かぶとえび 兜海老"
"かぶとちょう 兜町"
"かぶとやま 甲山"
"かぶぬし 株主"
"かぶばいきゃく 株売却"
"かぶや 株屋"
"かぶら 蕪 鏑"
"かぶわけ 株分け"
"かぶん 可分 過分 寡聞"
"かぶんすう 仮分数"
"かぷせる カプセル"
"かへい 花柄 加平 貨弊 貨幣"
"かへいた 嘉平太"
"かへえ 嘉兵衛"
"かへん 佳篇 下辺 可変"
"かべ 璧 壁"
"かべいちめん 壁一面"
"かべかけ 壁掛け"
"かべがみ 壁紙"
"かべがわ 壁側"
"かべぎわ 壁際"
"かべせん 可部線"
"かべん 花弁"
"かほ 嘉穂 果歩"
"かほう 火砲 家宝 加法 果報 下方"
"かほうこう 下方向"
"かほうでん 過放電"
"かほうもの 果報者"
"かほうわ 過飽和"
"かほく 鹿北 香北 華北 可北 河北"
"かほくしょう 河北省"
"かほご 過保護"
"かほり 佳保里"
"かぼう 苛暴"
"かぼちゃ 南瓜"
"かま 釡 罐 窰 竈 窯 竃 蒲 釜 鎌"
"かまい 釜井"
"かまいし 釜石"
"かまえ 蒲江 構え 鎌江 釜江"
"かまがさき 釜ケ崎"
"かまがた 鎌形"
"かまがや 鎌ヶ谷 鎌谷"
"かまがり 蒲刈"
"かまきり 蟷螂 螳螂"
"かまくら 鎌倉"
"かまくらこ 鎌倉湖"
"かまくらぼり 鎌倉彫"
"かます 叺 鰤"
"かまた 蒲田 鎌田"
"かまたり 鎌足"
"かまだ 鎌田"
"かまち 蒲池 框 蒲地"
"かまとと 蒲魚"
"かまとり 鎌取"
"かまど 竈 竃"
"かまはら 鎌原"
"かまふさ 釜房"
"かまべ 鎌部"
"かまぼこ 蒲鉾"
"かまもと 釜本 窯元"
"かみ 祇 髮 帋 守 香美 加美 可美 加味 上 髪 神 紙"
"かみい 神居"
"かみいいざか 上飯坂"
"かみいいだ 上飯田"
"かみいしづ 上石津"
"かみいずみ 神泉"
"かみいそ 上磯"
"かみいた 上板"
"かみいち 上市"
"かみいな 上伊那"
"かみうけな 上浮穴"
"かみうま 上馬"
"かみうら 上浦"
"かみえしゅう 上江洲"
"かみお 神尾"
"かみおおおか 上大岡"
"かみおか 神岡 上岡"
"かみおだいえき 上小田井駅"
"かみおぼろ 上尾幌"
"かみかくし 神隠し 神隠"
"かみかざり 髪飾り"
"かみかせだ 上加世田"
"かみかぜ 神風"
"かみかつ 上勝"
"かみかやく 紙火薬"
"かみかわ 神川 上川"
"かみかわち 上河内"
"かみがかり 神憑 神懸り 神懸"
"かみがた 紙型 上方 髪形 髪型"
"かみがみ 神々"
"かみがや 神ケ谷"
"かみき 上期"
"かみきた 上北"
"かみきたざわ 上北沢"
"かみきょうく 上京区"
"かみきれ 紙切れ 紙切"
"かみぎょう 上京"
"かみぎれ 紙切れ"
"かみくいしき 上九一色"
"かみくず 紙屑"
"かみくまもとえきまえ 上熊本駅前"
"かみぐみ 上組"
"かみこうす 上口洲"
"かみこうち 上高地"
"かみこしき 上甑"
"かみこっぷ 紙コップ"
"かみごうり 上郡"
"かみごおり 上郡"
"かみごとう 上五島"
"かみさいばら 上斉原"
"かみさかえまち 上栄町"
"かみさと 上里 上郷"
"かみさま 神様"
"かみさんごう 上参郷"
"かみざ 上座"
"かみざき 神崎"
"かみざわ 上澤"
"かみしつ 紙質"
"かみしばい 紙芝居"
"かみしばいなみ 紙芝居並"
"かみしひ 上志比"
"かみしほろ 上士幌"
"かみしま 上島"
"かみしも 上下 裃"
"かみしゃちょう 神社長"
"かみしろ 神城 神代 上代"
"かみじま 上島"
"かみじゅうじょう 上十条"
"かみじょう 上条 神城 上條"
"かみす 神栖"
"かみすぎ 上杉"
"かみすながわ 上砂川"
"かみすわ 上諏訪"
"かみずる 上水流"
"かみせい 紙製"
"かみそうやぎ 上草柳"
"かみそり 剃刀"
"かみた 上田"
"かみたいせん 神大戦"
"かみたいら 上平"
"かみたかい 上高井"
"かみたから 上宝"
"かみだい 紙代"
"かみだな 神棚"
"かみだのみ 神頼み"
"かみつ 過密 上津"
"かみつか 神塚"
"かみつが 上都賀"
"かみつしま 上対馬"
"かみつせん 花蜜腺"
"かみつな 上綱"
"かみつるま 上鶴間"
"かみづか 神塚"
"かみづる 上水流"
"かみて 上手"
"かみてきせかい 神的世界"
"かみで 上出"
"かみとばぐち 上鳥羽口"
"かみとり 神取"
"かみとんだ 上富田"
"かみなか 上那賀 上中"
"かみなが 神長 神永"
"かみなべ 神鍋"
"かみなり 雷"
"かみにいかわ 上新川"
"かみにし 上西"
"かみにんぎょう 紙人形"
"かみぬま 上沼"
"かみねんど 紙粘土"
"かみのかわ 上三川"
"かみのく 上の句"
"かみのくに 上ノ国"
"かみのけ 髪の毛"
"かみのげ 上野毛"
"かみのこ 神の子"
"かみのせき 上関"
"かみのほ 上之保"
"かみのやま 上山"
"かみはやし 神林"
"かみはら 神原"
"かみはんき 上半期"
"かみばこ 紙箱"
"かみばやし 上林"
"かみひこうき 紙飛行機"
"かみひとえ 紙一重"
"かみふうせん 紙風船 紙ふうせん"
"かみふくおか 上福岡"
"かみふぶき 紙吹雪"
"かみふらの 上富良野"
"かみぶくろ 紙袋"
"かみへい 上閉伊"
"かみまえづ 上前津"
"かみまき 紙巻き 紙巻"
"かみみず 上水"
"かみみぞ 上溝"
"かみみね 上峰"
"かみむ 上無"
"かみむら 神村 上村"
"かみもと 神本"
"かみや 上谷 紙屋 神谷"
"かみやく 上屋久"
"かみやしろ 上社"
"かみやま 上山 神山"
"かみやまだ 上山田"
"かみゆい 髪結い"
"かみゆうべつ 上湧別"
"かみゆそうれっしゃ 紙輸送列車"
"かみよ 神余"
"かみよもじ 神世文字"
"かみわざ 神技"
"かみん 仮眠"
"かみんじょ 仮眠所"
"かむい 神居"
"かめ 甕 瓶 龜 日目 亀"
"かめあり 亀有"
"かめい 家名 下命 亀井 加盟 仮名"
"かめいし 亀石"
"かめいど 亀戸"
"かめいの 亀井野"
"かめお 亀夫"
"かめおか 亀岡"
"かめがた 亀型"
"かめきち 亀吉"
"かめじま 亀島"
"かめじろう 亀次郎"
"かめたろう 亀太郎"
"かめだ 亀田"
"かめの 亀野"
"かめのすけ 亀之助"
"かめまん 亀萬"
"かめや 亀屋 亀谷"
"かめやま 亀山"
"かめやまこ 亀山湖"
"かめやまんねんどう 亀屋万年堂"
"かめら カメラ"
"かめん 下面 仮面"
"かめんげき 仮面劇"
"かも 鳬 鳧 賀茂 加茂 鴨"
"かもい 鴨井 神威 鴨居"
"かもう 蒲生"
"かもえ 鴨江"
"かもえない 神恵内"
"かもがた 鴨方"
"かもがわ 鴨川"
"かもく 課目 寡黙 科目"
"かもくきん 火木金"
"かもくど 火木土"
"かもしか 羚羊"
"かもした 鴨下"
"かもしだ 鴨志田"
"かもじ 髢"
"かもじま 鴨島"
"かもだ 加守田"
"かもつ 貨物"
"かもつおきば 荷物置場"
"かもつごと 荷物毎"
"かもつしゃ 貨物車 荷物車"
"かもつせいり 荷物整理"
"かもつせん 貨物船"
"かもつでんしゃ 荷物電車"
"かもつゆそう 荷物輸送"
"かもつる 賀茂鶴"
"かもづる 賀茂鶴"
"かもと 鹿本"
"かもなくふかもなく 可もなく不可もなく"
"かもねぎ 鴨葱"
"かものみや 鴨宮"
"かもみーる カモミール"
"かもみや 鴨宮"
"かもめ カモメ 鴎"
"かもん 家門 厦門 家紋 嘉門"
"かもんのかみ 掃部頭"
"かや 加悦 伽耶 榧 蚊帳 茅 萱"
"かやく 可約 化薬 火薬"
"かやくき 可約基"
"かやしま 萱島"
"かやつりぐさもく カヤツリグサ目"
"かやなま 金山"
"かやの 栢野"
"かやはら 栢原"
"かやばちょう 茅場町"
"かやべ 茅部"
"かやま 香山 加山"
"かやもり 萱森"
"かゆ 糜 粥"
"かよ 嘉代 香代 加代 佳代 佳世"
"かよう 花葉 賀陽 斯樣 可容 加陽 歌謡 火曜"
"かようさい 歌謡祭"
"かようせい 可溶性 可用性"
"かよこ 佳世子 加代子 夏代子 加世子 佳代子"
"から 伽羅 → 殼 柄 殻 唐 空 〜"
"からー カラー"
"からあげ 唐揚げ 空揚げ"
"からうま 空馬"
"からおけ カラオケ"
"からかね 唐銅"
"からき 唐木"
"からきだ 唐木田"
"からぎょう 空行"
"からくさ 唐草"
"からくち 辛口"
"からくわ 唐桑"
"からけん 空券"
"からげいき 空景気"
"からこるむ 和林"
"からさき 唐崎"
"からさわ 唐澤 柄沢 唐沢"
"からさわぎ 空騒ぎ"
"からし 芥子 辛子"
"からしじょうゆ 辛子醤油"
"からしま 辛島"
"からじし 唐獅子"
"からす 香良洲 鴉 カラス 烏"
"からすま 烏丸"
"からすやま 烏山"
"からぜき 空咳"
"からたけわり 幹竹割り"
"からたち 枳殻"
"からだ 體 軆 躰 躯 身体 体"
"からだじたい 体自体"
"からだじゅう 体中"
"からだぜんたい 体全体"
"からだつき 身体つき"
"からだづくり 体作り"
"からっぽ 空っぽ"
"からつ 唐津"
"からつきたまご 殻付卵"
"からづみ 空積み"
"からて 空手"
"からてか 空手家"
"からてんじく 唐天竺"
"からなみだ 空涙"
"からに 空荷"
"からはし 唐橋"
"からはふ 唐破風"
"からばこ 空箱"
"からびん 空瓶"
"からふと 樺太"
"からぶり 空振り 空振"
"からまつ 唐松"
"からまつそうあか カラマツソウ亜科"
"からみ 絡み"
"からみそ 辛味噌"
"からむ カラム"
"からめ 辛目"
"からめて 搦手 搦め手"
"からもの 唐物"
"からやま 唐山"
"からん 下欄"
"かり 鳫 鴈 獵 假 加里 猟 狩り 借り 雁 苅 狩 刈 仮"
"かりあげ 借り上げ"
"かりいれ 借入れ"
"かりいれきん 借入金"
"かりうけ 借受 借受け"
"かりうど 狩人"
"かりえき 仮駅"
"かりかた 借方"
"かりかぶ 借株"
"かりこ 雁子"
"かりこし 借越 借り越し"
"かりこみ 苅込 刈込"
"かりさかとうげ 雁坂峠"
"かりすま カリスマ"
"かりずまい 仮住まい 仮住い"
"かりた 苅田"
"かりたこう 苅田港"
"かりだ 刈田"
"かりだな 仮柵"
"かりちん 借り賃"
"かりて 借手 借り手"
"かりていも 訶梨帝母"
"かりとりき 刈取機"
"かりに 仮に"
"かりぬい 仮縫い"
"かりぬし 借り主"
"かりはく 仮泊"
"かりば 狩場"
"かりばら 借腹"
"かりばらい 仮払い 仮払"
"かりぶかい カリブ海"
"かりめん 仮免"
"かりもの 借り物"
"かりゃく 下略"
"かりや 苅屋 仮屋 借り家 雁屋 狩谷 刈谷"
"かりゅう 河流 渦流 顆粒 下流"
"かりゅうかい 花柳街 花柳界"
"かりゅうしほう 加粒子砲"
"かりゅうど 狩人"
"かりょう 加療 科料"
"かりょく 火力"
"かりょくせん 火力船"
"かりわ 刈羽"
"かりん 可憐 花櫚 華鈴"
"かる 輕 苅 刈 軽"
"かるい 科類"
"かるいさわ 軽井沢"
"かるいざわ 軽井沢"
"かるいし 軽石"
"かるがる 軽々"
"かるくち 軽口"
"かるさ 軽さ"
"かるた 歌留多 骨牌"
"かるまい 軽米"
"かるめ 軽目"
"かるめん カルメン"
"かるわざ 軽業"
"かれ 涸 彼"
"かれー カレー"
"かれーこ カレー粉"
"かれあて 彼宛"
"かれい 加齢 鰔 鰈 華麗"
"かれいい 餉"
"かれいきゃく 過冷却"
"かれいすい 加冷水"
"かれいど カレイド"
"かれき 枯木 枯れ木"
"かれくさ 枯れ草"
"かれさわ 涸沢"
"かれさんすい 枯山水"
"かれし 彼氏"
"かれじしん 彼自身"
"かれつ 苛烈"
"かれは 枯葉"
"かれひとり 彼一人"
"かれら 彼達 彼ら 彼等"
"かれん 苛斂 可憐"
"かれんだー カレンダー"
"かろう 家老 過労"
"かろうし 過労死"
"かろりー カロリー"
"かわ 巛 革 側 河 皮 川"
"かわい 川相 可哀 川井 河井 可愛 河合 川合"
"かわいい 可愛い"
"かわいそう 可愛いそう 可哀想"
"かわいだ 川井田"
"かわいで 河出"
"かわうえ 川上"
"かわうそ 川獺"
"かわうち 河内 川内"
"かわうら 河浦 川浦"
"かわかぜ 川風"
"かわかつ 川勝"
"かわかみ 河上 川上"
"かわがわ 川側"
"かわきた 河北 川北"
"かわきゅう 川久"
"かわぎし 川岸"
"かわくぼ 川久保"
"かわくら 川倉"
"かわぐち 河口 川口"
"かわぐちこ 河口湖"
"かわぐつ 革靴"
"かわけ 河毛"
"かわげ 河芸"
"かわごえ 川越え 川越"
"かわごけそうもく カワゴケソウ目"
"かわさき 川嵜 河崎 川崎"
"かわさきこう 川崎港"
"かわさきせん 川崎戦"
"かわさきはつとうきょういき 川崎発東京行"
"かわさきはつとうきょうゆき 川崎発東京行"
"かわさと 川里"
"かわざかな 川魚"
"かわざんよう 皮算用"
"かわしげ 川重"
"かわしま 河島 河嶋 川嶋 川島"
"かわしも 川下"
"かわじ 川治 川路"
"かわじま 川島"
"かわじり 川尻"
"かわすぎ 川杉"
"かわず 蛙 川津"
"かわせ 河瀬 川瀬 為替"
"かわせい 革製"
"かわせいひん 皮製品"
"かわせみ 翡 カワセミ"
"かわそえ 川副"
"かわぞい 河沿"
"かわぞえ 河添 川添"
"かわぞこ 川底"
"かわた 河田 川田"
"かわたな 川棚"
"かわたび 川旅 川渡"
"かわだ 河田 川田"
"かわだいら 川平"
"かわち 河内"
"かわちおんせん 川治温泉"
"かわちや 河内谷"
"かわつ 川津"
"かわつこう 川津港"
"かわづ 川津"
"かわづがけ 河津掛け"
"かわづはな 川津花"
"かわてつ 川鉄"
"かわで 河出"
"かわと 川人"
"かわとう 川藤 川東"
"かわな 川奈 川名"
"かわなか 川中"
"かわなかじま 川中島"
"かわなざき 川奈崎"
"かわなべ 川鍋 川辺"
"かわなみ 川波"
"かわにし 河西 川西"
"かわにしがわりゅういき 川西側流域"
"かわぬま 河沼"
"かわね 川根"
"かわの 川野 河野"
"かわのえ 川之江"
"かわのべ 河之邊"
"かわはば 川幅"
"かわはま 川浜"
"かわはら 河原 川原"
"かわば 川場"
"かわばた 河端 川幡 川畑 川端"
"かわばり 皮張り"
"かわひがし 川東 河東"
"かわひも 皮紐"
"かわひら 川平"
"かわふく 川福 川副"
"かわふじ 川藤"
"かわぶくろ 皮袋 革袋"
"かわぶち 川淵"
"かわべ 河邊 川邊 川部 川辺 川邉 河辺"
"かわまえちょう 川前町"
"かわまた 川俣 川又"
"かわみ 川見"
"かわみなみ 川南"
"かわみや 河宮"
"かわむら 河村 川村"
"かわも 川面"
"かわもと 川元 河本 川本"
"かわもり 川森"
"かわや 廁 厠"
"かわよう 川用 革用"
"かわら 香春 磧 瓦 河原 川原"
"かわらい 河原井"
"かわらがはま 瓦ケ浜"
"かわらけ 土器"
"かわらだ 河原田"
"かわらもの 河原者"
"かわり 変わり 代わり"
"かわりだね 変わり種"
"かわりめ 変り目"
"かわりやく 代役"
"かわわ 川和"
"かわわせん 河和線"
"かわん 下腕"
"かん 康 神 潤 槓 鹹 鸛 鰥 骭 驩 駻 陷 關 鑵 鑒 鐶 鉗 酣 邯 轗 豢 讙 諫 觀 蒄 莟 艱 羮 羹 罕 罐 繝 篏 箝 稈 瞰 盥 皖 癇 疳 燗 瀚 澣 灌 渙 淦 涵 歡 歛 樌 橄 桿 柬 旱 撼 揀 捍 拑 扞 戡 懽 悍 嵌 寰 宦 嫻 嫺 奸 奐 坩 坎 喊 啣 咸 厂 卷 勸 凾 丱 杆 浣 侃 喚 堪 冠 煥 寒 勧 棺 憾 款 柑 甲 敢 患 干 乾 澗 潅 竿 菅 桓 翰 姦 慣 諌 莞 刊 汗 幹 韓 漢 勘 官 監 看 歓 肝 閑 舘 環 簡 函 陥 缶 艦 緩 還 貫 鑑 寛 甘 換 完 観 関 管 巻 感 館 間"
"かんあく 奸悪"
"かんあつ 感圧 缶圧"
"かんあん 勘案"
"かんい 簡意 官位 簡易"
"かんいち 乾一 貫一"
"かんいり 缶入"
"かんいん 姦淫 館員"
"かんいんりょう 缶飲料"
"かんえい 官営 寛永"
"かんえいにち 漢英日"
"かんえつ 観閲 関越"
"かんえん 肝炎"
"かんおう 陥凹"
"かんおけ 棺桶"
"かんおん 漢音 感音"
"かんおんじ 観音寺"
"かんか 柑果 乾果 旱戈 坩堝 管下 干戈 看過 感化"
"かんかく 　 感覚 間隔"
"かんかくもう 感覚毛"
"かんかつ 寛闊 管割 管轄"
"かんかん 灌灌"
"かんかんがくがく 侃侃諤諤 侃々諤々"
"かんが 官衙"
"かんがい 館外 灌漑 潅漑 干害 寒害 感概 潅がい 感慨"
"かんがえ 考え"
"かんがく 漢学 関学"
"かんがくこう 関学高"
"かんがくせん 関学戦"
"かんがくで 関学出"
"かんがっき 管楽器"
"かんがん 汗顔 宦官"
"かんき 間期 乾季 喚起 寒気 乾期 換気 歓喜"
"かんきこう 換気孔"
"かんきせん 換気扇"
"かんきち 乾吉"
"かんきつ 柑橘"
"かんきのう 肝機能"
"かんきゃく 観客"
"かんきゃくせき 観客席"
"かんきゅう 緩急"
"かんきゅうしゃ 緩急車"
"かんきょ 閑居 官許"
"かんきょう 艦橋 感興 環境"
"かんきょうがくけんきゅうか 環境学研究科"
"かんきょうこう 環境光"
"かんきょうせん 関京戦"
"かんきょうたいけつ 関京対決"
"かんきょうちょう 環境庁"
"かんきょうほごぜい 環境保護税"
"かんきり 缶切り"
"かんきん 看経 桿菌 監禁 換金"
"かんきんきゃく 換金客"
"かんきんじょ 換金所"
"かんぎく 観菊"
"かんぎてん 歓喜天"
"かんぎょう 鑑行 官業 勧業"
"かんぎん 勧銀"
"かんく 管区"
"かんくう 関空 管腔"
"かんぐん 官軍"
"かんけい 環形 換刑 奸計 関係"
"かんけいあり 関係有"
"かんけいし 関係詞"
"かんけいしょかんちょう 関係諸官庁"
"かんけつ 間歇 観血 間欠 完結 簡潔"
"かんけつせん 間欠泉"
"かんけん 換券 官憲"
"かんげい 歓迎"
"かんげき 間隙 観劇 感激"
"かんげん 管絃 諌言 甘言 換言 管弦 還元"
"かんげんがく 管弦楽"
"かんこ 喚呼 歓呼"
"かんこう 還向 箝口 艦攻 緩行 敢行 慣行 完工 感光 官公 刊行 観光"
"かんこうきゃく 観光客"
"かんこうぎょう 観光業"
"かんこうざい 環孔材"
"かんこうしょ 官公署"
"かんこうじゅ 官公需"
"かんこうせん 観光船"
"かんこうたい 感光体"
"かんこうちゃ 缶紅茶"
"かんこうちょう 官公庁"
"かんこうばい 寒紅梅"
"かんこうへん 肝硬変"
"かんこうりつびょういん 官公立病院"
"かんこうれい 箝口令"
"かんこく 勧告 韓国"
"かんこくさん 韓国産"
"かんこくせき 韓国籍"
"かんこつだったい 換骨奪胎"
"かんこどり 閑古鳥"
"かんこぴ 完コピ"
"かんこぴふ 完コピ譜"
"かんこん 冠婚"
"かんご 漢語 看護"
"かんごう 冠号 嵌合 巻号"
"かんごく 監獄"
"かんごふ 看護夫 看護婦"
"かんごりん 漢語林"
"かんさ 間差 感作 鑑査 監査"
"かんさい 艦載 完済 簡裁 寛斎 関西"
"かんさいおおくらこう 関西大倉高"
"かんさいぐち 関西口"
"かんさいけん 関西圈"
"かんさいで 関西出"
"かんさいば 関西馬"
"かんさいぺいんと 関西ペイント"
"かんさいりゅう 関西流"
"かんさく 奸策 間作"
"かんさくめい 関作命"
"かんさつ 鑑札 監察 観察"
"かんさつぐん 監察軍"
"かんさやく 監査役"
"かんさん 換算 閑散"
"かんざい 管財"
"かんざき 神埼 神崎"
"かんざし 簪"
"かんざぶろう 勘三郎"
"かんざん 換算"
"かんざんじ 舘山寺"
"かんし 鉗子 管子 干支 冠詞 監視"
"かんしき 乾式 鑑識"
"かんしきこう 漢詩紀行"
"かんししゃ 監視車"
"かんしち 環七"
"かんしつ 間質 乾湿"
"かんしゃ 患者 官舎 感謝"
"かんしゃく 癇癪 疳積"
"かんしゃさい 感謝祭"
"かんしゃめん 緩斜面"
"かんしゅ 凾手 肝腫 函手 艦首 関手 艦種 看取 看守"
"かんしゅう 観衆 監修 慣習"
"かんしょ 甘蔗"
"かんしょう 勧奨 管掌 完勝 冠賞 環礁 緩衝 感傷 干渉 鑑賞 観賞"
"かんしょうえき 緩衝液"
"かんしょうぎょ 観賞魚"
"かんしょうけい 干渉計"
"かんしょうざい 緩衝材"
"かんしょうは 干渉波"
"かんしょうやく 緩衝役"
"かんしょく 寒色 閑職 間食 官職 感触 感蝕"
"かんしん 奸臣 歓心 関心 感心"
"かんしんじ 関心事"
"かんじ 莞爾 換字 完児 完爾 寛治 監事 完治 感じ 幹事 漢字"
"かんじゃ 冠者 患者"
"かんじゃく 閑寂"
"かんじやく 幹事役"
"かんじゅ 官需 感受 甘受"
"かんじゅく 慣熟 完熟"
"かんじょ 緩徐"
"かんじょう 管状 完乗 艦上 感状 環状 冠状 勘定 感情"
"かんじょうか 管状花"
"かんじょうみゃく 冠静脈"
"かんじょきん 緩徐筋"
"かんじよこいんじ 漢字横印字"
"かんじん 勧進 閑人 肝腎 肝心"
"かんじんかなめ 肝心要"
"かんじんちょう 勧進帳"
"かんすい 灌水 潅水 冠水 完遂"
"かんすいきんぞく 関水金属"
"かんすいぎょ 寒水魚"
"かんすう 函數 巻数 函数 関数"
"かんすうかん 関数環"
"かんすうけい 関数形"
"かんすうじ 漢数字"
"かんする 関する"
"かんせい 喊声 陥穽 官制 監製 閑静 喚声 乾性 官製 管制 慣性 歓声 感性 完成"
"かんせいがくいん 関西学院"
"かんせいがくいんだいり 関西学院大理"
"かんせいしゃ 完成車"
"かんせいば 慣性場"
"かんせいめい 官姓名"
"かんせかいどうてい 貫世界同定"
"かんせき 寛晰"
"かんせつ 冠雪 関節 間接"
"かんせつえき 関節液"
"かんせつかく 関節角"
"かんせつきょう 関節鏡"
"かんせつきょうしか 関節鏡視下"
"かんせつすいしゅ 関節水腫"
"かんせつぜい 間接税"
"かんせつひ 間接費"
"かんせつほう 関節包"
"かんせつわざ 関節技"
"かんせん 汗腺 艦戦 艦船 観戦 幹線 感染"
"かんせんき 観戦記"
"かんせんきゃく 観戦客"
"かんせんけん 観戦券"
"かんせんげん 感染源"
"かんせんせつ 感染説"
"かんぜい 関税"
"かんぜおん 観世音"
"かんぜりゅう 観世流"
"かんぜん 敢然 勧善 完全"
"かんぜんうちぜいほうしき 完全内税方式"
"かんぜんか 完全花"
"かんぜんかい 完全解"
"かんぜんじあい 完全試合"
"かんぜんたい 完全体"
"かんぜんむてきわざ 完全無敵技"
"かんそ 簡素"
"かんそう 乾草 観相 換装 完奏 間想 歓送 間奏 完走 乾燥 感想"
"かんそうげい 歓送迎"
"かんそうこ 乾倉庫"
"かんそうせん 感想戦"
"かんそうらん 乾燥卵"
"かんそく 患側 緩速 観測"
"かんそくじょ 観測所"
"かんそくすじ 観測筋"
"かんそくもう 観測網"
"かんそん 寒村"
"かんぞう 鑑三 肝臓"
"かんぞうがん 肝臓癌"
"かんぞく 奸賊 漢族"
"かんた 幹太"
"かんたい 冠体 桿体 艦体 鑑隊 寒帯 歓待 艦隊"
"かんたいか 簡体化"
"かんたいじ 簡体字"
"かんたいせん 艦隊戦"
"かんたいへいよう 環太平洋"
"かんたく 干拓"
"かんたろう 勘太郎"
"かんたん 簡單 邯鄲 感嘆 簡単"
"かんたんふ 感嘆符"
"かんだ 苅田 関田 神田"
"かんだい 漢代 関大 寛大"
"かんだいせん 関大戦"
"かんだがわより 神田川寄り"
"かんだち 神立"
"かんだつ 神立"
"かんだん 間断 寒暖 歓談"
"かんだんけい 寒暖計"
"かんち 奸智 奸知 姦智 寒地 感知 完治 関知"
"かんちがい 勘違い"
"かんちく 患畜"
"かんちばん 感知板"
"かんちゅう 管中 寒中"
"かんちょう 間諜 干潮 管長 浣腸 完調 官庁 館長 艦長"
"かんつう 姦通 貫通"
"かんつうざい 姦通罪"
"かんつうとびら 貫通扉"
"かんつうろ 貫通路"
"かんづめ 罐詰 缶詰"
"かんてい 艦艇 官邸 鑑定"
"かんていしょく 艦底色"
"かんていりゅう 勘亭流"
"かんてき 観的"
"かんてつ 官鉄 関鉄 貫徹 完徹"
"かんてん 旱天 干天 寒天 観点"
"かんでん 関電 感電"
"かんでんこう 関電工"
"かんでんし 感電死"
"かんでんち 乾電池"
"かんとう 竿頭 完投 敢闘 冠頭 竿灯 完答 巻頭 関東"
"かんとういち 関東一"
"かんとうかんれい 関東管令"
"かんとうがくいんせん 関東学院戦"
"かんとうぐん 関東軍"
"かんとうげん 巻頭言"
"かんとうし 間投詞"
"かんとうせん 関東戦"
"かんとうぜい 関東勢"
"かんとうてきかんかく 関東的感覚"
"かんとうに 関東煮"
"かんとうば 関東馬"
"かんとうりゅう 関東流"
"かんとく 監督"
"かんとくえん 関特演"
"かんとくさく 監督作"
"かんとくちょう 監督庁"
"かんとん 嵌頓 広東"
"かんとんご 廣東語"
"かんとんめん 広東麺"
"かんど 神戸 感度"
"かんどう 間道 勘当 完動 感動"
"かんどうさく 感動作"
"かんどうみゃく 肝動脈 冠動脈"
"かんどころ 勘所"
"かんどり 神取"
"かんな 寛和 鉋"
"かんない 幹内 館内 艦内 管内 関内"
"かんなぎ 覡 巫"
"かんなづき 神無月"
"かんなな 環七"
"かんなべ 神辺"
"かんなみ 函南"
"かんなり 金成"
"かんなん 艱難"
"かんにち 韓日"
"かんにゅう 嵌入"
"かんにん 勘忍 堪忍"
"かんにんぶくろ 堪忍袋"
"かんぬき 貫木 閂"
"かんぬし 神主"
"かんねい 奸佞 姦佞"
"かんねつ 乾熱 感熱"
"かんねつし 感熱紙"
"かんねん 観念"
"かんの 管野 菅野 冠野 神野"
"かんのう 感能 感応 完納 間脳 官能"
"かんのん 観音"
"かんのんきょう 観音教"
"かんのんざき 観音崎"
"かんのんぞう 観音像"
"かんはつ 間髪"
"かんば 悍馬"
"かんばい 観梅 寒梅 完売"
"かんばいこ 寒梅粉"
"かんばく 艦爆"
"かんばつ 旱魃 干魃 間伐 簡抜"
"かんばつざい 間伐材"
"かんばめい 冠馬名"
"かんばやし 上林 神林"
"かんばら 神原 蒲原"
"かんばん 燗番 乾板 看板"
"かんばんむすめ 看板娘"
"かんぱ 看破 寒波 カンパ"
"かんぱい 完敗 乾杯"
"かんぱく 関白"
"かんぱち 環八"
"かんぱつ 間髪"
"かんぱん 乾板 干犯 甲板"
"かんび 艦尾 甘美 完備"
"かんびーる 缶ビール"
"かんびいる 缶ビール"
"かんびそく 完備束"
"かんびょう 看病"
"かんびん 簡便"
"かんぴ 韓非 官費"
"かんぴょう 鑑評"
"かんぴょうき 間氷期"
"かんふー 功夫"
"かんぶ 患部 幹部"
"かんぶつ 奸物 換物 干物 乾物"
"かんぶつえ 潅仏会"
"かんぶり 寒ブリ"
"かんぶん 漢文"
"かんぶんくんどくたい 漢文訓読体"
"かんぷ 関釜 完膚 還付 乾布"
"かんぷう 完封 寒風"
"かんぷうざん 寒風山"
"かんぷく 感服"
"かんべ 神戸"
"かんべえ 勘兵衛"
"かんべつ 鑑別"
"かんべん 簡便 勘弁"
"かんぺき 癇癖 完壁 完ぺき 完璧"
"かんぼう 姦謀 観望 奸謀 監房 感冒 官房"
"かんぼうやく 感冒薬"
"かんぼく 灌木 潅木"
"かんぼじあ 柬蒲寨"
"かんぼつ 陥没"
"かんぽう 館報 艦砲 漢方 官報"
"かんぽうい 漢方医"
"かんぽうやく 漢方薬"
"かんま カンマ"
"かんまき 上牧"
"かんまく 間膜"
"かんまつ 巻末"
"かんまん 干満 緩慢"
"かんみ 寛美 甘味"
"かんみゃく 間脈"
"かんみん 官民"
"かんみんぞく 漢民族 韓民族"
"かんむ 桓武"
"かんむり 冠"
"かんむりょう 感無量"
"かんめ 貫目"
"かんめい 艦名 簡明 官名 感銘"
"かんめん 管面 乾麺"
"かんもん 環紋 喚問 関門"
"かんもんきょう 関門橋"
"かんやく 完訳 監訳 簡約"
"かんやくけい 簡約形"
"かんやくりつ 簡約律"
"かんゆ 肝油 換喩"
"かんゆう 奸雄 勧誘"
"かんよ 関与"
"かんよう 観洋 涵養 観葉 寛容 慣用 肝要"
"かんようく 慣用句"
"かんようよみ 慣用読"
"かんら 甘楽"
"かんらく 乾酪 歓楽 陥落"
"かんらん 觀覽 橄欖 甘藍 観覧"
"かんらんしゃ 観覧車"
"かんらんせき 観覧席"
"かんり 監理 官吏 管理"
"かんりがえ 管理換"
"かんりがかり 管理掛"
"かんりし 管理士"
"かんりしょく 管理職"
"かんりとう 管理棟"
"かんりひ 管理費"
"かんりゃく 簡略"
"かんりゃくけい 簡略形"
"かんりゅう 潅流 乾溜 貫流 還流 環流 寒流"
"かんりょう 官僚 完了"
"かんるい 感涙"
"かんれい 寒冷 慣例"
"かんれき 還歴 還暦"
"かんれん 關聯 関連"
"かんれんづけ 関連付"
"かんろ 甘露 寒露 管路"
"かんろく 環六 貫禄"
"かんわ 閑話 漢和 緩和"
"かんわきゅうだい 閑話休題"
"かんんけつへん 完結編"
"が ヵ 伽 瓦 鵞 鵝 訝 訛 衙 莪 畫 峩 娥 哦 呀 ケ 果 ヶ 牙 俄 峨 河 臥 芽 蛾 餓 茅 画 駕 雅 賀 我"
"がーたー ガーター"
"がーど ガード"
"がーりっく ガーリック"
"がい 愾 駭 葢 艾 礙 磑 睚 盖 皚 漑 崕 孩 垓 啀 剴 乂 我意 階 買い 甲斐 劾 咳 凱 碍 蓋 既 慨 崖 鎧 涯 骸 該 概 害 街 外"
"がいあく 害悪"
"がいあつ 外圧"
"がいい 外衣 害意"
"がいいん 外因"
"がいいんぶ 外陰部"
"がいえん 外薗 外苑 外延"
"がいえんひがしどおり 外苑東通り"
"がいか 蓋果 外貨 凱歌 外化"
"がいかい 外海 外界"
"がいかく 外殻 外角 外郭"
"がいかくきゅう 外角球"
"がいかさい 外貨債"
"がいかつ 概括"
"がいかん 外環 外観 概観"
"がいかんび 外観美"
"がいき 外気"
"がいきおん 外気温"
"がいきょう 外匡 概況"
"がいきょく 外局"
"がいきん 外勤"
"がいきんこん 外菌根"
"がいぎょ 害魚"
"がいくうかん 外空間"
"がいくせいか 学生課"
"がいけい 外傾 外径 外形 概形"
"がいけいたい 外形態"
"がいけん 外圏 外見"
"がいげんけい 外原型"
"がいこう 外光 外向 外交"
"がいこうけいしせい 外向傾姿勢"
"がいこうせん 外航船"
"がいこく 外国"
"がいこくかぶ 外国株"
"がいこくさい 外国債"
"がいこくさん 外国産"
"がいこくさんば 外国産馬"
"がいこくさんまい 外国産米"
"がいこくざい 外国材"
"がいこくじんせんしゅわく 外国人選手枠"
"がいこくじんとうろくしょ 外国人登録証"
"がいこくじんろてんしょう 外国人露店商"
"がいこくじんわく 外国人枠"
"がいこくせき 外国籍"
"がいこくせん 外国船"
"がいこくせんりょうぐん 外国占領軍"
"がいこくぜい 外国勢"
"がいこくば 外国馬"
"がいこくばわく 外国馬枠"
"がいこくもの 外国物"
"がいこつ 蓋骨 骸骨"
"がいご 外語"
"がいさい 外債"
"がいさん 概算"
"がいざい 外在 外材"
"がいし 碍子 外紙 外資 外史"
"がいしほういいかんそく 外篩包囲維管束"
"がいしゃ 外車 会社"
"がいしゅう 外周"
"がいしゅうき 概周期"
"がいしゅつ 外出"
"がいしょ 外書"
"がいしょう 街娼 外渉 外商 外相 外傷"
"がいしょく 外食"
"がいしん 外申 外信"
"がいじ 外耳 外字"
"がいじつせい 概日性"
"がいじゅ 外需"
"がいじん 外人"
"がいじんおんな 外人女"
"がいじんぜい 外人勢"
"がいじんわく 外人枠"
"がいすう 概数"
"がいず 概図"
"がいせい 外生 外征"
"がいせいき 外性器"
"がいせき 外戚 外積"
"がいせつ 外接 概説"
"がいせん 街宣 凱旋 外線"
"がいせんしゃ 街宣車"
"がいせんもん 凱旋門"
"がいぜん 蓋然"
"がいそう 外装 外層 外挿"
"がいそく 外側 外足"
"がいたい 外帯"
"がいため 外為"
"がいたん 外端 慨歎 慨嘆"
"がいだい 外大"
"がいち 外地"
"がいちゅう 害虫 外注"
"がいちょう 害鳥"
"がいてき 外敵 外的"
"がいてん 外点"
"がいでん 外伝 外電"
"がいとう 街燈 外套 街灯 外灯 街頭 該当"
"がいとうしゃ 該当車"
"がいど ガイド"
"がいどう 外道"
"がいどく 害毒"
"がいねん 外燃 概念"
"がいねんきき 外燃機関"
"がいはいよう 外胚葉"
"がいはく 該博 外泊"
"がいはん 外販"
"がいはんぼし 外反母趾 外反拇指"
"がいばん 外盤"
"がいひ 外被 外皮"
"がいひょう 概評"
"がいびぶん 外微分"
"がいふうしゃかん 凱風社刊"
"がいぶ 外部"
"がいぶもう 外部網"
"がいぶん 外聞"
"がいへき 外壁"
"がいへきあつ 外壁厚"
"がいほう 概包"
"がいぼう 外貌"
"がいまい 外米"
"がいむ 外務"
"がいむしょう 外務省"
"がいめん 外面"
"がいもう 外毛"
"がいもくほういいかんそく 外木包囲維管束"
"がいもん 外門"
"がいや 外野"
"がいやしゅ 外野手"
"がいやせき 外野席"
"がいゆう 外遊"
"がいよう 外洋 外用 概要"
"がいようづ 概要図"
"がいようやく 外用薬"
"がいらい 外来"
"がいらん 外乱"
"がいりゃく 概略"
"がいりょく 外力"
"がいりん 外輪"
"がいりんざん 外輪山"
"がいろ 街路"
"がいろじゅ 街路樹"
"がいろとう 街路灯"
"がいろん 概論"
"がいわくせい 外惑星"
"がう 號"
"がえ 換"
"がえし 返し"
"がお 顏 顔"
"がおう 画王"
"がおか ヶ丘"
"がおんしつ 画音質"
"がか 画架 画家"
"がかい 瓦壊 瓦解"
"がかく 畫角 画角"
"がかり 掛 係"
"がが 峨峨 峨々"
"ががく 雅楽"
"がき 餓鬼 垣"
"がぎじょうぶ 鉤状部"
"がぎょ 駕御"
"がぎょう ガ行"
"がく 鰐 鍔 萼 壑 齶 鄂 諤 樂 嶽 斈 咢 愕 學 顎 岳 楽 学 額"
"がくい 学位"
"がくいき 学位記"
"がくいり 額入り"
"がくいん 学院"
"がくえん 学園"
"がくえんがわ 学園際"
"がくえんさい 学園祭"
"がくえんもの 学園物"
"がくおん 楽音"
"がくがい 学外"
"がくきょうかい 学協会"
"がくぎょう 学業"
"がくぐん 学群"
"がくげい 学芸"
"がくげき 楽劇"
"がくさい 学才 学際 学祭"
"がくし 学資 学士"
"がくしいん 学士院"
"がくしき 学指揮 学識"
"がくしゃ 学舎 学者"
"がくしゃはだ 学者肌"
"がくしゅう 学習"
"がくしゅうあるごりずむ 学習アルゴリズム"
"がくしゅういん 学習院"
"がくしゅうじゅく 学習塾"
"がくしゅうせつ 学習説"
"がくしゅうづくえ 学習机"
"がくしゅうでえた 学習データ"
"がくしゅうはん 学習班"
"がくしゅうばいあす 学習バイアス"
"がくしょう 楽章"
"がくしょく 学食"
"がくしん 学術振興会 学術審議会 学振"
"がくじ 学事"
"がくじゅつ 学術"
"がくじょう 学術情報センター 学情"
"がくじょうもう 学術情報センター網 学情網"
"がくせい 学制 学生"
"がくせいか 学生掛"
"がくせいかばん 学生鞄"
"がくせいきかい 学生棋界"
"がくせいけん 学生券"
"がくせいずもう 学生相撲"
"がくせいふく 学生服"
"がくせいむき 学生向"
"がくせいりょう 学生寮"
"がくせき 学籍"
"がくせきぼ 学籍簿"
"がくせつ 楽節 学説"
"がくぜん 愕然"
"がくそう 学聡 学僧 楽想 学窓"
"がくそく 学則"
"がくそつ 学卒"
"がくたい 楽隊"
"がくたんきょうかん 学担教官"
"がくだん 楽壇 楽団"
"がくちょう 楽長 学長"
"がくていち 確定地"
"がくてき 学的"
"がくてん 楽典"
"がくとう 咢筒"
"がくとどういん 学徒動員"
"がくどう 学童"
"がくない 学内"
"がくねん 学年"
"がくねんまつ 学年末"
"がくの 嶽野"
"がくは 学派"
"がくばす 学バス"
"がくばつ 学閥"
"がくひ 学費"
"がくふ 楽譜"
"がくふう 学風"
"がくぶ 学部"
"がくぶそつ 学部卒"
"がくぶち 額縁"
"がくへん 萼片 咢片 がく片"
"がくほう 学報"
"がくむ 学務"
"がくめい 学名"
"がくめん 額面"
"がくもん 学問"
"がくもんじょ 学問所"
"がくや 嶽野 楽屋"
"がくやうら 楽屋裏"
"がくゆう 学友"
"がくゆうきょうかい 楽友協会"
"がくようひん 学用品"
"がくり 学理 楽理"
"がくりょう 学寮"
"がくりょうい 学寮委"
"がくりょうせん 学寮専"
"がくりょく 学力"
"がくるい 学類"
"がくれい 学齢"
"がくれき 学歴"
"がくれん 学連"
"がくわり 学割"
"がけ 垳 崖"
"がけい 芽型"
"がけした 崖下"
"がこう 画稿"
"がご 雅語"
"がごう 雅号"
"がさ 傘"
"がさい 画才"
"がさくちゅう 画策中"
"がざい 画材"
"がし 餓死 樫"
"がしつ 画質"
"がしゅう 我執 画集"
"がしゅん 賀春"
"がしょう 臥床 画商 賀正"
"がしんしょうたん 臥薪嘗胆"
"がじょう 芽条 賀状 牙城"
"がじょえんかんこう 雅叙園観光"
"がじんかって 我侭勝手"
"がす 瓦斯 ガス"
"がせつ 我説"
"がぜん 瓦全 俄然"
"がそ 画素"
"がそう 画層 芽層"
"がそごと 画素毎"
"がそりん ガソリン"
"がぞう 画像"
"がぞうしょり 画像処"
"がた 難 形 方 潟 型"
"がたさ 難さ"
"がだい 画題"
"がちょう 鵞鳥 鵝鳥 画帖 画調"
"がっ 合"
"がっか 学課 学科"
"がっかい 学界 学会"
"がっかごと 学科毎"
"がっかぜんきょういん 学科全教員"
"がっかん 学館"
"がっき 学期 楽器"
"がっきずき 楽器好き"
"がっきまつ 学期末"
"がっきゅう 学究 学級"
"がっきゅうき 学休期"
"がっきょく 楽曲"
"がっく 学区"
"がっけい 学系"
"がっけん 学研"
"がっこう 學校 学校"
"がっさい 合財 合切"
"がっさく 合作"
"がっさん 月山 合算"
"がっしゅう 合衆"
"がっしゅうこく 合州国"
"がっしゅく 合宿"
"がっしゅくじょ 合宿所"
"がっしょう 合焦 合従 合掌 合唱"
"がっせい 合生"
"がっせん 合戦"
"がっそう 合奏"
"がったい 合體 合体"
"がったいわざ 合体技"
"がっち 合致"
"がっちゃく 合着"
"がって 勝手"
"がってん 合點 合点"
"がっと ガット"
"がっぴ 月日"
"がっぴつ 合筆"
"がっぺい 合併"
"がっぽん 合本"
"がつ 歹 月"
"がつころ 月頃"
"がつごう 月号"
"がつすえ 月末"
"がつちゅう 月中"
"がつど 月度"
"がつばん 月版"
"がつぶん 月分"
"がつまつ 月末"
"がてん 合点"
"がでんいんすい 我田引水"
"がと 賀戸"
"がとう 餓島"
"がな 仮名"
"がにゅうどう 我入道"
"がね 鐘 金"
"がはく 画伯"
"がばん 画板"
"がひつ 画筆"
"がひん 訝賓"
"がびょう 画鋲"
"がふう 画風"
"がへい 画餅"
"がべい 画餅"
"がほう 芽胞 画法"
"がま 蟇 蝦蟆 釜 蒲 蝦蟇"
"がまごうり 蒲郡"
"がまごおり 蒲郡"
"がまもく ガマ目"
"がまん 我慢"
"がみ 髮 髪 上"
"がめん 画面"
"がめんした 画面下"
"がめんちゅうおううえ 画面中央上"
"がめんはし 画面端"
"がめんみぎ 画面右"
"がも 賀茂"
"がもう 蒲生"
"がようし 画用紙"
"がよく 我欲"
"がら 柄"
"がらく 雅楽"
"がらす ガラス 硝子"
"がらすたい 硝子体"
"がらっと ガラっと"
"がらん 伽藍"
"がりべん ガリ勉"
"がりゅう 我流"
"がりょう 雅量"
"がりょうてんせい 画竜点睛"
"がりょく 画力"
"がりん 芽鱗"
"がれーじ ガレージ"
"がれき 瓦礫"
"がろ ガロ"
"がろう 画廊"
"がろうでんせつ 餓狼伝説"
"がわ 巛 河 川 側"
"がん 鳫 鴈 顏 頷 阮 巖 嵒 嚴 偐 ガン 厳 龕 玩 巌 翫 贋 雁 癌 岸 眼 岩 顔 頑 願 丸 含 元"
"がんあつ 眼圧"
"がんい ⊃ 含意"
"がんいりょう 癌医療"
"がんえん 岩塩"
"がんか 眼窩 眼下 癌化 眼科"
"がんかい 眼科医 岩塊 眼界"
"がんきゅう 眼球"
"がんきゅうたん 眼球譚"
"がんきょう 元凶 頑強 眼鏡"
"がんきん 元金 眼筋"
"がんぎ 雁木"
"がんぐ 玩具"
"がんぐばこ 玩具箱"
"がんけい 眼形"
"がんけん 眼瞼 癌研 頑健"
"がんけんしん 癌検診"
"がんこ 頑固"
"がんこう 雁行 眼光"
"がんこくもじ 岩刻文字"
"がんこもの 頑固者 巌固者"
"がんさ 眼差"
"がんさいぼう 癌細胞"
"がんさく 贋作"
"がんし 眼視"
"がんしき 眼識"
"がんしぼう 癌死亡"
"がんしぼうゆ 含脂肪油"
"がんしゅう 含羞"
"がんしょ 願書"
"がんしょう 岩漿 岩礁"
"がんしょく 顔色"
"がんしん 眼振"
"がんじつ 元日"
"がんじょう 頑丈"
"がんじろう 鴈治郎"
"がんせいひろう 眼精疲労"
"がんせき 岩石"
"がんぜん 眼前"
"がんそ 元祖"
"がんそう 含嗽"
"がんたい 眼帯"
"がんたろう 巌太郎"
"がんたん 元旦"
"がんだい 岩大"
"がんだれ 厂"
"がんちく 含蓄"
"がんちゅう 眼中"
"がんちりょう 癌治療"
"がんつう 眼痛"
"がんてい 眼底"
"がんとくせん 岩徳線"
"がんねん 元年"
"がんのすけ 雁之助"
"がんばり 頑張り"
"がんばん 岩盤"
"がんぱく 雁帛"
"がんびょう 眼病"
"がんぺい 贋幣"
"がんぺき 岸壁 岩壁"
"がんぼう 眼房 願望"
"がんぽん 元本"
"がんま Γ γ"
"がんません γ線"
"がんめい 頑迷"
"がんめん 顔面"
"がんもう 願望"
"がんもく 眼目"
"がんもん 雁門"
"がんやく 丸薬"
"がんゆう 含有"
"がんゆごうきん 含油合金"
"がんよくせい 癌抑制"
"がんよぼう 癌予防"
"がんらい 元来"
"がんり 元利"
"がんりき 眼力"
"がんりゅうじま 巌流島 厳流島"
"がんりょう 含量 顔料"
"がんろう 玩弄"
"き 鰭 姫 肌 槻 其 碕 碁 祁 嵜 枳 箕 熙 龜 驥 騏 馗 饑 餽 逵 跪 跂 譏 諱 詭 覬 覊 虧 耆 羇 羈 稘 禧 祺 瞶 皈 癸 畸 猗 燬 熹 煕 淇 气 麾 歸 欹 欷 榿 杞 朞 曁 暉 晞 旡 揆 掎 憙 愾 徠 弃 幃 屓 竒 毀 圻 噐 喟 唏 卉 匱 剞 几 冀 來 窺 熈 倚 麒 生 城 妓 聞 棊 悸 着 愧 伎 嬉 来 僖 氣 企 毅 畿 綺 希 饋 岐 喜 徽 棄 揮 幾 忌 稀 飢 棋 黄 樹 奇 己 汽 軌 帰 祈 規 亀 輝 騎 旗 季 鬼 危 机 起 既 寄 期 紀 貴 器 基 記 機 木 気"
"きー キー"
"きーせん 妓生"
"きーぼーど キーボード"
"きーわーど キーワード"
"きあ 騎亜"
"きあい 気合 気合い"
"きあつ 気圧"
"きあつけい 気圧計"
"きあん 起案"
"きい 貴意 聴い 聞い 奇異 紀伊"
"きいち 喜市 輝一 喜一"
"きいちろう 喜一郎"
"きいと 生糸"
"きいとん 喜頓"
"きいはんとうおき 紀伊半島沖"
"きいれ 喜入"
"きいろ 黄色"
"きいん 起因"
"きいんげん 起因源"
"きう 気宇"
"きうえ 木植"
"きうえはら 木上原"
"きうち 木内"
"きうら 木浦"
"きうん 機運 気運"
"きえ 気恵 帰依 消え"
"きえい 機影 気鋭"
"きえこ 喜恵子"
"きえつ 喜悦"
"きえん 気焔 機縁 奇縁 気炎"
"きえんさん 希塩酸"
"きおい 紀尾井 気負い"
"きおう 既往"
"きおうじんじゃ 鬼王神社"
"きおうせん 棋王戦"
"きおく 記憶"
"きおくぼ 記憶薄"
"きおち 気落 気落ち"
"きおん 基音 気音 気温"
"きか 麾下 貴課 貴家 奇貨 奇禍 貴下 気化 帰化 幾何"
"きかい 喜界 気塊 貴会 器械 奇怪 機会 機械"
"きかいあぶら 機械油"
"きかいいん 既会員"
"きかいけん 機械研究所"
"きかいこう 機械工"
"きかいつうくかん 既開通区間"
"きかく 企劃 規格 企画"
"きかくあん 企画案"
"きかくだおれ 企画倒れ"
"きかくてん 企画展"
"きかくばん 規格判"
"きかくぶつき 企画部付"
"きかくぶづけ 企画部付"
"きかげき 喜歌劇"
"きかねつ 気化熱"
"きかん 汽罐 器管 軌間 旗艦 貴簡 既刊 気管 帰還 器官 季刊 貴艦 饋還 基幹 機関 期間"
"きかんがいしけん 期間外試験"
"きかんごと 機関毎"
"きかんし 気管支 機関士 機関紙"
"きかんしえん 気管支炎"
"きかんしゃ 機関車"
"きかんしゅ 機関手"
"きかんじゅう 機関銃"
"きかんぜんすう 奇完全数"
"きかんほう 機関砲"
"きかんもう 基幹網"
"きが 飢餓 気賀"
"きがい 気愾 気慨 気概 危害"
"きがえ 着換え 着替 着替え"
"きがく 器楽 貴学"
"きがた 木型 木方"
"きがね 気兼 気兼ね"
"きがまえ 気構え"
"きがる 気軽"
"きがわ 木川"
"きがん 奇岩 祈願"
"きき 喜々 嬉々 窺基 暉暉 輝輝 嬉嬉 毀棄 喜気 帰期 起期 記旗 奇鰭 奇奇 奇気 汽機 忌諱 騏驥 器機 諱忌 記紀 飢鬼 鬼気 危機 機器"
"ききあし 利き足"
"ききうで 利き腕 利腕"
"ききおう 騏鬼翁"
"ききおぼえ 聞き覚え"
"ききかいかい 奇々怪々"
"ききこみ 聞き込み"
"ききごごち 聞き心地"
"ききすて 聞き捨て"
"ききずて 聞き捨て"
"ききて 利き手 聞き手 聴き手"
"ききみみ 利き耳 聞き耳"
"ききめ 利き目 效 効き目"
"ききもの 聴きもの"
"ききゃく 棄却"
"ききやく 聞き役"
"ききゅう 危急 希求 気球"
"ききょ 起居"
"ききょう 奇矯 気胸 帰敬 帰京 桔梗 帰郷"
"ききょうもく キキョウ目"
"ききん 飢饉 寄金 基金"
"きぎ 樹々 木々"
"きぎけん 機技研"
"きぎしつ 基技室"
"きぎょう 起業 企業"
"きぎょうか 企業家 起業家"
"きぎょうごと 企業毎"
"きぎょうぞう 企業像"
"きぎょうたい 企業体"
"きく 鞫 椈 聴く 掬 鞠 菊"
"きくい 喜久井"
"きくいずみ 喜久泉"
"きくえい 菊栄"
"きくお 紀久男 菊雄 菊男 喜久雄 喜久男"
"きくか 菊鹿 キク科"
"きくかわ 菊川"
"きくがわ 菊川"
"きくこ 起久子 喜久子 菊子 貴久子"
"きくごろう 菊五郎"
"きくさと 喜久里"
"きくざけ 菊酒"
"きくじ 喜久治"
"きくすい 菊水"
"きくすいまる 菊水丸"
"きくぞう 木久蔵"
"きくた 菊田"
"きくち 菊池 菊地"
"きくちよ 菊千代"
"きくな 菊名"
"きくに 喜国"
"きくにんぎょう 菊人形"
"きくの 菊野"
"きくのすけ 菊之助"
"きくはら 菊原"
"きくばり 気くばり 気配り"
"きくばん 菊判"
"きくひめ 菊姫"
"きくびし 菊菱"
"きくま 菊間"
"きくまさ 菊政"
"きくまさむね 菊政宗"
"きくもく キク目"
"きくや 菊屋"
"きくゆうかい 菊友会"
"きくよう 菊陽"
"きくん 貴君"
"きぐ 機具 危ぐ 器具 危惧"
"きぐう 奇遇"
"きぐち 木口"
"きぐつ 木靴"
"きぐみ 木組み"
"きぐらい 気位"
"きぐろう 気苦労"
"きけい 詭計 畸計 畸形 畸型 奇形 貴兄"
"きけいぎょ 奇形魚"
"きけいしき 木形式"
"きけいじ 奇形児"
"きけつ 既決 帰結"
"きけん 貴顕 気圏 棄権 危険"
"きけんきゅう 危険球"
"きけんし 危険視"
"きげき 喜劇"
"きげきつい 機撃墜"
"きげつ 亀月"
"きげん 紀元 起源 機嫌 期限"
"きげんぎれ 期限切"
"きげんせつ 起源説"
"きげんぜん 紀元前"
"きこ 紀子"
"きこう 稀覯 帰航 機工 希覯 寄航 機甲 騎行 起工 貴校 帰港 奇行 騎甲 季候 紀行 気孔 気功 寄港 寄稿 気候 機構"
"きこうがたきんぞく 亀甲型金属"
"きこうし 貴公子 貴公士"
"きこうぞう 木構造"
"きこうもの 紀行物"
"きこうりょうへい 機甲猟兵"
"きこく 枳穀 鬼哭 帰国"
"きこくとどけ 帰国届"
"きこし 木越"
"きこつ 気骨"
"きこない 木古内"
"きこり 樵"
"きこん 気根 既婚"
"きご 木子 季語"
"きごう ∪ 揮毫 † ‰ Å ∫ ∝ ≪ ∠ ¬ ∨ ∧ ≫ ヶ ∵ ‡ ¶ ⌒ Ц 。 - ゜ ´ ｀ ＾ ヾ ゝ ゞ ♭ ≡ 仝 ： 〇 ー ‐ 〆 ， ＿ ‘ 、 ． ’ ヽ ‥ ¨ ” （ ） ； 〔 ［ ｛ ］ ｝ ‖ ゛ 〈 〉 「 ｜ ！ 」 〕 ？ ・ ÷ ＼ … 〃 ／ 《 々 ♂ “ ° ＋ ′ ― 》 ″ ¢ ± − ♪ ＜ ≦ ∞ £ ＝ ♀ 『 ∴ 』 ≧ ＄ 〜 ＊ ≠ ￥ ＆ 】 ℃ 【 ％ ￣ ＃ × ＞ ▲ § □ ☆ ★ △ ○ ▽ ◆ ● ▼ 〓 ◇ ◎ ＠ 〒 ↑ ← ■ → ※ ↓ 記号"
"きごうした 記号下"
"きごうもうど 記号モード"
"きごこち 着心地"
"きごころ 気心"
"きごし 木越"
"きさ 吉舎 蚶"
"きさい 騎西 鬼才 起債 既済 奇才 記載"
"きさかた 象潟"
"きさかぶんきてん 木坂分岐点"
"きさき 后 妃"
"きさく 既作 喜作"
"きさぬき 木佐貫"
"きさぶろう 喜三郎"
"きさま 貴様"
"きさらぎ 如月"
"きさらづ 木更津"
"きさわ 木沢"
"きさん 起算 帰参"
"きざ 起坐 気障"
"きざい 器財 器材 機材"
"きざき 稀崎 木崎"
"きざくらしゅぞう 黄桜酒造"
"きざけ 生酒"
"きざさ 季笹"
"きざし 兆"
"きざはし 階"
"きざみ 刻 刻み"
"きざんかん 機山館"
"きし 貴誌 貴紙 貴志 棋士 騎士 来住 岸"
"きしかいせい 起死回生"
"きしかわ 貴志川"
"きしがみ 岸上"
"きしけいこ 岸恵子"
"きしじま 岸島"
"きしだ 岸田"
"きしつ 器質 基質 気質"
"きしの 岸野"
"きしば 岸場"
"きしべ 岸辺"
"きしま 杵島"
"きしみ 軋み"
"きしもじん 鬼子母神"
"きしもと 岸本"
"きしゃ 喜捨 汽車 帰社 気車 貴社 記者"
"きしゃく 稀釈 希釈"
"きしゃくえき 希釈液"
"きしゃせき 記者席"
"きしゃたびそうだんしつ 汽車旅相談室"
"きしゃちん 汽車賃"
"きしゃのひろば 汽車の広場"
"きしやじま 岸屋島"
"きしゅ 期種 機首 期首 旗手 騎手 機種"
"きしゅう 奇襲 奇習 紀州"
"きしゅううめ 紀州梅"
"きしゅうじ 紀州路"
"きしゅうてん 起終点"
"きしゅうわざ 奇襲技"
"きしゅく 岐宿 耆宿 寄宿"
"きしゅくしゃ 寄宿舎"
"きしゅごと 機種毎"
"きしゅつ 既出"
"きしょ 奇書 貴書 貴所 寄書"
"きしょう 稀少 氣象 毀傷 起請 徽章 希少 記章 気性 気象 起床"
"きしょうえせせい 気象衛星"
"きしょうしゃ 希少車"
"きしょうちょう 気象庁"
"きしょうてんけつ 起承転結"
"きしょうなん 気性難"
"きしょうぼり 起請彫り"
"きしょうもん 起請文"
"きしょく 喜色 気色"
"きしょじまん 稀書自慢"
"きしり 軋り"
"きしろ 木城"
"きしわだ 岸和田"
"きしん 鬼神 帰心 寄進 貴信 紀信"
"きしんせん 姫神線"
"きしんへいだん 機神兵団"
"きじ 雉 木地 生地 記事"
"きじく 基軸 機軸"
"きじごと 記事毎"
"きじつ 期日"
"きじま 貴島 木嶋 木島"
"きじまだいら 木島平"
"きじもと 雉本"
"きじゅ 喜寿"
"きじゅう 機銃"
"きじゅうき 起重機"
"きじゅつ 既述 奇術 記述"
"きじゅん 帰順 規準 基準"
"きじゅんしゃ 基準車"
"きじゅんふく 基準服"
"きじょ 鬼女 貴女 機序"
"きじょう 木城 騎上 軌条 騎乗 機上 机上"
"きじょうば 騎乗馬"
"きじん 畸人 貴人 鬼神 奇人"
"きじんぶ 基人部"
"きす 鱚 木須 キス"
"きすい 気水 既遂"
"きすう 帰趨 機数 寄数 基数 奇数"
"きすうじほうていしき 奇数次方程式"
"きすうぺーじ 奇数頁"
"きすうほう 記数法"
"きすが 貴家"
"きすき 木次"
"きすぎ 来生"
"きすみ 木栖"
"きず 生酢 岐津 痍 疵 瑕 傷"
"きずあと 傷痕 傷跡"
"きずかい 気遣い"
"きずくり 木造"
"きずぐち 傷口"
"きずな 絆"
"きずもの 疵物 傷物"
"きせ 黄瀬 木瀬 吉瀬"
"きせい 紀勢 棋聖 規正 気勢 期生 既製 奇声 寄生 既成 帰省 規制"
"きせいこん 寄生根"
"きせいしゃ 規制車"
"きせいじゅう 寄生獣"
"きせいせん 棋聖戦"
"きせいせんちょくつう 紀勢線直通"
"きせいちゅう 寄生虫"
"きせいふく 既製服"
"きせいふてきごうしゃ 規制不適合車"
"きせき 鬼籍 奇蹟 寄蹟 軌跡 奇跡"
"きせせん 紀勢線"
"きせつ 既設 季節"
"きせつがら 季節柄"
"きせつごと 季節毎"
"きせつしゃ 季節車"
"きせつぞう 季節増"
"きせのん キセノン"
"きせる 煙管"
"きせん 黄線 貴賤 帰船 機船 棋戦 汽船 機先 基線 帰仙 帰線"
"きぜつ 気絶"
"きぜん 毅然"
"きそ 木祖 木曽 木曾 起訴 基礎"
"きそう 吉左右 寄贈 竸 帰巣 起草 気相 奇想"
"きそく 気息 規則"
"きそくえんえん 気息奄々"
"きそこう 基礎工"
"きそこまこうげん 木曽駒高原"
"きそざき 木曾岬"
"きそじ 木曽路"
"きそすう 奇素数"
"きそたい 基礎体"
"きそとう 基礎棟"
"きそん 毀損 既存"
"きぞう 寄贈"
"きぞく 貴族 帰属"
"きぞん 既存"
"きた 木田 来た 喜多 北"
"きたあいき 北相木"
"きたあいづ 北会津"
"きたあきた 北秋田"
"きたあげお 北上尾"
"きたあずみ 北安曇"
"きたあだち 北足立"
"きたあまべ 北海部"
"きたあやせ 北綾瀬"
"きたありま 北有馬"
"きたい 北井 奇胎 稀代 機体 危殆 気体 期待"
"きたいさく 期待作"
"きたいずみ 北泉"
"きたいたみ 北伊丹"
"きたいちがらす 北一硝子"
"きたいっき 北一輝"
"きたいば 期待馬"
"きたいばらき 北茨城"
"きたいばらぎし 北茨城市"
"きたいぼ 期待薄"
"きたうおぬま 北魚沼"
"きたうち 北内"
"きたうら 北浦"
"きたうらわ 北浦和"
"きたうわ 北宇和"
"きたえかた 鍛え方"
"きたえき 北駅"
"きたえだ 北枝"
"きたお 北尾"
"きたおおさかきゅうこう 北大阪急行"
"きたおおさかきんぺん 北大阪近辺"
"きたおおじ 北大路"
"きたおおつか 北大塚"
"きたおか 北岡"
"きたおかざき 北岡崎"
"きたおね 北尾根"
"きたおり 北折"
"きたかしま 北鹿島"
"きたかすかべ 北春日部"
"きたかぜ 北風"
"きたかた 北方"
"きたかちどき 北勝閧"
"きたかつしか 北葛飾"
"きたかつらぎ 北葛城"
"きたかべ 北壁"
"きたかまくら 北鎌倉"
"きたかみ 北上"
"きたかるいざわ 北軽井沢"
"きたかわ 北川"
"きたかわち 北河内"
"きたかわべ 北川辺"
"きたかんとう 北関東"
"きたかんばら 北蒲原"
"きたがき 北垣"
"きたがた 北方"
"きたがわ 北河 北側 北川"
"きたきつね 北狐 キタキツネ"
"きたきゅうしゅう 北九州"
"きたきんき 北近畿"
"きたく 寄託 北区 帰宅"
"きたくみん 北区民"
"きたくりはま 北久里浜"
"きたくわだ 北桑田"
"きたぐち 北口"
"きたぐに 北国"
"きたぐんま 北群馬"
"きたけ 着丈"
"きたこう 北港"
"きたこうじ 北小路"
"きたこま 北巨摩"
"きたこまつ 北小松"
"きたごう 北郷"
"きたさいたま 北埼玉"
"きたさく 北佐久"
"きたさわとうげ 北沢峠"
"きたざと 北里"
"きたざわ 北沢 北澤"
"きたざわしょ 北沢署"
"きたしおばら 北塩原"
"きたしが 北志賀"
"きたしたら 北設楽"
"きたしながわえき 北品川駅"
"きたしなの 北信濃"
"きたしらかわ 北白川"
"きたしんち 北新地"
"きたじま 北嶋 北島 喜多嶋"
"きたじょう 喜多條"
"きたすぎ 北杉"
"きたすな 北砂"
"きたせん 北線"
"きたせんじゅ 北千住"
"きたせんじゅぐち 北千住口"
"きたせんぞく 北千束"
"きたせんだい 北仙台"
"きたせんり 北千里"
"きたそうま 北相馬"
"きたぞの 北園"
"きたたいへいよう 北太平洋"
"きたたかき 北高来"
"きたたかぎ 北高来"
"きたたちばな 北橘"
"きたたに 北谷"
"きたたま 北多摩"
"きただ 北田"
"きただい 北代"
"きただいとう 北大東"
"きただけ 北岳"
"きたちく 北地区"
"きたちしま 北千島"
"きたちょうせん 北朝鮮"
"きたつがる 北津軽"
"きたつる 北都留"
"きたとしま 北豊島"
"きたとだ 北戸田"
"きたど 北戸"
"きたなか 北中"
"きたなかぐすく 北中城"
"きたならしの 北習志野"
"きたにほん 北日本"
"きたね 北根"
"きたの 北野"
"きたのうみ 北の湖"
"きたのたけし 北野武"
"きたのまる 北の丸"
"きたはし 北橋"
"きたはた 北波多"
"きたはちおうじ 北八王子"
"きたはっこうだ 北八甲田"
"きたはま 北浜"
"きたはら 北原"
"きたはらはくしゅう 北原白秋"
"きたはんきゅう 北半球"
"きたはんぶん 北半分"
"きたばたけ 北畑 北畠"
"きたばやし 北林"
"きたひろしま 北広島"
"きたふちゅうほうめん 北府中方面"
"きたべっぷ 北別府"
"きたほ 北穂"
"きたほだか 北穂高"
"きたほっかいどう 北北海道"
"きたまち 北町"
"きたまつ 北松"
"きたまつど 北松戸"
"きたまわり 北回り"
"きたみ 喜多見 北見"
"きたみざわ 北見沢"
"きたみまき 北御牧"
"きたむき 北向き"
"きたむたやま 北村山"
"きたむら 北村"
"きたむろ 北牟婁"
"きため 北目"
"きたもうこ 北蒙古"
"きたもと 北本"
"きたもり 北森"
"きたもりお 北杜夫"
"きたもろかた 北諸県"
"きたもん 北門"
"きたや 北谷"
"きたやま 北山"
"きたやまさ 北山佐"
"きたゆき 北行"
"きたより 北寄り"
"きたら 喜多羅"
"きたりゅう 喜多流"
"きたろう 喜太郎 鬼太郎 喜多郎"
"きたわき 北脇"
"きたん 綺譚 奇譚 忌憚"
"きたんかいきょう 紀淡海峡"
"きだ 貴田 木田"
"きだい 気大 稀代 機台 基台 貴台"
"きだて 気立 気だて"
"きだまり 木田余"
"きだん 綺譚 気団 奇談"
"きち 危地 機智 貴地 機知 既知 基地 吉"
"きちあと 基地跡"
"きちえもん 吉右衛門"
"きちがい 気違い"
"きちく 鬼畜"
"きちじ 吉事"
"きちじつ 吉日"
"きちじま 吉島"
"きちじょう 吉祥"
"きちじょうじ 吉祥寺"
"きちすう 吉数"
"きちのすけ 吉之助"
"きちゃく 帰着"
"きちゅう 機中 忌中"
"きちょう 貴族 綺帳 几帳 機長 記帳 基調 貴重"
"きちれい 吉例"
"きちろう 吉郎"
"きっか 橘花 菊華 菊花"
"きっかけ 切っ掛け"
"きっかしょうば 菊花賞馬"
"きっかわ 菊川 吉川"
"きっきょう 吃驚 吉凶"
"きっきん 喫緊"
"きっく キック"
"きっこう 拮抗 亀甲"
"きっこうまん 亀甲萬"
"きっさ 喫茶"
"きっさき 切尖 切先"
"きっしょう 吉祥"
"きっしょういん 吉祥院"
"きっす キッス"
"きっすい 吃水 喫水 生粋"
"きっせき 詰責"
"きっせん 吉仙"
"きっそう 吉左右"
"きっそうさん 吉草酸"
"きったか 橘高"
"きっちょう 吉兆"
"きっちん キッチン"
"きって 切手"
"きっと 屹度 急度 吃度 吉都 キット"
"きっぷ 気っ風 気風 キップ 切符"
"きっぽう 吉報"
"きつ 訖 屹 佶 拮 乞 吃 橘 吉 喫 桔 詰"
"きつえん 喫煙"
"きつえんか 喫煙家"
"きつえんしゃ 喫煙車"
"きつえんじょ 喫煙所"
"きつえんせき 喫煙席"
"きつおん 吃音"
"きつかわ 橘川"
"きつき 杵築"
"きつけ 着付け 気附 気付"
"きつぜん 屹然"
"きつつき 啄木鳥"
"きつと 吉都"
"きつね 狐"
"きつねいろ 狐色"
"きつねつき 狐憑き"
"きつねのまごか キツネノマゴ科"
"きつもん 詰問"
"きつりつ 吃立 屹立"
"きつれがわ 喜連川"
"きづ 岐津 木津"
"きづかい 氣遣い"
"きづかれ 気疲れ"
"きづき 木月 木築"
"きづく 気附"
"きづけ 気附 気付"
"きづち 木鎚"
"きて 来て"
"きてい 規程 既定 基底 規定"
"きていぎ 既定義"
"きていすういじょう 規定数以上"
"きていまく 基底膜"
"きてき 汽笛"
"きてん 貴店 機転 起点 基点"
"きでら 紀寺"
"きでりょく 起電力"
"きでん 機電 貴殿"
"きでんりょく 起電力"
"きと 企図 帰途"
"きとう 木頭 鬼頭 紀藤 祈梼 木藤 亀頭 祈祷 気筒"
"きとく 既得 奇特 危篤"
"きど 鬼怒 希土 輝度 木戸 城戸"
"きどあいらく 喜怒哀楽"
"きどう 気道 鬼道 棋道 機動 軌道 起動"
"きどうしき 軌道敷"
"きどうしゃ 気動車"
"きどうじき 軌道敷"
"きどうせんよう 機動戦用"
"きどく 既読"
"きどせん 木戸錢"
"きどって 気取って"
"きどで 木戸出"
"きない 畿内 機内"
"きないしょく 機内食"
"きなが 気長"
"きなさ 鬼無里"
"きなし 木梨"
"きなん 貴男 紀南 危難"
"きにち 忌日"
"きにゅう 記入"
"きにん 貴人 帰任"
"きにんだて 貴人点"
"きぬ 帛 衣 絹"
"きぬいと 絹糸"
"きぬえ 絹枝"
"きぬおりもの 絹織物"
"きぬかわ 衣川"
"きぬがさ 衣笠"
"きぬがわ 鬼怒川"
"きぬけ 気抜け"
"きぬた 砧"
"きね 杵"
"きねしま 杵嶋"
"きねま キネマ"
"きねん 祈念 記念"
"きねんけん 記念券"
"きねんさい 記念祭"
"きねんじゅ 記念樹"
"きねんひ 記念碑"
"きねんひてきけっさく 記念碑的傑作"
"きの 木野"
"きのう 帰納 機能 昨日"
"きのうごと 機能毎"
"きのうち 城内 木内 木之内"
"きのうつき 機能付"
"きのうび 機能美"
"きのうほうのかてい 帰納法の仮定"
"きのうよびだ 機能呼出"
"きのえ 木江 甲"
"きのえいぬ 甲戌"
"きのえうま 甲午"
"きのえさる 甲申"
"きのえたつ 甲辰"
"きのえとら 甲寅"
"きのえね 甲子"
"きのかわ 紀ノ川"
"きのくに 紀伊國"
"きのくにや 紀之國屋 紀伊国屋"
"きのこ 茸 蕈 キノコ"
"きのさき 城崎 城ノ崎"
"きのした 木ノ下 木の下 樹下 木下"
"きのしたけいすけ 木下恵介"
"きのつらゆき 紀貫之"
"きのと 乙"
"きのとい 乙亥"
"きのとう 乙卯"
"きのとうし 乙丑"
"きのととり 乙酉"
"きのとひつじ 乙未"
"きのとみ 乙巳"
"きのどく 気の毒"
"きのね 木の根"
"きのはら 木之原"
"きのぼり 木登り"
"きのみ 木の実"
"きのみきのまま 着の身着の侭"
"きのみや 来宮"
"きのもと 木ノ本 木之元"
"きのり 気乗り"
"きは 際"
"きはい 跪拝"
"きはいち 既配置"
"きはく 稀薄 気魄 気迫 希薄"
"きはた 木幡"
"きはだ 蘗 檗 木肌"
"きはち 喜八"
"きはちろう 喜八郎"
"きはっぴょう 既発表"
"きはつ 既発 輝発 揮発"
"きはつばい 既発売"
"きはつゆ 揮發油 揮発油"
"きはつゆぜい 揮発油税"
"きはら 樹原 木原"
"きはん 帰阪 機搬 規範"
"きはんせん 機帆船"
"きば 騎馬 木場 牙"
"きばく 起爆"
"きばこ 木箱"
"きばせん 騎馬戦"
"きばたらき 気ばたらき"
"きばつ 奇抜"
"きばらい 既払い"
"きばらし 気晴らし"
"きばん 機番 基板 基盤"
"きばんじょう 碁盤状"
"きばんてきぎじゅつ 基盤的技術"
"きひ 忌避"
"きひつ 起筆"
"きひろ 帰広"
"きひん 貴賓 気品"
"きひんせき 貴賓席"
"きび 驥尾 綺靡 機微 吉備 黍"
"きびき 忌引"
"きびす 踵"
"きびだんご 黍団子"
"きびょう 奇病"
"きびょうし 黄表紙"
"きびん 機敏"
"きふ 寄附 棋譜 寄付"
"きふう 棋風 気風"
"きふく 帰服 起伏"
"きふね 貴船"
"きふねぐち 貴船口"
"きぶ 基部"
"きぶかわ 貴生川"
"きぶくれ 着膨れ"
"きぶつ 器物"
"きぶつそんかいざい 器物損壊罪"
"きぶね 貴船"
"きぶん 紀文 気分"
"きぶんよし 気分良"
"きへい 喜平 機兵 騎兵"
"きへん 木偏"
"きべん 詭弁"
"きほう 紀宝 気泡 既報 木方 貴方 記法"
"きほく 輝北"
"きほん 基本"
"きほんかい 基本解"
"きほんがく 基本額"
"きほんきゅう 基本給"
"きほんけい 基本形"
"きほんこころえへん 基本心得篇"
"きほんは 基本波"
"きほんば 基本場"
"きほんぱたあん 基本パターン"
"きほんわざ 基本技"
"きぼ 規模"
"きぼう 希望"
"きぼうじゅん 希望順"
"きぼうほう 喜望峰"
"きぼく 亀卜"
"きぼし 木星"
"きぼつ 鬼没"
"きぼり 木彫り"
"きまえ 気前"
"きまぐれ 気まぐれ"
"きまじめ 生真面目"
"きまた 木俣"
"きまち 木町"
"きまちどおり 木町通"
"きまつ 期末"
"きまま 気まま"
"きまめ 黄豆"
"きまり 決り"
"きみ 貴美 辟 喜美 黄み キミ 公 生美 希美 黄身 気味 君"
"きみあき 公明"
"きみいがい 君以外"
"きみえ 希己枝 君枝 君江"
"きみお 公雄 公男 喜三男"
"きみか 公佳"
"きみがよ 君が代"
"きみこ きみ子 紀美子 季美子 季実子 君子 喜美子 公子"
"きみしま 君嶋 君島"
"きみじま 君嶋 君島"
"きみた 君田"
"きみたか 公尚 君孝"
"きみたち 君達"
"きみち 季道"
"きみつ 気密 君津 機密"
"きみつひ 機密費"
"きみとし 公稔"
"きみどり 木緑 黄緑"
"きみなお 公尚"
"きみのり 公紀"
"きみひこ 公彦"
"きみひと 公人"
"きみひろ 公広 公宏 公博 公裕"
"きみゃく 気脈"
"きみやす 公保"
"きみやま 君山"
"きみょう 帰命 奇妙"
"きみよ 君代"
"きみわる 気味悪"
"きむ 金 帰無"
"きむいるそん 金日成"
"きむすめ 生娘"
"きむち 沈菜 キムチ"
"きむら 木邑 木村"
"きめ 木目 肌理"
"きめい 記銘 貴名 記名 記明"
"きめうち 決め打ち"
"きめかた 決め方"
"きめたおし 極め倒し"
"きめだし 極め出し"
"きめて 決め手"
"きめら キメラ"
"きも 胆 肝"
"きもいり 肝煎り 肝いり"
"きもち 気持ち 気持"
"きもったま 肝っ玉"
"きもつき 肝付"
"きもと 樹本 木元 木本"
"きもの 着物"
"きもべつ 喜茂別"
"きもん 奇門 鬼門 奇問"
"きもんすう 旗門数"
"きゃ 迦 伽"
"きゃく 攫 卻 却 脚 客"
"きゃくあし 客足"
"きゃくいん 脚韻 客員"
"きゃくおうたい 客応対"
"きゃくかしゃく 客貨車区"
"きゃくがわ 客側"
"きゃくさき 脚先 客先"
"きゃくさま 客様"
"きゃくし 客死"
"きゃくしき 脚式"
"きゃくしつ 脚質 客室"
"きゃくしつりょうむりょう 客室料無料"
"きゃくしゃ 客車"
"きゃくしょうばい 客商売"
"きゃくしょく 脚色"
"きゃくじん 客人"
"きゃくすじ 客筋"
"きゃくせき 客席"
"きゃくせん 客船"
"きゃくぜんいん 客全員"
"きゃくそう 客層"
"きゃくたい 客体"
"きゃくちゅう 脚註 脚注"
"きゃくでん 客電"
"きゃくどうし 客同士"
"きゃくひき 客引き"
"きゃくぶ 脚部"
"きゃくほん 脚本"
"きゃくほんか 脚本家"
"きゃくま 客間"
"きゃくゆそう 客輸送"
"きゃくよう 客用"
"きゃくよせ 客寄せ 客寄"
"きゃくりょく 脚力"
"きゃしゃ 花車 華奢"
"きゃたつ 脚立"
"きゃっか 脚下 却下"
"きゃっかん 客観"
"きゃっかんし 客観視"
"きゃっこう 脚光"
"きゃっしゅ キャッシュ"
"きゃっち キャッチ"
"きゃっちふれーず キャッチフレーズ"
"きゃのん キャノン キヤノン"
"きゃはん 脚絆"
"きゃばれー キャバレー"
"きゃびねっと キャビネット"
"きゃぷてん キャプテン"
"きゃら 伽羅"
"きゃらたん キャラ端"
"きゃりあ キャリア"
"きゃりあー キャリアー"
"きゃんせる キャンセル"
"きゃんでぃ キャンディ"
"きゃんでぃー キャンディー"
"きゃんでぃーず キャンディーズ"
"きゃんぱす キャンパス"
"きゃんぺーん キャンペーン"
"きや 紀谷"
"きやく 既約 規約"
"きやくけい 既約形"
"きやす 喜安"
"きやすさ 気安さ"
"きやすめ 気休め"
"きやせ 着痩せ"
"きやま 基山 木山"
"きやまち 木屋町"
"きやむ 喜屋武"
"きやん 喜屋武"
"きゅーば 玖瑪"
"きゅーぴっと キューピット"
"きゅーぶ キューブ"
"きゅう 臼 鳩 鬮 邱 逑 赳 貅 裘 蚯 舊 翕 糺 穹 皀 疚 烋 歙 樛 柩 摎 恷 岌 扱 ９ 嗅 躬 丘 仇 朽 窮 笈 灸 汲 弓 宮 糾 給 九 泣 救 及 吸 究 求 球 級 休 久 急 旧"
"きゅうあい 求愛"
"きゅうあく 旧悪"
"きゅうい 球威"
"きゅういん 吸引"
"きゅうえき 旧駅"
"きゅうえん 救援 休演"
"きゅうえんきがいけんこう 吸煙危害健康"
"きゅうえんしゅつじょう 球宴出場"
"きゅうおん 旧恩 吸音"
"きゅうおんざい 吸音材"
"きゅうか 球果 求家 旧家 急下 休暇"
"きゅうかーぶ 急カーブ"
"きゅうかい 球界 求解 休会"
"きゅうかいうら 九回裏"
"きゅうかいついほう 球会追放"
"きゅうかく 球殻 嗅覚"
"きゅうかくだい 急拡大"
"きゅうかくど 急角度"
"きゅうかこう 急下降"
"きゅうかしょくぶつこう 球果植物綱"
"きゅうかそく 急加速"
"きゅうかん 旧館 急患 休閑 休館 休刊"
"きゅうかんちょう 九官鳥"
"きゅうかんび 休肝日"
"きゅうが 休芽"
"きゅうがく 休学"
"きゅうがた 旧型"
"きゅうがたきゃくしゃ 旧形客車"
"きゅうがたしゃ 旧型車"
"きゅうがたでんしゃ 旧形電車"
"きゅうき 給気 吸気"
"きゅうきてき 求基的"
"きゅうきゃく 旧客"
"きゅうきゅう 汲々 急求 救急"
"きゅうきゅうしゃ 救急車"
"きゅうきゅうばこ 救急箱"
"きゅうきょ 急きょ 急遽 急拠"
"きゅうきょう 窮境"
"きゅうきょく 窮極 究極"
"きゅうきょくせん 急曲線"
"きゅうきん 給金 球菌"
"きゅうぎ 球技"
"きゅうぎかいとう 旧議会棟"
"きゅうぎょう 休業"
"きゅうぎょうほしょうひ 休業保証費"
"きゅうくつ 窮屈"
"きゅうぐ 弓具"
"きゅうぐんぐんじん 旧軍軍人"
"きゅうけい 球茎 球形 求刑 急啓 休憩"
"きゅうけいしゃ 急傾斜"
"きゅうけいじょ 休憩所"
"きゅうけつ 吸血"
"きゅうけつき 救血鬼 吸血鬼"
"きゅうげき 急劇 急激"
"きゅうげん 急減"
"きゅうげんそく 急減速"
"きゅうこう 吸光 休耕 休校 旧交 休講 急行"
"きゅうこうか 急降下"
"きゅうこうけん 急行券"
"きゅうこうだい 久工大 九州工業大学 九工大"
"きゅうこうばい 急勾配"
"きゅうこうび 休稿日"
"きゅうこうようしゃ 急行用車"
"きゅうこく 救国 急告"
"きゅうこはまてつどう 旧小浜鉄道"
"きゅうこん 球根 求婚"
"きゅうご 救護"
"きゅうごく 旧国"
"きゅうさい 休載 救済"
"きゅうさか 急坂"
"きゅうさく 久作 窮策 旧作"
"きゅうさつ 旧札"
"きゅうさんだい 九産大"
"きゅうざか 急坂"
"きゅうざひょう 球座標"
"きゅうざぶろう 究三郎"
"きゅうし 球史 九死 急死 臼歯 給紙 休止"
"きゅうしあげ 急仕上げ"
"きゅうしき 旧式"
"きゅうしつ 吸湿"
"きゅうしふ 休止符"
"きゅうしゃ 廐舎 旧車 急斜 厩舎"
"きゅうしゅ 九首 級酒"
"きゅうしゅう 旧習 急襲 九州 吸収"
"きゅうしゅうきた 九州北"
"きゅうしゅうこう 九州工"
"きゅうしゅうこくさいだいふ 九州国際大附"
"きゅうしゅうさん 九州産"
"きゅうしゅうさんば 九州産馬"
"きゅうしゅうねつ 吸収熱"
"きゅうしゅうふうとんこつ 九州風豚骨"
"きゅうしゅうぶんこうけい 吸収分光計"
"きゅうしゅうもう 吸収毛"
"きゅうしゅつ 救出 休出"
"きゅうしゅん 急峻"
"きゅうしょ 究所 急所"
"きゅうしょう 旧称"
"きゅうしょく 求職 給食 休職"
"きゅうしろう 久四郎"
"きゅうしん 球心 求心 急進 休診"
"きゅうじ 九字 旧字 給仕"
"きゅうじつ 休日"
"きゅうじゅう 九十"
"きゅうじゅつ 救恤 弓術"
"きゅうじょ 救助"
"きゅうじょう 九条 宮場 弓場 窮状 球状 休場 球上 球場"
"きゅうじょうしょう 急上昇"
"きゅうじん 窮盡 旧人 求人"
"きゅうす 急須"
"きゅうすい 給水 吸水"
"きゅうすいしゃ 給水車"
"きゅうすいじょ 給水所"
"きゅうすいとう 給水塔"
"きゅうすう 級数"
"きゅうすうわ 級数和"
"きゅうず 旧図"
"きゅうせい 救世 球聖 旧制 急逝 急性 旧姓"
"きゅうせいき 九世紀"
"きゅうせいきょう 救世教"
"きゅうせいぐん 救世軍"
"きゅうせいしゅ 救世主"
"きゅうせいちょう 急成長"
"きゅうせいどう 急制動"
"きゅうせいびょう 急性病"
"きゅうせき 求積 旧跡"
"きゅうせつ 旧説"
"きゅうせん 急戦 旧線 休戦"
"きゅうせんかい 急旋回"
"きゅうせんどう 球泉洞"
"きゅうぜんじつ 休前日"
"きゅうそ 窮鼠"
"きゅうそう 穹蒼 給送 急送 九索"
"きゅうそく 休息 急速"
"きゅうそくじょ 休息所"
"きゅうぞう 急造 九蔵 急増"
"きゅうたい 旧態 球体"
"きゅうたま 九玉"
"きゅうたろう 久太郎"
"きゅうだい 九州大学 久大 旧題 及第 九大"
"きゅうだん 糺彈 糺弾 糾彈 糾弾 球団"
"きゅうだんか 球団歌"
"きゅうだんき 球団旗"
"きゅうだんしん 球団新"
"きゅうち 旧知 窮地"
"きゅうちゃき 給茶器"
"きゅうちゃく 吸着"
"きゅうちゅう 宮中"
"きゅうちょ 旧著"
"きゅうちょう 級長"
"きゅうちょうてき 求頂的"
"きゅうつい 胸椎"
"きゅうてい 宮廷"
"きゅうていし 急停止"
"きゅうていしゃ 急停車"
"きゅうてき 旧敵 仇敵"
"きゅうてん 急轉 急転"
"きゅうてんかい 急展開"
"きゅうてんぽくせん 旧天北線"
"きゅうでん 給田 九電 給電 宮殿"
"きゅうとう 急騰 給湯"
"きゅうどう 球道 旧道 弓道"
"きゅうどうかく 九同角"
"きゅうどうしゃ 求道者"
"きゅうどうしん 求道心"
"きゅうない 球内"
"きゅうなん 救難"
"きゅうにし 旧西"
"きゅうにゅう 吸入"
"きゅうねつ 吸熱"
"きゅうねん 九年 旧年"
"きゅうは 急派"
"きゅうはいき 給排気"
"きゅうはいきけい 吸排気系"
"きゅうはく 窮迫 急迫 休拍"
"きゅうはちこう 旧八高"
"きゅうはっしん 急発進"
"きゅうはん 急坂 旧版"
"きゅうば 九馬 急場"
"きゅうばい 急売"
"きゅうばん 旧盤 吸盤 旧版"
"きゅうひ 給費"
"きゅうひき 九匹"
"きゅうひつちゅう 休筆中"
"きゅうび 鳩尾 九尾"
"きゅうびのねこ 九尾の猫"
"きゅうびょう 急病"
"きゅうびん 急便"
"きゅうふ 宮阜 旧譜 給付 休譜 休符"
"きゅうふじょう 急浮上"
"きゅうぶれーき 急ブレーキ"
"きゅうぶん 旧聞"
"きゅうへん 急変"
"きゅうべえ 久兵衛"
"きゅうほう 急報"
"きゅうほうじ 久宝寺"
"きゅうぼ 急募"
"きゅうぼう 窮乏"
"きゅうぼん 旧盆"
"きゅうま 久馬"
"きゅうみん 窮民 休眠"
"きゅうみんが 休眠芽"
"きゅうむ 急務"
"きゅうむいん 厩務員"
"きゅうめい 及明 求明 糺明 窮命 旧名 糾明 救命 究明"
"きゅうめいかん 救命艇"
"きゅうめいきゅうきゅうし 救命救急士"
"きゅうめん 球面"
"きゅうめんは 球面波"
"きゅうや 久弥"
"きゅうやく 旧訳"
"きゅうやくせいしょ 旧約聖書"
"きゅうゆ 給油"
"きゅうゆう 旧友 級友"
"きゅうゆきがいしゃ 給湯機会社"
"きゅうゆぐち 給油口"
"きゅうゆしゃ 給油車"
"きゅうよ 窮餘 窮余 給与"
"きゅうよう 急用 休養"
"きゅうようあけ 休養明"
"きゅうらい 旧来"
"きゅうらぎ 厳木"
"きゅうらく 急落"
"きゅうり 胡瓜"
"きゅうりゅう 穹窿 九龍 急流"
"きゅうりょう 丘陵 給料"
"きゅうれい 急冷"
"きゅうれき 旧暦"
"きゅうろう 旧臘"
"きゅうわ 九羽"
"きゅうわり 九割"
"きゆう 既有 杞憂"
"きょ 舉 擧 鉅 醵 遽 踞 苣 筥 秬 炬 歔 據 倨 鋸 嘘 拒 渠 巨 許 距 拠 挙 去 居 虚"
"きょう 荊 棘 竟 鞏 鍄 轎 跫 誑 襁 莢 羌 繦 經 篋 筴 筺 筐 竅 矜 皀 疆 狹 烱 炯 洶 挾 拱 抂 恊 恟 徼 廾 峽 嬌 夾 嚮 匈 刧 况 竸 兢 僵 亰 姜 頃 劫 兄 叶 馨 杏 陜 梗 驕 侠 兇 僑 供 怯 彊 卿 匡 享 矯 蕎 亨 饗 喬 峡 凶 脅 況 挟 恐 競 境 経 香 驚 協 郷 鏡 胸 恭 響 興 叫 橋 狭 狂 共 京 教 強 今日"
"きょうあい 狭隘"
"きょうあく 強悪 兇悪 凶悪"
"きょうあくはん 凶悪犯"
"きょうあつ 強圧"
"きょうい 強意 驚異 胸囲 脅威"
"きょういく 教育"
"きょういくし 教育史"
"きょういくしゃしんしょ 教育社新書"
"きょういくしょう 教育省"
"きょういくしょく 教育職"
"きょういくひ 教育費"
"きょういち 京一 恭一"
"きょういちろう 恭一郎"
"きょういん 教員"
"きょううん 強運 凶運"
"きょうえい 鏡映 共栄 競泳"
"きょうえいどう 共栄堂"
"きょうえき 共役 共益"
"きょうえきひ 共益費"
"きょうえん 饗宴 狂宴 競演 協演 共演"
"きょうえんき 強塩基"
"きょうえんさく 共演作"
"きょうおう 響應 供応"
"きょうおん 跫音"
"きょうおんな 京女"
"きょうか 鏡花 莢果 狂歌 教化 教科 強化"
"きょうかい 疆界 協會 教会 境界 協会"
"きょうかいしほう 教会旋法"
"きょうかいりゅう 境界流"
"きょうかく 狭角 侠客 胸郭"
"きょうかつ 恐喝"
"きょうかね 京兼"
"きょうかふく 強化服"
"きょうかりょく 強火力"
"きょうかん 驕悍 叫喚 共感 教官"
"きょうかんかくてきひゆ 共感覚的比喩"
"きょうが 恭賀"
"きょうがい 境涯"
"きょうがく 教学 驚愕 共学"
"きょうがせ 京ヶ瀬"
"きょうがね 京兼"
"きょうがんい 強含意"
"きょうき 侠気 兇器 強記 狭軌 驚喜 狂喜 共起 凶器 狂気"
"きょうきゃく 橋脚"
"きょうきゅう 供給"
"きょうきゅうげん 供給源"
"きょうきょう 兢々 恐々"
"きょうきん 胸筋 胸襟"
"きょうぎ 教義 供犠 狭義 競技 協議"
"きょうぎしゃ 競技車"
"きょうぎょう 協業"
"きょうぎょうしんしょう 教行信証"
"きょうぎようぐるま 競技用車"
"きょうく 狂句 恐懼 教区"
"きょうくう 胸腔"
"きょうくん 教訓"
"きょうぐう 境遇"
"きょうけい 共形 教計"
"きょうけいば 共形場"
"きょうけつ 供血"
"きょうけん 鏡検 強肩 狂犬 強権 強健"
"きょうけんびょう 狂犬病"
"きょうげき 挾撃 挟撃 京劇"
"きょうげん 狂言"
"きょうこ 鞏固 強固 香子 教子 協子 享子 杏子 今日子 京子 恭子 響子"
"きょうこう 興行 胸腔 教皇 凶行 強硬 強行 恐慌"
"きょうこうきんげん 恐惶謹言"
"きょうこうぐん 強行軍"
"きょうこうさく 強攻策"
"きょうこうせん 京工繊"
"きょうこく 教国 狭谷 強国 峡谷"
"きょうこつ 胸骨"
"きょうこは 狂虎派"
"きょうご 教護"
"きょうごう 強豪 競合"
"きょうごく 京極"
"きょうさ 教唆"
"きょうさい 恐妻 共催 共済"
"きょうさいか 恐妻家"
"きょうさく 狭窄 共作 凶作 競作"
"きょうさはん 教唆犯"
"きょうさん 京産 共産 協賛"
"きょうさんせい 強酸性"
"きょうさんせん 京産戦"
"きょうさんだい 京都産業大学"
"きょうさんだいせん 京産大戦"
"きょうさんとう 共産党"
"きょうざい 教材"
"きょうざつ 夾雑"
"きょうざぶろう 恭三郎"
"きょうざめ 興覚め"
"きょうし 享祀 供試 教使 教師"
"きょうしありがくしゅう 教師あり学習"
"きょうしきょく 狂詩曲"
"きょうしつ 教室"
"きょうしなし 教師なし"
"きょうしゃ 香車 強者"
"きょうしやく 教師役"
"きょうしゅ 教主 興趣"
"きょうしゅう 共終 強襲 郷愁 教習"
"きょうしゅうしゃ 教習車"
"きょうしゅうじょ 教習所"
"きょうしゅく 強縮 恐縮"
"きょうしゅつ 供出"
"きょうしょ 教書"
"きょうしょう 京商"
"きょうしょうてん 共焦点"
"きょうしょきゅうしゃ 境勝厩舎"
"きょうしょく 強食 教職"
"きょうしろう 狂四郎"
"きょうしん 驕心 狭心 狂信 強震 共振"
"きょうしんざい 強心剤"
"きょうしんしゃしゅうだん 狂信者集団"
"きょうじ 共時 鏡次 衿持 挾持 矜恃 矜持 狂児 恭治 享治 恭二 教示 恭司"
"きょうじく 橋軸"
"きょうじせい 強磁性"
"きょうじば 強磁場"
"きょうじま 京嶋"
"きょうじゃく 強弱"
"きょうじゅ 享受 亨受 教授"
"きょうじゅう 凶獣"
"きょうじゅつ 供述"
"きょうじゅん 恭順"
"きょうじょう 兇状 教条"
"きょうじょうえきしゃ 橋上駅舎"
"きょうじん 強靱 凶刃 兇刃 狂人 強靭"
"きょうす 香車"
"きょうすい 胸水"
"きょうすけ 恭輔 恭助 恭介 京助 京介"
"きょうず 京津"
"きょうせい 狭正 嬌聲 嬌声 強勢 強請 共生 共棲 教生 矯正 強制"
"きょうせいきか 強正規化"
"きょうせいだいしっこう 強制代執行"
"きょうせき 共石"
"きょうせら 京セラ"
"きょうせん 胸腺 共線"
"きょうそ 教祖"
"きょうそう 狂想 狂躁 強壯 競漕 強壮 競走 競争"
"きょうそうきょく 協奏曲"
"きょうそうこうきょうきょく 協奏交響曲"
"きょうそうしん 競争心"
"きょうそうば 競走馬 競争馬"
"きょうそく 教則"
"きょうそん 共存"
"きょうぞう 享三 胸像 鏡像"
"きょうぞめ 京染"
"きょうぞん 共存"
"きょうたい 筺体 嬌態 矯態 狂態 筐体 匡体"
"きょうたいいき 狭帯域"
"きょうたく 教卓 供託"
"きょうたくじょ 供託所"
"きょうたる 京樽"
"きょうたん 驚嘆"
"きょうだ 怯懦 強打"
"きょうだい 京都大学 兄姉 鏡台 橋台 姉弟 強大 姉妹 兄妹 兄弟 京大"
"きょうだいあい 兄弟愛"
"きょうだいうぶつ 京大宇物"
"きょうだいきけん 京大基研"
"きょうだいこう 京大工"
"きょうだいだいけい 京大大型"
"きょうだいで 京大出"
"きょうだいり 京大理"
"きょうだる 京樽"
"きょうだん 兇彈 兇弾 教壇 教団 凶弾"
"きょうち 境地"
"きょうちくこうつう 京築交通"
"きょうちくとう 夾竹桃"
"きょうちゅう 胸中"
"きょうちゅうじゃく 強中弱"
"きょうちょ 共著"
"きょうちょう 凶兆 共聴 強調 協調"
"きょうつい 胸椎"
"きょうつう 共通"
"きょうつうけん 共通券"
"きょうづか 京塚"
"きょうづせん 京津線"
"きょうてい 教程 協定 協提 競艇"
"きょうていしせい 強停止性"
"きょうていじょう 強定常"
"きょうてき 狂的 強敵"
"きょうてん 教典 経典"
"きょうでん 強電"
"きょうでんしゃ 共電社"
"きょうと 教徒 京都"
"きょうとう 京濤 鏡筒 共闘 教頭"
"きょうとうほ 橋頭堡"
"きょうとく 京徳"
"きょうとぐち 京都口"
"きょうとせらみっく 京都セラミック"
"きょうとたいしょうてん 京都大賞典"
"きょうとたきぎのう 京都薪能"
"きょうとみなみ 京都南"
"きょうど 匈奴 郷土 強度"
"きょうどう 協働 共働 嚮導 教導 鏡胴 経堂 協同 共同"
"きょうどうしゅうはいそう 共同集配送"
"きょうどうたい 協同体 共同体"
"きょうどうばぬし 共同馬主"
"きょうどし 郷土史"
"きょうどまり 今日泊"
"きょうなんちょう 境南町"
"きょうにんぎょう 京人形"
"きょうねん 凶年 亨年 享年"
"きょうの 京野"
"きょうは 教派"
"きょうはく 強迫 脅迫"
"きょうはつ 今日初"
"きょうはん 共犯"
"きょうばい 競売"
"きょうばいせん 強焙煎"
"きょうばし 京橋"
"きょうばん 響板"
"きょうばんちゃ 京番茶"
"きょうふ 教父 京麩 恐怖"
"きょうふう 京風 強風"
"きょうふくぶ 胸腹部"
"きょうふしん 恐怖心"
"きょうふもの 恐怖物"
"きょうぶ 胸部"
"きょうぶんさん 共分散"
"きょうへい 恭平 恭兵 京平"
"きょうへき 胸壁"
"きょうへん 共変 共編"
"きょうへんどう 共変動"
"きょうべん 教鞭 強弁"
"きょうほ 享保 競歩"
"きょうほう 凶報"
"きょうほん 狂奔 教本"
"きょうぼう 狂暴 共謀 兇暴 凶暴"
"きょうぼうさ 狂暴さ"
"きょうぼく 経木"
"きょうまい 供米"
"きょうまく 胸膜 莢膜"
"きょうまる 京丸"
"きょうまん 驕慢"
"きょうみ 興味"
"きょうみしんしん 興味津津"
"きょうみとうげ 京見峠"
"きょうみぶかい 興味深い"
"きょうむ 教務"
"きょうむかかり 教務係"
"きょうむら 京村"
"きょうめい 共鳴"
"きょうめいたい 共鳴体"
"きょうめいばん 共鳴板"
"きょうめん 鏡面"
"きょうもと 京本"
"きょうもん 経文"
"きょうや 京哉"
"きょうやく 供役 共役 共訳 協約"
"きょうやくきょく 共役極"
"きょうやさい 京野菜"
"きょうゆ 教諭"
"きょうゆう 亨有 享有 共有"
"きょうゆうせい 共優性"
"きょうゆうたい 共有体"
"きょうゆうでんたい 強誘電体"
"きょうよ 供与"
"きょうよう 供用 強要 教養 共用"
"きょうようざい 強要罪"
"きょうようたい 共用体"
"きょうようとう 教養棟"
"きょうようひ 共用費"
"きょうらく 享楽"
"きょうらん 供卵 供覧 狂乱"
"きょうり 郷里"
"きょうりき 強力"
"きょうりきこ 強力粉"
"きょうりつ 共立"
"きょうりつせん 京立戦"
"きょうりゅう 恐龍 恐竜"
"きょうりゅうだいきこう 恐竜大紀行"
"きょうりゅうてん 恐竜展"
"きょうりょう 狭量 橋梁"
"きょうりょく 強力 協力"
"きょうりょくこ 強力粉"
"きょうれい 強冷"
"きょうれき 教歴"
"きょうれつ 強烈"
"きょうれん 教錬 教練"
"きょうれんけつ 強連結"
"きょうろ 狭路"
"きょうわ 興和 共和 協和"
"きょうわとう 共和党"
"きょうわんてい 協和音程"
"きょえい 巨影 虚栄"
"きょえいしん 虚栄心"
"きょえんばん 共演盤"
"きょか 炬火 許可"
"きょかん 居館 巨艦 巨漢"
"きょかんけつ 許冠傑"
"きょがく 巨額"
"きょがん 炬眼 巨岩"
"きょきょじつじつ 虚々実々"
"きょきん 拠金"
"きょぎ 虚偽"
"きょぎょう 虚業"
"きょく 巨躯 跼 蕀 洫 勗 亟 棘 旭 極 局 曲"
"きょくあて 局宛"
"きょくい 極意"
"きょくいがい 曲以外"
"きょくいん 局員"
"きょくう 虚空 極右"
"きょくうた 曲歌"
"きょくかい 曲解"
"きょくかく 極角"
"きょくかん 曲管"
"きょくかんちしよう 極寒地使用"
"きょくがい 局外"
"きょくがわ 局側"
"きょくきぼ 局規模"
"きょくぎ 曲技"
"きょくぎめ 曲決め"
"きょくけいしき 極形式"
"きょくげい 曲芸"
"きょくげん 局限 極限 極言"
"きょくげんりゅう 極限流"
"きょくこうしんくう 極高真空"
"きょくこうせい 曲構成"
"きょくさ 極左"
"きょくさく 曲作"
"きょくざい 局在"
"きょくざいか 極在化"
"きょくざひょう 極座標"
"きょくし 極至 旭志"
"きょくしゅう 曲集"
"きょくしゅうろく 曲収録"
"きょくしょ 局所座標系 局所"
"きょくしょう 極小"
"きょくしょうかい 極小解"
"きょくしょかい 局所解"
"きょくしょかん 局所環"
"きょくしょたい 局所体"
"きょくしん 極真"
"きょくじく 極軸"
"きょくじたい 曲自体"
"きょくじつ 旭日"
"きょくじゅん 曲順"
"きょくすい 曲水"
"きょくすう 局数 極数 曲数"
"きょくせい 極性"
"きょくせいとういつけい 極性統一形"
"きょくせつ 曲折"
"きょくせん 局線 曲線"
"きょくせんこう 曲先行"
"きょくせんたく 曲選択"
"きょくせんひょう 曲線標"
"きょくぜんしゅう 曲全集"
"きょくぜんたい 曲全体"
"きょくそう 曲想"
"きょくたい 極体"
"きょくたん 極端"
"きょくたんい 曲単位"
"きょくたんじょう 曲誕生"
"きょくだい 極大"
"きょくだいげん 極大元"
"きょくだん 曲弾"
"きょくち 極地 局地 極致 極値"
"きょくちゅう 局中 曲中"
"きょくちょう 曲調 局長"
"きょくつき 曲付"
"きょくてき 極的"
"きょくてん 極点"
"きょくとう 曲頭 極東"
"きょくど 極度"
"きょくどうざん 旭道山"
"きょくどめ 局留 局止め"
"きょくない 局内"
"きょくは 棘波"
"きょくはつ 局発"
"きょくば 曲馬"
"きょくばん 曲番 局番"
"きょくひ 棘皮"
"きょくふう 曲風"
"きょくぶ 局部"
"きょくへいめん 曲平面"
"きょくほく 極北"
"きょくむき 極向き"
"きょくめ 曲目"
"きょくめい 局名 曲名"
"きょくめん 局免 曲面 局面"
"きょくめんきょ 局免許"
"きょくもく 曲目"
"きょくやく 曲約"
"きょくよう 極洋"
"きょくりつ 曲率"
"きょくりょく 極力"
"きょくろん 極論"
"きょけつ 虚血心筋 虚血"
"きょけつせいしんしっかん 虚血性心疾患"
"きょけん 巨犬"
"きょげい 巨鯨"
"きょげん 虚言"
"きょこう 挙行 虚構"
"きょこうせんだん 虚航船団"
"きょこく 挙国"
"きょこん 巨根 許婚"
"きょごう 倨傲"
"きょさいぼう 巨細胞"
"きょざい 巨財"
"きょし 鋸歯 挙止 巨視"
"きょしき 挙式"
"きょしつ 居室"
"きょしゅ 挙手"
"きょしゅう 去就"
"きょしゅつ 拠出"
"きょしょ 居所 拠所"
"きょしょう 挙証 巨匠"
"きょしょく 拒食 巨食 虚飾"
"きょしん 許慎 虚心 巨神"
"きょしんけい 共振系"
"きょしんたんかい 虚心坦懐"
"きょしんへい 巨神兵"
"きょじつ 虚実"
"きょじゃく 虚弱"
"きょじゅ 巨樹"
"きょじゅう 居住"
"きょじょう 居城 許状"
"きょじん 虚人 巨神 巨人"
"きょじんぐん 巨人軍"
"きょじんせん 巨人戦"
"きょじんのほし 巨人の星"
"きょすう 虚数"
"きょすうかい 虚数解"
"きょせい 巨星 去勢 虚勢"
"きょせき 巨石"
"きょせん 巨泉"
"きょぜつ 拒絶"
"きょそ 挙惜"
"きょぞう 虚象 巨像 虚像 巨象"
"きょたい 巨体"
"きょたく 居宅"
"きょだい 巨大"
"きょだいあり 巨大蟻"
"きょだく 許諾"
"きょだつ 虚脱"
"きょだん 鋸断"
"きょっかい 曲解"
"きょっけい 極刑"
"きょてん 拠点"
"きょとう 巨塔 挙党 巨頭"
"きょどう 挙動"
"きょなん 鋸南"
"きょにゅう 巨乳"
"きょにんか 許認可"
"きょねん 去年"
"きょねんくれ 去年暮"
"きょねんすえ 去年末"
"きょねんどじっせき 去年度実績"
"きょねんまつ 去年末"
"きょひ 巨費 拒否"
"きょふ 巨富"
"きょぶ 虚部"
"きょへい 挙兵"
"きょほう 巨砲 巨峰 虚報"
"きょぼく 巨木"
"きょまん 巨万"
"きょむ 虚無"
"きょむそう 虚無僧"
"きょもう 虚妄"
"きょよう 許容"
"きょようじゅふうめんせき 許容受風面積"
"きょらい 去来"
"きょり 巨利 距離"
"きょりけい 距離計"
"きょりけいれんどうしき 距離系連動式"
"きょりそう 距離走"
"きょりゅう 居留"
"きょりゅうみん 居留民"
"きょれい 虚礼"
"きょんきょん キョンキョン"
"きょんじゅ 慶州"
"きよ キヨ 寄予 喜世 毀誉 奇与 喜代 季代 寄与 清"
"きよあき 清昭 清朗 清明"
"きよい 清井"
"きよう 紀陽 記要 機用 紀要 起用 器用"
"きようけん 崎陽軒"
"きよえ 清栄"
"きよおか 清岡"
"きよか 清佳"
"きよかず 清和 清一"
"きよかわ 清川"
"きよき 清木"
"きよくに 清久仁"
"きよくら 清倉"
"きよこ 希代子 紀代子 喜代子 清子 希世子 聖子 貴代子"
"きよさと 清里"
"きよし 澄 喜好 潔司 淳 僖良 清史 清茂 清志 清司 潔 喜代志 清"
"きよしげ 清滋 清重"
"きよしろう 清志朗 清志郎"
"きよじ 喜代治"
"きよす 清洲"
"きよすみ 清住"
"きよせ 清瀬"
"きよたか 清天 清高 清孝 清隆 清貴"
"きよたき 清滝 清竜"
"きよたけ 清武"
"きよたに 清谷"
"きよだ 清田"
"きよつか 清塚"
"きよつぐ 清次"
"きよと 清人"
"きよとし 清利"
"きよぬま 浄沼"
"きよね 清音"
"きよの 清野"
"きよのぶ 清信"
"きよのり 清典"
"きよはら 清原"
"きよはる 清治 清晴"
"きよひこ 清彦"
"きよひと 清人"
"きよひろ 清博 清宏 恭弘"
"きよまつ 清松"
"きよみ 喜代美 清見 貴予美 紀代美 聖美 清美"
"きよみず 清水"
"きよみずでら 清水寺"
"きよもと 清元"
"きよゆき 聖之 清之"
"きよわ 気弱"
"きら 吉良 綺羅"
"きらい 記頼 機雷 帰来 嫌い"
"きらいほう 鬼雷砲"
"きらく 喜楽 気楽"
"きらくてい 喜良久亭"
"きらぼし 綺羅星"
"きらら 雲母"
"きり 雰 錐 切 桐 霧"
"きりあげ 切り上げ 切上げ"
"きりいちよう 桐一葉"
"きりうり 切り売り"
"きりえ 切絵 切り絵"
"きりか 霧化"
"きりかえ 切り換え 切替え 切換 切り替え 切換え 切替"
"きりかえし 切り返し"
"きりかき 切り欠き"
"きりかけ 切掛"
"きりかた 切り方"
"きりかぶ 檮 切り株 切株"
"きりが 霧賀"
"きりがみ 切り紙"
"きりきず 斬傷 切り傷 切傷"
"きりきり 吉里吉里"
"きりきりまい きりきり舞い"
"きりぎりす 蟋蟀 蛬 キリギリス"
"きりくず 切りくず"
"きりくち 切り口 切口"
"きりぐち 切り口"
"きりこ 切子 桐子"
"きりこうじょう 切り口上"
"きりこみ 切込み"
"きりさげ 切下げ"
"きりさめ 霧雨"
"きりざい 桐材"
"きりしたん 切支丹"
"きりしま 霧島 桐嶋 桐島"
"きりじょう 霧状"
"きりすて 切り捨て 切捨て"
"きりすときょう 基督教"
"きりたっぷ 霧多布"
"きりたに 桐谷"
"きりだ 切り出"
"きりだし 切り出し"
"きりつ 起立 規律"
"きりつぼ 桐壺 桐壷"
"きりづま 切妻"
"きりと 桐戸"
"きりとり 切取 切取り 切り取り"
"きりどおし 切通 切通し"
"きりどおしざか 切通坂"
"きりなみ 霧浪"
"きりにしき 起利錦"
"きりぬき 切抜き 切り抜き"
"きりの 桐野"
"きりはら 桐原"
"きりはり 切り貼り"
"きりばな 切り花"
"きりばり 切り張り"
"きりひとは 桐一葉"
"きりび 鑽り火"
"きりふき 霧吹き"
"きりふだ 切り札 切札"
"きりぶち 桐渕"
"きりみ 切身 切り身"
"きりもと 桐本"
"きりもみ 錐揉み"
"きりもり 切り盛り 切盛り"
"きりゃく 機略"
"きりや 桐谷"
"きりやま 桐山"
"きりゅう 霧生 気流 桐生"
"きりゅういん 鬼龍院"
"きりょう 器量 帰寮"
"きりょく 氣力 棋力 気力"
"きりわけ 切り分け"
"きりん キリン 麒麟"
"きりんてい 麒麟亭"
"きるい 帰塁"
"きるかえあすてるか キルカエアステル科"
"きれ 喜連"
"きれあじ 切れ味"
"きれい 奇麗 綺麗"
"きれいごと 綺麗事"
"きれいずき 綺麗好き"
"きれいどころ 綺麗所"
"きれじ 切れ地"
"きれつ 亀裂"
"きれはし 切れ端"
"きれま 切れ間"
"きれまけ 切れ負け"
"きれめ 切れ目"
"きれん 喜連"
"きろ 帰路 岐路"
"きろく 記録"
"きろくし 記録紙"
"きろくぶ 季肋部"
"きろくやぶり 記録破り"
"きろぐらむ 瓩"
"きろめーとる 粁"
"きろりっとる 竏"
"きわ 紀和 際"
"きわく 木枠"
"きわこ 貴和子"
"きわまりづき 極月"
"きわみ 極み"
"きわむ 究"
"きわめつけ 極めつけ"
"きわめて 極めて"
"きわもの 際物"
"きん 饉 釿 鈞 釁 覲 箟 箘 窘 擒 掀 懃 忻 噤 听 檎 瑾 僅 巾 斤 欣 均 錦 勤 禽 芹 欽 琴 衿 襟 謹 禁 緊 今 菌 筋 近 金"
"きんあ 金鴉"
"きんあつ 禁圧"
"きんい 近医 近位"
"きんいち 欽一 錦一 金一"
"きんいっぷう 金一封"
"きんいつ 均一"
"きんいろ 金色"
"きんいん 金印 近因"
"きんうんどう 筋運動"
"きんえい 近影"
"きんえき 菌液"
"きんえん 近縁 禁煙"
"きんえんしゃ 禁煙車"
"きんえんじょ 禁煙所"
"きんえんせき 禁煙席"
"きんえんれい 禁煙令"
"きんか 槿花 近火 金貨"
"きんかい 琴海 勤快 近海 金塊"
"きんかく 金閣"
"きんかくじ 金閣寺"
"きんかさん 金華山"
"きんかざん 金華山"
"きんかん 金柑 近刊 金管"
"きんかんしょく 金環食 金環蝕"
"きんが 謹賀"
"きんがく 金額"
"きんがん 近眼"
"きんき 欣喜 錦旗 禁忌 近幾 近畿"
"きんきゅう 緊急"
"きんきょう 近況"
"きんきょり 近距離"
"きんきょりきゃく 近距離客"
"きんきょりわざ 近距離技"
"きんきん 近々 僅々"
"きんぎょ 金魚"
"きんぎょばち 金魚鉢"
"きんぎん 金銀"
"きんく 禁句"
"きんぐ キング"
"きんけい 近景 謹啓"
"きんけつ 金欠"
"きんけつびょう 金欠病"
"きんけん 勤倹 金属材料研究所 近県 金研 金権 金券"
"きんげん 謹厳 金言"
"きんげんだいきょく 近現代曲"
"きんげんてい 金原亭"
"きんこ 禁錮 禁固 金庫"
"きんこう 金鉤 金鉱 近郊 均衡"
"きんこうけい 近交系"
"きんこうだい 金工大"
"きんこうどう 金港堂"
"きんこく 近国 謹告"
"きんこけい 禁固刑"
"きんこつ 筋骨"
"きんこん 菌根"
"きんこんしき 金婚式"
"きんご 金吾"
"きんごう 金剛"
"きんごろう 金語楼"
"きんさ 僅差"
"きんさがち 僅差勝ち"
"きんさく 金策 近作 金作"
"きんざ 金座"
"きんざい 近在"
"きんざいけん 金材研"
"きんざん 金山"
"きんし 金鵄 菌糸 錦糸 近視 禁止"
"きんしがん 近視眼"
"きんしじょう 金市場"
"きんしつ 均質"
"きんしゃち 金鯱"
"きんしゅ 金種 禁酒"
"きんしゅう 錦繍"
"きんしゅうしゅく 筋収縮"
"きんしゅく 緊縮"
"きんしょう 金消 筋少 金章 金将 近称 僅少 金賞"
"きんしょうけん 金証券"
"きんしょうしょ 金証書"
"きんしょうまたいち 金商又一"
"きんしょく 金食"
"きんしれい 禁止令"
"きんしろう 金四郎"
"きんしん 謹慎 近親"
"きんしんこん 近親婚"
"きんじ 欽司 金治 金次 禁児 近似"
"きんじかい 近似解"
"きんじく 近軸"
"きんじさ 近時差"
"きんじつ 近日"
"きんじつてんいどう 近日点移動"
"きんじて 禁じ手"
"きんじとう 金字塔"
"きんじゅう 禽獣"
"きんじょ 近所"
"きんじょう 今上 金城 近状"
"きんじろう 金次郎"
"きんす 金子"
"きんせい 均斉 近世 謹製 均整 禁制 金星"
"きんせいしょく 金星食"
"きんせきがい 近赤外"
"きんせきもじ 金石文字"
"きんせつ 近接"
"きんせつかく 近接覚"
"きんせつば 近接場"
"きんせん 琴線 金銭"
"きんぜん 欣然"
"きんそく 禁足 禁則"
"きんぞう 金造 金蔵"
"きんぞく 勤属 勤続 金属"
"きんぞくかこうぎょう 金属加工業"
"きんぞくかん 金属缶"
"きんぞくくず 金属屑"
"きんぞくばん 金属板"
"きんぞくふん 金属粉"
"きんぞくぼう 金属棒"
"きんた 金太"
"きんたい 勤怠"
"きんたろう 金太郎"
"きんたろうあめ 金太郎飴"
"きんだい 金大 近大 近代"
"きんだいし 近代史"
"きんだいせん 近大戦"
"きんだいち 金田一"
"きんだいちこうすけ 金田一耕介"
"きんだか 金高"
"きんだち 公達"
"きんだん 禁男 禁断"
"きんだんのかじつ 禁断の果実"
"きんち 近地"
"きんちさんしゃ 禁治産者"
"きんちゃく 巾着 近着"
"きんちょ 近著"
"きんちょう 金長 謹聽 謹聴 金鳥 緊張"
"きんつば 金鍔"
"きんつま 金妻"
"きんてい 欽定 謹呈"
"きんてき 金的"
"きんてつ 近鉄"
"きんてんさい 禁転載"
"きんでん 筋電"
"きんとう 近東 均等"
"きんとき 金時"
"きんど 金土"
"きんどう 金道 金藤"
"きんどけい 金時計"
"きんなみ 金並"
"きんにく 筋肉"
"きんにくしつ 筋肉質"
"きんにくつう 筋肉痛"
"きんにっせいしゅせき 金日成主席"
"きんねん 近年"
"きんねんまれ 近年稀"
"きんのう 勤皇"
"きんのすけ 金之助"
"きんば 金歯 金馬"
"きんばく 緊縛"
"きんばり 金張り"
"きんぱい 金杯"
"きんぱく 金帛 緊迫 金箔"
"きんぱち 金八"
"きんぱつ 金髪"
"きんぱら 金原"
"きんびょうぶ 金屏風"
"きんぴ 金皮"
"きんぴん 金品"
"きんふたん 筋負担"
"きんぶち 金縁"
"きんぶん 金文 均分"
"きんぷん 金粉"
"きんべん 勤勉"
"きんべんせいじつ 謹勉誠実"
"きんべんとう 禁弁当"
"きんぺん 近辺"
"きんほんい 金本位"
"きんぼう 近傍"
"きんぼうすい 筋紡錘"
"きんぼうば 近傍場"
"きんぼし 金星"
"きんぽう 金峰"
"きんぽうげあか キンポウゲ亜科"
"きんぽうげか キンポウゲ科"
"きんぽうげしょくぶつ キンポウゲ植物"
"きんぽうげもく キンポウゲ目"
"きんぽくうこう 金浦空港"
"きんまく 筋膜"
"きんみつ 緊密"
"きんみゃく 金脈"
"きんみらい 近未来"
"きんむ 勤務"
"きんむい 勤務医"
"きんめい 金明"
"きんめっき 金メッキ"
"きんもくせい 金木犀"
"きんもじ 金文字"
"きんもつ 禁物"
"きんもん 金文"
"きんや 謹也 欽也 欣也 金弥"
"きんやっかん 金約款"
"きんゆ 禁輸"
"きんゆう 金融"
"きんゆうぎょう 金融業"
"きんゆうさい 金融債"
"きんよう 金曜"
"きんよく 禁欲"
"きんよくてきしゅうきょう 禁欲的宗教"
"きんらい 近来"
"きんらん 金襴"
"きんらんせんり 金蘭千里"
"きんらんそう 金蘭荘"
"きんり 金利"
"きんりゅう 金竜"
"きんりょう 斤量 金陵 禁猟 禁漁"
"きんりょく 金力 筋力"
"きんりん 錦林 近隣"
"きんるい 菌類"
"きんれい 禁令"
"きんろう 金狼 勤労"
"ぎ 祁 魏 萓 艤 羲 礒 犧 沂 曦 戲 巍 嶬 僞 伎 着 祇 妓 宜 木 城 欺 蟻 誼 儀 戯 擬 犠 疑 義 議 技 偽"
"ぎあ ギア"
"ぎあく 偽悪"
"ぎあん 議案"
"ぎいち 義一"
"ぎいん 議院 議員"
"ぎえん 義捐 義援"
"ぎおん 擬音 祇園"
"ぎおんばやし 祇園囃子"
"ぎおんまつり 祇園祭"
"ぎか 偽果 技家 技科"
"ぎかい 議会"
"ぎかいけん 技開研"
"ぎかいほん 技開本"
"ぎかん 技管 技官"
"ぎが 儀我 偽画 戯画"
"ぎがん 義眼"
"ぎきょうしん 義狭心 義侠心"
"ぎきょうだい 義兄弟"
"ぎきょく 戯曲"
"ぎぎ 魏魏 疑義"
"ぎく 疑懼"
"ぎけつ 議決"
"ぎけん 技研"
"ぎげい 技芸"
"ぎげいてん 伎芸天"
"ぎこう 技功 技工 技巧"
"ぎごく 疑獄"
"ぎごしょく 魏呉蜀"
"ぎさく 偽作"
"ぎさん 蟻酸"
"ぎし 魏史 義歯 義姉 義肢 技士 岸 技師"
"ぎしき 儀式"
"ぎしゅ 義手"
"ぎしょ 偽書"
"ぎしょう 偽証 偽称"
"ぎしょうざい 偽証罪"
"ぎしょうだに 棋将谷"
"ぎしん 疑心"
"ぎしんごう 偽信号"
"ぎじ 疑似 議事 擬似"
"ぎじえ 疑似餌"
"ぎじえさ 擬似餌"
"ぎじどう 議事堂"
"ぎじばり 疑似針"
"ぎじゅく 羲塾 義塾"
"ぎじゅつ 技術"
"ぎじゅついん 技術院"
"ぎじゅつし 技術史 技術士"
"ぎじゅつしゃむけ 技術者向け"
"ぎじゅつしょく 技術職"
"ぎじゅつせん 技術選 技術戦"
"ぎじゅつちょう 技術庁"
"ぎじゅつてん 技術展"
"ぎじゅつばたけ 技術畑"
"ぎじゅつむけ 技術向け"
"ぎじゅんじょ 擬順序"
"ぎじょう 儀杖 議定 議場 技情"
"ぎじょうへい 儀杖兵"
"ぎじん 擬人"
"ぎじんてきひょうげん 擬人的表現"
"ぎせい 擬制 擬声 犠牲"
"ぎせいしゃ 儀牲者"
"ぎせき 議席"
"ぎせん 義戰 義戦 岐セン"
"ぎぜん 偽善"
"ぎそう 艤装 擬装 偽装"
"ぎそく 義足"
"ぎぞう 偽造"
"ぎぞく 義賊"
"ぎたー ギター"
"ぎたい 擬態"
"ぎたん 義丹 技短"
"ぎだ 犠打"
"ぎだい 技大 議題"
"ぎだゆう 義太夫"
"ぎちょう 議長"
"ぎちょうやく 議長役"
"ぎっしゃ 牛車"
"ぎつう 技通"
"ぎてい 義弟 議定"
"ぎてきしょうめい 技適証明"
"ぎてん 儀典"
"ぎとう 蟻塔"
"ぎなん 岐南"
"ぎにんしん 擬妊娠"
"ぎねん 疑念"
"ぎねんりん 偽年輪"
"ぎのう 技能"
"ぎのうしょく 技能職"
"ぎのざ 宜野座"
"ぎのわん 宜野湾"
"ぎひょう 技評"
"ぎふ 義父 岐阜"
"ぎふと ギフト"
"ぎふぼ 義父母"
"ぎふん 義憤"
"ぎほう 技報 技法"
"ぎほうどう 技報堂"
"ぎぼ 義母"
"ぎまい 義妹"
"ぎまん 欺慢 欺瞞"
"ぎみ 気味"
"ぎむ 義務"
"ぎむづけ 義務づけ"
"ぎめい 偽名"
"ぎもん 疑問"
"ぎもんけい 疑問形"
"ぎもんし 疑問詞 疑問視"
"ぎもんしゅ 疑問手"
"ぎもんふ 疑問符"
"ぎゃ 伽"
"ぎゃく 謔 虐 逆"
"ぎゃくえん 逆縁"
"ぎゃくがわ 逆側"
"ぎゃくがわせ 逆為替"
"ぎゃくきでんあつ 逆起電圧"
"ぎゃくけい 逆形"
"ぎゃくげん 逆元"
"ぎゃくこう 逆向 逆光"
"ぎゃくさつ 虐殺"
"ぎゃくさん 逆算"
"ぎゃくざや 逆鞘"
"ぎゃくしべん 逆止弁"
"ぎゃくしゅう 逆襲"
"ぎゃくしん 逆臣 逆心 逆進"
"ぎゃくじゅん 逆順"
"ぎゃくじょう 逆上"
"ぎゃくすう 逆数"
"ぎゃくせいせつ 逆正接"
"ぎゃくせつ 逆接 逆説"
"ぎゃくそう 逆相 逆走"
"ぎゃくそこ 逆底"
"ぎゃくぞう 逆像"
"ぎゃくぞく 逆賊"
"ぎゃくたい 虐待"
"ぎゃくたん 逆探"
"ぎゃくて 逆手"
"ぎゃくてん 逆転"
"ぎゃくてんおう 逆転王"
"ぎゃくてんがち 逆転勝ち"
"ぎゃくてんげき 逆転劇"
"ぎゃくてんしょうり 逆点勝利"
"ぎゃくてんまけ 逆転負"
"ぎゃくびき 逆引"
"ぎゃくふぃるた 逆フィルタ"
"ぎゃくふう 逆風"
"ぎゃくへん 逆片"
"ぎゃくもど 逆戻"
"ぎゃくもどり 逆戻り"
"ぎゃくよう 逆用"
"ぎゃくり 逆理"
"ぎゃくりゅう 逆流"
"ぎゃぐ ギャグ"
"ぎゃっきょう 逆境"
"ぎゃっこう 逆光 逆行"
"ぎゃっぷ ギャップ"
"ぎゃんぶる ギャンブル"
"ぎゅう 牛"
"ぎゅうかわ 牛革"
"ぎゅうし 牛脂"
"ぎゅうしゃ 牛舎"
"ぎゅうしんてい 牛心亭"
"ぎゅうじ 牛耳"
"ぎゅうそうきんぺん 牛窓近辺"
"ぎゅうたん 牛タン"
"ぎゅうとう 牛刀"
"ぎゅうどん 牛丼"
"ぎゅうにく 牛肉"
"ぎゅうにくせつ 牛肉説"
"ぎゅうにゅう 牛乳"
"ぎゅうば 牛馬"
"ぎゅうほ 牛歩"
"ぎゅうらく 牛楽"
"ぎょ 馭 圉 圄 漁 禦 御 魚"
"ぎょーざ 餃子"
"ぎょい 御意"
"ぎょう 繞 痙 堯 驍 蟯 翹 澆 曉 嶢 僥 形 凝 尭 暁 仰 業 行"
"ぎょういこう 行以降"
"ぎょういち 行位置"
"ぎょうかい 業界"
"ぎょうかいうら 業界裏"
"ぎょうかいがん 凝灰岩"
"ぎょうかいし 業界紙"
"ぎょうかいはつ 業界初"
"ぎょうかいびょう 業界病"
"ぎょうかく 仰角 行革"
"ぎょうかん 行間"
"ぎょうかんかく 行間隔"
"ぎょうが 仰臥"
"ぎょうぎ 行義 行儀"
"ぎょうぎょうしい 仰々しい"
"ぎょうぎょうしく 仰々しく"
"ぎょうくぎり 行区切り"
"ぎょうけつ 凝血 凝結"
"ぎょうけつすい 凝結水"
"ぎょうこ 凝固"
"ぎょうこう 僥倖 行幸"
"ぎょうさくじょ 行削除"
"ぎょうざ 餃子"
"ぎょうし 凝視"
"ぎょうした 行下"
"ぎょうしてい 行指定"
"ぎょうしゃ 業社 業者"
"ぎょうしゅ 業種"
"ぎょうしゅう 凝聚 凝集"
"ぎょうしゅく 凝縮"
"ぎょうしょ 行書"
"ぎょうしょう 行商"
"ぎょうしょたい 行書体"
"ぎょうじ 行司 行事"
"ぎょうじゃ 行者"
"ぎょうじゅうざが 行住座臥"
"ぎょうじょう 行上 行状"
"ぎょうじん 行人"
"ぎょうすう 行数"
"ぎょうずい 行水"
"ぎょうせい 暁星 行政"
"ぎょうせいかんりちょう 行政管理庁"
"ぎょうせいざい 行政罰"
"ぎょうせいしょく 行政職"
"ぎょうせいちょう 行政庁"
"ぎょうせき 業績"
"ぎょうせん 暁泉"
"ぎょうせんとう 行先頭"
"ぎょうぜんご 行前後"
"ぎょうそう 形相"
"ぎょうそうにゅう 行挿入"
"ぎょうぞう 行三"
"ぎょうたい 業態"
"ぎょうたん 行端"
"ぎょうたんい 行単位"
"ぎょうだ 行田"
"ぎょうちゅう 行中 蟯虫"
"ぎょうてん 仰天"
"ぎょうとう 行頭"
"ぎょうとく 行徳"
"ぎょうない 行内"
"ぎょうはんい 行範囲"
"ぎょうばんごう 行番号"
"ぎょうぶ 行歩 刑部"
"ぎょうぶんかつ 行分割"
"ぎょうへんしゅう 行編集"
"ぎょうほうこう 行方向"
"ぎょうまつ 行末"
"ぎょうむ 業務"
"ぎょうむぼうがいざい 業務妨害罪"
"ぎょうめ 行目"
"ぎょうれつ 行列"
"ぎょうれつせき 行列積"
"ぎょえい 魚影"
"ぎょえん 御苑"
"ぎょかい 魚会 魚貝 魚介"
"ぎょかく 漁獲"
"ぎょがん 魚眼"
"ぎょきょう 魚協 漁況 漁協"
"ぎょぎょう 漁業"
"ぎょく 閠 嶷 漁区 玉"
"ぎょくおん 玉音"
"ぎょくさい 玉砕"
"ぎょくざ 玉座"
"ぎょくしょう 玉漿"
"ぎょくせき 玉石"
"ぎょくとう 玉頭 玉東"
"ぎょくはく 玉帛"
"ぎょくりんじ 玉林寺"
"ぎょくろ 玉露"
"ぎょぐ 漁具"
"ぎょぐん 魚群"
"ぎょけい 魚形"
"ぎょこう 漁港"
"ぎょしゃ 御者 馭者"
"ぎょしゅ 魚種"
"ぎょしょう 漁礁"
"ぎょしん 魚信"
"ぎょじ 御璽"
"ぎょじょう 漁場"
"ぎょせん 漁船"
"ぎょそん 漁村"
"ぎょたい 魚体"
"ぎょたく 魚拓"
"ぎょっこう 玉鉤"
"ぎょにく 魚肉"
"ぎょふ 漁夫"
"ぎょぶつ 御物"
"ぎょほう 漁法"
"ぎょみん 漁民"
"ぎょめい 御名"
"ぎょらい 魚雷"
"ぎょらいてい 魚雷艇"
"ぎょりゅう 魚龍"
"ぎょりん 魚鱗"
"ぎょるい 魚類"
"ぎょれん 魚連"
"ぎよこぶんれつ 偽横分裂"
"ぎり 切 斬り 義理"
"ぎりしあ 希臘"
"ぎりしゃ ギリシャ"
"ぎりょう 技倆 議了 技量"
"ぎれい 儀礼"
"ぎろん 議論"
"ぎわ 羲和 際"
"ぎわく 疑惑"
"ぎん 憖 崟 垠 岑 吟 銀"
"ぎんいち 銀一"
"ぎんいちろう 銀一郎"
"ぎんいろ 銀色"
"ぎんいろしゃ 銀色車"
"ぎんいろゆうこうしょう 銀色有功賞"
"ぎんうち 銀打"
"ぎんえい 吟詠"
"ぎんか 銀貸 銀花 銀貨"
"ぎんかく 銀閣"
"ぎんかくじ 銀閣寺"
"ぎんが 銀河"
"ぎんがまる 銀河丸"
"ぎんがみ 銀紙"
"ぎんこう 銀鉤 銀行"
"ぎんこういん 銀行印"
"ぎんこうかん 銀交換"
"ぎんこんしき 銀婚式"
"ぎんざ 銀座"
"ぎんざどおり 銀座通"
"ぎんざん 銀山"
"ぎんしょう 銀将 銀章 吟誦 吟嘯 銀賞 吟唱"
"ぎんしょっき 銀食器"
"ぎんじ 銀次"
"ぎんじょう 吟醸"
"ぎんじょうしゅ 吟醸酒"
"ぎんすいしょう 銀水晶"
"ぎんずいしょう 銀水晶"
"ぎんせい 銀星 銀製"
"ぎんせかい 銀世界"
"ぎんせん 銀泉"
"ぎんぞう 銀蔵"
"ぎんだまでっぽう 銀玉鉄砲"
"ぎんなん 銀杏"
"ぎんばん 銀盤"
"ぎんぱい 銀杯"
"ぎんぱく 銀箔"
"ぎんぷんちょう 銀粉蝶"
"ぎんべえ 銀兵衛"
"ぎんほんい 銀本位"
"ぎんまく 銀幕"
"ぎんみ 吟味"
"ぎんゆう 吟遊"
"ぎんりん 銀鈴"
"ぎんれい 銀嶺"
"く 貢 孔 供 鳩 鉤 驅 衢 窶 瞿 煦 桍 柧 枸 懼 惧 怐 嶇 實 吼 吁 區 劬 ９ 倶 狗 玖 躯 久 矩 駈 工 九 句 駒 駆 区 口 苦"
"くーにゃん 姑娘"
"くーぽん クーポン"
"くーら クーラ"
"くーりー 苦力"
"くい 悔い 久井 悔 杭"
"くいーん クイーン"
"くいき 区域"
"くいけ 食い気"
"くいず クイズ"
"くいたん 杭端"
"くいちがい 食い違い"
"くいとう 杭頭"
"くいどうらく 喰い道楽"
"くいにげ 食い逃げ"
"くいほうだい 食い放題 喰い放題"
"くいもの 食い物 喰い物"
"くう 刧 φ 腔 劫 空"
"くうあつ 空圧"
"くうい 空尉 空位"
"くういき 空域"
"くうかい 空回 空海"
"くうかん 空間"
"くうかんは 空間波"
"くうかんひずみ 空間歪"
"くうが 空牙"
"くうき 空気"
"くうきあつ 空気圧"
"くうきあな 空気穴"
"くうきげん 空気源"
"くうきじゅう 空気銃"
"くうきちょうしつ 空気調湿"
"くうきょ 空虚"
"くうきりゅう 空気流"
"くうぎょう 空行"
"くうぐん 空軍"
"くうげき 空隙"
"くうこう 空港"
"くうこうせいびじょうえき 空港整備場駅"
"くうこうぜい 空港税"
"くうさつ 空撮"
"くうしきぜくう 空色是空"
"くうしつじょうきょう 空室状況"
"くうしゃ 空車"
"くうしゅう 空襲"
"くうしゅうごう 空集合"
"くうしょ 空所"
"くうじ 空自"
"くうじきほんは 空耳基本波"
"くうせい 空制"
"くうせき 空席"
"くうせつ 空節"
"くうせん 空戦"
"くうぜん 空前"
"くうそ 空疎"
"くうそう 空想"
"くうそうきょり 空走距離"
"くうそうじょうたい 空走状態"
"くうそうへき 空想癖"
"くうそくぜしき 空即是色"
"くうたいくう 空対空"
"くうたいち 空対地"
"くうちゅう 空中"
"くうちゅうせん 空中戦"
"くうちょう 空腸 空調"
"くうてい 空挺"
"くうてん 空転"
"くうどう 空洞"
"くうにゅうりょく 空入力"
"くうねんぴ 空燃費"
"くうはく 　 空白"
"くうばく 空爆"
"くうひ 空費 空飛"
"くうふく 空腹"
"くうぶん 空文"
"くうほう 空包 空砲"
"くうぼ 空母"
"くうぼうそう 空乏層"
"くうぼせん 空母戦"
"くうもじ 空文字"
"くうや 空也"
"くうゆ 空輸"
"くうらん 空欄"
"くうりき 空力"
"くうりすと 空リスト"
"くうりょくてき 空力的"
"くうりょくふかぶつ 空力付加物"
"くうれい 空冷"
"くうれつ 空列"
"くうろ 空路"
"くうろん 空論"
"くぇすちょん クェスチョン"
"くぇっしょん クェッション"
"くえい 区営"
"くえき 苦役"
"くえすと クエスト"
"くえん 枸櫞"
"くえんさん 枸櫞酸"
"くぉーと クォート"
"くおん 久遠"
"くか 久賀"
"くかい 苦界 区会 句会"
"くかく 区画"
"くかた 久方"
"くかん 区間"
"くかんごと 区間毎"
"くが 玖賀 玖珂 久我"
"くがい 苦界 区外"
"くがいそう 九蓋草"
"くがく 苦学"
"くがつ 長月 ９月 九月"
"くがつひめ 九月姫"
"くき 莖 九鬼 茎 久喜"
"くきざき 茎崎"
"くきまきひげ 茎巻鬚 茎巻きひげ"
"くきもと 久木元"
"くきゅう 区急"
"くきょう 苦境"
"くぎ 供犠 釘"
"くぎうち 釘打"
"くぎし 釘師"
"くぎちょうせい 釘調整"
"くぎづけ 釘付け"
"くぎの 久木野"
"くぎみや 釘宮"
"くぎもと 釘本"
"くぎょう 公卿 苦行"
"くぎり 句切 区切り 区切"
"くぎん 苦吟"
"くく 九九"
"くくりぞめ 纐"
"くぐい 鵠"
"くぐつ 裹 傀儡"
"くぐの 久々野"
"くけい 矩形"
"くけいは 矩形波"
"くけいばん 矩形板"
"くけいまど 矩形窓"
"くげ 公卿 公家"
"くげがた 公家方"
"くげぬま 鵠沼"
"くげん 苦言"
"くこ 枸杞"
"くこうぞう 句構造"
"くごう 久郷"
"くさ 艸 日 草"
"くさい クサい"
"くさお 草尾"
"くさか 日下 久坂"
"くさかい 草皆 草開"
"くさかべ 日下部"
"くさかり 草苅 草刈り 草刈"
"くさがみ 草上"
"くさき 草木"
"くさけいば 草競馬"
"くさずもう 草相撲"
"くさせんり 草千里"
"くさたいかい 草大会"
"くさち 草地"
"くさつ 草津"
"くさなぎ 草薙"
"くさなぎのたち 草薙の太刀"
"くさなぎのつるぎ 草薙剣"
"くさの 草野"
"くさのね 草の根"
"くさは 草葉"
"くさはら 草原"
"くさば 草場"
"くさばな 草花"
"くさび 楔"
"くさま 草間 日馬"
"くさむら 叢"
"くさやきゅう 草野球"
"くさやなぎ 草柳"
"くさよもぎ 藾"
"くさり 銷 鎖"
"くされえん 腐れ縁"
"くさわけ 草分 草分け"
"くし 梳 串 釧 櫛 駆使"
"くしがた 櫛型 櫛形"
"くしがはま 櫛ケ浜"
"くしきの 串木野"
"くしくも 奇しくも"
"くしさし 串刺"
"くしざし くし刺し 串刺"
"くしだ 串田"
"くしてい 区指定"
"くしはら 串原 櫛原"
"くしびき 櫛引"
"くしま 久嶋 串間"
"くしまうみ 久島海"
"くしもと 串本"
"くしゃみ 嚔"
"くしやき 串焼 串焼き"
"くしやま 串山"
"くしょう 苦笑"
"くしら 串良"
"くしろ 釧路"
"くしん 苦心"
"くじ 九字 籤 久慈 九時"
"くじしょう 久慈商"
"くじびき 籤引き くじ引き"
"くじゃく 孔雀"
"くじゅ 口授"
"くじゅう 久住 苦汁 苦渋"
"くじゅうくり 九十九里"
"くじゅうくりはま 九十九里浜"
"くじょ 駆除"
"くじょう 九条 苦情"
"くじら クジラ 鯀 鯨"
"くじらい 鯨井"
"くじらおか 鯨岡"
"くす 樟 玖珠 楠"
"くすおか 楠岡"
"くすだ 楠田"
"くすだま 薬玉"
"くすね 藥煉"
"くすのき 楠木 樟 楠"
"くすのきあか クスノキ亜科"
"くすのきか クスノキ科"
"くすのきまさしげ 楠正成"
"くすのせ 楠瀬"
"くすのは 樟葉"
"くすはら 楠原"
"くすみ 楠見"
"くすもと 楠元 楠本"
"くすやま 楠山"
"くすり 藥 薬"
"くすりし 薬師"
"くすりや 薬屋"
"くすりゆび 薬指"
"くず 葛 屑"
"くずう 葛生"
"くずおか 葛岡"
"くずかご 屑篭"
"くずきじ 屑記事"
"くずきり 葛切 葛切り"
"くずこ 葛粉"
"くずてつ 屑鉄"
"くずは 葛葉 楠葉"
"くずはもーる 樟葉モール"
"くずはら 葛原"
"くずまき 葛巻"
"くずみ 久住"
"くずゆ 葛湯"
"くずりゅう 九頭竜"
"くずりゅうこ 九頭竜湖"
"くずれ 崩れ"
"くせ 久世 癖"
"くせげ 癖毛"
"くせつ 苦節"
"くせもの 曲者"
"くせん 苦戦"
"くせんてい 駆潜艇"
"くぜ 久瀬 久世"
"くぜつ 口説"
"くそ 糞"
"くたんもん 狗蜑門"
"くだ 管"
"ください 下さい"
"くだされたく 被下度"
"くだまつ 下松"
"くだもの 果物"
"くだら 百濟 百済 百斉"
"くだり 件 下り"
"くだりざか 下り坂"
"くだん 件 九段"
"くだんきた 九段北"
"くだんした 九段下"
"くち 口"
"くちあたり 口当り"
"くちいがい 口以外"
"くちうつし 口移し"
"くちうら 口占 口裏"
"くちえ 口絵"
"くちかず 口数"
"くちがね 口金"
"くちき 朽木"
"くちきき 口利き"
"くちきり 口切り"
"くちく 駆逐"
"くちくたいしれい 駆逐隊司令"
"くちぐせ 口癖 口ぐせ"
"くちぐち 口々"
"くちぐるま 口車"
"くちげんか 口喧嘩"
"くちこみ 口コミ"
"くちさき 吻 口先"
"くちじょうず 口上手"
"くちすう 口数"
"くちぞえ 口添え"
"くちた 口田"
"くちたっしゃ 口達者"
"くちだし 口出し"
"くちづけ 口づけ"
"くちづて 口伝"
"くちどめ 口止め"
"くちなし 梔"
"くちのつ 口之津"
"くちのは 朽葉"
"くちのまち 口ノ町"
"くちは 朽葉"
"くちば 朽葉"
"くちばし 嘴 喙"
"くちばや 口早"
"くちぱく 口パク"
"くちひげ 髭"
"くちび 口火"
"くちびる 口唇 唇"
"くちぶえ 口笛"
"くちぶり 口振り 口ぶり"
"くちべた 口下手"
"くちべに 口紅"
"くちべらし 口減らし"
"くちまね 口真似"
"くちもと 口許 口元"
"くちゃ 苦茶"
"くちやくそく 口約束"
"くちゅう 駆虫"
"くちょう 区長 口調"
"くちよごし 口汚し"
"くちわ 口和"
"くちわき 口脇"
"くっきょう 究竟 倔強 屈強"
"くっきょく 屈曲"
"くっきょくは 屈曲波"
"くっきん 屈筋"
"くっさく 掘鑿 掘削"
"くっし 屈指"
"くっしゃろこ 屈斜路湖"
"くっしょん クッション"
"くっしん 屈伸"
"くっしんばつじゅう 屈伸抜重"
"くっせい 屈性"
"くっせつ 屈折"
"くったく 屈託"
"くっちゃん 倶知安"
"くっぷく 屈服 屈伏"
"くつ 鞋 崛 倔 履 堀 屈 沓 窟 掘 靴"
"くつあと 靴跡"
"くつう 苦痛"
"くつかけ 沓掛"
"くつかわ 沓川"
"くつき 朽木"
"くつざわ 沓澤"
"くつした くつ下 靴下"
"くつじゅう 屈従"
"くつじょく 屈辱"
"くつじょくせん 屈辱戦"
"くつずれ 靴擦れ"
"くつぞこ 靴底"
"くつばこ 靴箱"
"くつひも 靴紐"
"くつみ 九津見"
"くつや 靴屋"
"くつわ 銜 轡"
"くつわだ 轡田"
"くてん 区点 句点"
"くでん 口伝"
"くとう 久東 苦闘"
"くとうてん 句読点"
"くどう 久道 区道 駆動 工藤"
"くどうげん 駆動源"
"くどお 久遠"
"くどき 口説き"
"くどく 功徳 口説く"
"くどやま 九度山"
"くない 工内 苦無 区内 宮内"
"くないちょう 宮内庁"
"くなこく 狗奴国"
"くなしり 国後"
"くなり 九那里"
"くなん 苦難"
"くに 六合 久邇 圀 訓 國 邦 国"
"くにあき 国明 邦明 邦昭 国昭"
"くにい 国井 國井"
"くにえだ 國枝 国枝"
"くにお 邦生 久仁雄 邦央 邦雄 国雄 国夫 国男 國雄 邦男 邦夫"
"くにかず 邦和"
"くにかた 國方"
"くにがみ 国頭"
"くにがら 国柄"
"くにがわ 国側"
"くにきょうかい 国協会"
"くにく 苦肉"
"くにぐに 国々"
"くにこ 都子 くに子 久仁子 邦子"
"くにこう 国高"
"くにさか 国坂"
"くにさき 国東"
"くにさだ 國貞"
"くにさわ 国沢"
"くにざかい 国境"
"くにざね 国実"
"くにしげ 国重"
"くにしま 国島"
"くにしゅどう 国主導"
"くにじ 邦次"
"くにじま 国島"
"くにじゅう 国中"
"くにせん 国線"
"くにぜんたい 国全体"
"くにたいこう 国対抗"
"くにたち 国立"
"くにだ 国田"
"くにつかみ 国津神"
"くにとみ 国富"
"くにとも 國友 邦朋"
"くにとりものがたり 国盗物語"
"くになまり 国訛り"
"くになり 邦成"
"くにのぶ 国信"
"くにはま 国浜"
"くにはる 邦明 邦治"
"くにばんごう 国番号"
"くにひこ 国彦 國彦 邦彦"
"くにひさ 邦久 国久"
"くにひと 邦仁"
"くにひろ 邦洋 国博 訓弘 邦宏"
"くにびと 国人"
"くにふじ 國藤"
"くにふみ 邦文"
"くにべつ 国別"
"くにまさ 国政 邦匡"
"くにまつ 國松"
"くにみ 国見"
"くにみつ 國光"
"くにむね 國宗"
"くにもと 国本"
"くにものがたり 国物語"
"くにやしょてん 国屋書店"
"くにやす 國安 国泰 国安"
"くにゆき 邦之"
"くによし 國吉 國義 邦義 国吉"
"くぬぎ 功力 功刀 檪 櫟 椡 椪 椢 栩 椚"
"くねん 九年"
"くの 久野"
"くのいち くノ一"
"くのう 久能 苦悩"
"くのくら 玄倉"
"くのへ 九戸"
"くはい 苦杯"
"くば 玖場 久場"
"くび 頸 馘首 頚 馘 首"
"くびかざり 珞 首飾り 首飾"
"くびかせ 首枷"
"くびき 軛 頚城"
"くびきり 首切り 首切"
"くびくくり 首縊り"
"くびさ 首差"
"くびしめ 首締"
"くびす 踵 跟"
"くびすじ 首筋"
"くびつり 首吊"
"くびなげ 首投げ"
"くびひねり 首捻り"
"くびわ 首輪"
"くふう 工夫"
"くぶ 九分"
"くぶん 区分"
"くべつ 区別"
"くべつなし 区別無し"
"くほんぶつ 九品仏"
"くぼ 玖保 窪 久保"
"くぼう 久宝 公方"
"くぼかわ 久保川 窪川"
"くぼがみ 久保上"
"くぼき 久保木"
"くぼさわ 久保沢"
"くぼた クボタ 窪田 久保田"
"くぼち くぼ地 窪地"
"くぼでら 窪寺 久保寺"
"くぼの 窪野"
"くぼや 窪谷"
"くま 隅 久万 球磨 隈 熊"
"くまい 熊井"
"くまいし 熊石"
"くまがい 熊谷"
"くまがね 熊ヶ根"
"くまがや 熊谷"
"くまがやこう 熊谷工"
"くまくす 熊楠"
"くまくら 熊倉"
"くまぐす 熊楠"
"くまげ 熊毛"
"くまげら 熊啄木鳥"
"くまこう 熊公"
"くまこうせいもんまえ 熊高正門前"
"くまさか 熊坂"
"くまさき 熊崎"
"くまさわ 熊沢"
"くまざわ 熊沢"
"くまそ 熊襲"
"くまだ 隈田 熊田"
"くまだい 熊大"
"くまつづらか クマツヅラ科"
"くまで 熊手"
"くまとり 熊取"
"くまどり 隈取り"
"くまの 熊野"
"くまはち 熊八"
"くまもと 隈本 熊本"
"くまやま 熊山"
"くみ 与 久美 組"
"くみあい 組合"
"くみあいひ 組合費"
"くみあげ 九美上"
"くみあわせ 組み合せ 組合せ 組み合わせ"
"くみいれ 組入れ"
"くみいん 組員"
"くみえ 久美恵"
"くみかえ 組換え 組み替え"
"くみかた 組み方"
"くみきょく 組曲"
"くみこ クミ子 玖海子 久美子"
"くみこみ 組込 組み込み"
"くみたい 組対"
"くみたいそう 組体操"
"くみたて 組立 組み立て"
"くみたてこう 組立工"
"くみちがい 組み違い"
"くみちょう 組長"
"くみはば 組幅"
"くみはま 久美浜"
"くみはん 組み版 組版"
"くみばん 組版"
"くみひも 組紐"
"くみめい 組名"
"くみやま 久御山"
"くみん 区民"
"くめ 久米 粂"
"くめい 苦鳴 区名"
"くめうち 粂内"
"くめた 久米田"
"くめだ 久米田"
"くめなん 久米南"
"くめの 粂野"
"くめのせんにん 久米の仙人"
"くめひろし 久米宏"
"くめん 工面"
"くも 蜘蛛 蜘 雲"
"くもあひ 雲合"
"くもい 雲井"
"くもおとこ 蜘蛛男"
"くもがくれ 雲隠れ"
"くもがた 雲形"
"くもがたじょうぎ 雲型定規"
"くもつ 貢物 供物"
"くもとりやま 雲取山"
"くものい 雲乃井"
"くものす 蜘蛛の巣"
"くもま 雲間"
"くもゆき 雲行き 雲行"
"くもり 曇り 曇"
"くもん 久門 公文 苦悶"
"くやくしょ 区役所"
"くやしなき 悔し泣き"
"くやしなみだ 悔し涙"
"くやま 久山"
"くゆう 区有"
"くよう 供養"
"くようさい 供養祭"
"くら 藏 峅 庫 鞍 倉 蔵"
"くらあく 暗悪"
"くらい 位"
"くらいし 倉石"
"くらいまっくす クライマックス"
"くらいり 蔵入"
"くらいれ 倉入"
"くらうち 蔵内"
"くらうつし 倉移"
"くらかげ 鞍掛"
"くらかた 倉片"
"くらがえ 鞍替"
"くらがり 闇"
"くらく 苦楽"
"くらくえんぐち 苦楽園口"
"くらくしょん クラクション"
"くらげ 水母 海月 鮓 クラゲ"
"くらさ 暗さ"
"くらさき 倉崎"
"くらさわ 倉沢"
"くらし 暮らし"
"くらしき 倉敷"
"くらしげ 倉茂 倉重"
"くらした 蔵下"
"くらしっく クラシック"
"くらしな 倉品"
"くらしま 倉島"
"くらす クラス"
"くらすた クラスタ"
"くらた 蔵田 鞍田 倉田"
"くらたけ 倉岳"
"くらたや 蔵田家"
"くらち 倉知"
"くらっち クラッチ"
"くらて 鞍手"
"くらでこうつう 鞍手交通"
"くらとみ 倉富"
"くらに 倉荷"
"くらのうち 蔵之内"
"くらはし 倉橋"
"くらはら 倉原"
"くらふと クラフト"
"くらぶ クラブ 倶楽部"
"くらぶち 倉淵"
"くらべ 倉部"
"くらま 蔵間 鞍馬"
"くらまえ 藏前 蔵前"
"くらまた 倉又"
"くらめ 暗め"
"くらもち 倉持"
"くらもと 蔵元 蔵本 倉本"
"くらやみ 暗闇"
"くらよし 倉吉"
"くり 涅 庫裡 繰 栗"
"くりーにんぐ クリーニング"
"くりーむ クリーム"
"くりあげ 繰り上げ"
"くりいれ 繰入"
"くりいろ 栗色"
"くりお 栗生"
"くりかえし 々 繰返し 繰りかえし 繰り返し"
"くりから 倶利迦羅 倶利伽羅"
"くりげ 栗毛"
"くりここくさい 栗子国際"
"くりこし 繰越"
"くりこま 栗駒"
"くりごはん 栗御飯"
"くりさわ 栗沢"
"くりす 栗栖"
"くりすたる クリスタル"
"くりすます クリスマス"
"くりた 栗太 栗田"
"くりっぷ クリップ"
"くりっぷぼーど クリップボード"
"くりつ 栗津 区立"
"くりにっく クリニック"
"くりねずみ 栗鼠"
"くりの 栗野"
"くりのべしさん 繰延資産"
"くりはし 栗橋"
"くりはま 久里浜"
"くりはまおき 久里浜沖"
"くりはら 久利原 栗原"
"くりはらこまき 栗原小巻"
"くりばやし 栗林"
"くりもと 栗源 栗本"
"くりや 厨 廚"
"くりやま 栗山"
"くりゅう 九龍"
"くりょ 苦慮"
"くりん 九厘"
"くる 久留"
"くるー クルー"
"くるいざき 狂咲"
"くるす 来須"
"くるすの 栗栖野"
"くるぶし 踝"
"くるま 俥 クルマ 車"
"くるまいがい 車以外"
"くるまいす 車椅子"
"くるまいぞんしゃかい 車依存社会"
"くるまいちだいぶん 車一台分"
"くるまいど 車井戸"
"くるまかんけい 車関係"
"くるまかんれん 車関連"
"くるまがわ 車側"
"くるまこうにゅうじ 車購入時"
"くるまさんぎょう 車産業"
"くるまざき 車折"
"くるまざっし 車雑誌"
"くるましゃかい 車社会"
"くるまじたい 車自体"
"くるまぜんたい 車全体"
"くるまたに 車谷"
"くるまだ 車田"
"くるまだい 車代"
"くるまつうがく 車通学"
"くるまどうし 車同士 車同志"
"くるまどおり 車通り"
"くるまどめ 車止"
"くるまぶんか 車文化"
"くるまや 車屋"
"くるまやま 車山"
"くるまゆうせん 車優先"
"くるまよい 車酔い 車酔"
"くるまよう 車用"
"くるまりよう 車利用"
"くるみ 久留味 胡桃"
"くるみざわ 胡桃沢"
"くるみもく クルミ目"
"くるめ 久留米"
"くるわ 廓"
"くれ 暮れ 呉 暮"
"くれーしゃげき クレー射撃"
"くれーたー クレーター"
"くれーむ クレーム"
"くれぐれ 呉呉 暮々"
"くれし 呉市"
"くれじっと クレジット"
"くれせん 呉線"
"くれたけ 呉竹"
"くれない 紅"
"くれないのぶた 紅の豚"
"くれはかがく 呉羽化学"
"くればやし 暮林 紅林"
"くれよん クレヨン"
"くろ 黒"
"くろーず クローズ"
"くろあめ 黒飴"
"くろいし 黒石"
"くろいそ 黒磯"
"くろいろ 黒色腫 黒色"
"くろいわ 黒岩"
"くろう 苦労"
"くろうしょう 苦労性"
"くろうじ 黒氏"
"くろうと 玄人"
"くろうばなし 苦労話"
"くろうめもどきもく クロウメモドキ目"
"くろえ 黒江"
"くろおとこ 黒男"
"くろかび 黒黴"
"くろかみ 黒髪"
"くろかわ 黒河 黒川"
"くろがそ 黒画素"
"くろがね 黒銀 鐵 鉄 黒鉄"
"くろき 黒木"
"くろぎ 黒木"
"くろぐろ 黒々"
"くろけい 黒系"
"くろこ 黒子"
"くろご 黒衣 黒子"
"くろさか 黒坂"
"くろさき 黒崎"
"くろさわ 黒沢 黒澤"
"くろさわあきら 黒澤明 黒沢明"
"くろざとう 黒砂糖"
"くろしお 黒潮"
"くろしかく ■"
"くろしかげ 黒鹿毛"
"くろしろ 黒白"
"くろじ 黒地 黒字"
"くろす クロス 黒須"
"くろすいしょう 黒水晶"
"くろすみ 黒住"
"くろせ 黒瀬"
"くろせん 黒線"
"くろたき 黒滝"
"くろたてじま 黒縦縞"
"くろだ 黒田"
"くろだい 黒鯛"
"くろだけ 黒岳"
"くろだま 黒玉"
"くろだんしゃく 黒男爵"
"くろち 黒地"
"くろぢ 黒地"
"くろっく クロック"
"くろつち 黒土"
"くろでんわ 黒電話"
"くろとかげ 黒蜥蜴"
"くろぬり 黒塗り"
"くろねこ 黒猫"
"くろば 黒羽"
"くろばね 黒羽"
"くろばん 黒番"
"くろひめ 黒姫"
"くろびかり 黒光り"
"くろびし 黒菱"
"くろふく 黒服"
"くろふね 黒船"
"くろぶた 黒豚"
"くろべ 黒部"
"くろべこ 黒部湖"
"くろほね 黒保根"
"くろぼし ● 黒星"
"くろまく 黒幕"
"くろまじゅつ 黒魔術"
"くろまつ 黒松"
"くろまほう 黒魔法"
"くろまめ 黒豆"
"くろまる ● 黒丸"
"くろみかずら 黒御鬘"
"くろみや 黒宮"
"くろむぎしゅ 黒麦酒"
"くろめ 黒目"
"くろもよう 黒模様"
"くろもん 黒門"
"くろやなぎ 黒柳"
"くろやま 黒山"
"くろゆり 黒百合"
"くろわし 黒鷲"
"くわ 钁 久和 鍬 桑"
"くわおり 桑折"
"くわかど 桑門"
"くわけ 区分け"
"くわこう 桑港"
"くわしく 詳しく"
"くわずぎらい 食わず嫌い"
"くわた 桑田"
"くわだ 桑田"
"くわだて 企"
"くわづる 桑鶴"
"くわな 桑名"
"くわの 桑野"
"くわはた 桑畑"
"くわはら 桑原"
"くわばら 桑原"
"くわむら 桑村"
"くわもと 桑本"
"くわやま 桑山"
"くわり 桑理 区割り"
"くん 醺 裙 葷 皹 皸 燻 熏 桾 勳 勲 薫 董 訓 君"
"くんいく 訓育"
"くんかい 訓戒"
"くんこく 訓告"
"くんし 君子"
"くんしゅ 葷酒 君手 君主"
"くんしょう 勲章"
"くんしん 君臣"
"くんじ 訓辞 訓示"
"くんじょう 燻蒸"
"くんせい 董製 燻製"
"くんづけ 君付"
"くんとう 薫陶"
"くんどう 訓導"
"くんどく 訓読"
"くんねっぷ 訓子府"
"くんぷう 薫風"
"くんみんせいおん 訓民正音"
"くんやん 崑央"
"くんゆ 訓諭"
"くんよみ 訓読み"
"くんりん 君臨"
"くんれい 訓令"
"くんれん 訓練"
"くんれんし 訓練士"
"くんれんじょ 訓練所"
"くんわ 訓話"
"ぐ 惧 壷 壺 麌 颶 禺 狗 倶 虞 愚 具"
"ぐあい 工合 具合い 具合"
"ぐあん 愚案"
"ぐう 藕 嵎 宮 寓 偶 遇 隅"
"ぐうい 寓意"
"ぐうえん 宮宛"
"ぐうかんすう 偶関数"
"ぐうき 偶奇"
"ぐうじ 宮司"
"ぐうすう 偶数"
"ぐうすうづき 偶数月"
"ぐうすうぺーじ 偶数頁"
"ぐうぜん 偶然"
"ぐうぞう 偶像"
"ぐうぞうし 偶像視"
"ぐうていもく 偶蹄目"
"ぐうはつ 偶発"
"ぐうもく 寓目"
"ぐうりょく 偶力"
"ぐうわ 寓話"
"ぐきょ 愚挙"
"ぐけい 愚兄"
"ぐげん 具現"
"ぐこう 愚考 愚行"
"ぐさ 種"
"ぐさい 愚妻"
"ぐざい Ξ ξ"
"ぐしかみ 具志頭"
"ぐしかわ 具志川"
"ぐしけん 具志堅"
"ぐしゃ 愚者"
"ぐしょう 具象"
"ぐしん 具申"
"ぐじょう 郡上"
"ぐすくべ 城辺"
"ぐず 愚図"
"ぐせ 癖"
"ぐせい 愚生"
"ぐそく 愚息 具足"
"ぐたい 具体"
"ぐたいあん 具体案"
"ぐたいけい 具体形"
"ぐち 愚痴 口"
"ぐちょく 愚直"
"ぐどん 愚鈍"
"ぐねつむこう グネツム綱"
"ぐのう 愚能"
"ぐのこっちょう 愚の骨頂"
"ぐはん 虞犯"
"ぐび 具備"
"ぐびじん 虞美人"
"ぐびじんそう 虞美人草"
"ぐふう 颶風"
"ぐほう 求法"
"ぐまい 愚昧"
"ぐみ グミ 萸 茱 組"
"ぐみん 愚民"
"ぐもん 愚問"
"ぐらい 位"
"ぐらいだー グライダー"
"ぐらうんど グラウンド"
"ぐらす グラス"
"ぐらふ グラフ"
"ぐらふぃくす グラフィクス"
"ぐらふぃっく グラフィック"
"ぐらみーしょう グラミー賞"
"ぐらむ グラム"
"ぐらんで グランデ"
"ぐらんど グランド"
"ぐり 栗"
"ぐりーん グリーン"
"ぐりーんぴあ グリーンピア"
"ぐりこーげん グリコーゲン"
"ぐりせりん グリセリン"
"ぐりる グリル"
"ぐるーぷ グループ"
"ぐるめ グルメ"
"ぐるり 周"
"ぐれ 昏"
"ぐれー グレー"
"ぐれーとぶりてん 大不列顛"
"ぐれーぷ グレープ"
"ぐれい グレイ"
"ぐれつ 愚劣"
"ぐれん 紅蓮"
"ぐれんたい 愚連隊"
"ぐれんな 紅蓮奈"
"ぐろ 黒"
"ぐろーばる グローバル"
"ぐろう 愚弄"
"ぐろん 愚論"
"ぐわい 具合"
"ぐん 麕 羣 郡 軍 群"
"ぐんい 軍医"
"ぐんいち 軍一"
"ぐんえい 軍営 群栄"
"ぐんか 群化 軍歌"
"ぐんかく 軍拡"
"ぐんかん 軍鑑 軍艦"
"ぐんかんき 軍艦旗"
"ぐんかんく 軍管区"
"ぐんかんけい 軍関係"
"ぐんがくたい 軍楽隊"
"ぐんき 軍規 軍紀 軍機 軍旗"
"ぐんきょ 群居"
"ぐんけ 郡家"
"ぐんこう 軍港"
"ぐんこく 軍国"
"ぐんさい 軍才"
"ぐんさんふくごうたい 軍産複合体"
"ぐんし 軍史 軍師 軍士"
"ぐんしきん 軍資金"
"ぐんしゅう 群聚 群集 群衆"
"ぐんしゅく 軍縮"
"ぐんしん 軍神"
"ぐんじ 群司 軍二 軍事 郡司"
"ぐんじひ 軍事費"
"ぐんじゅ 軍需"
"ぐんじょう 群青"
"ぐんじん 軍人"
"ぐんせい 軍政 群生"
"ぐんぜい 軍勢"
"ぐんぜさんぎょう グンゼ産業"
"ぐんぜんたい 群全体"
"ぐんそう 軍曹"
"ぐんそくど 群速度"
"ぐんそしき 軍組織"
"ぐんぞう 群像"
"ぐんぞく 軍属"
"ぐんたい 群体 軍隊"
"ぐんだい 群大"
"ぐんだり 軍荼利"
"ぐんだん 群団 軍団"
"ぐんちえん 群遅延"
"ぐんちゅうおう 軍中央"
"ぐんちょう 軍長"
"ぐんて 軍手"
"ぐんてい 軍偵"
"ぐんていすう 群定数"
"ぐんとう 群島"
"ぐんない 郡内"
"ぐんば 軍馬"
"ぐんばい 軍配"
"ぐんばつ 軍閥"
"ぐんぱつ 群発"
"ぐんび 軍備"
"ぐんぶ 軍部 群舞 郡部"
"ぐんぷく 軍服"
"ぐんぽうかいぎ 軍法会議"
"ぐんま 群馬"
"ぐんみん 軍民"
"ぐんむきょくちょう 軍務局長"
"ぐんめいれい 軍命令"
"ぐんもう 群盲"
"ぐんもん 軍門"
"ぐんゆう 群雄"
"ぐんよう 軍用"
"ぐんようしゃ 軍用車"
"ぐんらく 群落"
"ぐんりゅうせい 群流星"
"ぐんれい 軍令"
"ぐんろん 群論"
"け 華 褻 迦 懸 乖 氣 恠 假 花 仮 ケ ヶ 気 袈 祁 怪 卦 化 毛 家"
"けーき ケーキ"
"けーす ケース"
"けーぶる ケーブル"
"けあがり 蹴上がり"
"けあげ 蹴上"
"けあな 毛穴"
"けい 境 卿 競 京 馨 黥 鷄 頸 醯 逕 迥 輕 谿 謦 螢 莖 繼 綮 經 絅 笄 磬 硅 盻 瓊 煢 烱 炯 溪 檠 枅 攜 挈 挂 憬 憇 惠 徑 彑 奚 奎 夐 匸 勍 勁 剄 冏 冂 兮 蹊 脛 楔 ケイ 佳 珪 契 刑 径 憩 稽 痙 畦 罫 荊 茎 係 慧 詣 掛 頚 鶏 渓 繋 啓 桂 掲 圭 携 蛍 慶 敬 警 景 傾 経 兄 継 恵 軽 型 計 形 系"
"けいあい 敬愛"
"けいあつ 傾圧"
"けいい 軽易 慶伊 敬意 経緯"
"けいいち 螢一 蛍一 桂一 佳一 敬一 慶一 圭一 啓一 恵一"
"けいいちろう 圭一郎 圭一朗 啓一郎 敬一郎"
"けいいん 契印"
"けいえい 経営"
"けいえいがくしょう 経済学賞"
"けいえいたい 経営体"
"けいえいなん 経営難"
"けいえん 敬遠"
"けいおう 京王 慶応 慶應"
"けいおういなだつつみ 京王稲田堤"
"けいおうかく 京王閣"
"けいおうぐち 京王口"
"けいおん 軽音"
"けいおんがく 軽音楽部 軽音楽"
"けいおんき 警音器"
"けいか 圭花 京華 桂花 軽過 計科 経過"
"けいかい 軽快 警戒"
"けいかいしん 警戒心"
"けいかく 計畫 経過句 形覚 計画"
"けいかん 頚管 景観 警官"
"けいかんもの 警官物"
"けいが 慶賀"
"けいがい 謦咳 形骸"
"けいがいぎんが 系外銀河"
"けいがく 啓学"
"けいがん 炯眼 慧眼"
"けいき 掲記 圭樹 計器 刑期 継起 契機 景気"
"けいきざい 軽機材"
"けいきどう 経気道"
"けいきゅう 京急"
"けいきょ 軽挙"
"けいきょう 景況"
"けいきんぞく 軽金属"
"けいく 警句"
"けいくうぼ 軽空母"
"けいぐ 敬具"
"けいけつびょう 壊血病"
"けいけん 經驗 敬虔 経験"
"けいけんあり 経験有"
"けいけんずみ 経験済"
"けいけんば 経験馬"
"けいげん 軽減"
"けいこ 華子 敬子 奎子 蛍子 慶子 啓子 桂子 稽古 景子 圭子 佳子 恵子"
"けいこう 馨香 経口 螢光 蛍光 携行 傾向"
"けいこうかん 蛍光管"
"けいこうがくえん 啓光学園"
"けいこうぎょう 軽工業"
"けいこうぞうはくざい 蛍光増白剤"
"けいこうたい 蛍光体"
"けいこうとう 蛍光燈 螢光灯 蛍光灯"
"けいこうひにんやく 経口避妊薬"
"けいこく 溪谷 渓谷 警告"
"けいこくとう 警告燈 警告灯"
"けいこごと 稽古事"
"けいこつ 脛骨 頚骨"
"けいこば 稽古場"
"けいご 啓吾 圭悟 警護 敬語"
"けいごう 契合"
"けいごうきん 軽合金"
"けいごしゃ 警護車"
"けいさい 掲載"
"けいさいかろんぶん 掲載可論文"
"けいさいじゅん 掲載順"
"けいさぎょう 軽作業"
"けいさく 啓作"
"けいさつ 警察"
"けいさつぎょう 警察業"
"けいさつしょ 警察署"
"けいさつちょう 警察庁"
"けいさつび 警察曰"
"けいさつようじどうしゃ 警察用自動車"
"けいさん 経産 珪酸 計算"
"けいさんきかいろ 計算機回路工学"
"けいさんぎ 計算木"
"けいさんじゃく 計算尺"
"けいさんぷ 経産婦"
"けいざい 経済"
"けいざいきかくちょう 経済企画庁"
"けいざいちょう 経済庁"
"けいざぶろう 啓三郎"
"けいし 啓示 圭史 景士 啓史 警視 罫紙 圭司 軽視"
"けいしき 型式 形式"
"けいしきび 形式美"
"けいしちょう 警視庁"
"けいしつ 形質 軽質"
"けいしつゆ 軽質油"
"けいしゃ 傾斜"
"けいしゃかく 傾斜角"
"けいしゃりょう 軽車両"
"けいしゅう 慶州 慶周 閨秀"
"けいしゅく 慶祝"
"けいしゅつ 掲出"
"けいしょう 軽症 軽傷 警鐘 景勝 形象 敬称 継承"
"けいしょうりゃく 敬省略 敬称略"
"けいしょく 軽食"
"けいしん 茎針 恵信 京津 敬信 京神 軽震"
"けいじ 啓次 圭児 敬治 慶事 圭司 啓治 恵司 継時 桂治 形而 啓示 敬二 慶治 啓二 啓司 敬司 経時 圭二 計時 刑事 掲示"
"けいじどうしゃ 軽自動車"
"けいじどうしゃぜい 軽自動車税"
"けいじどうしゃわく 軽自動車枠"
"けいじはん 刑事犯"
"けいじばつ 刑事罰"
"けいじばん 掲示板"
"けいじもの 刑事物"
"けいじやく 刑事役"
"けいじゅ 圭樹"
"けいじゅん 軽巡"
"けいじゅんようせんかん 軽巡洋戦艦"
"けいじょう 京城 啓上 経常 計上 形状"
"けいじょうひ 経常費"
"けいじょうようしゃ 軽乗用車"
"けいじろう 恵二郎 啓二郎 慶次郎 圭二郎 圭次郎"
"けいす ケイス"
"けいすい 型推 軽水"
"けいすいろ 軽水炉"
"けいすう 計數 計数 係数"
"けいすうかん 計数管"
"けいすうたい 係数体"
"けいすけ 景介 惠介 啓祐 佳佑 圭祐 啓輔 啓典 慶輔 慶裕 啓介 圭介 桂輔 啓助 佳祐 敬介"
"けいず 系図"
"けいずい 頸髄"
"けいずかい 窩主買 系図買"
"けいせい 形声 傾城 形勢 京成 形成"
"けいせいせきや 京成関屋"
"けいせき 形跡"
"けいせきくっせつ 蛍石屈折"
"けいせつ 螢雪 蛍雪"
"けいせん 恵泉 係船 繋船 経線 ╂ ┸ ┥ ┰ ┝ ┿ ┷ ┨ ┯ ┠ ╋ ┻ ┫ ┳ ┣ ┗ ┛ ┓ ┏ ┃ ━ ┌ │ ─ ┐ ├ └ ┬ ┼ ┘ ┤ 罫線 ┴"
"けいせんしゃ 軽戦車"
"けいせんわく 罫線枠"
"けいそ 珪素 ケイ素 硅素 形素"
"けいそう 勁草 慶早 珪藻 計装 係争 軽装"
"けいそうせん 慶早戦"
"けいそく 計測"
"けいそつ 輕率 軽率"
"けいぞう 恵造 慶三 経三 形像 恵贈 恵三 啓三 佳三 敬三"
"けいぞく 繼續 継続"
"けいぞん 桂損"
"けいた 圭太 慶太"
"けいたい 敬体 携帯 形態"
"けいたいそ 形態素"
"けいたく 恵沢"
"けいだ 慶田"
"けいだい 継代 境内 掲題 慶大"
"けいだいじょう 慶大情"
"けいだんれん 経団連"
"けいちつ 啓蟄"
"けいちゅう 傾注"
"けいちょう 茎頂 軽佻 敬重 軽重 慶長 傾聴 慶弔"
"けいつい 頚椎"
"けいてい 係蹄 逕庭 兄弟"
"けいていしゃ 兄弟車"
"けいてき 警笛"
"けいでんき 継電器"
"けいと 慶人 毛糸"
"けいとう 鷄頭 継投 傾倒 系統"
"けいとうじゅ 系統樹"
"けいとくくうこう 啓徳空港"
"けいとざんぐつ 軽登山靴"
"けいとだま 毛糸玉"
"けいとら 軽トラ"
"けいとらっく 軽トラック"
"けいど 傾度 軽度 経度"
"けいどうみゃく 頚動脈"
"けいない 系内"
"けいなわ 京奈和"
"けいなん 慶南"
"けいにりん 軽二輪"
"けいにりんしゃ 軽二輪車"
"けいねん 経年"
"けいのじょう 蛍之丞"
"けいはく 敬白 軽薄"
"けいはつ 啓発"
"けいはん 京阪"
"けいはんざい 軽犯罪"
"けいはんしん 京阪神"
"けいはんな 京阪奈"
"けいば 競馬"
"けいばおう 競馬王"
"けいばつ 閨閥 刑罰"
"けいばほう 競馬報"
"けいひ 荊扉 桂皮 経費"
"けいひこうき 軽飛行機"
"けいひん 景品 京浜"
"けいひんきたいき 京浜北行"
"けいひんみなみいき 京浜南行"
"けいび 軽微 警備"
"けいびてい 警備艇"
"けいびへい 警備兵"
"けいびん 軽便"
"けいふ 系譜"
"けいふく 京福 敬服"
"けいふん 鶏糞"
"けいぶ 頚部 頸部 警部 軽侮"
"けいぶほ 警部補"
"けいぶん 慶文"
"けいぶんしゃ 勁文社 勁分社"
"けいべつ 軽蔑"
"けいほう 刑法 警報"
"けいほうこう 径方向"
"けいほく 京北"
"けいぼ 敬慕 継母"
"けいぼう 閨房 圭膀 警棒"
"けいま 桂馬"
"けいまい 兄妹"
"けいみょう 軽妙"
"けいむ 警務"
"けいむしょ 刑務所"
"けいめい 経明 啓明"
"けいめん 軽免"
"けいめんきょ 軽免許"
"けいもう 啓蒙"
"けいもうてきかつどう 啓蒙的活動"
"けいやく 契約"
"けいやくひ 契約費"
"けいゆ 軽油 経由"
"けいゆう 経由 系由"
"けいゆしゃ 軽油車"
"けいゆぜい 軽油税"
"けいよ 恵与"
"けいよう 繋養 掲揚 形容 京葉"
"けいようぐち 京葉口"
"けいようし 形容詞"
"けいよんりん 軽四輪"
"けいら 警邏"
"けいらく 経絡"
"けいらん 鶏卵"
"けいり 計理 経理"
"けいりか 経理掛"
"けいりがかり 経理掛"
"けいりし 計理士"
"けいりひかえ 経理控"
"けいりゃく 経略 計略"
"けいりゅう 稽留 繋留 渓流"
"けいりゅうおん 継留音"
"けいりゅうざお 渓流竿"
"けいりょう 軽量 計量"
"けいりょうば 軽量馬"
"けいりん 経綸 桂林 競輪"
"けいりんおう 競輪王"
"けいりんどう 啓林堂"
"けいるい 繋累 係累"
"けいれい 敬礼"
"けいれき 経歴"
"けいれつ 勁烈 系列"
"けいれん 痙攣"
"けいろ 毛色 経路"
"けいろう 敬老"
"けいろうどう 軽労働"
"けいわ 計和"
"けう 稀有 希有"
"けおり 毛織り"
"けおりもの 毛織物"
"けかえし 蹴返し"
"けが 怪我"
"けがに 毛蟹"
"けがれ 穢 汚れ"
"けがわ 毛皮"
"けぎらい 毛嫌い"
"けげん 怪訝"
"けごん 華厳 華嚴"
"けさ 畩 袈裟 今朝"
"けさがた 今朝方"
"けさき 毛先"
"けさほど 今朝程"
"けし 消し 芥子"
"けしいん 消印"
"けしき 気色 景色"
"けしこみ 消込"
"けしさる 消し去る"
"けしもく ケシ目"
"けしょう 化生 化粧"
"けしょうすい 化粧水"
"けしょうばこ 化粧箱"
"けしょうばん 化粧板"
"けしん 仮身 化身"
"けずね 毛脛"
"けせん 気仙"
"けせんぬま 気仙沼"
"けそう 懸想"
"けそうぶみ 懸想文"
"けた 桁"
"けたおち 桁落ち"
"けたか 気高"
"けたぐり 蹴手繰り"
"けたごと 桁毎"
"けたすう 桁数"
"けたはずれ 桁外れ けた外れ"
"けたひょうじ 桁表示"
"けため 桁目"
"けだし 蓋し"
"けち 吝"
"けちょう 怪鳥"
"けっか 結跏 欠課 結果"
"けっかい 結界 決潰 欠壊 決壊"
"けっかく 欠格 結核"
"けっかくきん 結核菌"
"けっかん 缺陷 穴間 欠陥 血管"
"けっかんしゃ 欠陥車"
"けっき 蹶起 血気 決起"
"けっきゅう 結球 血球"
"けっきょ 穴居"
"けっきょく 結局"
"けっきん 欠勤"
"けっこう 結好 欠航 欠行 血行 決行 結構"
"けっこうむかし 結構昔"
"けっこん 血痕 結婚"
"けっこんばなし 結婚話"
"けっさい 決済 決裁"
"けっさく 結紮 傑作"
"けっさくせん 傑作撰 傑作選"
"けっさくば 傑作馬"
"けっさつ 結紮"
"けっさん 決算"
"けっさんい 決算委"
"けっし 血祀 決死"
"けっしきそ 血色素"
"けっして 決して"
"けっしゃ 結社"
"けっしゅう 結集"
"けっしゅつ 傑出"
"けっしょう 血症 血笑 結漿 血漿 結晶 決勝"
"けっしょうせき 結晶石"
"けっしょうせん 決勝戦"
"けっしょうばん 血小板"
"けっしょく 血色 欠食"
"けっしん 結審 決心"
"けっせい 血清 結成"
"けっせき 結石 欠席"
"けっせつ 結節"
"けっせん 血戦 決戰 決選 決戦 血栓 結線"
"けっそう 血相"
"けっそく 欠測 結束"
"けっそん 欠損"
"けったく 結託"
"けっちゃく 決着 結着"
"けっちゅう 血中"
"けっちょう 結腸"
"けっちん 血沈"
"けってい 決定"
"けっていあん 決定案"
"けっていき 決定木"
"けっていぎ 決定木"
"けっていせん 決定戦"
"けっていだ 決定打"
"けってん 缺點 欠点"
"けっとう 血糖 結党 決闘 血統"
"けっぱい 欠配"
"けっぱく 潔白"
"けっぱん 血判"
"けっぴょう 結氷"
"けっぴん 欠品"
"けっぺき 潔癖"
"けっぺきしょう 潔癖性"
"けっぽう 血泡"
"けつ 頡 闕 蹶 譎 訐 襭 缺 纈 竭 碣 獗 歇 桀 杰 抉 孑 夬 厥 刔 决 偈 亅 蕨 桔 傑 血 訣 潔 欠 穴 結 決"
"けつあつ 血圧"
"けつあつけい 血圧計"
"けつい 決意"
"けついん 闕員 欠員"
"けつえき 血液"
"けつえきびょう 血液病"
"けつえん 結縁 血縁"
"けつおう 傑王"
"けつがん 頁岩"
"けつぎ 決義 決議"
"けつぎあん 決議案"
"けつげん 結言"
"けつご 結語"
"けつごう 欠号 結合"
"けつごうみゃく 結合脈"
"けつごうもう 結合網"
"けつごうりつ 結合律"
"けつじつ 結実"
"けつじょ 闕如 欠如"
"けつじょう 決定 欠場"
"けつぜい 血税"
"けつぜん 決然 蹶然"
"けつぞう 結像"
"けつぞく 血族"
"けつだん 結団 決断"
"けつにょう 血尿"
"けつばん 欠番"
"けつぶつ 傑物"
"けつべつ 決別 訣別"
"けつぼう 欠亡 欠乏"
"けつまくえん 結膜炎"
"けつまつ 結末"
"けつみゃく 血脈"
"けつめい 結盟"
"けつゆうびょう 血友病"
"けつらく 欠落"
"けつりゅう 血流"
"けつりょう 血量"
"けつるい 血涙"
"けつれい 欠礼"
"けつれつ 決裂"
"けつろ 血路 結露"
"けつろん 結論"
"けづな 毛綱"
"けづや 毛艶"
"けとう 毛唐"
"けどういん 祁答院"
"けなげ 健気"
"けなしだいら 毛無平"
"けなみ 毛並み 毛並"
"けにん 化人"
"けぬき 鑷"
"けねん 懸念"
"けはい 気配"
"けはひ 気配 化粧"
"けばり 毛鉤"
"けびいし 検非違使"
"けびょう 仮病"
"けまうち 毛馬内"
"けまり 蹴鞠"
"けまりうた 手毬歌"
"けみがわ 検見川"
"けみがわはま 検見川浜"
"けむ 烟 煙"
"けむし 毛虫"
"けむり 烟 煙"
"けもてら 化学療法"
"けもの 獸 獣"
"けものぞく 獣族"
"けものみち 獣道"
"けやき 欅"
"けら 螻蛄"
"けらい 家来"
"けらく 快楽"
"けろり けろり"
"けわい 化粧"
"けん 繭 巻 鰹 黔 鵑 驗 騫 顴 顯 險 鉉 釼 蹇 譴 謇 諠 臉 羂 繝 綣 眷 眩 甄 獻 狷 涓 歉 檢 權 椦 暄 舉 擧 搴 慳 慊 愃 愆 惓 幵 嶮 娟 妍 圈 劵 剱 劒 劔 劍 凵 儉 俔 監 縣 絢 瞼 虔 腱 倹 倦 喧 牽 硯 筧 樫 捲 鹸 建 献 絹 懸 憲 遣 剣 堅 兼 圏 険 軒 賢 拳 謙 検 健 鍵 顕 券 肩 犬 験 嫌 間 見 県 権 研 件"
"けんあく 険悪"
"けんあん 検案 懸案"
"けんい 権威"
"けんいき 県域"
"けんいち 乾一 研一 堅一 賢一 憲一 謙一 剣一 健一"
"けんいちろう 健一朗 謙一郎 顕一郎 健一郎"
"けんいん 検印 牽引"
"けんいんしゃ 牽引車"
"けんうん 絹雲"
"けんえい 兼営 県営"
"けんえき 権益 検疫"
"けんえきじょ 検疫所"
"けんえつ 憲悦 検閲"
"けんえん 犬猿 嫌煙"
"けんえんか 嫌煙家"
"けんお 嫌惡 嫌悪"
"けんおうどう 圏央道"
"けんおん 検温"
"けんおんけん 建音研"
"けんおんけんし 建音研資"
"けんか 献花 堅果 県下 喧嘩"
"けんかい 狷介 県会 研開 見解"
"けんかうり 喧嘩売"
"けんかく 見覚"
"けんかごし 喧嘩腰"
"けんかりょうせいばい 喧嘩両成敗"
"けんかん 建艦"
"けんが 懸下"
"けんがい 圏外 県外"
"けんがく 建学 見学"
"けんがん 検眼"
"けんき 嫌気"
"けんきざい 嫌忌剤"
"けんきせいきん 嫌気性菌"
"けんきち 賢吉 健吉"
"けんきゃく 健脚"
"けんきゅう 研究"
"けんきゅうか 研究家"
"けんきゅうかいごと 研究会毎"
"けんきゅうきょうりょくがかり 研究協力掛"
"けんきゅうしょく 研究職"
"けんきゅうしょだい 研究所第"
"けんきゅうしん 研究心"
"けんきゅうじょ 研究所"
"けんきゅうせん 研究船"
"けんきゅうだい 研究第"
"けんきゅうてきかち 研究的価値"
"けんきゅうとう 研究棟"
"けんきゅうはん 研究班"
"けんきゅうひ 研究費"
"けんきょ 検挙 謙虚"
"けんきょう 県境 牽強"
"けんきょうちゅう 検鏡中"
"けんきょうふかい 牽強附会"
"けんきん 兼勤 献金"
"けんぎ 建議 県議 嫌疑"
"けんぎゅう 犬牛"
"けんぎょう 検校 兼業"
"けんけい 県警"
"けんけつ 献血"
"けんけつしゃ 献血車"
"けんけんごうごう 喧々囂々 喧喧囂囂"
"けんけんふくよう 拳拳服膺"
"けんげきじん 剣劇人"
"けんげん 顕現 権限"
"けんこ 腱固"
"けんこう 驗效 兼行 軒昂 健康"
"けんこうこつ 肩胛骨 肩甲骨"
"けんこうやれん 県高野連"
"けんこく 建国"
"けんこんいってき 乾坤一擲"
"けんご 謙吾 健吾 健五 憲吾 建悟 堅固 研吾 健悟"
"けんごう 剣豪"
"けんさ 検査"
"けんさいん 検査院"
"けんさき 剣先"
"けんさく 羂索 研削 献策 検索"
"けんさじょ 検査所"
"けんさつ 賢察 検札 検察"
"けんさつちょう 検察庁"
"けんさぼ 検査簿"
"けんさん 研鑽"
"けんざい 建材 顕在 健在"
"けんざかい 県境"
"けんざぶろう 健三郎"
"けんざん 験算 見参 剣山 検算"
"けんし 県史 賢史 絹糸 研紙 検視 検死 研資 剣士 犬歯"
"けんしき 見識"
"けんしゃく 検車区"
"けんしゅう 検収 研修"
"けんしゅうい 研修医"
"けんしゅうこ 検修庫"
"けんしゅうじょ 研修所"
"けんしゅうひ 研修費"
"けんしゅつ 検出"
"けんしょう 腱鞘 肩章 顕彰 懸賞 健勝 憲章 検証"
"けんしょうあん 憲章案"
"けんしょうえん 腱鞘炎"
"けんしょうば 顕彰馬"
"けんしょく 兼職"
"けんしん 剣心 健診 健晋 検針 謙信 献身 検診"
"けんじ 研児 建司 顕二 謙司 憲志 健爾 賢児 健至 健士 拳児 剣持 献辞 堅持 賢次 賢司 謙二 謙治 研治 憲二 憲治 憲司 健之 健次 研仁 健治 顕示 健児 賢治 健司 研二 賢二 検事 健二"
"けんじつ 堅実"
"けんじゃ 賢者"
"けんじゅう 拳銃"
"けんじゅつ 剣術"
"けんじょう 健常 見城 謙譲 献上"
"けんじょうけい 謙譲形"
"けんじょうじ 健常児"
"けんじょうれい 県条例"
"けんじろう 研二郎 健二郎 顕次郎 健次郎"
"けんじん 賢人 県人 賢臣"
"けんすい 懸垂"
"けんすう 検数 軒数 件数"
"けんすけ 謙介 堅助 健輔 健介"
"けんず 検図"
"けんせい 憲政 県政 権勢 牽制"
"けんせいあくそうきゅう 牽制悪送球"
"けんせいきゅう 牽制球"
"けんせいし 牽制死"
"けんせき 譴責"
"けんせきうん 巻積雲"
"けんせつ 建設"
"けんせつあと 建設跡"
"けんせつしょう 建設省"
"けんせつひよう 建設費"
"けんぜい 県税"
"けんぜみ 研ゼミ"
"けんぜん 建前 健全"
"けんそう 建掃 喧騒 喧噪"
"けんそううん 巻層雲"
"けんそく 検測 検束"
"けんそん 謙遜"
"けんぞう 研造 剣三 賢三 謙三 建造 健蔵 健三"
"けんぞうひ 建造費"
"けんぞく 眷族 眷属"
"けんた 健太"
"けんたい 献体 検体 倦怠"
"けんたいかい 県大会"
"けんたろう 謙多郎 謙太郎 健太郎"
"けんたん 健啖 兼担 県短"
"けんだい 建大"
"けんだいひょう 県代表"
"けんち 検地 見知 見地 検知"
"けんちく 建築"
"けんちくか 建築家"
"けんちくぎょう 建築業"
"けんちくざい 建築材"
"けんちくし 建築士"
"けんちくてん 建築展"
"けんちくひ 建築費"
"けんちじ 県知事"
"けんちゃ 献茶"
"けんちょ 顕著"
"けんちょう 懸吊 健聴 堅調 県庁"
"けんちょうじ 健聴耳"
"けんてい 献呈 検定"
"けんていふ 献呈譜"
"けんてつ 賢哲 建鐵 建鉄"
"けんでん 喧伝"
"けんと 県都 憲人 健人"
"けんとう 拳闘 健闘 見当 検討"
"けんとうか 拳闘家"
"けんとうきょく 県当局"
"けんとうし 遣唐使"
"けんとうぶ 県東部"
"けんどう 県道 剣道"
"けんどじゅうらい 捲土重来"
"けんどちょうらい 捲土重來 捲土重来"
"けんない 圏内 県内"
"けんなん 県南 険難"
"けんにょう 検尿"
"けんにん 検認 兼任"
"けんのう 権能 献納"
"けんのん 剣呑 険呑"
"けんば 犬馬"
"けんばいき 券売機"
"けんばく 懸瀑"
"けんばん 鍵板 鍵盤"
"けんばんごと 鍵盤毎"
"けんぱ 検波"
"けんぱく 絹帛 建白"
"けんひ 県費"
"けんび 顕微 兼備"
"けんびきょう 顕微鏡"
"けんびし 剣菱"
"けんぴん 検品"
"けんぶ 剣舞"
"けんぶち 剣淵"
"けんぶつ 見物"
"けんぶつき 見物記"
"けんぶつきゃく 見物客"
"けんぶん 検分 見聞"
"けんぶんしつちょくつう 研分室直通"
"けんぷ 絹布"
"けんべん 検便"
"けんぺい 憲兵"
"けんぺいりつ 建蔽率"
"けんぺん 券片"
"けんぼう 健忘 権謀"
"けんぼうさいか 県防災課"
"けんぼうじゅっすう 権謀術数"
"けんぽ 健保"
"けんぽう 剣法 拳法 憲法"
"けんぽうあん 憲法案"
"けんぽういん 憲法院"
"けんぽうか 拳法家"
"けんぽうだいきゅうじょう 憲法第九条"
"けんぽうだいじゅうさんじょう 憲法第一三条"
"けんぽく 県北"
"けんぽん 献本"
"けんま 研摩 研磨"
"けんまく 劍幕"
"けんまこん 研磨痕"
"けんみん 県民"
"けんむ 建武 兼務"
"けんめ 件目"
"けんめい 県名 件名 賢明 懸命"
"けんめん 券面"
"けんもち 犬持 剣持 堅持"
"けんもつ 監物"
"けんもん 検問"
"けんもんじょ 検問所"
"けんや 賢也 顕也"
"けんやく 検約 倹約"
"けんやくか 倹約家"
"けんゆう 県有"
"けんゆうかん 健友館"
"けんよう 兼用"
"けんようしゃ 兼用車"
"けんようすい 懸壅垂"
"けんらん 絢爛"
"けんり 権利"
"けんりかぶ 権利株"
"けんりつ 県立"
"けんりつしんがっこう 県立進学校"
"けんりゅう 劍竜"
"けんりょう 見料 検量"
"けんりょく 権力"
"けんりよう 券利用"
"けんれん 拳攣 研連"
"けんれんかいかく 牽攣乖隔"
"けんろう 堅牢"
"けんろく 兼六"
"けんろん 圏論"
"けんわ 健和"
"げ 拐 睨 觧 偈 解 夏 毛 外 下"
"げーと ゲート"
"げーむ ゲーム"
"げい 麑 霓 貎 藝 睨 皃 囈 倪 猊 鯨 迎 芸"
"げいいん 鯨飲"
"げいか 猊下"
"げいぎ 芸妓"
"げいげき 迎撃"
"げいこ 藝子"
"げいこうだい 芸工大"
"げいごう 迎合"
"げいごと 芸事"
"げいしゃ 迎車 芸者"
"げいしゃやく 芸者役"
"げいしゅん 迎春"
"げいじゅつ 藝術 芸術"
"げいじゅついん 芸術院"
"げいじゅつか 芸術家"
"げいじゅつさい 芸術祭"
"げいせい 芸西"
"げいたいかい 芸大会"
"げいたっしゃ 芸達者"
"げいたん 芸短"
"げいだい 芸大"
"げいとう 藝當 芸当"
"げいにん 芸人"
"げいのう 芸濃 芸能"
"げいのうかいいり 芸能界入"
"げいひん 迎賓"
"げいび 芸備"
"げいびけい 猊鼻渓"
"げいふう 芸風"
"げいほく 芸北"
"げいめい 芸名"
"げいれき 芸歴"
"げか 外科"
"げかい 下回 外界 外科医 下界"
"げかん 下巻"
"げき 鷁 鬩 闃 郤 檄 屐 逆 戟 隙 劇 撃 激"
"げきあせ 激汗"
"げきあま 激甘"
"げきか 激化"
"げきから 激辛"
"げきが 劇画"
"げきくうかん 劇空間"
"げきげん 激減"
"げきこう 激昂"
"げきこみ 激混"
"げきさっか 劇作家"
"げきさん 激賛"
"げきしょ 激暑"
"げきしょう 激賞"
"げきしょく 激職"
"げきしん 激震"
"げきじゃく 激弱"
"げきじょう 激情 劇場"
"げきじょうか 激情家"
"げきせん 激戦"
"げきそう 激走"
"げきぞう 激増"
"げきたい 撃退"
"げきだん 劇団"
"げきちゅう 劇中"
"げきちゅうげき 劇中劇"
"げきちょう 外記丁"
"げきちん 撃沈"
"げきちんは 撃沈破"
"げきつい 撃墜"
"げきついおう 撃墜王"
"げきつう 激痛"
"げきてき 劇的"
"げきとう 激闘"
"げきとつ 激突"
"げきとつし 激突死"
"げきど 激怒"
"げきどう 激動"
"げきなみだ 激涙"
"げきは 撃破"
"げきはつ 激発"
"げきひょう 劇評"
"げきぶん 檄文"
"げきへん 激変"
"げきむ 劇務 激務"
"げきめつ 撃滅"
"げきやく 劇薬"
"げきやす 激安"
"げきりゅう 激流"
"げきりん 逆鱗"
"げきれい 激励"
"げきれつ 激烈"
"げきろん 激論"
"げぎ 外儀"
"げぐう 外宮"
"げけつ 下血"
"げこ 下戸"
"げこう 下向 下校"
"げこくじょう 下剋上"
"げさく 戯作"
"げざい 下剤"
"げざん 下山"
"げし 夏至"
"げしゃ 下車"
"げしゃいん 下車印"
"げしゅく 下宿"
"げしゅにん 下手人"
"げじげじ 蚰蜒"
"げじゅん 下旬"
"げす 下司 下種 下衆"
"げすい 下水"
"げすと ゲスト"
"げせわ 下世話"
"げせん 下賎 下船"
"げそく 下足"
"げた 〓 下駄"
"げたばこ 下駄箱"
"げだい 外題"
"げだつ 解脱"
"げだん 下段"
"げっか 激化 月下"
"げっかひょうじん 月下氷人"
"げっかん 月間 月刊"
"げっきゅう 月給"
"げっけい 月計 月経"
"げっけいかん 月桂冠"
"げっけいじゅ 月桂樹"
"げっこう 激高 激昂 月光"
"げっこうちゅう 月光蟲"
"げっさん 月産"
"げっし 齧齒 齧歯"
"げっしゃ 月謝"
"げっしゅう 月収"
"げっしゅつ 月出"
"げっしゅつたいしょく 月出帯蝕"
"げっしょう 月商"
"げっしょく 月蝕 月食"
"げっしるい げっ歯類"
"げっすいきん 月水金"
"げっぴょう 月評"
"げっぷ 月賦"
"げっぺい 月餅"
"げっぽ 月歩"
"げっぽう 月俸 月報"
"げつ 齧 蘖 囓 月"
"げつえい 月影"
"げつか 月火"
"げつかすい 月火水"
"げつかん 月間"
"げつがく 月額"
"げつご 月後"
"げつじ 月次"
"げつど 月度"
"げつぶん 月分"
"げつまえ 月前"
"げつまつ 月末"
"げつまつじつ 月末日"
"げつめん 月面"
"げつもく 月木"
"げつよう 月曜"
"げつようびごろ 月曜日頃"
"げつようよる 月曜夜"
"げつり 月利"
"げつれい 月齢 月例"
"げて 下手"
"げてもの 下手物"
"げてん 下天"
"げとう 夏油"
"げどう 外道 下道"
"げどく 解毒"
"げなん 下男"
"げに 実に"
"げねつ 解熱"
"げば 下馬"
"げばひょう 下馬評"
"げひ 下卑"
"げひん 下品"
"げび 下卑"
"げほう 外法"
"げぼく 下僕"
"げらく 下落"
"げり 下痢"
"げりゃく 下略"
"げりら ゲリラ"
"げるちん ゲル沈"
"げれつ 下劣"
"げれんで ゲレンデ"
"げろ 下呂"
"げろう 外郎 下郎"
"げん 顏 彦 験 軒 衒 芫 眩 痃 愿 广 嚴 呟 儼 偐 監 嫌 訝 厳 幻 舷 諺 弦 絃 玄 減 源 原 元 言 限 現"
"げんあつ 減圧"
"げんあん 現案 原案"
"げんいち 源一 元一"
"げんいちろう 源一郎"
"げんいん 現員 減員 原因"
"げんうん 眩暈"
"げんえい 幻影"
"げんえいきゃく 幻影脚"
"げんえき 原液 減益 現役"
"げんえきば 現役馬"
"げんおん 原音 現音"
"げんおんせい 原音声"
"げんか 現価 現下 減価 言下 喧嘩 原価"
"げんかい 言海 幻界 幻海 玄海 厳戒 限界"
"げんかいなだ 玄海灘"
"げんかく 幻覚 厳格"
"げんかくせいぶつ 原核生物"
"げんかし 原歌詞"
"げんかしょうきゃくひ 減価償却費"
"げんかん 厳寒 玄関"
"げんかんぐち 玄関口"
"げんかんげんぞう 減感現像"
"げんかんすう 原関数"
"げんが 原画"
"げんがい 言外"
"げんがく 絃楽 衒学 減額 弦楽"
"げんがくしじゅうそう 弦楽四重奏曲"
"げんがぞう 原画像"
"げんがっき 弦楽器"
"げんがっきょく 弦楽曲"
"げんがてん 原画展"
"げんき 原基 原器 元気"
"げんきかい 現棋界"
"げんきじるし 元気印"
"げんきどうしょてん 源喜堂書店"
"げんきもの 元気者"
"げんきゃく 減却"
"げんきゅう 減給 言及"
"げんきょう 現況 元凶"
"げんきょく 限局 元曲 原曲"
"げんきよし 元気良"
"げんきん 厳禁 現金"
"げんきんばらい 現金払"
"げんぎ 原義"
"げんぎょ 言語"
"げんぎょう 現業"
"げんくう 源空"
"げんけい 減軽 減刑 原型 原形"
"げんけいしつ 原形質"
"げんけいしつまく 原形質膜"
"げんけいてきようそ 原形的要素"
"げんけん 原券 原研"
"げんげつ 限月"
"げんげんご 原言語"
"げんこう 弦高 減光 元寇 言行 現行 原稿"
"げんこうしゃ 玄光社"
"げんこうはん 現行犯"
"げんこく 現国 原告"
"げんこつ 拳骨"
"げんこん 現今"
"げんこんたん 原根端"
"げんご 源後 幻語 源吾 原語 言語"
"げんごう 元号"
"げんごろうまる 源五郎丸"
"げんさい 衒妻 幻妻 減殺"
"げんさく 原作"
"げんさくどうぶつ 原索動物"
"げんさん 減産 原産 減算"
"げんざい 原罪 現在"
"げんざいけい 現在形"
"げんざいだか 現在高"
"げんざいまで 現在迄"
"げんざいやく 現在約"
"げんざいりょう 原材料"
"げんざいりょうひ 原材料費"
"げんざぶろう 源三郎"
"げんざん 減算"
"げんし 元祀 原紙 幻視 原資 減資 原始 原子"
"げんしち 源七"
"げんしつ 言質"
"げんしとう 原始島"
"げんしゃ 減車"
"げんしゅ 原酒 原種 元首 厳守"
"げんしゅう 減収"
"げんしゅく 厳粛"
"げんしゅつ 現出"
"げんしょ 原初 原書"
"げんしょう 現症 減少 現象"
"げんしょく 減色 減食 原色 現職"
"げんしりきこうがっか 原子力工学科"
"げんしりょくせん 原子力船"
"げんしろ 原子炉"
"げんしん 原審"
"げんしんごう 元信号 原信号"
"げんじ 言辞 玄二 源治 源氏"
"げんじそくど 現示速度"
"げんじつ 現実"
"げんじつみ 現実味"
"げんじな 源氏名"
"げんじゃく 減弱"
"げんじゅう 幻獣 現住 厳重"
"げんじゅうみん 原住民"
"げんじゅうろう 幻十郎"
"げんじょう 玄奘 原状 現場 現状"
"げんじょういじあん 現状維持案"
"げんじょうしゃけん 原乗車券"
"げんじょうしゃけんがく 原乗車券額"
"げんじょうほうこく 現況報告"
"げんじろう 源二郎"
"げんじん 原人"
"げんすい 元師 減水 元帥 減衰"
"げんすいは 減衰波"
"げんすいばく 原水爆"
"げんすう 元数 減数"
"げんすん 原寸"
"げんず 原図"
"げんせい 原生 現姓 現勢 現世 厳正"
"げんせいかえん 原生花園"
"げんせいりん 原生林"
"げんせき 原籍 原石"
"げんせつ 言説"
"げんせりやく 現世利益"
"げんせん 言泉 原潜 源泉 厳選"
"げんぜい 減税"
"げんぜん 儼然 厳然"
"げんそ 原素 元素"
"げんそう 現送 幻想"
"げんそく 舷側 減速 原則"
"げんそくざい 減速材"
"げんそん 玄孫 減損 現存"
"げんぞう 原像 現像"
"げんぞうえき 現像液"
"げんぞうりょうむりょう 現像料無料"
"げんぞん 現存"
"げんた 玄太 元太 源太"
"げんたい 減退"
"げんたいけん 原体験"
"げんたつ 厳達"
"げんたろう 玄太郎 厳太郎"
"げんたん 減反"
"げんたんか 原単価"
"げんだ 源田"
"げんだい 原題 現代"
"げんだいおんがくし 現代音楽調"
"げんだいかなづかい 現代仮名遣"
"げんだいげき 現代劇"
"げんだいし 現代史"
"げんだいせん 現代戦"
"げんだいのうがくしゅう 現代能楽集"
"げんだいびょう 現代病"
"げんだいぶんめいびょう 現代文明病"
"げんだいもの 現代物"
"げんち 言質 現地"
"げんちがし 現地貸"
"げんちゃり 原チャリ"
"げんちゅう 原虫 原註"
"げんちゅうしんちゅう 原中心柱"
"げんちょ 原著"
"げんちょう 弦長 現調 幻聴"
"げんちょさくぶつ 原著作物"
"げんちょしゃちゅう 原著者註"
"げんつき 原付"
"げんつきしゃ 原付車"
"げんてい 限定"
"げんていし 限定詞"
"げんていしゃ 限定車"
"げんていしゅ 限定酒"
"げんていつき 限定付"
"げんていみかいじょ 限定未解除"
"げんてん 原典 減点 原点"
"げんでぃれくとりー 現ディレクトリー"
"げんとう 舷灯 幻燈 幻灯 厳冬"
"げんど 限度"
"げんどう 原動 言動"
"げんどうきつき 原動機付"
"げんどうりょく 源動力"
"げんどがく 限度額"
"げんな 元和"
"げんない 源内"
"げんなおし 験直し"
"げんなま 現生 現ナマ"
"げんに 現に"
"げんにほんご 源日本語"
"げんにん 現任"
"げんのう 玄翁 言翁 玄能"
"げんはけい 原波形"
"げんはんけつ 原判決"
"げんば 現場"
"げんばく 原爆"
"げんばしどうぶ 現場指揮部"
"げんばつ 厳罰"
"げんばん 原盤 原版"
"げんぱい 減配"
"げんぱつ 原発"
"げんぱつおき 原発沖"
"げんぱつようねんりょう 原発用燃料"
"げんひしつ 原皮質"
"げんひそう 原皮層"
"げんひょうひ 原表皮"
"げんびん 減便"
"げんぴ 厳秘"
"げんぴょう 原票"
"げんぴん 現品"
"げんぶ 玄武"
"げんぶがん 玄武岩"
"げんぶつ 原物 現物"
"げんぶん 原文"
"げんぶんいっち 言文一致"
"げんぶんそう 弦分奏"
"げんぷ 原譜 厳父"
"げんぷう 厳封"
"げんぷく 元服"
"げんぺい 源平"
"げんぺいせいすいき 源平盛衰記"
"げんぺいとうまでん 源平討魔伝"
"げんぼ 原簿"
"げんぼく 原木"
"げんぼん 原本"
"げんぽう 現法 減俸 減法"
"げんぽん 原本"
"げんま 玄馬 幻魔"
"げんまい 玄米"
"げんまいしょく 玄米食"
"げんまいちゃ 玄米茶"
"げんまき 弦巻"
"げんみつ 厳密"
"げんみつかい 厳密解"
"げんむ 幻梦 幻夢"
"げんめ 限目"
"げんめい 厳命 言明"
"げんめつ 減滅 幻滅"
"げんめん 減免"
"げんもう 原毛 減耗"
"げんもく 眩目"
"げんもけい 原模型"
"げんもん 厳門"
"げんや 幻夜 原野"
"げんゆ 原油"
"げんゆう 現有"
"げんよう 原葉 幻幼 現用"
"げんり 原理"
"げんりゅう 原流 源流"
"げんりゅういきふきん 源流域付近"
"げんりゅうすい 源流水"
"げんりゅうち 限流値"
"げんりょう 減量 原料 限量"
"げんろく 元禄"
"げんろん 言論 原論"
"げんわく 幻惑 眩惑"
"こ 仔 瑚 虚 拠 去 炬 壷 壺 ヶ 皷 鴣 餬 錮 辜 詁 觚 蠱 蝴 蛄 乕 虍 葫 胯 罟 粐 箍 瞽 痼 瓠 濾 滸 滬 涸 沽 楜 桍 柧 杞 怙 徠 夸 呱 刳 凅 冱 兒 來 估 个 女 冴 箇 ⌒ 木 粉 コ 乎 姑 扈 枯 呼 来 娘 琥 児 袴 糊 己 菰 虎 跨 鈷 胡 狐 孤 股 固 古 故 弧 戸 雇 誇 鼓 湖 顧 庫 小 個 子"
"こーかさす 高加索"
"こーす コース"
"こーち コーチ"
"こーでぃねーしょん コーディネーション"
"こーと コート"
"こーど コード"
"こーな コーナ"
"こーひー 珈琲 コーヒー"
"こーぽ コーポ"
"こーらす コーラス"
"こーる コール"
"こーるど コールド"
"こーん コーン"
"こあくつ 小圷"
"こあくとう 小悪党"
"こあくま 小悪魔"
"こあざ 小字"
"こあし 小足"
"こあみ 小網"
"こあら コアラ 古荒 伊熊描"
"こい 濃 湖衣 戀 故意 鯉 恋"
"こいうた 恋歌 恋唄"
"こいがくぼ 恋ヶ窪"
"こいがたき 恋敵"
"こいがわ 鯉川"
"こいき 小粋"
"こいけ 菰池 小池"
"こいけだ 小池田"
"こいこ 恋子"
"こいごころ 恋心"
"こいし 礫 小石"
"こいしかわ 小石川"
"こいしわら 小石原"
"こいじ 恋路"
"こいずみ 小泉"
"こいそ 小磯"
"こいち 小市"
"こいちじかん 小一時間"
"こいちゃ 濃茶"
"こいで 小出"
"こいとせいさくしょ 小糸製作所"
"こいなか 恋仲"
"こいにょうぼう 恋女房"
"こいぬ 小犬 仔犬 子犬"
"こいぬま 濃沼 鯉沼"
"こいのぼり 鯉幟"
"こいひとよ 恋一夜"
"こいひめ 湖衣姫"
"こいびと 恋人"
"こいびとやく 恋人役"
"こいぶち 鯉渕 鯉淵"
"こいぶみ 恋文"
"こいものがたり 恋物語"
"こいわ 小岩"
"こいわい 小岩井"
"こいん 雇員 コイン"
"こう 嵩 劫 湊 頁 塙 衝 皐 肴 仰 恰 鈎 袷 耗 斯う 黌 鵁 鱇 鬨 餃 頏 靠 隍 闔 閧 閘 鑛 鏗 鎬 鍠 鉤 遘 遑 逅 誥 詬 訌 覯 蝗 蛟 蚣 薨 胛 肓 羔 缸 纐 絎 絖 絳 簧 篝 箜 窖 稾 磽 礦 矼 盍 皓 皎 皋 畊 猴 狡 狎 犒 熕 煌 烋 滉 溘 湟 淆 浤 洸 洽 汞 槹 槓 槁 椌 棡 昿 曠 晄 昴 昊 杲 效 攷 搆 扛 扣 慷 惶 恍 恆 怐 徨 崗 峺 峇 寇 嫦 媾 壙 嚆 啌 哮 哽 哄 咬 呷 吼 吭 匣 凰 冦 冓 傚 倥 佝 伉 亢 亘 亙 叩 国府 鴿 膠 胱 肛 睾 晧 乞 爻 耿 佼 孔 后 倖 喉 巧 坑 候 縞 絋 宏 孝 侯 功 効 河 庚 興 勾 剛 杭 昂 廣 糠 梗 黄 綱 控 弘 康 洪 幸 腔 江 拘 肱 膏 鋼 閤 砿 貢 紘 絞 交 晃 紅 肯 垢 巷 硬 抗 攻 横 浩 恒 耕 郊 港 酵 校 鴻 荒 皇 航 口 購 溝 香 厚 慌 鉱 講 降 甲 稿 更 好 衡 光 後 敲 構 考 向 広 工 公 行 高 項"
"こうあ 興亜"
"こうあっしつ 高圧室"
"こうあつ 降圧 高圧"
"こうあん 公案 公安 考案"
"こうい 皇位 好位 校医 口胃 厚意 更衣 高位 好意 行為"
"こういき 高域 広域"
"こういしょう 後遺症"
"こういち 鉱一 講一 耿一 高１ 晃市 康市 航一 巧一 宏一 好位置 好一 興市 興一 剛一 耕一 晃一 弘一 幸市 功一 公一 孝市 高一 光一 幸一 孝一 康一 浩一"
"こういちろう 耕一郎 康一郎 宏一良 公一郎 光一郎 晃一朗 幸一郎 鴻一郎 興一郎 浩一郎"
"こういってん 紅一点"
"こういん 荒淫 光陰 行員 拘引 工員 公印"
"こうう 降雨"
"こううりん 後右輪"
"こううん 航運 耕耘 好運 幸運"
"こううんかく 光雲閣"
"こううんき 耕運機"
"こうえい 後裔 後衛 光影 公営 光栄"
"こうえいきょう 好影響"
"こうえいば 公営馬"
"こうえき 公役 公益 交易"
"こうえつ 校閲"
"こうえねけん 高エネルギー物理学研究所 高エネルギー研究所 高エネ研"
"こうえねるぎ 高エネルギー"
"こうえん 後縁 高塩 光塩 好演 後援 公演 公園 講演"
"こうえんしょうざいとうよ 抗炎症剤投与"
"こうえんじ 高円寺"
"こうえんじゅん 講演順"
"こうえんろんぶんしゅうひ 講演論文集費"
"こうお 好悪"
"こうおつ 甲乙"
"こうおつつけ 甲乙付"
"こうおん 厚恩 高音 硬音 構音 恒温 高温"
"こうおんしつ 好音質"
"こうおんそう 恒温槽"
"こうか 孔果 晃華 功科 黄禍 校歌 甲賀 考課 硬化 硬貨 工科 降下 高架 高価 効果"
"こうかい 狡獪 後回 紅海 公海 黄海 更改 高階 航海 後悔 公開"
"こうかいがくせんこう 航海学専攻"
"こうかいき 航海記"
"こうかいぎ 公会議"
"こうかいし 航海士"
"こうかいずみ 公開済"
"こうかいどう 公会堂"
"こうかいはん 航海班"
"こうかがく 光化学"
"こうかきかえ 項書換え"
"こうかきかえけい 項書き換え系"
"こうかく 厚角 高角 攻殻 口角 甲殻 広角 降格"
"こうかくじゅう 甲殻獣"
"こうかくほう 高角砲"
"こうかくるい 甲殼類"
"こうかしきどうろ 高架式道路"
"こうかした 高架下"
"こうかしょう 効果小"
"こうかそくどしゃ 高加速度車"
"こうかつ 狡猾"
"こうかふこうか 幸か不幸か"
"こうかみ 鴻上"
"こうかん 巷間 好漢 公館 公刊 高官 鋼管 交歓 交感 好感 交換"
"こうかんけい 項関係"
"こうかんしゅ 交換手"
"こうかんしょく 好感触"
"こうかんじょ 交換所"
"こうかんずみ 交換済"
"こうかんばり 交換針"
"こうかんまく 交換膜"
"こうかんもう 交換網"
"こうかんりつ 交換律"
"こうが 高雅 黄河 甲賀"
"こうがい 笄 慷概 慷慨 港外 坑外 光害 構外 校外 口蓋 郊外 公害 梗概 口外"
"こうがいじ 紅孩児"
"こうがく 溝壑 向学 高額 光学 後学 工学"
"こうがくいん 工学院"
"こうがくし 工学士"
"こうがくしゃ 好学社"
"こうがくしん 向学心"
"こうがくじ 光学事"
"こうがくぶで 工学部出"
"こうがくぶほんぶとう 工学部本部棟"
"こうがしゃ 恒河沙"
"こうがっか 工学課 工学科"
"こうがっかい 工学会"
"こうがりゅう 甲賀流"
"こうがん 厚顔 紅顔 睾丸"
"こうがんざい 抗癌剤"
"こうがんむち 厚顔無恥"
"こうき 好気 降旗 幸喜 公起 光樹 衡機 綱紀 校規 康熈 工機 好輝 高機 公器 浩貴 幸毅 光輝 後気 香気 広軌 好機 好奇 高貴 工期 後記 後期"
"こうきしゃ 後期車"
"こうきしん 好奇心"
"こうきじてん 康煕字典"
"こうきせいきん 好気性菌"
"こうきち 光吉 耕吉 康吉 幸吉 孝吉 厚吉"
"こうきゅう 光球 降給 後宮 鋼球 考究 降級 硬球 公休 高給 講究 恒久 高級"
"こうきゅうえん 好救援"
"こうきゅうぎょ 高級魚"
"こうきゅうごびゅう 高級語彙"
"こうきゅうざい 高級材"
"こうきゅうしゃ 高級車"
"こうきゅうしゅうかてい 光吸収過程"
"こうきょ 鉤距 薨去 皇居"
"こうきょう 鋼橋 口供 広狭 好況 公共 交響"
"こうきょういく 公教育"
"こうきょうがく 交響楽"
"こうきょうざい 公共財"
"こうきょうし 交響詩"
"こうきょうしん 公共心"
"こうきょうじぎょうひ 公共事業費"
"こうきょうてきだんしょう 交響的断章"
"こうきょうどぶんぷ 光強度分布"
"こうきょく 鉤曲"
"こうきん 抗菌 拘禁 公金"
"こうきんざい 抗菌材"
"こうぎ 好誼 厚誼 高誼 講議 恒偽 広義 抗議 講義"
"こうぎいん 工業技術院 工技院"
"こうぎけん 航技研"
"こうぎじゅつぶ 光技術部"
"こうぎとう 講義棟 講義搭"
"こうぎょう 鋼業 航業 興行 鉱業 興業 工業"
"こうぎょく 硬玉 紅玉"
"こうく 工区 鉤矩 校区"
"こうくう 高空 口腔 航空"
"こうくうけん 航空券"
"こうくうさい 航空祭"
"こうくうせん 航空戦"
"こうくうてっこうばくだん 航空撤甲爆弾"
"こうくうひ 航空費"
"こうくうろ 航空路"
"こうぐ 工具"
"こうぐう 厚遇"
"こうぐち 坑口 高口"
"こうぐん 蝗軍 行軍 皇軍"
"こうけい 肯綮 皇兄 後傾 口径 項型 後経 後継 光景"
"こうけいき 好景気"
"こうけいさんけい 項計算系"
"こうけいしゃなん 後継者難"
"こうけいば 後継馬"
"こうけっか 好結果"
"こうけっかくざい 抗結核剤"
"こうけつ 硬結 絞結 纐纈 高潔"
"こうけん 後験 甲券 高見 工研 公権 光顕 硬券 後件 後見 貢献"
"こうげい 工藝 工芸"
"こうげいし 工芸史"
"こうげいてん 工芸展"
"こうげき 攻撃"
"こうげきじゅん 攻撃順"
"こうげきだま 攻撃玉"
"こうげきわざ 攻撃技"
"こうげつ 香月"
"こうげん 鉤玄 膠原 抗原 広言 巧言 口減 光源 高原 公言"
"こうげんがく 考現学"
"こうげんびょう 膠原病"
"こうこ 後顧 考古 江湖 公庫"
"こうこう 鉤校 耿々 煌々 交媾 後攻 膏肓 後行 口腔 航行 孝行 高校"
"こうこうぎょう 鉱工業"
"こうこうど 高々度"
"こうこうまで 高校迄"
"こうこく 廣告 鴻鵠 皇國 抗告 侯国 興国 公国 公告 皇国 広告"
"こうこくぎょう 広告業"
"こうこくしかん 皇國史観"
"こうこくしゃ 広告車"
"こうこくぬし 広告主"
"こうこくひ 広告費"
"こうこつ 甲骨 硬骨 恍惚"
"こうこつかん 硬骨漢"
"こうこつぎょ 硬骨魚"
"こうご 口語 交互"
"こうごう 媾合 皇后"
"こうごうしい 神々しい"
"こうごうせい 光合成"
"こうごきたい 乞御期待"
"こうごたい 口語体"
"こうさ 黄砂 甲佐 公差 較差 考査 交叉 交差"
"こうさい 甲西 香西 高斎 光彩 虹彩 公債 公済 交際 高裁"
"こうさいかい 弘済会"
"こうさいどう 廣済堂"
"こうさいどうしゅっぱん 廣斉堂出版"
"こうさいひ 交際費"
"こうさいぼう 膠細胞"
"こうさいりんどう 弘西林道"
"こうさか 上坂 上阪 香阪 神坂 高坂 幸坂 江坂 香坂"
"こうさき 神前"
"こうさく 耕筰 鉤索 鋼索 幸作 工作 耕作 交錯"
"こうさし 交差視"
"こうさつ 絞殺 高察 考察"
"こうさん 考算 好酸 抗酸 興産 降参 鉱産 公散 公算 高３"
"こうさんきん 抗酸菌"
"こうさんきんびょうけんきゅうじょ 抗酸菌病研究所"
"こうざ 硬座 高座 講座 口座"
"こうざい 功罪 鋼材 香西"
"こうざいりょう 好材料"
"こうざき 神崎"
"こうざしゃ 硬座車"
"こうざつ 交雑"
"こうざひ 講座費"
"こうざぶろう 幸三郎"
"こうざん 甲山 鑛山 高山 鉱山"
"こうざんじ 高山寺"
"こうざんびょう 高山病"
"こうし 合志 後肢 郊祀 鉤止 犢 嚆矢 孝子 子牛 甲子 厚志 公司 公使 光子 孔子 行使 講士 公私 格子 講師"
"こうしあい 好試合"
"こうしえんぐち 甲子園口"
"こうしき 項式 硬式 公式"
"こうしきせん 公式戦"
"こうしきせんはつ 公式戦初"
"こうしけっしょう 高脂血症"
"こうしぞう 格子像"
"こうしつ 高質 硬質 皇室"
"こうしど 格子戸"
"こうしゃ 後車 公舎 稿者 降車 公社 校舎 後者"
"こうしゃく 講釈 公爵 候爵 侯爵"
"こうしゃぐち 降車口"
"こうしゃさい 公社債"
"こうしゃほう 高射砲"
"こうしゅ 鉤取 好守 公主 絞首 好手 攻守 後手"
"こうしゅう 抗州 興収 紅萩 甲州 広州 口臭 公衆 講習"
"こうしゅうおんど 江州音頭"
"こうしゅうせい 光周性"
"こうしゅうはねつれん 高周波熱錬"
"こうしゅうわん 杭州湾"
"こうしゅかいそう 甲種回送"
"こうしゅく 拘縮"
"こうしゅけい 絞首刑"
"こうしゅそう 攻守走"
"こうしゅつ 後出"
"こうしゅつよう 高出葉"
"こうしゅび 好守備"
"こうしゅん 香春"
"こうしょ 向暑 高所"
"こうしょう 光昭 高唱 工商 行賞 厚相 哄笑 工廠 工匠 口承 公娼 口誦 公傷 好尚 高承 鉱床 考証 校章 公証 公章 高尚 公称 交渉"
"こうしょうきょくく 鉤章棘句"
"こうしょうじ 光照寺"
"こうしょうぶ 好勝負"
"こうしょく 好色 公職 交織 更埴"
"こうしょとくしゃそう 高所得者層"
"こうしろう 幸四郎"
"こうしん 亢進 昂進 後身 庚申 高進 口唇 恒真 後進 行進 交信 更新"
"こうしんえつ 甲信越"
"こうしんしゃ 更新車"
"こうしんじょ 興信所"
"こうしんせい 更新世"
"こうしんちほう 甲信地方"
"こうしんりょう 香辛料"
"こうしんりょく 向心力"
"こうじ 恒治 弘司 滉二 浩次 浩志 鉤餌 剛次 香次 耕二 耕司 浩仁 弘二 康二 広治 厚二 功児 光次 吼児 虹児 考爾 甲児 幸志 好餌 柑子 皓司 耕次 公司 晧司 康治 耕治 光二 糀 小路 貢司 康司 幸二 幸治 幸次 幸司 宏次 孝次 交事 孝治 光司 康次 宏治 公示 浩司 浩二 高次 晃司 麹 孝二 工事"
"こうじえん 広辞苑"
"こうじえんだいいにばん 広辞苑第二版"
"こうじき 光磁気"
"こうじきょく 航時局"
"こうじく 向軸 光軸"
"こうじしゃ 工事車"
"こうじつ 後日 口実"
"こうじひ 工事費"
"こうじまち 麹町"
"こうじゅ 坑儒 口授"
"こうじゅつ 公述 講述 口述 後述"
"こうじゅようしきそ 光受容色素"
"こうじゅん 公準 恒順 降順"
"こうじゅんかん 好循環"
"こうじゅんしゃ 交殉社"
"こうじょ 公序 控除"
"こうじょう 鉤縄 光条 交情 荒城 厚情 恒常 甲状 口上 工場 向上"
"こうじょうあと 工場跡"
"こうじょううら 工場裏"
"こうじょうけん 好条件"
"こうじょうしん 向上心"
"こうじょうせん 甲状腺"
"こうじょうわたし 工場渡"
"こうじょがく 控除額"
"こうじょけい 控除計"
"こうじりん 広辞林"
"こうじろ 神代"
"こうじろう 康次郎 公二郎 香次郎 幸次郎 孝次郎 宏次郎"
"こうじん 紅塵 公人 黄塵 後陣 荒神 幸甚 後塵 工人"
"こうじんしゃ 行人社 工人舎"
"こうじんぶつ 好人物"
"こうすい 交綏 幸水 降水 硬水 香水"
"こうすいびん 香水瓶"
"こうすいびんてん 香水瓶展"
"こうすう 項数 口数 校数 工数"
"こうすけ 康介 廣祐 江介 康祐 耕輔 宏祐 宏介 功介 広介 幸輔 耕助"
"こうず 国府津 高津 神津 構図"
"こうずい 洪水"
"こうずか 好事家"
"こうずけ 上野"
"こうずしま 神津島"
"こうずじま 神津島"
"こうせ 興世"
"こうせい 甲西 高声 耕生 佼成 鋼製 貢成 硬性 校生 更正 向性 後生 較正 幸生 佼正 抗生 公正 攻勢 恒星 高生 厚生 後世 校正 更生 構成"
"こうせいあん 構成案"
"こうせいぎんこう 恒生銀行"
"こうせいさあびす 厚生サービス"
"こうせいしゃ 鋼製車"
"こうせいしょう 厚生省"
"こうせいしん 公正心"
"こうせいずり 校正刷り"
"こうせいせき 好成績"
"こうせいねん 好青年"
"こうせいのか 高性能化"
"こうせいば 校正場"
"こうせいぶっしついり 抗生物質入"
"こうせいようえき 校正用液"
"こうせき 鑛石 航跡 口跡 鉱石 洪積 功績"
"こうせきせい 洪積世"
"こうせつ 高説 後節 公設 降雪 巧拙"
"こうせん 工繊 鋼線 抗戦 好戦 工業高等専門学校 工専 公選 交線 鉱泉 交戦 光線 高専"
"こうせんさく 鋼線索"
"こうせんしゅ 好選手"
"こうせんじゅう 光線銃"
"こうせんすい 鉱泉水"
"こうぜつ 高舌"
"こうぜん 紅髯 昂然 公然"
"こうぜんじ 光善寺"
"こうそ 皇祖 控訴 公訴 酵素"
"こうそう 香草 厚層 航送 皇宗 高僧 好走 降霜 後送 抗争 高層 構想"
"こうそうかいだん 構想段階"
"こうそうば 好走馬"
"こうそうぼく 高草木"
"こうそうるい 好走塁"
"こうそく 航測 光束 校則 梗塞 光速 拘束 高速"
"こうそくしゃ 高速車"
"こうそくせん 高速船"
"こうそくぞうしょくろ 高速増殖炉"
"こうそくだん 高速弾"
"こうそくてい 高速艇"
"こうそくてつどうもう 高速鉄道網"
"こうそくろ 高速炉"
"こうそしつ 好素質"
"こうそしん 控訴審"
"こうそつ 高卒"
"こうぞ 楮"
"こうぞう 行三 耕三 弘蔵 肯三 浩三 幸三 孝蔵 孝三 構造"
"こうぞうざい 構造材"
"こうぞうたい 構造体"
"こうぞく 航続 皇族 後続"
"こうぞくしゃ 後続車"
"こうぞくは 後続波"
"こうぞくば 後続馬"
"こうた 幸田 晃太 小歌 小唄"
"こうたい 剛体 抗体 交替 後退 交代"
"こうたいか 鋼体化"
"こうたいごう 皇太后"
"こうたいし 皇太子"
"こうたいしょう 好対照"
"こうたいとう 後退灯"
"こうたいないぶ 鋼体内部"
"こうたいは 後退波"
"こうたいよう 向太陽"
"こうたく 光澤 光沢"
"こうたに 甲谷"
"こうたり 神足"
"こうたろう 耕太郎 晃太朗 光太郎 廣太郎 輝太郎 幸太郎 孝太郎 浩太郎"
"こうたん 降誕 後端"
"こうたんさい 降誕祭"
"こうだ 行田 甲田 国府田 神田 好打 光田 古宇田 香田 幸田 好田 黄田"
"こうだい 航大 後代 広大 工大"
"こうだいさい 工大祭"
"こうだいじ 高台寺"
"こうだえき 江田駅"
"こうだか 甲高"
"こうだく 黄濁"
"こうだん 光弾 降段 巷談 降壇 高段 後段 講壇 公団 講談"
"こうだんし 好男子 皇男子"
"こうち 狡智 狡知 好地 河内 幸地 耕地 拘置 巧緻 巧遅 後置 高地 公知 高知"
"こうちく 構築"
"こうちし 後置詞"
"こうちのうけんきゅうしゃ 工知能研究者"
"こうちゃ 紅茶"
"こうちゃく 膠着 降着"
"こうちゅう 工注 校注 甲冑 甲虫"
"こうちゅうきゅう 好中球"
"こうちょ 好著"
"こうちょう 公聴 高潮 腔腸 紅潮 高調 校長 好調"
"こうちょく 交直 硬直"
"こうちょくりゅう 交直流"
"こうちょくりょうようしゃ 交直両用車"
"こうちん 工賃"
"こうつ 刻子"
"こうつい 項対"
"こうつう 交通"
"こうつうし 交通史"
"こうつうはく 交通博"
"こうつうひ 交通費"
"こうつうほういはん 交通法違反"
"こうつうもう 交通網"
"こうつごう 好都合"
"こうづ 国府津"
"こうづき 香月 神月 上月"
"こうづけ 上野"
"こうづけのすけ 上野介"
"こうづしま 神津島"
"こうてい 航程 黄帝 鉤悌 高弟 皇弟 校訂 公邸 公定 校庭 行程 皇帝 高低 工程 肯定"
"こうていえき 口蹄疫"
"こうていてい 高低低"
"こうてき 好適 公的"
"こうてきしゅ 好敵手"
"こうてつ 更迭 鋼鉄"
"こうてん 光点 好点 後転 好天 荒天 公転 後天 好転 交点"
"こうでい 拘泥"
"こうでら 香寺"
"こうでん 香奠 香典 光電"
"こうでんかん 光電管"
"こうでんしゃ 高電社 弘電社"
"こうでんそくこう 光電測光"
"こうでんぱ 光電波"
"こうとう 好投 降等 公党 江東 喉頭 高騰 口答 後頭 恒等 高等 口頭"
"こうとうしゅ 好投手"
"こうとうだい 勾当台"
"こうとうむけい 荒唐無稽"
"こうとうよう 後頭葉"
"こうとく 光徳 行徳 公徳 神徳"
"こうとくせん 高徳線"
"こうとりい 公取委"
"こうど 硬度 光度 高度"
"こうどう 孝道 香道 皇道 黄道 坑道 公道 講堂 行動"
"こうどうしょく 行動食"
"こうどうでえた 行動データ"
"こうどく 鉱毒 購読 講読"
"こうどくりつちょうさ 購読率調査"
"こうどけい 高度計 好時計"
"こうない 坑内 港内 構内 校内"
"こうないえん 口内炎"
"こうなん 香南 硬軟 江南 港南 甲南"
"こうなんてつどう 興南鉄道"
"こうに 高２"
"こうにちうんどう 抗日運動"
"こうにちえいが 抗日映画"
"こうにゅう 購入"
"こうにゅううかがい 購入伺い"
"こうにゅうがく 購入額"
"こうにゅうしゃがわふたん 購入者側負担"
"こうにゅうずみ 購入済"
"こうにゅうひ 購入費"
"こうにゅうもうしこみ 購入申込み"
"こうにん 公認 後任"
"こうねつ 高熱 光熱"
"こうねつすいりょう 光熱水料"
"こうねつひ 光熱費"
"こうねん 高年 光年 降年 後年"
"こうねんき 更年期"
"こうねんぼう 高年俸"
"こうの 香野 甲野 河野"
"こうのう 効能"
"こうのし 交野市"
"こうのす 鴻巣"
"こうのすけ 幸之助"
"こうのとり 鸛"
"こうは 光波 硬派"
"こうはい 後背 興廃 高配 交配 荒廃 後輩"
"こうはく 赤白 紅白 工博"
"こうはくうたがっせん 紅白歌合戦"
"こうはた 光畑"
"こうはつ 好発 後発"
"こうはません 興浜線"
"こうはまみなみせん 興浜南線"
"こうはら 香原"
"こうはん 撹拌 鋼鈑 孔版 公判 広範 広汎 後半"
"こうはんいん 甲板員"
"こうはんせん 後半戦"
"こうはんそうこう 降坂走行"
"こうば 工場"
"こうばい 紅梅 公売 勾配 購買 公倍"
"こうばいよく 購買欲"
"こうばく 広漠 宏漠"
"こうばたい 好馬体"
"こうばん 降番 工番 鋼板 降板 甲板 項番 交番"
"こうばんげき 降番劇"
"こうひ 黄扉 侯妃 工費 向日 公比 高飛 公費 校費"
"こうひつ 硬筆"
"こうひょう 公評 講評 好評 公表"
"こうひょうげん 項表現"
"こうひん 公賓"
"こうび 後備 交尾 後尾"
"こうびしゃ 後尾車"
"こうびん 後便"
"こうふ 鉱夫 工夫 坑夫 江府 公布 交付 甲府"
"こうふう 校風"
"こうふく 降服 降伏 幸福"
"こうふくしこうふたん 高福祉高負担"
"こうふくじ 洪福寺"
"こうふちょう 好不調"
"こうふみなみ 甲府南"
"こうふん 亢奮 亢憤 昂奮 口吻 公憤 興奮"
"こうふんぱたん 興奮パタン"
"こうぶ 後部"
"こうぶせき 後部席"
"こうぶつ 鉱物 好物"
"こうぶつゆ 鉱物油"
"こうぶん 構文"
"こうぶんき 構文木"
"こうぶんぎ 構文木"
"こうぶんしゃ 光文社"
"こうぶんしょ 公文書"
"こうぶんとう 構文糖"
"こうぶんどう 弘文堂"
"こうぶんぷ 項分布"
"こうへい 高平 恒平 工兵 耕平 康平 浩平 幸平 公平"
"こうへき 厚壁 後壁"
"こうへん 後篇 後編"
"こうへんきゅう 好返球"
"こうへんさいぼう 孔辺細胞"
"こうへんすうきごう 項変数記号"
"こうべ 首 頭 神戸"
"こうべきいと 神戸生絲"
"こうべだいこう 神戸大工"
"こうべつ 項別"
"こうべん 抗弁"
"こうほ 好捕 侯補 候補"
"こうほあん 候補案"
"こうほう 高峰 航法 廣報 公報 工法 後方 広報"
"こうほうし 公報紙 広報紙"
"こうほうしゃ 後方車"
"こうほく 江北 港北"
"こうほしゃ 候補車"
"こうほしゃあつめ 候補者集め"
"こうほしゃごと 候補者毎"
"こうほば 候補馬"
"こうほん 稿本 校本"
"こうぼ 酵母 公募"
"こうぼう 鉤芒 弘法 光芒 高望 工房 公房 好防 興亡 攻防"
"こうぼうき 興亡記"
"こうぼうせん 攻防戦"
"こうぼきん 酵母菌"
"こうぼく 香木 高木 公僕"
"こうま 子馬 仔馬 好摩"
"こうまい 高邁"
"こうまく 硬膜"
"こうまつがく 考末学"
"こうまん 高慢"
"こうみ 小海 香味"
"こうみつ 高密"
"こうみゃく 鉱脈"
"こうみょう 光明 功名 巧妙"
"こうみょうしん 功名心"
"こうみょうじ 弘明寺"
"こうみん 公民"
"こうみんけんうんどう 公民権運動"
"こうみんけんていし 公民権停止"
"こうむ 工務 公務"
"こうむら 甲村 高村"
"こうめ 小梅"
"こうめい 孝明 孔明 校名 公明 高名 工明"
"こうめいいけ 光明池"
"こうめいてい 孝明帝"
"こうめいとう 公明党"
"こうめん 後面"
"こうもう 咬耗 噛耗 鴻毛 紅毛 孔孟 膏盲"
"こうもく 綱目 項目"
"こうもくあん 項目案"
"こうもくごと 項目毎"
"こうもと 甲本 河本 孝本"
"こうもり 幸森 蝙蝠"
"こうもん 孔紋 黄門 閘門 粫門 後門 校門 肛門"
"こうや 紺屋 幸也 功也 曠野 狗也 高野 広野 荒野"
"こうやうち 高野内"
"こうやぎ 香焼"
"こうやく 膏薬 口約 公約"
"こうやぐち 高野口"
"こうやさん 高野山"
"こうやせん 交野線"
"こうやま 高山 光山"
"こうゆ 香油"
"こうゆう 校友 孔融 交遊 公有 交友"
"こうゆうしょう 交遊抄"
"こうよ 公誉"
"こうよう 宏陽 黄葉 綱要 甲陽 昂揚 広葉 光洋 江陽 後葉 公用 高揚 効用 紅葉"
"こうようじゅ 広葉樹"
"こうよく 高翼"
"こうら 甲良 甲羅"
"こうらい 高麗"
"こうらいしば 高麗芝"
"こうらく 後楽 攻落 行楽"
"こうらくきゃく 行楽客"
"こうらくしゃ 行楽車"
"こうらん 鉤欄 攪亂 撹亂 攪乱 香蘭 高覧"
"こうり 冰 小売り 公吏 小売 高利 功利 氷 公理"
"こうりえん 香里園"
"こうりがし 高利貸"
"こうりき 高力"
"こうりぎょう 小売業"
"こうりざとう 氷砂糖"
"こうりしょう 小売商"
"こうりつ 高率 公立 効率"
"こうりつよし 効率良"
"こうりね 小売値"
"こうりみず 氷水"
"こうりゃく 攻略 後略"
"こうりやま 郡山"
"こうりゅう 蛟龍 蛟竜 紅龍 後流 拘留 興隆 交流"
"こうりゅうかいせいしゃ 交流回生車"
"こうりゅうじ 広隆寺"
"こうりゅうじあい 交流試合"
"こうりゅうせん 交流戦"
"こうりょ 考慮"
"こうりょう 広陵 綱領 校了 香料 講料 衡量 稿料 光量 荒涼"
"こうりょく 抗力 効力"
"こうりん 光輪 降臨 光臨 後輪"
"こうりんくどうしゃ 後輪駆動車"
"こうりんじく 後輪軸"
"こうりんぼう 香林坊"
"こうれい 降霊 交霊 高齢 好例 恒例"
"こうれしゃふくし 高齢者福祉"
"こうれつ 項列 後列"
"こうれん 拘攣 鉤連"
"こうろ 鈩 香露 香炉 行路 高炉 航路"
"こうろう 絳蝋 高樓 高楼 功労"
"こうろうたて 功労盾"
"こうろく 公録"
"こうろん 公論 口論"
"こうろんおつばく 甲論乙駁"
"こうわ 高話 興和 講和 講話"
"こうわきのう 交話機能"
"こうわほう 口話法"
"こうわん 港湾"
"こえ 聲 肥 越 声"
"こえい 孤影"
"こえいもん 虎衛門"
"こえしつ 声質"
"こえじ 越路"
"こえずか 肥塚"
"こえだめ 肥だめ"
"こえづか 肥塚"
"こえんゆう 小円遊"
"こおう 呼応"
"こおどり 小躍り"
"こおに 小鬼"
"こおり 桑折 冰 郡 氷"
"こおりざとう 氷砂糖"
"こおりだ 凍田"
"こおりやま 郡山"
"こおろぎ 蟋蟀 蛩"
"こか 瓠果 古歌 固化"
"こかいいん 子会員"
"こかいがわ 小貝川"
"こかく 顧客"
"こかげ 木陰"
"こかじ 小鍛治"
"こかつ 涸渇 枯渇"
"こかわ 胡川 粉河"
"こかん 股間"
"こかんきょう 古環境"
"こかんせつ 股関節"
"こが 古河 古賀"
"こがい 個飼い 小粥 庫外 戸外"
"こがいしゃ 小会社 子会社"
"こがく 古楽"
"こがた 小形 小型"
"こがたしゃ 小型車"
"こがたな 小刀"
"こがっき 子楽器 古楽器"
"こがね 小金 黄金"
"こがねい 小金井"
"こがねはら 小金原"
"こがねまる 小金丸"
"こがめ 子亀"
"こがら 小柄"
"こがらし 凩 木枯 木枯し"
"こがわ 古川"
"こがわせ 小為替"
"こがん 湖岸"
"こき 子機 子器 呼気 古希"
"こきお 古希男"
"こきざみ 小刻み"
"こきたない 小汚い"
"こきのう 子機能"
"こきみ 小気味"
"こきゃく 顧客"
"こきゅう 胡弓 固給 呼吸"
"こきゅうこん 呼吸根"
"こきょう 故郷"
"こきろく 古記録"
"こきん 古今"
"こぎって 小切手"
"こぎて 漕ぎ手"
"こぎれい 小綺麗"
"こく 石 棘 釛 轂 槲 梏 斛 尅 國 圀 哭 剋 谷 詰 穀 克 鵠 黒 酷 告 刻 国"
"こくい 黒衣 国威"
"こくいっこく 刻一刻"
"こくいん 刻印"
"こくう 虚空 穀雨"
"こくうん 黒雲 国運"
"こくえい 国営"
"こくえき 国益"
"こくえん 黒煙 黒鉛"
"こくおう 国王"
"こくかんこんよう 国漢混用"
"こくがい 国外"
"こくがいさん 国外産"
"こくがいしゃ 国外車"
"こくがく 國學"
"こくがくいん 國學院 国学院"
"こくがくしゃ 国学者"
"こくぎ 国議 国技"
"こくけん 国研"
"こくけんばん 黒鍵盤"
"こくげん 刻限"
"こくこ 国庫"
"こくこうしりつ 国公私立"
"こくこうりつ 国公立"
"こくこく 刻刻 刻々"
"こくご 国語"
"こくごう 国号"
"こくさい 國際 国債 国際"
"こくさいきかくあん 国際規格案"
"こくさいきょうぎょう 国際興業"
"こくさいこうき 国際光器"
"こくさいつうこうぜい 国際通行税"
"こくさく 国策"
"こくさん 国産"
"こくさんしゃ 国産車"
"こくさんはつ 国産初"
"こくさんまい 国産米"
"こくし 国史 国試 国士 酷使"
"こくしかん 国士舘"
"こくしびょう 黒死病"
"こくしょ 酷暑 国書"
"こくしょう 國生 国生"
"こくしょく 黒色"
"こくしょくしゅ 黒色腫"
"こくじ 刻時 国璽 国字 国事 酷似 告示"
"こくじょう 国情"
"こくじょく 国辱"
"こくじん 黒人"
"こくすい 国粋"
"こくせい 国勢 国政"
"こくせき 国籍"
"こくせつ 国設"
"こくせん 国選"
"こくぜ 国是"
"こくぜい 国税"
"こくぜいちょう 国税庁"
"こくそ 告訴"
"こくそう 穀倉"
"こくぞく 国賊"
"こくた 穀田"
"こくたい 國軆 国体"
"こくたいふくしゃ 黒体輻射"
"こくたいほうしゃ 黒体放射"
"こくたん 黒檀"
"こくだい 国大"
"こくち 告知"
"こくちょう 国鳥"
"こくてい 国定"
"こくてつ 国鉄"
"こくてつし 国鉄史"
"こくてん 黒点"
"こくでん 国電"
"こくとうげんまい 黒糖玄米"
"こくど 国土"
"こくどう 国道"
"こくどうぞい 国道沿"
"こくどしゃ 国土舎"
"こくどちょう 国土庁"
"こくない 国内"
"こくないさん 国内産"
"こくないせんのりつぎ 国内線乗継ぎ"
"こくないむけ 国内向"
"こくなん 国難"
"こくね 古久根"
"こくはく 穀帛 酷薄 告白"
"こくはつ 告発"
"こくばん 黒板"
"こくひ 国費"
"こくひょう 酷評"
"こくひん 国賓"
"こくびゃく 黒白"
"こくふ 国府"
"こくふく 克服"
"こくふだ 国府田"
"こくぶ 国府 国分"
"こくぶん 国文 国分"
"こくぶんじ 国分寺"
"こくぶんぽう 国文法"
"こくへん 黒変"
"こくべつ 告別"
"こくほ 国保"
"こくほう 國寶 国宝"
"こくぼ 小久保"
"こくぼう 国防"
"こくぼうぐん 国防軍"
"こくぼうしょう 国防省"
"こくぼうそうしょう 国防総省"
"こくぼうひさくげん 国防費削減"
"こくみん 国民"
"こくみんしゃこうそう 国民車構想"
"こくみんちょうようれい 国民徴用令"
"こくみんとう 国民党"
"こくむ 国務"
"こくむいん 国務院"
"こくむしょう 国務省"
"こくめい 国名 克明"
"こくもつ 穀物"
"こくやく 国躍"
"こくゆう 国有"
"こくゆうりん 国有林"
"こくようせき 黒曜石 黒燿石"
"こくら 小倉"
"こくらきた 小倉北"
"こくらみなみ 小倉南"
"こくりつ 国立"
"こくりつじゅんかんきびょう 国立循環器病"
"こくりゅう 黒龍 黒竜"
"こくりょう 国領"
"こくりょく 国力"
"こくるい 穀類"
"こくれん 國聯 国連"
"こくれんき 国連旗"
"こくれんぐん 国連軍"
"こくろう 国労"
"こぐし 小串"
"こぐち 木口 小口"
"こぐちはいそうぎょう 小口配送業"
"こぐま 小熊"
"こぐれ 小暮"
"こぐんふんとう 孤軍奮闘"
"こけ 苔"
"こけい 固型 固形"
"こけつ 纐纈 固結 虎穴"
"こけら 柿"
"こけらおとし 柿落し"
"こけん 狐拳 沽券 估券"
"こげちゃ 焦茶"
"こげちゃいろ 焦げ茶色"
"こげつ 鼓月 湖月 木月"
"こげつき 焦げ付き"
"こげんた 子源太"
"ここ 爰 此処 個々"
"ここあ ココア"
"ここう 股肱 餬口 孤高"
"ここく 故国"
"ここじん 個個人"
"ここち 心地"
"ここちよし 心地好"
"ここに 此処に 個々に"
"ここの 九"
"ここのえ 九重"
"ここのえほんぽたまざわ 九重本舗玉澤"
"ここのつ 九つ"
"ここらへん ここら辺"
"こころ 心"
"こころあたり 心当り"
"こころいき 心意気"
"こころえ 心得"
"こころおち 心落ち"
"こころから 心から"
"こころがけ 心掛け"
"こころがまえ 心構え"
"こころくばり 心配り"
"こころざし 志"
"こころづかい 心遣い"
"こころづくし 心尽し 心尽くし"
"こころづけ 心付け"
"こころづもり 心積もり"
"こころなし 心無"
"こころのこり 心残り"
"こころまち 心待ち"
"こころみ 試 試み"
"ここん 古今"
"ここんてい 古今亭"
"こご 古語"
"こごえ 小声"
"こごしょう 子児姓"
"こごた 小牛田"
"こごと 小言"
"こさい 湖西"
"こさか 小坂"
"こさかい 小堺"
"こさかた 小坂田"
"こさく 小作"
"こささ 小笹"
"こさざ 小佐々"
"こさじやまもり 小匙山盛り 小匙山盛"
"こさつ 古刹"
"こさはら 古佐原"
"こさめ 小雨"
"こさん 古参"
"こさんじ 小三治"
"こさんば 小三馬"
"こざ 古座"
"こざいく 小細工"
"こざかい 小坂井"
"こざかいなだ 小境灘"
"こざかな 小魚"
"こざき 駒崎"
"こざさ 小笹"
"こざしき 跨座式"
"こざわ 涸沢"
"こし 古紙 輿 枯死 古志 虎視 越 腰"
"こしお 小潮"
"こしかけ 腰掛 腰掛け"
"こしかた 来し方"
"こしかわ 越川"
"こしが 越賀"
"こしがみ 漉紙"
"こしがや 越谷"
"こしき 古式 甑"
"こしきり 越桐"
"こしこでん 古史古伝"
"こしじ 越路"
"こしじそう 越路荘"
"こしだ 越田"
"こしだか 腰高"
"こしつ 痼疾 固執 個室"
"こしづか 越塚"
"こしなか 越中"
"こしなげ 腰投げ"
"こしぬけ 腰抜け"
"こしの 越廼"
"こしのかんばい 越乃寒梅"
"こしば 小柴"
"こしぼね 腰骨"
"こしまき 腰巻"
"こしみず 小清水 輿水"
"こしみはる 越美晴"
"こしむら 越村"
"こしもと 越元 腰元"
"こしゃく 小癪"
"こしやまそう 越山荘"
"こしゅ 鼓手 古酒 戸主 固守"
"こしゅう 個集 固執"
"こしゅつ 庫出"
"こしょ 古書"
"こしょう 壺漿 壷漿 小性 楜 小姓 胡椒 呼称 湖沼 故障"
"こしょうか コショウ科"
"こしょうぎ 小将棋"
"こしょうしゃ 故障車"
"こしょうもく コショウ目"
"こしょく 古色"
"こしょてん 古書展"
"こしょり 呼処理"
"こしろ 小代 古代"
"こじ 居士 古字 弧児 固辞 固持 古寺 孤児 故事 誇示"
"こじか 小鹿 子鹿"
"こじき 古事記 乞食"
"こじだい 子時代"
"こじつ 故実"
"こじま 古島 戸島 小嶋 児島 小島"
"こじまわん 児島湾"
"こじゅう 扈従"
"こじゅうと 小舅 小姑"
"こじょう 湖上 古城"
"こじょうれんけつ 弧状連結"
"こじり 鐺"
"こじろう 小次郎"
"こじわ 小じわ"
"こじん 古人 故人 個人"
"こじんあて 個人宛"
"こじんい 個人医"
"こじんおいぬき 個人追抜"
"こじんきゃく 個人客"
"こじんぎしゅうだん 個人技集団"
"こじんこじん 個人々々"
"こじんごと 個人毎"
"こじんせつ 古人説"
"こじんせん 個人戦"
"こじんたいしゅうだん 個人対集団"
"こじんたく 個人宅"
"こじんてきな 個人的な"
"こじんめいる 個人メール"
"こじんより 個人寄"
"こじんわざ 個人技"
"こすい 鼓吹 湖水"
"こすう 戸数 個数"
"こすぎ 小杉"
"こすけがわ 小助川"
"こすげ 小菅"
"こすだ 小須田"
"こすと コスト"
"こすど 小須戸"
"こすみ 小角"
"こすも コスモ"
"こすもす 秋桜"
"こずえ 梢"
"こせ 小瀬"
"こせい 古生 個性"
"こせいせん 湖西線"
"こせがれ 小悴"
"こせき 古関 古跡 小関 戸籍"
"こせつてん 子節点"
"こせん 古銭"
"こせんきょう 跨線橋"
"こせんじょう 古戦場"
"こぜに 小銭"
"こぜりあい 小競合"
"こそく 姑息"
"こそし 古曽志"
"こそだて 子育て"
"こぞう 子象 小僧 小憎"
"こぞって 挙って"
"こぞの 小園"
"こたい 固態 鼓隊 固体 個体"
"こたえ 答え 答"
"こたか 小高"
"こたけ 小竹"
"こたち 子達"
"こたつ 炬燵"
"こたに 小谷"
"こたび 此度"
"こたろう 虎太郎 小太郎"
"こたん 枯淡 古淡"
"こだい 誇大 古代"
"こだいこ 小太鼓"
"こだいし 古代史"
"こだいぞめ 古代染"
"こだいへん 古代篇"
"こだいら 小平"
"こだか 小高"
"こだし 小出し"
"こだち 小太刀 木立"
"こだつの 小立野"
"こだぬき 子狸"
"こだま 兒玉 谺 小玉 木霊 児玉"
"こだわり 拘泥り 拘泥"
"こち 東風 鯒 乞 故知"
"こちゃく 固着"
"こちょう 蝴蝶 胡蝶 誇張"
"こちら 此方"
"こちり 古地理"
"こっ 国"
"こっか 黒化 國家 国花 国歌 』 ］ 国家 ） 】"
"こっかい 告解 黒海 国会"
"こっかく 骨格"
"こっかくきん 骨格筋"
"こっかたいこっか 国家対国家"
"こっかん 骨幹 酷寒"
"こっき 克己 黒旗 国旗"
"こっきしん 克己心"
"こっきゅう 黒球"
"こっきょう 国境"
"こっきょうがっさく 国共合作"
"こっきょうないせん 国共内戦"
"こっくぴっと コックピット"
"こっけい 滑稽"
"こっけん 国憲 黒鍵 国権"
"こっこ 国庫"
"こっこう 国光 国交"
"こっこうりつ 国公立"
"こっこく 刻々"
"こっし 骨子"
"こっせつ 骨折"
"こっそうがく 骨相学"
"こっちょう 骨頂"
"こっとう 骨董"
"こっとうてきかち 骨董的価値"
"こっぱ 木っ端 木端 木ッ端"
"こっぷ コップ"
"こつ 榾 兀 コツ 笏 乞 忽 惚 骨"
"こつえん 忽焉"
"こつがら 骨柄"
"こつくり 木造"
"こつじょう 骨状"
"こつずい 骨髄"
"こつぜん 忽然"
"こつぜんと 忽然と"
"こつそしょうしょう 骨粗鬚症 骨粗鬆症"
"こつづみ 小鼓"
"こつにく 骨肉"
"こつばん 骨盤"
"こつぶ 小粒"
"こつまくえん 骨膜炎"
"こつるせん 小鶴線"
"こづか 小塚"
"こづかい 小遣い"
"こづつみ 小包"
"こづる 小鶴"
"こづれ 子連れ"
"こて 籠手 鐺 鏝 小手"
"こてい 湖底 固定"
"こていきゅう 固定給"
"こていぐ 固定具"
"こていしさんぜい 固定資産税"
"こていじゅうざ 固定銃座"
"こていたん 固定端"
"こていひ 固定費"
"こていまど 固定窓"
"こてがわ 古手川"
"こてき 鼓笛"
"こてさし 小手指"
"こてつ 小鉄"
"こてなげ 小手投げ"
"こてわざ 小手技"
"こてん 個展 古典"
"こでら 小寺"
"こと 糊塗 亊 殊 古都 異 言 琴 事"
"こといみ 言忌み"
"ことう 厚東 湖東 小藤 孤島"
"ことえり 言選り"
"ことかぜごうき 琴風豪規"
"ことがうめ 琴ヶ梅"
"ことがら 事柄"
"ことこまか 事細か"
"ことごと 事々"
"ことごとく 尽く 悉く"
"ことさら 殊更"
"ことし 今年"
"ことしあき 今年秋"
"ことしくれ 今年暮"
"ことしすえ 今年末"
"ことしぢゅう 今年中"
"ことしなついこう 今年夏以降"
"ことしはつ 今年初"
"ことしはる 今年春"
"ことじたい 事自体"
"ことづけ 事付 言付け"
"ことづて 言傳て"
"ことてんざん 琴天山"
"ことでん 琴電"
"こととい 言問"
"ことなし 事無"
"ことなる 異なる"
"ことに 琴似 殊に"
"ことにしき 琴錦"
"ことね 琴音"
"ことの 琴野 琴乃"
"ことのついで 事の序"
"ことのは 言の葉"
"ことのほか 殊の外"
"ことはじめ 事始め"
"ことば 詞 言葉"
"ことばかず 言葉数"
"ことばじり 言葉尻"
"ことばづかい 言葉遣い"
"ことひら 琴平"
"ことひらはつおかやまいき 琴平発岡山行"
"ことひらはつおかやまゆき 琴平発岡山行"
"ことふじ 琴富士"
"ことぶき 壽 寿"
"ことぶきそう 寿荘"
"ことぶきや 寿屋 壽屋"
"ことべっぷ 琴別府"
"ことほどさように 事程左様に"
"ことみ 琴美"
"ことり 小鳥"
"ことわざ 諺"
"ことわり 理"
"こどう 鼓動"
"こどうぐ 小道具"
"こどく 蠱毒 孤独"
"こどほう 弧度法"
"こどまり 小泊"
"こども 子ども 小人 子供"
"こどもごころ 子供心"
"こどもずき 子供好き"
"こどもなみ 子供並"
"こな 紛 粉"
"こない 庫内 来ない"
"こなか 小中"
"こなかい 小仲井"
"こなかだい 小仲台"
"こなから 二合半"
"こながい 小長井"
"こなきじじい 子泣爺"
"こなぐすり 粉薬"
"こなごな 紛々 粉々"
"こなじょう 粉状"
"こなせっけん 粉せっけん"
"こなつ 小夏"
"こなふき 粉吹き"
"こなみ 小波"
"こなみじん 粉微塵"
"こなや 粉屋"
"こなゆき 粉雪"
"こならい 小習"
"こなんきせん 湖南汽船"
"こにし 小西"
"こにしき 小錦"
"こにしろく 小西六"
"こにもつ 小荷物"
"こにんずう 小人数"
"こぬき 小貫"
"こぬま 小沼"
"こね コネ"
"こねこ 仔猫 小猫 子猫"
"この 斯の 此 此の"
"このあいだ この間"
"このうら 金浦"
"このえ 近衛"
"このえちょう 近江町"
"このかた 此方"
"このかん この間"
"このころ この頃"
"このご 此期"
"このごろ 此頃 この頃"
"このしゅ この種"
"このしろ 鮗"
"このたび 此度 この度"
"このとき この時"
"このは 木の葉"
"このはな 此花"
"このへん 此邊"
"このまえ この前"
"このみ 好 木實 この身 木の実 好み"
"このみち 此路"
"このよ この世"
"このわた 海鼠腸"
"このんで 好んで"
"こはぎ 小萩"
"こはく 琥珀"
"こはぜ 鞐"
"こはた 小幡 木幡 古畑 戸畑"
"こはば 小幅"
"こはま 小濱"
"こはまおんせんえき 小浜温泉駅"
"こはまけいゆ 小浜経由"
"こはまちょう 小浜町"
"こはら 小原"
"こはり 小針"
"こはる 小春"
"こはん 湖畔"
"こば 古場 木場 古葉 古馬"
"こばい 故買"
"こばか 小馬鹿"
"こばし 小橋"
"こばた 小幡"
"こばたけ 小畑"
"こばち 小鉢"
"こばな 小鼻"
"こばなし 小噺 小話"
"こばなれ 子離れ"
"こばやかわ 小早川"
"こばやし 古林 小林"
"こばやしあきら 小林旭"
"こばると コバルト"
"こばん 小判"
"こばんごう 子番号"
"こばんざめ コバンザメ"
"こひつじ 小羊 子羊"
"こひとり 子一人"
"こひなた 小日向"
"こひやま 小桧山"
"こひょう 小兵"
"こひるいまき 小比類巻"
"こび 媚 媚び"
"こびき 木挽"
"こびと 小人"
"こびん 小壜 小瓶"
"こぴー コピー"
"こふう 古風"
"こふくげきじょう 鼓腹撃壤"
"こふじ 小藤"
"こふみ 湖吹美"
"こふん 古墳"
"こぶ 瘤 鼓舞"
"こぶし 辛夷 舉 擧 拳"
"こぶた 子豚"
"こぶちざわ 小淵沢"
"こぶつしょう 故物商 古物商"
"こぶどう 古武道"
"こぶね 小舟"
"こぶへい こぶ平"
"こぶり 小降り"
"こぶん 子分 古文"
"こぶんけん 古文献"
"こへい 雇兵"
"こべ 小部"
"こべつ 戸別 個別"
"こほく 湖北"
"こほり 氷"
"こぼけ 小歩危"
"こぼり 古保里 小堀"
"こぼりじゅうけん 小堀住研"
"こま 小間 齣 独楽 コマ 狛 細 駒"
"こまーしゃる コマーシャル"
"こまあらし 駒嵐"
"こまい 駒井"
"こまいずみ 駒泉"
"こまいぬ 狛犬 狛"
"こまえ 小前 狛江 駒枝"
"こまおくり 駒送り コマ送り"
"こまおと 駒音"
"こまおとし 齣落"
"こまか 細か"
"こまがた 駒形"
"こまがだけ 駒ヶ岳"
"こまがね 駒ヶ根"
"こまがみね 駒ヶ峯"
"こまがわなかの 駒川中野"
"こまき 駒木 小牧"
"こまぎれ 細切れ"
"こまく 鼓膜"
"こまぐみ 駒組み"
"こまごま 細々"
"こまごめ 駒込"
"こまさい 駒祭"
"こまざき 駒崎"
"こまざわ 駒沢"
"こませ 駒瀬"
"こまた 小俣"
"こまたすくい 小股掬い"
"こまたんい 駒単位"
"こまだ 駒田"
"こまだい 駒台 駒大"
"こまち 小町"
"こまちや 小町谷"
"こまつ コマツ 小松"
"こまつざき 小松崎"
"こまつしま 小松島"
"こまつだ 小松田"
"こまつな 小松菜"
"こまつばら 小松原"
"こまど 小窓"
"こまどく 駒得"
"こまば 駒場"
"こまばさい 駒場祭"
"こまばりょう 駒場寮"
"こまみや 駒宮"
"こまむら 駒村"
"こまめ 細目"
"こまりょう 駒寮"
"こまる 小丸"
"こまわり 小回り"
"こまんど コマンド"
"こみ 込み 込"
"こみかた 混み方"
"こみけ コミケ"
"こみだし 小見出し"
"こみち 子径 小径 蹊 徑 径 小路 小道"
"こみちしょぼう 径書房"
"こみっく コミック"
"こみっと コミット"
"こみなとてつどう 小湊鉄道"
"こみね 小峯 小峰"
"こみみ 小耳"
"こみや 小宮"
"こみやま 込山"
"こみゅにけーしょん コミュニケーション"
"こむ 込"
"こむかい 小向"
"こむぎ 小麦"
"こむぎこ 小麦粉"
"こむすび 小結"
"こむすめ 小娘"
"こむそう 虚無僧"
"こむた 小牟田"
"こむら 腓 小村 古村"
"こむらがえり 腓返り"
"こむろ 小室"
"こめ 個目 ※ 米"
"こめあぶら 米油"
"こめいじ 古明地"
"こめがふくろ 米ヶ袋"
"こめこうじ 米麹"
"こめこめ 米米"
"こめじるし ※"
"こめそうば 米相場"
"こめたに 米谷"
"こめだ 米田"
"こめだわら 米俵"
"こめつき 米搗き"
"こめつぶ 米粒"
"こめでぃー コメディー"
"こめでぃあん コメディアン"
"こめどころ 米所"
"こめぬか 米糠"
"こめの 米野"
"こめひょう 米兵"
"こめびつ 米櫃"
"こめぶくろ 米袋"
"こめや 米屋"
"こめん 湖面"
"こめんと コメント"
"こも 薦 菰"
"こもごも 交 交々"
"こもじ 小文字"
"こもだ 小茂田 菰田"
"こもち 子持 子持ち"
"こもどし 小戻し"
"こもどり 小戻り"
"こもの 菰野 薦野 小物"
"こものいれ 小物入"
"こもり 子守 小森 古森 子守り"
"こもりうた 子守歌 子守唄"
"こもりや 小森谷"
"こもりやく 子守役"
"こもれび 木洩日 木洩れ日"
"こもろ 小諸"
"こもん 小紋 古文 顧問"
"こもんじょ 古文書"
"こや 小屋"
"こやぎ 子山羊"
"こやく 子役"
"こやぐち 小屋口"
"こやし 肥やし"
"こやす 子安"
"こやだいら 小屋平"
"こやち 小谷内"
"こやづ 小谷津"
"こやなぎ 小柳"
"こやなぎるみこ 小柳ルミ子"
"こやの 小谷野"
"こやま 古山 湖山 小山"
"こゆ 児湯"
"こゆう 個有 固有"
"こゆうしんけいしつ 固有新形質"
"こゆき 小雪"
"こゆび 小指"
"こよい 今宵"
"こよう 雇傭 雇用"
"こようたい 固溶体"
"こよみ 暦"
"こら 児等 子等"
"こらい 古来"
"こらむ コラム"
"こり 狐狸"
"こりー コリー"
"こりつ 孤立"
"こりょ 顧慮"
"こりょう 湖陵"
"こりょうり 小料理"
"これ 旃 斯れ 之 惟 是 此"
"これいじょう これ以上"
"これお 是雄"
"これかた 是方"
"これくしょん コレクション"
"これさだ 是定"
"これしき 是しき"
"これだけ 是だけ"
"これとう 惟任"
"こればかり 是許"
"これほど 是程"
"これまで 是迄"
"これら コレラ"
"ころ 転 頃"
"ころあい 頃合"
"ころう 虎狼 固陋"
"ころし 殺し"
"ころな コロナ"
"ころも 衣"
"ころもがえ 衣更え"
"ころもがわ 頃川"
"ころんびあ 哥倫比亞"
"こわ 声 聲"
"こわいろ 聲色 声色"
"こわき 小脇"
"こわきえん 小湧園"
"こわきえんまえ 小涌園前"
"こわく 蠱惑"
"こわけ 小分け"
"こわざ 小技"
"こわだ 古和田"
"こわだか 聲高 声高"
"こわだんぱん 強談判"
"こわっぱ 小童"
"こわね 聲音 声音"
"こわもて 強面"
"こわれもの 壊れ物"
"こゑ 聲"
"こん 鶤 鯤 鯀 跟 袞 蒟 菎 琿 獻 狠 滾 溷 渾 棍 悃 很 崑 壼 献 近 コン 坤 墾 困 梱 昏 恨 琴 艮 昆 懇 婚 痕 紺 魂 金 根 混 今"
"こんい 懇意"
"こんいろ 紺色"
"こんいん 婚姻"
"こんいんとどけ 婚姻届"
"こんか 婚家 今夏"
"こんかい 今回"
"こんかいはつ 今回初"
"こんかん 根冠 根幹"
"こんが 混芽"
"こんがいこうしょう 婚外交渉"
"こんがん 懇願"
"こんき 今季 婚期 今期 根気"
"こんきはつしゅい 今季初首位"
"こんきまつ 今季末"
"こんきゃく 困却"
"こんきゅう 困窮"
"こんきょ 根拠"
"こんぎ 婚儀"
"こんく 困苦"
"こんくーる コンクール"
"こんくらべ 根競べ"
"こんくりーと コンクリート"
"こんけい 根系 根茎"
"こんけつ 混結 混血"
"こんげつ 今月"
"こんげつすえ 今月末"
"こんげん 根元 根源"
"こんこう 金光 渾淆 混淆 混交"
"こんこん 渾渾 昏昏 滾滾 懇々"
"こんご 今後"
"こんごう 今号 根号 金剛 混合"
"こんごういん 金剛院"
"こんごうえき 混合液"
"こんごうき 混合気"
"こんごうざわ 金剛沢"
"こんごうしゃ 金剛砂"
"こんごうじ 金剛寺"
"こんごうせき 金剛石"
"こんごうせん 混合戦"
"こんごうづえ 金剛杖"
"こんごうりき 金剛力"
"こんごうりゅう 金剛流"
"こんごとも 今後共"
"こんさーと コンサート"
"こんさい 混載 根菜"
"こんさるたんと コンサルタント"
"こんさるてぃんぐ コンサルティング"
"こんざい 混在"
"こんざつ 混雑"
"こんしゅう 今秋 今週"
"こんしゅうまつごろ 今週末頃"
"こんしゅん 今春"
"こんしょう 混晶"
"こんしょく 混色 混織"
"こんしょくこう 混色光"
"こんしろ 紺白"
"こんしん 根針 渾心 混信 渾身 懇親"
"こんじ 根治 恨事 今次 今時"
"こんじき 金色"
"こんじきどう 金色堂"
"こんじゃく 今昔"
"こんじょう 紺青 懇情 今生 根性"
"こんじょうなし 根性無"
"こんじょうもの 根性物"
"こんじょうよう 根状葉"
"こんじょうわる 根性悪"
"こんすい 昏睡"
"こんすたんちのーぷる 君府"
"こんせい 金精 懇請 混声 混成"
"こんせき 今夕 痕跡"
"こんせつ 今節 懇切"
"こんせぷと コンセプト"
"こんせん 混戦 混線"
"こんせんさす コンセンサス"
"こんせんとぴっくす コンセントピックス"
"こんぜつ 根絶"
"こんぜん 渾然 混然 婚前"
"こんぜんせい 婚前姓"
"こんそーしあむ コンソーシアム"
"こんそう 混走"
"こんたくと コンタクト"
"こんたん 根端 魂胆"
"こんだ 今田 金田"
"こんだく 混濁"
"こんだて 献立"
"こんだん 懇談"
"こんち 根治"
"こんちゃ 紺茶"
"こんちゅう 昆蟲 昆虫"
"こんちゅうき 昆虫記"
"こんちゅうしょく 昆虫食"
"こんちゅうもう 昆虫網"
"こんちょう 今朝"
"こんてい 根底"
"こんてくすと コンテクスト"
"こんてな コンテナ"
"こんてんつ コンテンツ"
"こんでぃしょん コンディション"
"こんでんさ コンデンサ"
"こんとう 昏倒 今冬"
"こんとら コントラ"
"こんとろーる コントロール"
"こんとん 渾沌 混沌"
"こんど 今度"
"こんどう 金藤 金堂 近藤 混同"
"こんなん 困難"
"こんにち 今日"
"こんにちは 今日は"
"こんにゃく 蒟蒻 菎蒻"
"こんにゅう 混入"
"こんねん 今年"
"こんの 金野 紺野 昆野 今野"
"こんばーと コンバート"
"こんばい 困憊"
"こんばん 今晩"
"こんばんは 今晩は"
"こんぱ コンパ"
"こんぱい 困憊"
"こんぱいら コンパイラ"
"こんぱいる コンパイル"
"こんぱく 魂魄"
"こんぱくと コンパクト"
"こんぱち コンパチ"
"こんぱにおん コンパニオン"
"こんぱん 今般"
"こんひ 根被"
"こんび コンビ"
"こんびなーと コンビナート"
"こんびにえんす コンビニエンス"
"こんびねーしょん コンビネーション"
"こんぴゅーた コンピュータ"
"こんぴゅーたー コンピューター"
"こんぴら 金比羅"
"こんぴらづけ 今平積"
"こんぶ 昆布"
"こんぷれっくす コンプレックス"
"こんへんちょう 混変調"
"こんぺき 紺碧"
"こんぼう 棍棒 混紡 懇望 こん棒"
"こんぽーねんと コンポーネント"
"こんぽう 梱包"
"こんぽうざい 梱包材"
"こんぽうひ 梱包費"
"こんぽん 根本"
"こんま ， コンマ"
"こんめい 昏迷 昆明 混迷"
"こんもう 根毛 懇望"
"こんや 紺屋 今夜"
"こんやく 婚約"
"こんよう 混用"
"こんよく 混浴"
"こんらん 混乱"
"こんりゅう 根瘤 根粒 建立"
"こんりんざい 金輪際"
"こんれい 婚礼"
"こんろ 焜炉 コンロ"
"こんろん 崑崙 崑崘 昆倫"
"こんわ 混和 懇話"
"こんわく 困惑"
"こんわくがお 困惑顔"
"ご 期 冴 胡 炬 壷 壺 子 齬 蜈 茣 篌 珸 牾 沍 晤 忤 寤 唔 兒 5 宕 庫 ５ 伍 児 呉 梧 瑚 娯 互 醐 檎 午 悟 碁 吾 五 護 誤 御 語 後"
"ごーすと ゴースト"
"ごーる ゴール"
"ごあいこ ご愛顧"
"ごあいさつ ご挨拶"
"ごあいよう ご愛用"
"ごあんない ご案内"
"ごい 戀 伍井 語意 恋 五位 五井 語彙"
"ごいけんやく 御意見役"
"ごいし 碁石"
"ごいそ 語彙素"
"ごいっしょ 脚一緒 ご一緒"
"ごいっとうさま 御一統様"
"ごいらい ご依頼"
"ごう 鼇 遨 軣 號 盒 熬 毫 敖 囂 嗷 哈 刧 噛 業 傲 劫 壕 拷 濠 轟 剛 郷 強 豪 合 号"
"ごうい 合意"
"ごういあん 合意案"
"ごういん 強引"
"ごうう 豪雨"
"ごうおん 号音 轟音"
"ごうか 業火 劫火 豪華"
"ごうかい 豪快"
"ごうかく 合格"
"ごうかくいん 合格印"
"ごうかせん 豪華船"
"ごうかん 強姦 号館"
"ごうかんざい 強姦罪"
"ごうかんま 強姦魔"
"ごうがい 號外 号外"
"ごうがしゃ 恒河沙"
"ごうき 豪鬼 豪気 豪毅 剛己 剛気 剛毅 号機"
"ごうきゅう 号泣"
"ごうきん 合金"
"ごうぎ 豪儀 合議"
"ごうく 合区"
"ごうけい 合計"
"ごうけいがく 合計額"
"ごうけつ 豪傑"
"ごうけつじ 豪血寺"
"ごうけん 剛堅 剛健 合憲"
"ごうげい 傲睨"
"ごうげつ 法月"
"ごうこん 合コン"
"ごうご 傲語 豪語"
"ごうごう 轟々 囂囂"
"ごうし 合祀 合志 合資 郷士"
"ごうしつ 号室"
"ごうしゃ 豪奢 号車"
"ごうしゅう 豪州"
"ごうしゅうさん 豪州産"
"ごうしょう 合焦 豪商 号証"
"ごうじ 合字"
"ごうじょう 強情"
"ごうすう 号数"
"ごうせい 豪盛 合生 剛性 合性 豪勢 合成"
"ごうせいかわ 合成革"
"ごうせいゆ 合成油"
"ごうせつ 豪雪"
"ごうせん 合繊 合線 号線"
"ごうぜん 傲然 轟然"
"ごうそ 強訴"
"ごうそっきゅう 剛速球"
"ごうそっきゅうとうしゅ 豪速球投手"
"ごうぞく 豪族"
"ごうた 剛太"
"ごうたい 剛体"
"ごうたいぼう 剛体棒"
"ごうたん 豪胆"
"ごうだ 剛田 郷田 合田"
"ごうだつ 強奪"
"ごうだん 強談"
"ごうち 郷地"
"ごうちょく 剛直"
"ごうちん 轟沈"
"ごうつ 江津"
"ごうつくばり 業突張"
"ごうづ 江津"
"ごうてい 豪邸"
"ごうとう 号棟 強盗"
"ごうとくじ 豪徳寺"
"ごうど 神戸"
"ごうどう 合同"
"ごうの 郷野"
"ごうのうら 郷ノ浦"
"ごうはら 郷原 業腹"
"ごうはん 合板"
"ごうばつ 劫罰"
"ごうばん 合板"
"ごうひ 合否"
"ごうひつ 合筆"
"ごうびょう 業病"
"ごうびん 合瓶"
"ごうふく 剛愎 剛腹"
"ごうへき 剛壁"
"ごうへん 合片"
"ごうべん 合弁"
"ごうべんか 合弁花"
"ごうほう 号俸 号砲 合法"
"ごうほうらいらく 豪放磊落"
"ごうほうり 合法裏"
"ごうぼう 号棒"
"ごうま 降魔"
"ごうまん 傲慢"
"ごうめ 合目 号目"
"ごうめい 合名"
"ごうもう 剛毛"
"ごうもくてき 合目的"
"ごうもん 拷問"
"ごうゆう 遨遊 傲遊 豪遊"
"ごうよく 強慾 強欲"
"ごうり 合理"
"ごうりき 剛力 強力 合力"
"ごうりしゅぎてき 公理主義的"
"ごうりゃく 劫掠"
"ごうりゅう 合流"
"ごうりゅうば 剛竜馬"
"ごうりょく 合力"
"ごうれい 号令"
"ごえ 聲 声"
"ごえい 護衛"
"ごえいか 御詠歌"
"ごえいてん ご栄転"
"ごえいへい 護衛兵"
"ごえつ 呉越"
"ごえつどうしゅう 呉越同舟"
"ごえもん 五衛門 五右衛門"
"ごえん 誤嚥"
"ごえんじょ ご援助"
"ごおうぼ ご応募"
"ごおん 御恩 語音 呉音"
"ごおんこ ご恩顧"
"ごか 五霞 五箇"
"ごかい 碁界 五回 五階 誤解"
"ごかいそう ご会葬"
"ごかいとう ご回答"
"ごかく 五角 互角 互格"
"ごかくけい 五角形"
"ごかくにん ご確認"
"ごかしょう 五個荘"
"ごかじょう 五カ条"
"ごかせ 五ヶ瀬"
"ごかぞく ご家族"
"ごかっけい 五角形"
"ごかつやく 後活躍 ご活躍"
"ごかてい ご家庭"
"ごかん 語間 語感 五感 語幹 互換"
"ごかんおう 五冠王"
"ごかんしょ 後漢書"
"ごかんまつ 語幹末"
"ごかんよう ご寛容"
"ごがく 語学"
"ごがつ 皐月 ５月 五月"
"ごがつさい 五月祭"
"ごがつびょう 五月病"
"ごがん 護岸"
"ごき 語基 御器 語気 誤記"
"ごきそ 御器所"
"ごきたい ご期待"
"ごきにゅう ご記入"
"ごきぶり ゴキブリ"
"ごきぼう ご希望"
"ごきゃく 五脚"
"ごきゅう 誤球"
"ごきょう 五経 五橋"
"ごきょうじ ご教示"
"ごきょうどう 後教導"
"ごきょうりょく ご協力"
"ごきんじょ ご近所"
"ごぎ 語義"
"ごぎょう 五行"
"ごぎょうせつ 五行説"
"ごく 語句 極 獄"
"ごくあく 極悪"
"ごくい 極意"
"ごくいちぶ 極一部"
"ごくう 御供 悟空"
"ごくけい 極刑"
"ごくげつ 極月"
"ごくごく 極々"
"ごくさい 極彩"
"ごくさいしき 極彩色"
"ごくさむ 極寒"
"ごくし 獄死"
"ごくしゅう 極宗"
"ごくしょう 極小"
"ごくしょうすう 極少数"
"ごくしょうりょう 極少量"
"ごくしょき 極初期"
"ごくしん 極信"
"ごくじょう 極上"
"ごくそく 極促"
"ごくそつ 獄卒"
"ごくちゅう 獄中"
"ごくつぶし 穀潰し"
"ごくていおん 極低温"
"ごくていおんいき 極低音域"
"ごくていそく 極低速"
"ごくとうぐんじほうてい 極東軍事法廷"
"ごくどう 極道"
"ごくどうし 極道史"
"ごくひ 極秘"
"ごくひん 極貧"
"ごくびしょう 極微小"
"ごくふつう 極普通"
"ごくぶと 極太"
"ごくぼそ 極細"
"ごくぼそびき 極細挽き"
"ごくみ ゴクミ"
"ごくもん 獄門"
"ごくもんとう 獄門島"
"ごくらく 極楽"
"ごくらくちょう 極楽鳥"
"ごくろう ご苦労"
"ごくろうさま ご苦労さま"
"ごけ 碁笥 後家"
"ごけい 語形 互恵"
"ごけいいか 五桂以下"
"ごけた 五桁"
"ごけっこん ご結婚"
"ごけっせき ご欠席"
"ごけつ 五傑"
"ごけにん 御家人"
"ごけん 護憲"
"ごけんしょう ご健勝"
"ごけんとう ご検討"
"ごげん 語源"
"ごげんせつ 語源説"
"ごこう 五香 五劫 後光"
"ごこうい ご好意 ご厚意"
"ごこうぎ ご厚誼 ご高誼"
"ごこうし ご厚志"
"ごこうしょう ご高承"
"ごこうじょう ご厚情"
"ごこうはい ご高配"
"ごこうらん ご高覧"
"ごこく 護国 後刻"
"ごこくじ 護国寺"
"ごこち 心地"
"ごこんじょう ご懇情"
"ごご 午后 午後"
"ごごう 五合"
"ごごち 心地"
"ごさ 誤差"
"ごさい 五歳 後妻"
"ごさく 吾作"
"ごさぼう 誤差棒"
"ごさん 午餐 誤算"
"ごさんか ご参加"
"ごさんれつ ご参列"
"ござ 茣蓆 後座 蓙 茣蓙"
"ごし 腰 五指"
"ごしあい 五試合"
"ごしえん ご支援"
"ごしき 五色"
"ごしちちょう 五七調"
"ごしっくたい ゴシック体"
"ごしつもん ご質問"
"ごしどう ご指導"
"ごしま 五島"
"ごしゃく 語釈"
"ごしゅうしん ご執心"
"ごしゅうにん ご就任"
"ごしゅうめ 五週目"
"ごしゅじん ご主人"
"ごしゅっせい 御出席"
"ごしゅっせき ご出席"
"ごしゅるい 五種類"
"ごしゅん 呉春"
"ごしょ 御所"
"ごしょいずみ 御所泉"
"ごしょう 五章 後生"
"ごしょうかい ご紹介 ご照会"
"ごしょうたい ご招待"
"ごしょうち ご承知"
"ごしょがわら 五所川原"
"ごしょく 五色 誤植 誤殖"
"ごしょのうら 御所浦"
"ごしよう ご使用"
"ごしん 誤審 護身 誤診 誤信"
"ごしんえい 御真影"
"ごしんせん 五新線"
"ごしんたく ご神託"
"ごしんぱい ご心配"
"ごじ 五次 五時 護持 ５時 誤字"
"ごじあい ご自愛"
"ごじさん ご持参"
"ごじせい ご時勢"
"ごじっぽ 五十歩"
"ごじつ 後日"
"ごじつたん 後日譚"
"ごじてん 語辞典"
"ごじひ ご慈悲"
"ごじみゃく 五次脈"
"ごじゅう 五重 五十"
"ごじゅうしょ ご住所"
"ごじゅうそう 五重奏"
"ごじゅうにんまち 五十人町"
"ごじゅっぽ 五十歩"
"ごじゅつ 後述"
"ごじゅん 語順"
"ごじゅんせつ 五旬節"
"ごじょ 互助 互除"
"ごじょう 誤乗 互譲 五條 五条"
"ごじょうざか 五条坂"
"ごじょうめ 五城目"
"ごじら ゴジラ"
"ごじん 吾人 御仁"
"ごじんたい 御神体"
"ごすい 午睡"
"ごすう 語数"
"ごすけ 吾助"
"ごすんくぎ 五寸釘"
"ごず 牛頭"
"ごずみ 後炭"
"ごせ 御所"
"ごせい 碁聖 互生 語勢 悟性"
"ごせいうん ご盛運"
"ごせいえい 御盛栄 ご清栄"
"ごせいきゅう ご請求"
"ごせいぎょう ご盛業"
"ごせいしょう ご清祥 ご清勝"
"ごせいらん 御清覧"
"ごせん 互選 五千 五泉 五線"
"ごせんし 五線紙"
"ごせんぞ ご先祖"
"ごせんふ 五線譜"
"ごぜ 瞽女"
"ごぜん 御膳 御前 午前"
"ごそう 五艘 護送"
"ごそうしゃ 護送車"
"ごそうだん ご相談"
"ごそうふ ご送付"
"ごそくろう ご足労"
"ごそんじ 御存じ"
"ごぞく 五族 語族"
"ごぞんじ ご存知 ご存じ"
"ごたい 五体"
"ごたいりく 五大陸"
"ごたく 五択 御託"
"ごたくせん ご託宣"
"ごたしょう ご多祥"
"ごたぼう ご多忙"
"ごたま 五玉"
"ごたようちゅう ご多用中"
"ごたろう 五太郎"
"ごたん 五反"
"ごたんい 語単位"
"ごたんだ 五反田"
"ごたんばせんぞい 御殿場線沿"
"ごたんばほうめん 御殿場方面"
"ごだい 五代 伍代"
"ごだいこ 五大湖"
"ごだいご 後醍醐"
"ごだつ 誤脱"
"ごだん 五段"
"ごちそう ご馳走"
"ごちゃく 五着 御着"
"ごちゅう 語中"
"ごちゅうい ご注意"
"ごちゅうもん ご注文"
"ごちょう 語長 伍長 語調"
"ごっかん 極寒"
"ごつうち ご通知"
"ごつごう ご都合"
"ごつぼ 五坪"
"ごづめづ 牛頭馬頭"
"ごて 後手"
"ごてい 五帝"
"ごてがち 後手勝"
"ごてん 御殿"
"ごてんした 御殿下"
"ごてんば 御殿場"
"ごでん 誤伝"
"ごと 如 亊 五斗 言 事 毎"
"ごとう 五頭 誤答 語頭 五嶋 五島 後藤"
"ごとうあんし 吾当安此"
"ごとうじ 後藤寺"
"ごとうちゃく ご到着"
"ごとく 五徳"
"ごとに 毎に"
"ごど 五度"
"ごどく 誤読 語読"
"ごにゅう 五入"
"ごにん 五人 誤認"
"ごね ゴネ"
"ごねん 五年"
"ごのうせん 五能線"
"ごのへ 五戸"
"ごのみ 好み"
"ごはい 誤配"
"ごはいりょ ご配慮"
"ごはさん ご破算"
"ごはってん ご発展"
"ごはっと ご法度"
"ごはん ご飯 御飯"
"ごはんえい ご繁栄"
"ごはんじょう ご繁盛"
"ごば 後場"
"ごばく 誤爆"
"ごばらい 後払い"
"ごばん 五番 碁盤"
"ごひき 五匹"
"ごひゃく 五百"
"ごび 語尾"
"ごびゅう 誤謬"
"ごふ 護符"
"ごふう 碁風"
"ごふく 呉服 五福"
"ごふん 五分"
"ごぶ 五分"
"ごぶがり 五分刈り"
"ごぶさた ご無沙汰"
"ごぶん 五分 誤聞"
"ごへい 語弊"
"ごへんじ ご返事"
"ごへんそう ご返送"
"ごべん 五弁"
"ごほう 語法 誤報"
"ごほうこく ご報告"
"ごほうし ご芳志 ご奉仕"
"ごほうねん ご放念"
"ごほうび ご褒美"
"ごほうめい ご芳名"
"ごほく 吾北"
"ごほんぎ 五本木"
"ごほんらい 語本来"
"ごぼいん 五母音"
"ごぼう 牛蒡 御坊"
"ごま 護摩 胡麻"
"ごまあぶら 胡麻油"
"ごまがら 胡麻殻"
"ごまつ 語末"
"ごまのはぐさか ゴマノハグサ科"
"ごまん 五万"
"ごみ 込 護美 塵芥 埖 塵 ゴミ 五味"
"ごみおか 五味岡"
"ごみばこ ゴミ箱"
"ごむ 護謨 ゴム"
"ごめい 五名"
"ごめいわく ご迷惑"
"ごめん 御免"
"ごめんこうむる 蒙御免"
"ごもく 五目"
"ごもるてがか ゴモルテガ科"
"ごもん 御門 御紋"
"ごや 小屋"
"ごやく 語訳 誤訳"
"ごよう 誤用 御用"
"ごようきき 御用聞"
"ごようけんせつ 五洋建設"
"ごようしゃ 御容謝"
"ごようたし 御用達"
"ごようだつ 御用達"
"ごようちょう 御用帳"
"ごようめい ご用命"
"ごようろん 語用論"
"ごよく 五欲"
"ごらいこう ご来光"
"ごらいじょう ご来場"
"ごらいてん ご来店"
"ごらいりん ご来臨"
"ごらく 娯楽"
"ごらくさく 娯楽作"
"ごらん ご覧 御覧"
"ごり 鮴"
"ごりかい ご理解"
"ごりむちゅう 五里霧中"
"ごりやく ご利益"
"ごりゅう 五竜"
"ごりゅうせい ご隆盛"
"ごりょう 御寮 御陵"
"ごりょうかく 五稜郭"
"ごりょうしゃ 御料車"
"ごりょうしょう ご了承"
"ごりょうしん ご両親"
"ごりょうぼくじょう 御料牧場"
"ごりよう ご利用"
"ごりん 五厘 五輪"
"ごるふ ゴルフ"
"ごれい 誤例"
"ごれんらく ご連絡"
"ごろ 語呂 頃"
"ごろー ＧＯＲＯ"
"ごろあわせ 語呂合せ"
"ごろう 悟郎 悟朗 伍朗 五郎 ＧＯＲＯ"
"ごろうまる 五郎丸"
"ごろく 語録"
"ごろごろ ゴロゴロ"
"ごろね ごろ寝"
"ごろべえ 五郎兵衛"
"ごん 諢 權 嚴 金 艮 魂 厳 権 言"
"ごんぎょう 勤行"
"ごんぐ 欣求"
"ごんげ 権化"
"ごんげん 権現"
"ごんご 言語"
"ごんじゃ 権者"
"ごんずい 権瑞"
"ごんぞう 権造"
"ごんだ 権田"
"ごんどう 権藤"
"ごんどうくじら 巨頭鯨"
"ごんべえ 権兵衛"
"ごんりょう 艮陵"
"さ 蓑 早 挫 蹉 莎 瑣 狹 渣 槎 柤 搓 扠 嵳 嗄 嗟 做 狭 紗 磋 些 叉 瑳 作 詐 嵯 唆 茶 沙 裟 砂 佐 査 鎖 左 差"
"さーかす サーカス"
"さーかむすくらいぶ サーカムスクライブ"
"さーくる サークル"
"さーびす サービス"
"さーふぃん サーフィン"
"さーぶ サーブ"
"さーべい サーベイ"
"さい 差位 鰓 切 責 偲 財 佐井 悽 衰 凄 齊 顋 靫 霽 釵 賽 豺 腮 纔 縡 綵 碎 猜 犲 灑 濟 淬 樶 寨 摧 儕 崔 晒 サイ 殺 蔡 宰 塞 栽 采 債 斉 砦 齋 哉 催 犀 彩 済 災 差異 砕 西 採 斎 載 裁 細 祭 菜 妻 才 最 歳 再 際"
"さいあい 最愛"
"さいあく 最悪"
"さいいち 才一"
"さいいちろう 斉一郎"
"さいいん 西院"
"さいいんざい 催淫剤"
"さいうしゃせん 最右車線"
"さいうん 彩雲"
"さいえい 再映"
"さいえん 最遠 再縁 菜園 再演 才媛"
"さいえんす サイエンス"
"さいえんてぃすと サイエンティスト"
"さいえんもの 再演物"
"さいおう 最奥 再往 塞翁"
"さいおく 最奥"
"さいおんじ 西恩寺 西園寺"
"さいおんじこう 西園寺公"
"さいか 雑賀 載荷 災禍 裁可 最下"
"さいかい 西海 際会 斎戒 再会 再開"
"さいかく 才覚"
"さいかや さいか屋"
"さいかわ 犀川 斉川"
"さいかん 才幹 再刊 細管"
"さいが 雑賀 齋賀"
"さいがい 最外 災害"
"さいがわ 犀川"
"さいき 彩木 妻木 再記 催奇 佐伯 債鬼 祭器 才気 斉木 斎木 再起 再帰"
"さいきかんぱつ 才気煥発"
"さいきけい 再帰形"
"さいきせい 最輝星"
"さいきゅう 最急"
"さいきょ 再挙"
"さいきょう 埼京 西京 最強"
"さいきょうせつ 最強説"
"さいきん 細菌 最近"
"さいきんせいえんしょう 細菌性炎症"
"さいぎ 祭儀 猜疑"
"さいぎしん 猜疑心"
"さいぎょうほうし 西行法師"
"さいく 細工"
"さいくつ 採掘"
"さいくつしゃ 採掘車"
"さいくもの 細工物"
"さいくりんぐ サイクリング"
"さいくる サイクル"
"さいくん 細君"
"さいぐさ 三枝"
"さいけい 再掲"
"さいけいこく 最恵国"
"さいけつ 裁決 採血 採決"
"さいけん 債権 債券 再建 再見"
"さいけんしゃ 再検者"
"さいげつ 歳月"
"さいげん 際限 再現"
"さいこ 西湖 採子 才子 最古"
"さいこう 採鉱 再興 採光 再考 最高"
"さいこういせん 最高位戦"
"さいこうがくふ 最高学府"
"さいこうきぼうがく 最高希望額"
"さいこうさく 最高作"
"さいこうしん 最高神"
"さいこうねぶつ 最高値物"
"さいこく 催告"
"さいころ 骰子 賽子 サイコロ"
"さいこん 細根 再婚"
"さいご 西醐 最期 最後"
"さいごう 西郷"
"さいごく 西国"
"さいごっぺ 最後屁"
"さいごまで 最後迄"
"さいごん 西貢"
"さいさ 歳差 最左"
"さいさい 再々 再載 歳々"
"さいさうんどう 才差運動"
"さいさき 幸先"
"さいさくきじ 製作記事"
"さいさん 再三 採算"
"さいし 載祀 斉志 孥 祭祀 才子 再四 再試 妻子"
"さいしき 彩色"
"さいしつ 祭室"
"さいしゅ 採取"
"さいしゅう 採集 最終"
"さいしゅうあん 最終案"
"さいしゅうけい 最終景"
"さいしゅうこう 最終稿"
"さいしゅうさく 最終作"
"さいしゅうしんぶん 済州新聞"
"さいしゅうて 最終手"
"さいしゅうとう 済州島"
"さいしゅうはいりつ 最終敗率"
"さいしゅうわ 最終話"
"さいしゅつ 歳出"
"さいしょ 才所 最所 最初"
"さいしょう 宰相 最少 最小"
"さいしょうぎ 最小木"
"さいしょうげん 最少限 最小元 最小限"
"さいしょうじじょうかい 最小二乗解"
"さいしょく 菜食 才色 彩色"
"さいしょほど 最初程"
"さいしん 祭神 西神 最深 再審 細心 最新"
"さいじ 斎次 斉次 祭事 細事"
"さいじき 歳時記"
"さいじつ 祭日"
"さいじゃく 最弱"
"さいじょ 才女"
"さいじょう 斎場 齋城 西條 最上 西城 西条"
"さいじょうよう 最重要"
"さいじん 才人"
"さいすん 採寸"
"さいず サイズ"
"さいせい 採精 再製 再生"
"さいせいき 最盛期"
"さいせいし 再生紙"
"さいせいじ 最盛時"
"さいせいばり 再生針"
"さいせき 砕石 採石"
"さいせつ 砕屑 細説"
"さいせん 西線 賽銭 再戦 再選 細線"
"さいぜん 最前 最善"
"さいぜんしゅ 最善手"
"さいそう 再送"
"さいそく 細則 最速 催促"
"さいぞう 才蔵"
"さいた 齊田 財田 才田 斉田 最多"
"さいたい 臍帯 妻帯"
"さいたく 採択"
"さいたしょう 最多勝"
"さいたま 埼玉"
"さいたまけんかすし 埼玉県加須市"
"さいたまけんわらびし 埼玉県蕨市"
"さいたん 採炭 最短"
"さいたんかい 最短解"
"さいたんしゅすう 最短手数"
"さいたんろ 最短路"
"さいだ 斉田 斎田"
"さいだい 歳代 埼大 細大 最大"
"さいだいげん 最大元 最大限"
"さいだいじ 西大寺"
"さいだいよさんがく 最大予算額"
"さいだん 祭壇 裁断"
"さいち 才知 佐一"
"さいちゅう 最中"
"さいちょう 最澄 最長"
"さいてい 最底 裁定 最低"
"さいていうんちんがく 最低運賃額"
"さいていきぼうがく 最低希望額"
"さいていしゃ 査定者"
"さいていちじょうこう 最低地上高"
"さいてき 最的 最適"
"さいてきかあり 最適化有り"
"さいてきかい 最適解"
"さいてきかなし 最適化無し"
"さいてきせいぎょかい 最適制御解"
"さいてげん 最低限"
"さいてん 祭典 採点"
"さいと 西都"
"さいとう 齊藤 齋藤 斎藤 斉藤"
"さいど 彩度 サイド 再度"
"さいどう 細動"
"さいどく 再読"
"さいない 最内"
"さいないわく 最内枠"
"さいなん 災難"
"さいなんとうたん 最南東端"
"さいにゅう 歳入"
"さいにょう 採尿"
"さいにん 再認 再任"
"さいねん 再燃"
"さいのう 塞納 臍嚢 才能"
"さいのかわら 賽の河原"
"さいのめ 賽の目"
"さいはい 再拝 采配"
"さいはく 西伯"
"さいはつ 再発"
"さいはん 再犯 再版 再販 最汎"
"さいばい 栽培"
"さいばん 採番 裁判"
"さいばんさいはつ 再版再発"
"さいひ 歳費 採否"
"さいひんち 最頻値"
"さいび 最微"
"さいふ 採譜 財布"
"さいぶ 細部"
"さいぶん 細分"
"さいぶんかつ 細分割"
"さいへん 再編"
"さいほう 再報 裁縫"
"さいほうばこ 裁縫箱"
"さいぼう 細棒 細砲 細胞"
"さいぼうけんだくえき 細胞懸濁液"
"さいぼうこん 細胞塊"
"さいぼうしつ 細胞質"
"さいぼうしん 細胞診"
"さいぼうへき 細胞壁"
"さいぼうまく 細胞膜"
"さいぼうりゅう 細胞流"
"さいまつ 歳末"
"さいみつ 細密 最密"
"さいみゃく 細脈"
"さいみょうじ 斎明寺"
"さいみん 催眠"
"さいみんちょうたい 細明朝体"
"さいむ 債務"
"さいめい 斉明"
"さいめいちょう 細明朝"
"さいもく 細目"
"さいもと 斉本"
"さいもん 彩文 紫門 柴門"
"さいもんふみ 柴門ふみ"
"さいやく 災厄"
"さいゆう 最尤"
"さいゆうき 西遊記"
"さいよう 採用"
"さいらい 再来"
"さいり 犀利 再履"
"さいりゃく 才略"
"さいりゅう 細流"
"さいりゅうど 細粒度"
"さいりょう 才量 宰領 裁量 最良"
"さいるい 催涙"
"さいれい 祭礼"
"さいろう 豺狼"
"さいろく 載録 再録 採録"
"さいろん 再論"
"さいわい 倖 幸 幸い"
"さいわいく 幸区"
"さいわいちょう 幸町"
"さいわき 才脇"
"さいわん 才腕"
"さいん サイン"
"さう 然"
"さうさぶ 操作部"
"さうんど サウンド"
"さえ 冴"
"さえき 差益 冴木 佐伯"
"さえぐさ 三枝"
"さえこ 小枝子 冴虎 佐栄子 さえ子 冴子 沙絵子"
"さえざえ 冴々"
"さえじま 冴島"
"さえだ 佐枝"
"さえつ 査閲"
"さえど 佐江戸"
"さえば 冴羽"
"さえみ 三絵美"
"さお 佐保 杆 棹 竿"
"さおとめ 早乙女 五月女"
"さおり 早織 佐織 里織 小織 小緒里 沙織"
"さか 茶菓 逆 阪 酒 坂"
"さかい 阪井 左海 酒居 酒伊 境井 坂井 境 堺 酒井"
"さかいがわ 境川"
"さかいし 堺市"
"さかいすじ 堺筋"
"さかいだ 境田"
"さかいで 坂出"
"さかいまさあき 堺正章"
"さかいみなと 境港"
"さかいめ 境目"
"さかうえ 坂上"
"さかうち 坂内"
"さかうらみ 逆恨み 逆怨み"
"さかえ 榮 栄"
"さかえだ 栄田"
"さかえだに 栄谷"
"さかえまち 栄町"
"さかお 阪尾"
"さかかく 坂角"
"さかがみ 阪上 坂上"
"さかがわ 坂川"
"さかき 坂城 坂木 榊"
"さかきた 坂北"
"さかきばら 榊原"
"さかきばらおんせんぐち 榊原温泉口"
"さかくら 阪倉 坂倉"
"さかぐち 阪口 坂口"
"さかぐら 酒蔵"
"さかげ 逆毛"
"さかこし 坂越"
"さかさ 逆さ 逆"
"さかさい 逆井"
"さかざき 坂崎"
"さかした 阪下 坂下"
"さかしま 倒 逆"
"さかしら 賢しら"
"さかずき 觚 盞 柧 盃 杯"
"さかずめ 坂詰"
"さかた 酒田 阪田 坂田"
"さかたに 阪谷"
"さかだい 酒代"
"さかだち 逆立ち"
"さかづき 盃 杯"
"さかて 酒手 逆手"
"さかと 坂戸"
"さかとったり 逆とったり"
"さかど 坂戸"
"さかな 肴 魚"
"さかなが 阪長"
"さかなし 坂梨"
"さかなたち 魚達"
"さかなへん 魚偏"
"さかなや 魚屋"
"さかなりょうり 魚料理"
"さかにわ 坂庭"
"さかね 坂根"
"さかの 坂野"
"さかのうえ 坂上"
"さかはぎ 逆剥"
"さかば 酒場"
"さかびき 逆引き"
"さかびん 酒瓶"
"さかべ 坂部"
"さかほぎ 坂祝"
"さかま 坂間"
"さかまきおんせん 坂巻温泉 逆巻温泉"
"さかまち 坂町"
"さかみず 酒水"
"さかみち 坂路 坂道"
"さかむし 酒蒸し"
"さかむら 坂村"
"さかもぎ 逆茂木"
"さかもと 阪元 酒本 坂元 阪本 坂本"
"さかもときゅう 坂本九"
"さかもり 酒盛"
"さかや 酒屋"
"さかやき 月代"
"さかり 盛 盛り"
"さかりば 盛り場"
"さかわ 栄和 佐川 坂和"
"さかわがわ 酒匂川"
"さかん 主典 差換 佐官 左官"
"さが 嵯峨 佐賀 性"
"さがえ 寒河江"
"さがく 差額"
"さがしもの 捜し物"
"さがしょう 佐賀商"
"さがた 嵯峨田"
"さがね 嵯峨根"
"さがの 嵯峨野"
"さがのせき 佐賀関"
"さがみ 相摸 相模"
"さがみこ 相模湖"
"さがみはら 相模原"
"さがみわん 相模湾"
"さがら 相良 相楽"
"さがり 下がり"
"さがる 下ル"
"さがわ 佐川"
"さがん 左岸 左眼"
"さき 尖 早岐 前 左記 早記 沙樹 沙貴 早紀 咲 嵜 埼 碕 崎 先"
"さきいき 先行き"
"さきいと 先糸"
"さきえ 咲恵"
"さきおくり 先送り"
"さきおととい 一昨昨日"
"さきおととし 一昨昨年"
"さきがけ 先掛 魁 先駆け"
"さきぐあい 咲具合"
"さきこ 咲子 沙樹子 佐紀子"
"さきごう 先号"
"さきごろ 先頃"
"さきさま 先様"
"さきざき 先崎 先々"
"さきた 崎田 咲田"
"さきだか 先高"
"さきち 佐吉"
"さきづけ 先付け"
"さきと 崎戸"
"さきどり 先取り"
"さきのり 先乗"
"さきはま 崎浜 咲浜"
"さきばらい 先払 先払い"
"さきばん 先番"
"さきほど 先程"
"さきまけ 先負"
"さきまわり 先回り"
"さきみ 咲美"
"さきもの 先物"
"さきものがい 先物買"
"さきや 崎谷"
"さきやま 崎山"
"さきゅう 砂丘"
"さきゆき 先行き"
"さきょう 左京"
"さきよみ 先読み 先読"
"さきわたし 先渡し"
"さきん 差金 砂金"
"さぎ 鷺 詐欺"
"さぎさか 匂坂"
"さぎさわ 鷺沢"
"さぎざい 詐欺罪"
"さぎしち 鷺七"
"さぎぬま 鷺沼"
"さぎょう サ行 作業"
"さぎょうい 作業衣"
"さぎょうぎ 作業着"
"さぎょうしゃ 作業車"
"さぎょうせん 作業船"
"さぎょうづくえ 作業机"
"さぎょうば 作業場"
"さぎょうふく 作業服"
"さく 乍 酢 辟 齪 鑿 縒 簀 筰 筴 槊 柞 嘖 册 做 捉 炸 佐久 削 咋 搾 朔 柵 窄 昨 冊 錯 索 作 策"
"さくい 作為 作意"
"さくいん 索引"
"さくか 朔果 さく果 昨夏"
"さくかんとく 作監督"
"さくが 作画"
"さくがら 作柄"
"さくがん 削岩"
"さくきまで 昨季迄"
"さくぎ 昨木"
"さくぎれ 索切"
"さくげつ 昨月"
"さくげん 削減"
"さくこん 昨今"
"さくご 錯誤"
"さくごえ 柵越え"
"さくさく 昨々"
"さくさん 酢酸"
"さくざつ 錯雑"
"さくし 策士 作詞 錯視 作詩 索師"
"さくしか 作詞家"
"さくしゃ 作者"
"さくしゅ 搾取"
"さくしゅう 作州 昨秋"
"さくしゅつ 作出"
"さくしゅん 昨春"
"さくじ 作事"
"さくじつ 朔日 昨日"
"さくじょ 削除"
"さくじょう 柵状"
"さくじょする 削除する"
"さくず 作図"
"さくせい 作製 作成"
"さくせいあん 作成案"
"さくせつ 作設"
"さくせん 作戰 作戦"
"さくそう 錯綜"
"さくぞうぶ 作像部"
"さくたき 作滝"
"さくたろう 朔太郎"
"さくだい 作題"
"さくだん 炸弾"
"さくちゅう 作中"
"さくちょう 昨朝 錯聴"
"さくつけ 作付け 作付"
"さくづ 作図"
"さくづけ 作付け 作付"
"さくてい 策定"
"さくてき 索敵"
"さくとう 作東 作陶 昨冬"
"さくどう 索道 策動"
"さくなみ 作並"
"さくにゅう 搾乳"
"さくねん 昨年"
"さくねんあき 昨年秋"
"さくねんくれ 昨年暮"
"さくねんなつ 昨年夏"
"さくねんはる 昨年春"
"さくねんまつ 昨年末"
"さくねんらい 昨年来"
"さくのべ 作延"
"さくはつ 炸発"
"さくばく 索寞 索莫 索漠"
"さくばん 昨晩"
"さくひょう 作表"
"さくひん 作品"
"さくふ 作譜"
"さくふう 作風"
"さくぶん 作文"
"さくへんきょく 作編曲"
"さくほう 作法"
"さくぼう 朔望 策謀"
"さくぼうげつ 朔望月"
"さくま 佐久間"
"さくみ 作見 朔美"
"さくめ 作目"
"さくもつ 作物"
"さくや 昨夜"
"さくやく 炸薬"
"さくやま 咲山 作山"
"さくゆ 搾油"
"さくら 紗倉 砂倉 佐倉 櫻 桜"
"さくらい 櫻井 桜井"
"さくらいろ 桜色"
"さくらえ 桜江"
"さくらおか 桜丘"
"さくらかわ 桜川"
"さくらがい 桜貝"
"さくらがおか 櫻ヶ丘 桜ケ丘 桜ヶ丘"
"さくらがほう 櫻画報"
"さくらがわ 桜川"
"さくらぎ 桜木 桜樹"
"さくらぎちょう 櫻木町"
"さくらぐみ 桜組"
"さくらこ 桜子"
"さくらこうじ 桜小路"
"さくらざわ 桜沢"
"さくらしんまち 桜新町"
"さくらじま 桜島"
"さくらじょうすい 桜上水"
"さくらぜんせん 桜前線"
"さくらそうか サクラソウ科"
"さくらそうもく サクラソウ目"
"さくらだ 桜田"
"さくらだい 桜台"
"さくらだもんえき 桜田門駅"
"さくらづつみ 桜堤"
"さくらどおり 桜通"
"さくらにく 桜肉"
"さくらのみや 桜宮"
"さくらば 櫻庭 桜庭"
"さくらばし 桜橋"
"さくらふじ 桜富士"
"さくらまち 桜町"
"さくらまつり 桜祭"
"さくらもと 桜本"
"さくらん 錯乱"
"さくりゃく 策略"
"さくれい 作例"
"さくれつ 炸裂"
"さくろう 索郎"
"さぐち 佐口"
"さぐん 鎖群"
"さけ 鮭 酒"
"さけい 左傾"
"さけうりば 酒売場"
"さけかす 酒粕"
"さけかわ 鮭川"
"さけてん 酒店"
"さけのみ 酒飲"
"さけびごえ 叫び声"
"さけびん 酒瓶"
"さけみ 酒見"
"さけめ 裂け目 裂目"
"さける 辟"
"さけるい 酒類"
"さげ 下げ"
"さげん 左舷"
"さこ 逧 佐古 迫"
"さこう 酒向 鎖交 佐甲 酒匂"
"さこえ 迫江"
"さこく 鎖国"
"さこだ 迫田"
"さこつ 鎖骨"
"さこん 左近"
"さごじょう 沙悟浄"
"ささ 篠 佐々 笹"
"ささい 瑣細 些細"
"ささえ 支え"
"ささお 笹尾"
"ささおか 佐佐岡 笹岡"
"ささかみ 笹神"
"ささかわ 笹川"
"ささがわ 笹川"
"ささき 笹氣 笹木 佐々木"
"ささぎ 大角豆"
"ささくら 笹倉"
"ささぐり 篠栗"
"ささこ 笹子"
"ささこもち 笹子餅"
"ささざき 笹崎"
"ささざわ 笹沢"
"ささした 笹下"
"ささずし 笹寿司"
"ささせ 笹瀬"
"ささたに 笹谷"
"ささだ 笹田"
"ささつ 査察"
"ささつせん 笹津線"
"ささづか 笹塚"
"ささぬま 笹沼"
"ささの 笹野"
"ささのうち 笹之内"
"ささはら 佐々原 笹原"
"ささべ 笹部"
"ささめゆき 細雪"
"ささもと 篠本 笹本"
"ささもり 笹森"
"ささや 笹谷"
"ささやか 細やか"
"ささやま 篠山 笹山"
"ささら 簓"
"ささり 佐々里"
"さざ 佐々"
"さざえ 蠑螺"
"さざなみ 小波 細波 漣 さざ波"
"さざれ 細"
"さざんか サザンカ"
"さし 砂嘴"
"さしあし 差し足 差脚"
"さしあみ 刺し網"
"さしいれ 差し入れ 差入 差入れ"
"さしえ 挿し絵 插絵 插繪 挿絵"
"さしおさえ 差押"
"さしかえ 差し替え 差替"
"さしがさ 差し傘"
"さしがね 差し金 指金 指矩 差金"
"さしき 佐敷 挿し木"
"さしきず 刺し傷"
"さしさわり 差し障り 差障り"
"さしず 指図"
"さしだ 指田"
"さしだしにん 差出人"
"さしつかえ 差し支え"
"さして 差し手 指し手"
"さしで 差し出"
"さしとめ 差止"
"さしどめ 差止め"
"さしなわ 差し縄"
"さしね 指値 さし値"
"さしの 指野"
"さしば 差し歯 差歯"
"さしひき 差し引き 差引"
"さしま 猿島"
"さしみ 刺身"
"さしむかい 差向い"
"さしもどし 差し戻し 差戻し"
"さしもの 指物"
"さしゅ 詐取"
"さしゅう 査収"
"さしゅうごう 差集合"
"さしょう 瑣小 些少 査証 詐称"
"さしわたし 差渡し"
"さしんしつ 左心室"
"さしんぼう 左心房"
"さじ 佐冶 瑣事 佐治 些事 匙"
"さじかげん 匙加減"
"さじき 桟敷"
"さじきせき 桟敷席"
"さじま 佐島"
"さじょう 叉状 鎖錠 砂上"
"さじん 砂塵"
"さすが 流石"
"さすけ 佐助"
"さすだ 佐須田"
"さすぺんど サスペンド"
"さすれば 然爲れば"
"さず 左図"
"させ 佐瀬"
"させい 嗄声"
"させつ 左折"
"させつしゃ 左折車"
"させぼ 佐世保"
"させん 鎖線 左遷"
"させんけい 左線形"
"さそ 誘"
"さそいみず 誘い水"
"さそう 佐宗"
"さそく 左側"
"さそり 蝎 蠍"
"さそりおとこ 蠍男"
"さそりざ 蠍座"
"さそん 差損"
"さぞ 嘸"
"さた 佐多 佐屋 沙多 沙汰"
"さたけ 佐武 佐竹"
"さたみさき 佐多岬"
"さたろう 佐太郎"
"さたん 嗟歎 嗟嘆 左端"
"さだ 偵 佐田 禎 貞 定"
"さだあき 禎章 貞明"
"さだい 佐大"
"さだいえ 定家"
"さだいじん 左大臣"
"さだえ 貞江"
"さだお 定雄 定夫 定男 貞雄 貞男 貞夫"
"さだおか 定岡"
"さだおき 貞煕"
"さだかた 貞方 定方"
"さだかつ 定勝"
"さだき 定樹 貞木"
"さだきち 定吉"
"さだこ 貞子"
"さだとし 貞俊"
"さだのぶ 定伸"
"さだはる 貞治"
"さだひこ 定彦 貞彦"
"さだひろ 定宏"
"さだまつ 貞松"
"さだみさき 佐田岬"
"さだみち 貞通"
"さだみつ 貞光"
"さだめ 宿命 定め"
"さだめごと 定め事"
"さだやす 定康"
"さだゆき 貞行"
"さだよし 貞芳"
"さだん 左段"
"さち 佐知 倖 幸"
"さちえ 佐智恵"
"さちお 幸夫 幸雄 佐千男"
"さちこ 佐智子 祥子 佐知子 早智子 幸子"
"さちよ 祥代"
"さっか 作家"
"さっかー サッカー"
"さっかく 錯覚"
"さっかしょう 擦過傷"
"さっかん 作監"
"さっき 先刻 殺気"
"さっきゅう 早急"
"さっきょう 作凶"
"さっきょく 作曲"
"さっきょくか 作曲家"
"さっきん 殺菌"
"さっこん 昨今"
"さっさ 佐々"
"さっし 冊子"
"さっしょう 殺生 殺傷"
"さっしょうせき 殺生石"
"さっしん 殺身 刷新"
"さっすい 撒水"
"さっすう 冊数"
"さっせい 殺青 殺生"
"さっせつ 殺節"
"さっそう 颯爽"
"さっそく 早速"
"さっち 察知"
"さっちも 三進も"
"さっちゅう 殺虫"
"さって 幸手"
"さっと 颯と"
"さっとう 殺到"
"さっぷうけい 殺風景"
"さっぽう 殺法"
"さっぽろ 札幌"
"さっぽろしきたくきた 札幌市北区北"
"さっぽろみなみこうこう 札幌南高校"
"さつ 颯 紮 箚 扎 刹 册 撒 拶 刷 薩 撮 擦 殺 察 札 冊"
"さつい 殺意"
"さつうばこ 茶通箱"
"さつえい 撮影"
"さつえいかい 撮映会"
"さつえいじょ 撮影所"
"さつえいずみ 撮影済"
"さつがい 殺害"
"さつき 佐月 皐月 五月 皐"
"さつきがおか 五月丘"
"さつきしょうば 皐月賞馬"
"さつきだ 五月田"
"さつこう 殺光"
"さつじん 殺陣 殺人"
"さつじんき 殺人鬼"
"さつじんざい 殺人罪"
"さつじんはん 殺人犯"
"さつすう 冊数"
"さつぞう 撮像"
"さつたば 札束"
"さつぬません 札沼線"
"さつばつ 殺伐"
"さつま 薩摩"
"さつまじる 薩摩汁"
"さつめ 冊目"
"さつゆう 殺熊"
"さつようえいきゃくほん 撮影用脚本"
"さつりく 殺戮"
"さづか 佐塚"
"さて 扨 偖"
"さてい 査定"
"さておき 扨措き"
"さてつ 蹉跌 砂鉄"
"さてん 茶店"
"さでん 佐伝"
"さと 聰 理 聡 郷 智 里"
"さといも 里芋"
"さといもか サトイモ科"
"さといももく サトイモ目"
"さとう 左党 差等 佐東 砂糖 佐藤"
"さとういり 砂糖入"
"さとうにしき 佐藤錦"
"さとうみず 砂糖水"
"さとえ さと江"
"さとおや 里親"
"さとがえり 里帰り"
"さとこ 智子 理子 砂登子 沙都子 郷子 佐登子 里子 聡子"
"さとごころ 里心"
"さとし 聡史 智志 訓 覺 聰 里志 理史 智史 知 聖 恵 覚志 叡 理 悟史 賢 諭 智嗣 智 悟 慧 覚 聡志 哲 敏 聡"
"さとしょう 里庄"
"さとなか 里中"
"さとひろ 理洋"
"さとみ 智美 沙都美 里見 聡美 恵規 悟美 聡巳 里美"
"さとみつ 理満"
"さとむら 里村"
"さとやま 里山"
"さとり 悟り"
"さとる 知 逹 覺 了 聡 哲 智 覚 悟 達"
"さど 佐渡"
"さどう 佐道 差動 茶道 作動"
"さどがや 佐渡谷"
"さどく 査読"
"さどわら 佐土原"
"さない 左内 佐内"
"さなえ 早植 早生 差波江 早苗"
"さなか 最中"
"さながら 宛ら"
"さなぎ 蛹 佐薙"
"さなげ 猿投"
"さなごうち 佐那河内"
"さなだ 真田"
"さなみ 佐奈美"
"さなる 佐鳴"
"さぬき 佐貫 讃岐"
"さぬま 砂沼"
"さねあつ 実篤"
"さねちか 実近"
"さねとう 實藤 実藤"
"さねとみ 実美"
"さねはる 実治"
"さの 佐野"
"さのう 左脳 佐納"
"さのかわ 佐野川"
"さのさか 佐野坂"
"さは 左派"
"さはい 差配"
"さはら 薩哈剌 佐原"
"さはん 茶飯"
"さはんじ 茶飯事"
"さば 鯆 佐波 鯖"
"さばえ 鯖江"
"さばおり 鯖折り"
"さばき 捌"
"さばきやく 捌役"
"さばく 佐幕 砂漠"
"さばし 佐橋"
"さばずし 鯖鮨"
"さび 銹 寂 鏥 錆"
"さびしろ 淋代"
"さびどめ 錆止め 錆び止め さび止め"
"さぴえんす サピエンス"
"さぶ 佐武 サブ"
"さぶさーきっと サブサーキット"
"さぶしょ 三仏生"
"さぶろう 三朗 三郎"
"さぶん 差分"
"さぶんかい 差分解"
"さぷらい サプライ"
"さへん サ変 左辺"
"さべつ 差別"
"さべん 左弁"
"さほ 左保 沙穂"
"さほう 差法 左方 作法"
"さほこ 佐保子"
"さほど 然程"
"さぼう 茶房 砂防"
"さぼてんもく サボテン目"
"さぽーと サポート"
"さま 樣 様"
"さまかた 様方"
"さまさま 様様"
"さまざま 様々"
"さまざまな 様々な"
"さまたげ 妨げ"
"さまつ 些末 瑣末"
"さまに 様似"
"さまほん 様本"
"さまりー サマリー"
"さみず 三水"
"さみだれ 五月雨"
"さむえ 作務衣"
"さむかわ 寒川"
"さむがり 寒がり"
"さむがわ 寒川"
"さむけ 寒気"
"さむさ 寒さ"
"さむざむ 寒々"
"さむぞら 寒空"
"さむらい 壻 侍 士"
"さめ 雨 鮫"
"さめかわ 鮫川"
"さめがい 醒ケ井"
"さめしま 鮫島"
"さめじま 鮫島"
"さめす 鮫州"
"さも 然も"
"さもん 左門 査問"
"さや 莢 鞘 沙耶"
"さやあて 鞘当 鞘当て"
"さやいんげん 莢隠元"
"さやえんどう 莢豌豆"
"さやか 沙也加"
"さやこ 彩也子"
"さやま 佐山 狭山"
"さゆう ←→ 左右"
"さゆううち 左右打ち"
"さゆうぎゃく 左右逆"
"さゆうじく 左右軸"
"さゆうそうしょうか 左右相称花"
"さゆうそうしょうけい 左右相称形"
"さゆうたん 左右端"
"さゆうどう 左右動"
"さゆり 沙由里 早百合 小百合"
"さよ 小夜"
"さよう 左葉 左用 左様 佐用 作用"
"さようかく 作用角"
"さようそ 作用素"
"さよく 左翼"
"さよくしゅ 左翼手"
"さよこ 沙夜子 紗世子 小夜子 佐代子"
"さら 沙羅 更 皿"
"さらいげつ 再来月"
"さらいしゅう 再来週"
"さらいねん 再来年"
"さらう 攫"
"さらうんど サラウンド"
"さらがた 皿型"
"さらさ 更紗"
"さらさら 更々"
"さらし 晒"
"さらしくび 晒し首"
"さらしな 更級 更科"
"さらす 晒"
"さらせにあもく サラセニア目"
"さらだ サラダ"
"さらち 更地"
"さらに 更に"
"さらぬ 然らぬ"
"さらば 然らば"
"さらべつ 更別"
"さらまんだ 沙羅曼蛇 沙羅蔓蛇"
"さらりーまん サラリーマン"
"さり 紗理"
"さりとて 然りとて"
"さりゅうさいさい 茶流彩彩"
"さりょう 査領"
"さる サル 申 沙流 猿"
"さるがき 桾"
"さるがく 猿学"
"さるくら 猿倉"
"さるぐつわ 猿轡"
"さるぐんだん 猿軍団"
"さるげんとどくさか サルゲントドクサ科"
"さること 然ること"
"さるすべり 百日紅 サルスベリ"
"さるた 猿田"
"さるとび 猿飛"
"さるどし 猿年"
"さるばし 猿橋"
"さるふぁざい サルファ剤"
"さるふつ 猿払"
"さるまね 猿真似"
"さるめんかじゃ 猿面冠者"
"さるめんかんじゃ 猿面冠者"
"さるや 猿谷"
"さるやま 猿山"
"さるわたり 猿渡"
"されき 砂礫"
"されこうべ 髑髏"
"さろま 佐呂間"
"さわ 佐波 佐和 澤 沢"
"さわい 澤井 沢井"
"さわいり 沢入"
"さわうち 沢内 澤内"
"さわおか 澤岡"
"さわかい 茶話会"
"さわき 沢木"
"さわくり 沢栗"
"さわぐち 沢口"
"さわこ 佐和子"
"さわざき 沢崎 澤崎"
"さわすぎ 沢杉"
"さわた 佐和田"
"さわたり 沢渡"
"さわだ 澤多 澤田 沢田"
"さわとうげ 沢峠"
"さわのぼり 澤登 沢登"
"さわはた 澤幡"
"さわまつ 沢松"
"さわむら 澤村 沢村"
"さわもと 澤本"
"さわや 澤谷 沢弥"
"さわら 椹 鰆 早良 佐原"
"さわわたり 沢渡"
"さわん 左腕"
"さん 蒜 嶄 斬 驂 鑚 鑽 跚 贊 讚 衫 蠶 芟 纉 繖 粲 爨 潸 汕 棧 攅 戔 慘 彡 簒 參 刪 杉 3 ３ 撒 燦 珊 傘 桟 惨 纂 蚕 餐 讃 賛 産 山 散 酸 参 算 三"
"さんあくにん 三悪人"
"さんい 三位 賛意"
"さんいち 三一"
"さんいつ 散佚 散逸"
"さんいん 産院 参院 山陰"
"さんいんせん 参院選"
"さんえい 三栄"
"さんえき 三駅"
"さんえんしゅぎ 三猿主義"
"さんおう 三桜"
"さんおくえんじけん 三億円事件"
"さんか 惨禍 山窩 賛歌 傘下 産科 讃歌 酸化 参加"
"さんかい 山塊 山海 散開 散会 参会 三回 三階"
"さんかいじゅく 山海塾"
"さんかいめ ３回目"
"さんかく 贊畫 参画 ▲ ▼ 三角 ▽ △"
"さんかくいた 三角板"
"さんかくきん 三角巾"
"さんかくけい 三角形"
"さんかくす 三角州"
"さんかくちゅう 三角柱"
"さんかくとう 三角塔"
"さんかくは 三角波"
"さんかくまど 三角窓"
"さんかけん 参加券"
"さんかげつ 三カ月 三箇月 三ヶ月"
"さんかしょ 三個所"
"さんかじゅん 参加順"
"さんかた 三方"
"さんかっけい 三角形"
"さんかどう 酸化銅"
"さんかねつ 酸化熱"
"さんかば 参加馬"
"さんかひ 参加費"
"さんかまく 酸化膜"
"さんかん 三韓 三巻 山間 参観"
"さんかんおう 三冠王"
"さんかんがく 産官学"
"さんかんしおん 三寒四温"
"さんかんしき 三管式"
"さんかんせん 三冠戦"
"さんかんちゅうしんちゅう 三環中心柱"
"さんかんば 三冠馬"
"さんが 山河 参賀"
"さんがい 三界 惨害 三階"
"さんがく 産額 産学 山岳"
"さんがくおう 山岳王"
"さんがくたび 山岳旅"
"さんがくぶけい 山岳部系"
"さんがくりん 山岳林"
"さんがつ 弥生 ３月 三月"
"さんがにち 三箇日 三が日"
"さんがね 三ケ根"
"さんがねさん 三ヶ根山"
"さんがん 三願 三眼"
"さんがんし 三眼視"
"さんき 三機 算機"
"さんきし 三騎士"
"さんきち 三吉"
"さんきゃく 三脚"
"さんきゅう 三級 山九 産休"
"さんきゅうだん 三球団"
"さんきょう 三協 三強 三共 山峡"
"さんきょうだい 三兄弟"
"さんきょくめ 三曲目"
"さんきん 三禁"
"さんきんこうたい 参勤交代 参勤交替"
"さんぎ 参議"
"さんぎいん 参議院"
"さんぎいんせんじ 参議院選時"
"さんぎょう 三行 産業"
"さんぎょうしょう 産業省"
"さんく 産駒"
"さんぐう 参宮"
"さんぐらす サングラス"
"さんぐん 三軍"
"さんけ 三家 産気"
"さんけい 散形 参詣 山系 産経"
"さんけいえん 三渓園"
"さんけた 三桁"
"さんけつ 三傑 酸欠"
"さんけつし 酸欠死"
"さんけん 産研 三軒 三権 散見 三研"
"さんげ 散華"
"さんげき 惨劇"
"さんげん 三元 山弦"
"さんげんしょく 三原色"
"さんげんじゃや 三軒茶屋"
"さんげんぢゃや 三軒茶屋"
"さんこう 三皇 三江 三晃 三光 三興 三高 三項 山行 参考"
"さんこうざい 散孔材"
"さんこうせいうん 散光星雲"
"さんこのれい 三顧の礼"
"さんご 産後 珊瑚"
"さんごう 三郷 参號 三号 三劫"
"さんごかい 珊瑚海"
"さんごく 三石 三国"
"さんごくし 三国史 三国志"
"さんごしょう 珊瑚礁"
"さんさ 三叉"
"さんさい 三歳 山菜 三才"
"さんさく 散索 散策"
"さんさくひん 三作品"
"さんさつ 三冊"
"さんさろ 三叉路"
"さんさん 燦々 三々"
"さんさんごご 三々五々"
"さんさんななびょうし 三三七拍子"
"さんざい 散在 散財"
"さんざん 惨々 散々"
"さんし 産仔 三誌 三枝"
"さんしあい 三試合"
"さんした 三下"
"さんしまい 三姉妹"
"さんしゃ 山車 三舎 三社 三者"
"さんしゃいん サンシャイン"
"さんしゃく 参酌"
"さんしゃくだま 三尺玉"
"さんしゃさんよう 三者三様"
"さんしゅ 三種"
"さんしゅう 参集"
"さんしゅうかん 三週間"
"さんしゅうしゃ 三修社"
"さんしゅうめ 三週目"
"さんしゅつ 産出 算出"
"さんしゅつふくよう ３出複葉"
"さんしょ 山椒"
"さんしょう 酸漿 三賞 山椒 三唱 三章 参照"
"さんしょううお 山椒魚 鯢"
"さんしょうわく 参照枠"
"さんしょく 蚕食 三食 三色"
"さんしょくき 三色旗"
"さんしろう 三士郎 三四郎"
"さんしろういけ 三四郎池"
"さんしん 三信 三振"
"さんしんき 三神器"
"さんしんだつしゅ 三振奪取"
"さんしんとうない 三親等内"
"さんじ 讃辞 三時 賛辞 惨事 ３次 産児 三次 参事"
"さんじく 三軸"
"さんじげん 三次元 ３次元"
"さんじみゃく 三次脈"
"さんじゃく 三尺"
"さんじゃくだま 三尺玉"
"さんじゅう 卅 三重 三十"
"さんじゅういちじょう 三一条"
"さんじゅうく 三重苦"
"さんじゅうさつ 三重殺"
"さんじゅうさんげんどう 三十三間堂 三十三間堂"
"さんじゅうし 三銃士"
"さんじゅうしょう 三重唱"
"さんじゅうそう 三重奏"
"さんじゅうのとう 三重塔"
"さんじゅつ 算術"
"さんじゅん 相俊"
"さんじょ 三女 賛助"
"さんじょう 三乗 三條 山上 惨状 三条 参上"
"さんじょうき 三畳紀"
"さんじょく 産褥"
"さんすい 撤水 散水 山水"
"さんすう 算数"
"さんすうか 三数花"
"さんすうかじゅぎょう 算数科授業"
"さんすくみ 三竦み"
"さんすんだま 三寸玉"
"さんず 三途"
"さんずのかわ 三途の川"
"さんずん 三寸"
"さんせい 産生 惨悽 惨凄 三星 三精 三世 酸性 参政 賛成"
"さんせいう 酸性雨"
"さんせいこ 酸性湖"
"さんせいし 酸性紙"
"さんせいすい 酸性水"
"さんせいどう 三省堂"
"さんせき 山積"
"さんせつこん 三節棍"
"さんせん 参戦"
"さんせんくかん 三線区間"
"さんせんべん 三尖弁"
"さんぜん 燦然"
"さんぜんいん 三千院"
"さんぜんえん 三千円"
"さんぜんり 三千里"
"さんそ 酸素"
"さんそう 散層 酸愴 惨愴 三相 三索 山荘 三層"
"さんそん 山村"
"さんぞう 三蔵"
"さんぞく 山賊"
"さんぞくせい 三属性"
"さんたい 算体 三体"
"さんたく 三択"
"さんたろう 三太郎"
"さんたん 讃歎 讃嘆 惨澹 惨憺 賛嘆"
"さんたんし 三端子"
"さんだ 三田"
"さんだい 散大 三台 参内 三大"
"さんだいきょうそ 三代教祖"
"さんだいばなし 三題話"
"さんだいめ 三代目"
"さんだつ 簒奪"
"さんだゆう 三太夫"
"さんだん 算段 散弾 三段"
"さんだんきょう 三段峡"
"さんだんじゅう 散弾銃"
"さんだんとび 三段跳び"
"さんち 三値 山地 産地"
"さんちゃく 参着 三着"
"さんちゃほう 三家和"
"さんちゅう 山中"
"さんちゅうごえ 山中越"
"さんちょう 山頂"
"さんちょうめ 三丁目"
"さんてい 算程 算定"
"さんていばん 三訂版"
"さんてつ 三鉄"
"さんてん 三点 …"
"さんてんせいやく 参天製薬"
"さんと 三都 三斗"
"さんとう 三頭 山東 三等 三島 三東"
"さんとうか 山頭火"
"さんとうへい 三等兵"
"さんとりーほーる サントリーホール"
"さんど 三度"
"さんどう 参道 賛同"
"さんどがさ 三度笠"
"さんどぬり 三度塗"
"さんない 山内"
"さんなん 山南 三男"
"さんにゅう 算入 参入"
"さんにん ３人 三人"
"さんにんさんよう 三人三様"
"さんにんたび 三人旅"
"さんにんむすめ 三人娘"
"さんねん ３年 三年"
"さんねんざか 三年坂"
"さんのう 山王"
"さんのへ 三戸"
"さんのまる 三の丸"
"さんのみや 三の宮 三宮"
"さんはい 山廃"
"さんはんきかん 三半器官"
"さんば 三羽 産婆"
"さんばい 三杯 三倍"
"さんばいず 三杯酢"
"さんばいぞうじょうしゅ 三倍増醸酒"
"さんばかたいしょう 三馬鹿大将"
"さんばがらす 三羽烏"
"さんばし 棧橋 桟橋"
"さんばそう 三番叟"
"さんばば 三婆"
"さんばりー サンバリー"
"さんばん 三番"
"さんぱ 三派"
"さんぱい 贊拜 惨敗 参拝"
"さんぱく 三泊 三拍"
"さんぱつ 三発 散発 散髪"
"さんび 讃美 賛美"
"さんびか 賛美歌"
"さんびき 三匹"
"さんびゃく 三百"
"さんびゃくにんまち 三百人町"
"さんびょうし 三拍子"
"さんぴ 賛否"
"さんぴあざ サンピアザ"
"さんぴん 三一"
"さんふくせん 三複線"
"さんふじんか 産婦人科"
"さんふらんしすこ 桑港"
"さんぶ 三分 山武 三部"
"さんぶさく 三部作"
"さんぶつ 産物"
"さんぶん 三分 散文"
"さんぶんかつあん 三分割案"
"さんぷ 産婦 撒布 散布 算譜"
"さんぷく 山腹"
"さんぷたい 撒布体"
"さんぷらざ サンプラザ"
"さんぷりんぐ サンプリング"
"さんぷる サンプル"
"さんぷん 三分"
"さんへいほう 三平方"
"さんべんしゅ 三鞭酒"
"さんぺい 散兵 三平"
"さんぺいじる 三平汁"
"さんほうこう 三方向"
"さんぼう 三方 参謀"
"さんぼく 山北"
"さんぼだい 三菩提"
"さんぼん ≡ 三本"
"さんぼんあし 三本足"
"さんぼんぎ 三本木"
"さんぼんじめ 三本締め"
"さんぼんばしら 三本柱"
"さんぼんまつ 三本松"
"さんぼんゆび 三本指"
"さんぽ 散歩"
"さんぽう 纂法 三方 三宝 山砲 算法"
"さんぽういん 三宝院"
"さんぽみち 散歩道"
"さんま 秋刀魚"
"さんまい 三昧 三枚"
"さんまきめ 三巻目"
"さんまん 三万 散漫 散慢"
"さんみ 三位 酸味"
"さんみいったい 三身一体"
"さんみゃく 三藐 山脈"
"さんめい 山名 賛明 三名"
"さんめん 三面"
"さんもく 三目"
"さんもん 山門 三文"
"さんもんばん 三文判"
"さんや 山野 山谷"
"さんやく 三役"
"さんゆ 産油"
"さんゆうかん 三遊間"
"さんゆうてい 三遊亭"
"さんよ 參與 贊譽 参与"
"さんよう 山容 算用 山陽 三洋"
"さんようしょうかい 三陽商会"
"さんようじ 山陽路"
"さんようちゅう 三葉虫"
"さんらく 三楽"
"さんらん 産卵 散乱"
"さんらんかく 散乱角"
"さんらんけい 産卵鶏"
"さんらんげん 散乱源"
"さんらんこう 散乱光"
"さんらんしょう 産卵床"
"さんらんそう 産卵槽"
"さんらんたい 散乱体"
"さんらんは 散乱波"
"さんらんばこ 産卵箱"
"さんりく 三陸"
"さんりづか 三里塚"
"さんりゅう 三流"
"さんりゅうしゅ 散粒種"
"さんりゅうてつがくしゃ 二流哲学者"
"さんりょう 三稜 算料"
"さんりょうけい 三稜形"
"さんりん 山林"
"さんりんか 三輪花"
"さんりんしゃ 三輪車"
"さんりんじてんしゃ 三輪自転車"
"さんりんよう 三輪用"
"さんるい 三塁"
"さんるいしゅ 三塁手"
"さんるいだ 三塁打"
"さんれつ 三裂 参列"
"さんれん 三連"
"さんれんきゅう 三連休"
"さんれんしょう 三連勝"
"さんれんせい 三連星"
"さんれんせん 三連戦"
"さんれんぞく 三連続"
"さんれんぱ 三連覇"
"さんれんぱい 三連敗"
"さんれんぷ 三連符"
"さんろうた 三朗太"
"さんろく 山麓"
"さんわ 三羽 三話 三和"
"ざ 藏 左 蔵 坐 挫 座"
"ざい 戝 濟 劑 斉 西 才 済 罪 剤 材 財 在"
"ざいあく 罪悪"
"ざいあくし 罪悪視"
"ざいい 在位"
"ざいえい 在英"
"ざいおう 在欧"
"ざいか 罰科 罪科 財貨 在荷"
"ざいかい 在会 財界"
"ざいかん 在官"
"ざいがい 在外"
"ざいがいこくにほんじん 在外国日本人"
"ざいがく 在学"
"ざいきょう 在京"
"ざいきん 在勤"
"ざいぎょう 罪業"
"ざいく 細工"
"ざいけい 財経 財形"
"ざいけいほうていしゅぎ 罪刑法定主義"
"ざいげん 罪滅 財源"
"ざいこ 在庫"
"ざいこう 在広 在校"
"ざいこくがい 在国外"
"ざいさん 財産"
"ざいさんぜい 財産税"
"ざいしつ 在室 材質"
"ざいしゃ 在社"
"ざいしょ 在所"
"ざいしょく 在職"
"ざいじゅう 在住"
"ざいじょう 罪状"
"ざいす 座椅子"
"ざいせい 財政"
"ざいせいなん 財政難"
"ざいせき 材積 在席 在籍"
"ざいせん 在仙"
"ざいぜん 財前"
"ざいたく 在宅"
"ざいだん 財団"
"ざいちゅう 在中"
"ざいつ 財津"
"ざいとう 財投"
"ざいに 在荷"
"ざいにしかいがん 在西海岸"
"ざいにち 在日"
"ざいにっぽん 在日本"
"ざいにん 罪人 在任"
"ざいはく 財帛"
"ざいばつ 財閥"
"ざいぶつ 財物"
"ざいべい 在米"
"ざいほう 財宝"
"ざいま 在間"
"ざいむ 財務"
"ざいめい 罪名"
"ざいもく 材木"
"ざいもくざかいがん 材木座海岸"
"ざいもくや 材木谷"
"ざいや 在野"
"ざいらい 在来"
"ざいらいしゃ 在来車"
"ざいらいせんがたとっきゅう 在来線型特急"
"ざいらんようぼうし 剤乱用防止"
"ざいりゅう 在留"
"ざいりょう 在寮 材料"
"ざいりょうひ 材料費"
"ざいりょく 財力"
"ざう 座右"
"ざえもん 左衛門"
"ざお 竿"
"ざおう 蔵王"
"ざか 坂"
"ざがく 座学"
"ざがね 座金"
"ざき 嵜 崎"
"ざぎょう ザ行"
"ざくつ 座屈"
"ざくろ 柘榴 榴"
"ざけ 酒"
"ざこ 雑魚 雑喉 座古"
"ざこう 座高"
"ざこうじ 座光寺"
"ざこたらず 座高不足"
"ざこつ 坐骨"
"ざこね 雑寝"
"ざこば 雑喉場"
"ざし 座視"
"ざしき 座敷"
"ざしきろう 座敷牢"
"ざしきわらし 座敷童"
"ざしつ 座室"
"ざしゅ 座種"
"ざしょう 坐礁 挫傷 座礁"
"ざせき 座席"
"ざせきけん 座席券"
"ざせきした 座席下"
"ざせきしゃ 座席車"
"ざせきわく 座席枠"
"ざせつ 挫折"
"ざぜん 坐禅 座禅"
"ざぞう 座像"
"ざた 沙汰"
"ざたく 座卓"
"ざだん 座談"
"ざちょう 座長"
"ざっか 雑貨"
"ざっかん 雑感"
"ざっき 雑記"
"ざっきちょう 雑記帳"
"ざっきょ 雑居"
"ざっきん 雑菌"
"ざっけん 雑件"
"ざっこく 雑穀"
"ざっし 雑誌"
"ざっしゅ 雑種"
"ざっしゅうにゅう 雑収入"
"ざっしょく 雑色 雑食"
"ざっそう 雑草"
"ざっそく 雑則"
"ざった 雑多"
"ざっとう 雑沓 雑踏"
"ざっぱ 雑把 雑破"
"ざっぱく 雑駁"
"ざっぴ 雑費"
"ざっぽう 雑報"
"ざつ 雜 襍 雑"
"ざつえき 雑役 雑益"
"ざつおん 雑音"
"ざつがく 雑学"
"ざつぎだん 雑技団"
"ざつぎょ 雑魚"
"ざつさぎょう 雑作業"
"ざつじ 雑事"
"ざつぜん 雑然"
"ざつだん 雑談"
"ざつねん 雑念"
"ざつのう 雑嚢"
"ざつはいすい 雑排水"
"ざつぶつ 雑物"
"ざつぶん 雑文"
"ざつみんとう 雑民党"
"ざつむ 雑務"
"ざつよう 雑用"
"ざとう 座頭"
"ざね 実"
"ざひょう 座標"
"ざひょうじく 座標軸"
"ざぶとん 座布団"
"ざぶろう 三郎"
"ざま 座間"
"ざまみ 座間見"
"ざめん 座面"
"ざやく 坐薬 座薬"
"ざゆう 座右"
"ざら 皿"
"ざり 座利"
"ざりがに 蜊蛄"
"ざる 笊"
"ざるご 笊碁"
"ざるそば 笊蕎麦"
"ざれごと 戯事"
"ざわ 澤 沢"
"ざん 参 鏨 讒 竄 殘 懴 懺 慚 慘 巉 嶄 塹 算 惨 山 慙 斬 暫 残"
"ざんあつけい 残圧計"
"ざんい 残遺"
"ざんかん 斬姦 斬奸"
"ざんがい 斬刈 残骸"
"ざんがく 残額"
"ざんき 残基 慚愧 慙悸 慙愧 残機"
"ざんきゅう 斬級"
"ざんきょう 残響"
"ざんきりょう 残気量"
"ざんきん 残金"
"ざんぎゃく 残虐"
"ざんぎょう 残業"
"ざんぎょうしょく 残業食"
"ざんぎょうでい 残業デイ"
"ざんくろう 斬九郎"
"ざんけん 残件"
"ざんげ 慚悔 懺悔"
"ざんげん 讒言"
"ざんこく 残酷"
"ざんごう 塹壕"
"ざんさ 残差"
"ざんさい 残滓 斬衰"
"ざんさぎょう 残作業"
"ざんさつ 惨殺"
"ざんさへいほうわ 残差平方和"
"ざんし 慙死 惨死 残滓"
"ざんしゃ 讒者"
"ざんしゅ 斬首"
"ざんしょ 残暑"
"ざんしょう 残照"
"ざんしん 嶄新 斬新"
"ざんじ 暫時"
"ざんじつろく 残日録"
"ざんじんざんば 斬人斬馬"
"ざんすう 残数"
"ざんせき 残席"
"ざんせつ 残雪"
"ざんぜつ 嶄絶"
"ざんぜん 嶄然"
"ざんそん 残存"
"ざんぞう 残象 残像"
"ざんぞん 残存"
"ざんだか 残高"
"ざんだんすう 残弾数"
"ざんち 残置"
"ざんてい 暫定"
"ざんていあん 暫定案"
"ざんていかい 暫定解"
"ざんとう 残党"
"ざんどすう 残度数"
"ざんにっすう 残日数"
"ざんにん 惨忍 残忍"
"ざんねん 残念"
"ざんばつ 斬伐"
"ざんぱい 惨敗"
"ざんぱん 残飯"
"ざんぴん 残品"
"ざんぶ 残部"
"ざんぶん 残分"
"ざんぺん 残片"
"ざんぼう 讒謗"
"ざんまい 三昧"
"ざんむ 残務"
"ざんよ 殘餘 残余"
"ざんりゅう 残留"
"ざんりゅういりゅうみん 在留居留民"
"ざんりょう 残料 残量"
"ざんるい 残塁"
"し 矢 髭 砥 弛 笥 芝 柴 自 匙 此 祇 梔 衰 恃 齒 鷙 駛 駟 阯 錙 釶 輜 趾 齎 貲 豕 諡 謚 蚩 茲 舐 肆 耜 耆 翅 緇 絲 粢 篩 笶 竢 祗 祠 祀 痣 熾 滓 泗 沚 摯 揣 恣 徙 弑 廝 幟 帋 巵 妛 屎 尸 址 嘴 嗤 啻 咫 咨 呰 厶 厮 卮 俟 侈 漬 偲 嗜 巳 之 次 時 柿 仔 嗣 屍 刺 示 獅 祉 脂 孜 諮 賜 雌 斯 仕 肢 知 岐 糸 歯 思 枝 施 司 紫 飼 史 四 止 始 資 支 覗 士 志 至 姿 姉 伺 試 旨 視 使 師 紙 市 指 私 詞 詩 死 誌 子 氏"
"しーずん シーズン"
"しーた θ"
"しーたは θ波"
"しーど シード"
"しーるど シールド"
"しーん シーン"
"しあい 仕合 試合"
"しあいうん 試合運"
"しあいこうしゃ 試合巧者"
"しあいじゅん 試合順"
"しあがり 仕上がり"
"しあげ 仕上げ 仕上"
"しあげこう 仕上工"
"しあたー シアター"
"しあつ 指圧"
"しあわせ 仕合せ 幸せ"
"しあん 私案 シアン 試案 思案"
"しい 肆意 示威 資意 思惟 私意 恣意 椎"
"しいえき 志井駅"
"しいか 詩歌"
"しいき 篩域 市域 椎木"
"しいく 飼育"
"しいくすい 飼育水"
"しいざかな 強肴"
"しいじ 椎路"
"しいた Θ θ"
"しいたけ 椎茸"
"しいだ 椎田 志井田"
"しいて 強いて"
"しいな 粃 秕 椎菜 椎名"
"しいなまこと 椎名誠"
"しいの 椎野"
"しいば 椎葉"
"しいる 罔"
"しいれ 仕入れ 仕入"
"しいれね 仕入値"
"しいん 死因 試飲 子音"
"しう゛ぁ 湿婆"
"しうち 仕打ち 仕打"
"しうと 舅"
"しうとめ 姑"
"しうら 市浦"
"しうん 紫雲"
"しうんじ 紫雲寺"
"しうんてん 試運転"
"しぇあ シェア"
"しぇぱーど シェパード"
"しぇるへんすう シェル変数"
"しえい 私営 市営"
"しえいしゃ 市営車"
"しえき 私益 使役"
"しえん 私怨 紫煙 支援"
"しえんかたんそ 四塩化炭素"
"しお 志雄 史生 入 鹽 潮 汐 塩"
"しおあじ 塩味"
"しおいがい 塩以外"
"しおいり 塩入"
"しおうち 塩内"
"しおかぜ 潮風 汐風"
"しおから 塩辛"
"しおかり 塩狩"
"しおかわ 塩川"
"しおがま 塩釜 塩竃"
"しおがまこう 塩釜港 塩竃港"
"しおき 仕置き 仕置"
"しおくり 仕送り"
"しおけ 塩気"
"しおこさじ 塩小匙"
"しおこしょう 塩胡椒"
"しおこんぶ 塩昆布"
"しおさい 潮騒"
"しおさめ 爲納め 仕納め"
"しおざき 潮崎 塩崎"
"しおざけ 塩鮭"
"しおざわ 塩澤 塩沢"
"しおじ 塩路 汐路"
"しおじり 塩尻"
"しおず 塩津"
"しおずか 塩塚"
"しおせ 塩瀬"
"しおた 塩田"
"しおたに 塩谷"
"しおだ 塩田"
"しおち 潮地"
"しおつぐ 塩次"
"しおづけ 塩漬け"
"しおどき 潮時"
"しおどめ 汐留"
"しおの 塩野"
"しおのえ 塩江"
"しおのぎ 塩野義"
"しおはま 塩浜"
"しおはら 塩原"
"しおばら 塩原"
"しおひ 潮干"
"しおひがり 潮干狩"
"しおふき 潮吹き"
"しおべつ 塩別"
"しおまねき 潮招き"
"しおみ 潮見 塩見"
"しおみず 塩水"
"しおみだい 汐見台"
"しおむら 塩村"
"しおもと 塩本"
"しおや 塩谷 塩屋"
"しおやき 塩焼"
"しおゆ 塩湯"
"しおり 詩央里 栞"
"しおん 私怨 子音 紫苑"
"しか 私家 志賀 翅果 然 爾 雌花 餝 紙価 飾 市価 史家 歯科 鹿"
"しかい 斯界 此界 歯科医 死海 市会 視界 司会"
"しかいしゃせき 司会者席"
"しかいやく 司会役"
"しかえし 仕返し"
"しかおい 鹿追"
"しかかり 仕掛り"
"しかぎこうし 歯科技工士"
"しかく ◆ 視角 死角 刺客 ◇ □ 四角 ■ 視覚 資格"
"しかくきゅう 資格給"
"しかくけい 四角形"
"しかくごうま 四角号碼"
"しかくぼ 鹿窪"
"しかけ 仕掛け 仕掛"
"しかご 市俄古"
"しかさわぐち 鹿沢口"
"しかざわ 鹿沢"
"しかし 併し 然し"
"しかしょ 四ヶ所"
"しかじか 然然 然々 云々"
"しかず 若かず 如かず"
"しかた 志方 仕方"
"しかたに 鹿谷"
"しかっけい 四角形"
"しかつ 師勝 死活"
"しかと 聢"
"しかど 鹿戸"
"しかの 鹿野"
"しかのしま 志賀島"
"しかばね 屍"
"しかべ 鹿部"
"しかま 色麻 志鎌 飾磨"
"しかまた 鹿又"
"しかまち 鹿町"
"しかみ 爾見 鹿見"
"しかも 然も 而も"
"しからば 然らば"
"しかり 尓 然り"
"しかりべつ 然別"
"しかりべつこ 然別湖"
"しかん 篩管 視感 支間 弛緩 士関 士官 仕官 歯冠 視姦"
"しかんけん 資環研"
"しが 四賀 齒牙 志賀 滋賀"
"しがい 紫外 屍骸 市街 死骸 市外"
"しがいこう 紫外光"
"しがいせん 市街戦"
"しがき 志垣"
"しがく 史学 私学 歯学"
"しがさと 滋賀里"
"しがっか 歯学科"
"しがつ 卯月 ４月 四月"
"しがらき 紫香楽 信楽"
"しがらきのみやあと 紫香楽宮跡"
"しがらみ 柵"
"しがん 此岸 志願"
"しき 志岐 磯城 鋪 織 惻 志気 志木 始期 士気 死期 拭 四季 識 指揮 色 敷 式"
"しきい 閾 敷居"
"しきいき 識閾 識域"
"しきいし 敷石"
"しきいた 敷板"
"しきいち しきい値 閾値"
"しきかいぞうど 色解像度"
"しきかく 色覚"
"しきがみ 式神"
"しきがわ 敷皮"
"しききん 敷金"
"しきぎょう 私企業"
"しきけん 識見"
"しきこう 式項"
"しきこうぞう 式構造"
"しきさい 四季菜 色彩"
"しきさしんごう 色差信号"
"しきし 色紙"
"しきしだい 式次第"
"しきしま 磯城島 敷島"
"しきしゃ 識者"
"しきしゅ 色種"
"しきしゅうさ 色収差"
"しきしん 色神"
"しきじ 式次 式辞"
"しきじたい 式自体"
"しきじつ 式日"
"しきじゃく 色弱"
"しきじょう 色情 式場"
"しきじりつ 識字率"
"しきすう 色数"
"しきそ 式素 色素"
"しきそう 色相"
"しきそうかん 色相環"
"しきそくぜくう 色即是空"
"しきそせいかんぴしょう 色素性乾皮症"
"しきた 敷田"
"しきたま 敷玉"
"しきたり 爲來り 仕來り"
"しきだ 敷田"
"しきち 敷地"
"しきちゅう 式中"
"しきちょう 色調"
"しきてい 式亭"
"しきてん 式典"
"しきど 色度"
"しきね 式根"
"しきねじま 式根島"
"しきばん 色板"
"しきばんごう 式番号"
"しきひょう 色票"
"しきふ 敷布"
"しきふくはんそうは 色副搬送波"
"しきふね 式船"
"しきぶ 式部"
"しきぶとん 敷き布団 敷布団"
"しきぶん 式文"
"しきへんけい 式変形"
"しきべつ 識別"
"しきほう 四季報"
"しきぼう 指揮棒"
"しきみ 櫁 樒"
"しきみか シキミ科"
"しきみもどきか シキミモドキ科"
"しきめ 式女"
"しきめい 色名"
"しきもう 色盲"
"しきもの 敷き物 敷物"
"しきやみ 頻闇"
"しきゅう 死球 四球 子宮 支給 至急"
"しきゅうかく 子宮角"
"しきゅうがく 支給額"
"しきゅうこう 子宮口"
"しきゅうせん 子宮腺"
"しきょ 死去"
"しきょう 試供 市況 司教"
"しきょういく 私教育"
"しきょく 詩曲 支局"
"しきり 頻 頻り 仕切り"
"しきりしょ 仕切書"
"しきりとびら 仕切扉"
"しきりに 頻"
"しきろう 識浪"
"しきん 試金 至近 資金"
"しきんぐり 資金繰り"
"しきんげん 資金源"
"しきんせき 試金石"
"しきんだん 至近彈 至近弾"
"しぎ 信貴 鷸 私議 思議 市議 仕儀 鴫"
"しぎこ 鴫子"
"しぎの 鴫野"
"しぎゃく 嗜虐"
"しぎょう 施業 紙業 仕業 始業"
"しぎょく 紫玉"
"しぎょはっせいすう 死魚発生数"
"しぎん 市銀 詩吟"
"しく 珠玖 詩句 市区"
"しくうかん 視空間"
"しくつ 試掘"
"しくはっく 四苦八苦"
"しくみ 仕組み 仕組"
"しぐさ 仕種 仕草"
"しぐま σ Σ"
"しぐれ 時雨"
"しぐん 市郡"
"しぐんくちょうそんあざ 市郡区町村字"
"しけ 時化"
"しけい 司計 紙型 市警 私刑 死刑"
"しけいおん 歯茎音"
"しけいしゅう 死刑囚"
"しけつ 止血"
"しけん 四間 私権 私見 試験"
"しけんかん 試験管"
"しけんし 試験紙"
"しけんしゃ 試験車"
"しけんじょ 試験所"
"しけんびしゃ 四間飛車"
"しげ 楙 成 恵 繁 重 茂 滋"
"しげあき 重明 重昭 成章"
"しげい 重井"
"しげえだ 重枝"
"しげお 成雄 惠雄 繁生 滋男 恵雄 茂生 滋夫 滋雄 茂夫 繁雄 繁夫 繁男 重夫 重男 茂男 成夫 茂雄 重雄"
"しげかず 繁一 重一"
"しげかつ 重勝"
"しげがき 茂垣"
"しげき 枝隙 刺戟 茂喜 繁樹 重樹 茂樹 滋樹 刺激"
"しげきしゅう 刺激臭"
"しげく 繁く"
"しげこ シゲ子 滋子 茂子"
"しげさだ 繁定"
"しげさと 重里"
"しげし 茂志"
"しげじ 茂司"
"しげぞう 茂三"
"しげた 重田"
"しげたか 重高 重隆"
"しげたけ 重武"
"しげつぐ 重継"
"しげとし 成俊 恵俊"
"しげとも 成伴"
"しげなが 重永"
"しげなり 重成"
"しげのぶ 茂伸 重信 滋延"
"しげのり 繁徳 卯典 繁則 茂典 重徳 重則"
"しげはら 重原"
"しげはる 重治"
"しげひこ 茂彦 重彦"
"しげひろ 繁弘 重博 重弘 重宏"
"しげふみ 重文"
"しげまさ 茂昌"
"しげまつ 重松"
"しげみ 成美 茂見 茂美"
"しげみち 茂道"
"しげみつ 重光"
"しげむら 重村"
"しげもり 重森 繁盛"
"しげや 茂哉"
"しげゆき 繁行 滋之 茂行 茂之 繁之 重行"
"しげよし 誠良 重義"
"しげり 成里"
"しげる 楙 繁 滋 茂"
"しげん 死言 始源 至言 始原 資源"
"しげんかん 始原環"
"しげんすう 四元数"
"しげんたんさくしゃ 資源探索車"
"しこ 醜 四股 鬼"
"しこう 篩孔 伺侯 市交 紙工 私行 市郊 歯垢 私好 施工 志向 至高 嗜好 施行 試行 思考 指向"
"しこうあん 試行案"
"しこうして 而して"
"しこうせんひたいおう 市交線非対応"
"しこうてい 始皇帝"
"しこうれい 施行令"
"しこく 四国"
"しこくおき 四国沖"
"しこたん 色丹"
"しこたんとう 色丹島"
"しこつ 篩骨 歯骨 趾骨 指骨 肢骨 死骨"
"しこつおきな 醜つ翁"
"しこつこ 支笏湖"
"しこつとうやこくりつこうえん 支笏洞爺国立公園"
"しこな 醜名 四股名"
"しこめ 醜女"
"しこり 痼 凝"
"しころ 鍜 錣 錏"
"しこん 紫紺"
"しご 私語 死語 死後"
"しごう 紫合 諡号"
"しごく 至極"
"しごせん 子午線"
"しごと 仕事"
"しごとがら 仕事柄"
"しごとぎ 仕事着"
"しごとづくえ 仕事机"
"しごとば 仕事場"
"しごめん 子午面"
"しさ 指唆 視差 示唆"
"しさい 市債 仔細 司祭 子細"
"しさいぼう 篩細胞"
"しさく 思索 施策 試作"
"しさくしゃ 試作車"
"しさくひん 詩作品"
"しさつ 刺殺 視察"
"しさん 私産 四散 試算 資産"
"しさんか 資産家"
"しざ 視座"
"しざい 死罪 私財 資材"
"しざん 試算 死産"
"しし 志士 祠祀 貎 肉 獅 死屍 四肢 宍 獅子"
"ししうち 猪内"
"ししき 司式 始式"
"ししきゅう 四死球"
"ししくい 宍喰"
"ししざ 獅子座"
"ししつ 脂質 支質 紙質 資質"
"ししづか 宍塚"
"ししど 宍戸"
"ししどじょう 宍戸錠"
"ししゃ 視射 試射 四捨 使者 試写 死者 支社"
"ししゃく 子爵"
"ししゃも 柳葉魚 シシャモ"
"ししゅ 死守"
"ししゅう 死臭 刺しゅう 刺繍 詩集"
"ししゅういり 刺繍入り"
"ししゅうき 思秋期"
"ししゅうへん 市周辺"
"ししゅく 私淑"
"ししゅつ 支出"
"ししゅつがく 支出額"
"ししゅんき 思春期"
"ししょ 四書 私書 史書 支署 司書 支所"
"ししょう 四生 視床 死傷 刺傷 師匠 支障"
"ししょうすじ 師匠筋"
"ししょうせつ 私小説"
"ししょく 試食"
"ししょばこ 私書箱"
"ししよう 試使用"
"ししん 視診 私心 指針 私信"
"ししんけい 歯神経 視神経"
"しじ 指似 指事 榻 師事 私事 支持 指示"
"しじつ 史実"
"しじま 四十万 黙 静寂"
"しじみ 蜆"
"しじゃく 枝雀"
"しじやく 指示薬"
"しじゅう 四重 四十 始終"
"しじゅうから 四十雀"
"しじゅうくにち 四十九日"
"しじゅうしちし 四十七士"
"しじゅうそう 四重奏"
"しじゅく 私塾"
"しじゅほうしょう 紫綬褒章"
"しじょ 子女"
"しじょう 糸状 矢状 四條 誌上 紙上 試乗 施錠 四条 私情 市上 至上 史上 市場"
"しじょうき 試乗記"
"しじょうきょう 私情協"
"しじょうしゃ 試乗車"
"しじょうなわて 四條畷"
"しじょうのあい 至上の愛"
"しじょうはつ 史上初"
"しじょうれい 市条例"
"しじん 私人 詩人"
"しすい 泗水 酒々井 止水 市水"
"しすう 紙数 指数"
"しすてむ システム"
"しすてむず システムズ"
"しず 靜 志津 静"
"しずい 雌蕊"
"しずえ 志津恵 静枝 静江"
"しずお 靜生 鎮雄 静男 静夫 静雄"
"しずおか 靜岡 静岡"
"しずおかしりつしょう 静岡市立商"
"しずか 静佳 靜か 静 静か 閑か 静香"
"しずかごぜん 静御前"
"しずぎん 静銀"
"しずく 滴 雫"
"しずくいし 雫石"
"しずけさ 静けさ"
"しずこ 志津子 静子"
"しずごころ 静心"
"しずだい 静大"
"しずない 静内"
"しずや 靜谷 静谷"
"しずりだい 静理大"
"しずる 静流"
"しせい 雌性 志誠 刺青 私生 市井 市勢 私製 施政 市政 市制 至誠 四声 姿勢"
"しせいかく 姿勢角"
"しせいかつ 私生活"
"しせいし 市政史"
"しせいじ 私生児"
"しせいせいど 氏姓制度"
"しせいたい 四声体"
"しせいどう 資生堂"
"しせかいこうきょうきょく 新世界交響曲"
"しせき 枝跡 歯石 史跡"
"しせつ 私説 使節 私設 施設"
"しせん 四川 死線 支線 視線"
"しせんどう 詩仙堂"
"しぜん 自然"
"しぜんこう 自然光"
"しぜんし 自然死"
"しぜんしはくぶつかん 自然史博物館"
"しぜんぞう 自然増"
"しぜんたい 自然体"
"しぜんてきかんきょう 自然的環境"
"しそ 紫蘇 始祖"
"しそう 祀竃 祀竈 死相 志操 使嗾 宍粟 視奏 試走 試奏 思想"
"しそうか 思想家"
"しそうし 思想史"
"しそうのうろう 歯槽膿漏"
"しそか シソ科"
"しそく 子息 四則"
"しそちょう 始祖鳥"
"しそもく シソ目"
"しそん 子孫"
"しぞう 私蔵 死蔵"
"しぞく 氏族 士族"
"した 舖 舐 舍 ↓ 舌 下"
"したあご 下顎"
"したあじ 下味"
"したい 死體 屍体 肢体 姿態 死体"
"したいじんいしょく 死体腎移植"
"したいふ 士大夫"
"したうけ 下請 下請け"
"したうち 舌打ち 舌打"
"したえ 下絵"
"したか 志鷹"
"したがき 下書 下書き"
"したがって 従って"
"したがわ 下側"
"したぎ 下着"
"したぎすがた 下着姿"
"したく 私宅 支度 仕度"
"したくちびる 下唇"
"したぐつ 襪"
"したけんぶん 下検分"
"したごころ 下心"
"したごしらえ 下拵え"
"したさき 舌先"
"したさんかく 下三角"
"したざわり 舌触り"
"したしい 親"
"したしく 親しく"
"したしょく 下職"
"したしらべ 下調 下調べ"
"したじ 下地"
"したじき 下敷 下敷き"
"したじゅんび 下準備"
"したず 下図"
"したそうだん 下相談"
"したたか 健か 強か"
"したたらず 舌足らず"
"しただ 下田"
"したっぱ 下っ端 下っぱ 下端"
"したっぱら 下っ腹"
"したつ 示達"
"したつけ 下付"
"したづつみ 舌鼓"
"したづみ 下積み"
"したて 仕立 下手 仕立て"
"したてだしなげ 下手出し投げ"
"したてなげ 下手投げ"
"したてん ．"
"したで 下手"
"したどり 下取 下取り"
"したどりがく 下取額"
"したなめずり 舌舐めずり"
"したぬり 下塗"
"したね 下値"
"したの 下野"
"したはんぶん 下半分"
"したばえ 下生"
"したばたらき 下働き"
"したばなし 下話"
"したび 下火"
"したまえば 下前歯"
"したまち 下町"
"したみ 下見"
"したみち 下道"
"したむき 下向き"
"しため 下目"
"したや ↓"
"したやじるし ↓"
"したら 設楽"
"したん 枝端 紫檀 始端"
"しだ 齒朶 羊齒 羊歯 信太 試打 志田 志太"
"しだい 私大 次第"
"しだいすう 始代数"
"しだし 仕出し"
"しだじょうしゅししょくぶつ シダ状種子植物"
"しだら 設楽"
"しだれざくら 枝垂れ桜"
"しだれやなぎ 枝垂れ柳"
"しだわら 志俵"
"しだん 指彈 師団 指弾"
"しだんしょ 示談書"
"しち 叱 貭 質 七"
"しちいれ 質入れ"
"しちうけ 質請け"
"しちかく 視知覚"
"しちがしゅく 七ヶ宿"
"しちがつ 文月 ７月 七月"
"しちがはま 七ヶ浜"
"しちく 紫竹"
"しちけん 質権"
"しちごさん 七五三"
"しちごちょう 七五調"
"しちしょう 七生"
"しちじ 七時"
"しちじゅう 七十 七重"
"しちじゅうしち 七十七"
"しちじょう 七城 七丈"
"しちじょうかわらまち 七条河原町"
"しちずんどけい シチズン時計"
"しちだん 七段"
"しちてんばっとう 七転八倒"
"しちなん 七難"
"しちなんはっく 七難八苦"
"しちにん 七人"
"しちのへ 七戸"
"しちふくじん 七福神"
"しちふくせい 七福星"
"しちふだ 質札"
"しちぶ 七分"
"しちへんげ 七変化"
"しちほのさい 七歩の才"
"しちみ 七味"
"しちめんちょう 七面鳥"
"しちめんどう 七面倒"
"しちゃく 試着"
"しちや 質屋"
"しちゅー シチュー"
"しちゅう 支柱 市中"
"しちゅうこん 支柱根"
"しちゅうしんぶ 市中心部"
"しちょう 輜重 市町 支庁 思潮 市庁 視聴 試聴 市長"
"しちょうかく 視聴覚"
"しちょうかくてきこうか 視聴覚的効果"
"しちょうき 試聴記"
"しちょうしゃ 市庁舎"
"しちょうせん 市長選"
"しちょうそん 市町村"
"しちょく 司直"
"しちょっけい 視直径"
"しちよう 七曜"
"しちり 七里"
"しちりん 七輪"
"しちろう 七郎"
"しっか 膝下 失火"
"しっかい 悉皆"
"しっかく 失格"
"しっかり 聢り 確り"
"しっかん 疾患"
"しっき 湿気 漆器"
"しっきゃく 失脚"
"しっきん 失禁"
"しっく 疾駆"
"しっくい 漆喰"
"しっけ 湿気"
"しっけい 失敬"
"しっけつ 失血"
"しっけん 失権 識見"
"しっこう 失効 執行"
"しっこく 桎梏 漆黒"
"しっこし 尻腰"
"しっさく 失策"
"しっしき 湿式"
"しっしっ 叱叱"
"しっしょう 失笑"
"しっしょく 失職"
"しっしん 湿疹 失神"
"しっせい 執政 叱声 叱正 失政"
"しっせき 叱斥 失跡 叱責"
"しっそ 質素"
"しっそう 疾走 失踪"
"しっそく 失速"
"しった 叱咤"
"しったい 失態"
"しったん 悉曇"
"しっち 失地 湿地"
"しっちょう 室長 失調"
"しっつい 失墜"
"しって 尻手 知って"
"しってん 質点 失点"
"しっと 嫉妬"
"しっとう 執刀 失投"
"しっとしん 嫉妬心"
"しっぱい 失敗"
"しっぱいさく 失敗作"
"しっぴ 失費 櫛比"
"しっぴつ 執筆"
"しっぴつじゅん 執筆順"
"しっぷ 湿布"
"しっぷう 疾風"
"しっぺい 疾病"
"しっぺがえし しっぺ返し"
"しっぽ 尻尾"
"しっぽう 七宝"
"しっぽうとう 七宝塔"
"しっぽうやき 七宝焼き 七宝焼"
"しっぽく 卓袱"
"しつ 膝 隰 隲 貭 蟋 瑟 濕 出 叱 執 悉 嫉 湿 漆 疾 失 質 室"
"しつい 失意 視追"
"しついん 室員"
"しつう 止痛"
"しつおか 室岡"
"しつおん 室温"
"しつかい 室会"
"しつかん 質感"
"しつがい 膝蓋 室外"
"しつがいこつ 膝蓋骨"
"しつぎ 質疑"
"しつぎょう 失業"
"しつけ 躾 仕付"
"しつげい 漆芸"
"しつげん 湿原 失言"
"しつご 失語"
"しつじ 執事"
"しつじつ 質実"
"しつじゅん 湿潤"
"しつちょう 室長"
"しつてき 質的"
"しつてん 質点"
"しつでん 湿田"
"しつど 湿度"
"しつどう 室堂"
"しつどくしょう 失読症"
"しつどけい 湿度計"
"しつない 室内"
"しつないがく 室内楽"
"しつないこう 室内光"
"しつないとう 室内灯"
"しつねん 失念"
"しつば 叱罵"
"しつばんごう 室番号"
"しつぼう 失望"
"しつむ 悉無 執務"
"しつめい 室名 失明"
"しつもん 質問"
"しつもんばこ 質問箱"
"しつよう 執拗"
"しつらく 失楽"
"しつりょう 室料 質量"
"しつりょうたい 質量体"
"しつりょうぶんせきけい 質量分析計"
"しつれい 失礼"
"しつれいせんばん 失礼千番"
"しつれん 失恋"
"しづえ 志津恵"
"しづか 謐"
"しづがわ 志津川"
"しづく 滴 雫"
"して 爲手 支手 仕手"
"してぃ シティ"
"してい 子弟 姉弟 私邸 師弟 指定"
"していけん 指定券"
"していしゃ 指定車"
"していしゅつりょくそうし 指定出力装置"
"していしょく 指定職"
"していせき 指定席券 指定席"
"していせきけん 指定席券"
"していせきしゃ 指定席車"
"していふく 指定服"
"してき 至適 史的 詩的 私的 指摘"
"してせん 仕手戦"
"してつ 私鉄"
"してん 祀典 祀天 支点 始点 支店 視点"
"してんのう 四天王"
"してんのうじまえ 四天王寺前"
"しで 椣"
"しでむし 埋葬虫"
"しでん 紫電 市電"
"しでんかい 紫電海 紫電改"
"しと 司徒 使徒 使途"
"しとう 至当 死闘"
"しとど 鵐"
"しとね 褥"
"しとみ 蔀"
"しとめにん 仕留人"
"しとやか 淑やか"
"しど 志度"
"しどう 市道 私道 始動 指導"
"しどうようきょうかしょ 指導用教科書"
"しどく 試読"
"しどちょうせい 視度調整"
"しな 科 支那 品"
"しない 竹刀 市内"
"しなうす 品薄"
"しなかず 品数"
"しながわ 品川"
"しながわくひがししながわ 品川区東品川"
"しなぎれ 品切 品切れ"
"しなこ 信成子"
"しなさだめ 品定め"
"しなじな 品々"
"しなぞろえ 品揃え"
"しなだ 品田"
"しなだい 品代"
"しなつるせん 品鶴線"
"しなの 品野 品濃 信濃"
"しなぷす シナプス"
"しなもの 品物"
"しなりお シナリオ"
"しなん 指南 至難"
"しにあ シニア"
"しにがみ 死神"
"しにく 視肉"
"しにせ 老舗"
"しにゅう 刺入"
"しにょう 屎尿 し尿"
"しにん 視認 死人"
"しねま シネマ"
"しねん 思念"
"しの 志乃 詩乃 志野 信乃 紫乃 篠"
"しのかわ 篠川 篠河"
"しのき 篠木"
"しのぎ 凌ぎ 鎬 凌"
"しのくりせん 篠栗線"
"しのざき 篠崎"
"しのしま 篠島"
"しのしょうにん 死の商人"
"しのすけ 志の輔"
"しのたけ 篠竹"
"しのだ 信田 篠田"
"しのづか 篠塚"
"しののい 篠ノ井"
"しののめ 東雲"
"しのはら 篠原"
"しのばず 不忍"
"しのばずぐち 不忍口"
"しのばずのいけ 不忍池"
"しのび 忍び 忍"
"しのびのもの 忍ノ者"
"しのぶ 信夫 偲 紫伸 忍"
"しのぶえ 篠笛"
"しのぶぐさ 荵"
"しのみや 四宮 四ノ宮 篠宮"
"しのむら 篠村"
"しのもと 篠本"
"しのやま 篠山"
"しのろ 篠路"
"しはい 紙背 賜杯 支配"
"しはいぎ 支配木"
"しはく 糸帛"
"しはす 師走"
"しはつ 始発"
"しはらい 支払い 支払"
"しはらいがく 支払額"
"しはらいずみ 支払済"
"しはらいせきにんがく 支払責任額"
"しはん 紫斑 四半 師範 市販"
"しはんしゃ 市販車"
"しはんやく 市販薬"
"しば 斯波 死馬 司馬 柴 芝"
"しばい 芝居"
"しばいけ 芝池"
"しばいじゃや 芝居茶屋"
"しばうら 芝浦"
"しばかり 柴刈り 柴刈 芝刈"
"しばかわ 芝川"
"しばがき 柴垣"
"しばくさ 芝草"
"しばけいけん 芝経験"
"しばこうえん 芝公園"
"しばこうだい 芝工大"
"しばさき 柴崎"
"しばざき 柴崎"
"しばし 暫し 暫"
"しばした 芝下"
"しばしば 屡々 屡ゝ 屡"
"しばす 市バス 始バス"
"しばせいねんかいかん 芝青年会館"
"しばた 芝田 新発田 柴多 柴田"
"しばち 芝地"
"しばの 芝野 柴野"
"しばはま 芝浜"
"しばはら 紫原 芝原"
"しばふ 芝生"
"しばふせき 芝生席"
"しばまた 柴又"
"しばまち 柴町"
"しばみや 柴宮"
"しばやま 芝山 柴山"
"しばらく 暫く"
"しばれる 凍れる"
"しばん 篩板 指板"
"しひ 市費 私費"
"しひょう 死票 私評 指標"
"しびれ 痺"
"しびん 溲瓶"
"しふく 紙幅 私腹 至福 雌伏 私服"
"しふと シフト"
"しふん 私憤"
"しぶ 篩部 澀 市部 澁 ４分 渋 支部"
"しぶあき ４分空"
"しぶい 渋井"
"しぶいち 四分一"
"しぶおんぷ 四分音符"
"しぶかわ 渋皮 渋川"
"しぶがきたい シブがき隊"
"しぶき 沫 飛沫"
"しぶこう 渋公"
"しぶさわ 澁澤 渋沢"
"しぶし 志布志"
"しぶしぶ 渋々"
"しぶた 渋田"
"しぶたに 渋谷"
"しぶつ 私物"
"しぶとうげ 渋峠"
"しぶみ 渋み"
"しぶみがわ 渋海川"
"しぶや 澁谷 渋谷"
"しぶやく 澁谷區"
"しぶろく 四分六"
"しぶん 詩文"
"しぶんか 死文化"
"しぶんしょ 私文書"
"しへい 子平 紙幣"
"しへん 四辺 紙片 詩篇"
"しへんけい 四辺形"
"しべ 蕋 蘂 蕊"
"しべちゃ 標茶"
"しべつ 死別 標津 士別 標別"
"しべとろ 蕊取"
"しべりあ 西伯利亞"
"しべん 至便 支弁 思弁"
"しほ 志帆 鹽 潮 汐 紫穂 志穂 志保"
"しほう 視法 市報 至宝 司法 四方 紫峰"
"しほこ 志保子"
"しほさゐ 潮騒"
"しほどき 潮時"
"しほひ 潮干"
"しほふき 潮吹き"
"しほろ 士幌"
"しほん 資本"
"しほんか 資本家"
"しぼ 思慕"
"しぼう 子房 脂肪 志望 死亡"
"しぼうさん 脂肪酸"
"しぼうた 柴生田"
"しぼうゆ 脂肪油"
"しぼくのしん 徙木之信"
"しぼつ 死歿 死没"
"しぼり 絞り"
"しま 四万 志麻 揣摩 嶌 志真 志摩 嶋 縞 島"
"しまい 仕舞い 仕舞 姉妹"
"しまいしゃ 姉妹車"
"しまいへん 姉妹篇"
"しまいやく 姉妹役"
"しまうち 島内"
"しまうま シマウマ"
"しまお 嶋尾"
"しまおか 島岡"
"しまかげ 島影 島陰"
"しまがはら 島ヶ原"
"しまきんぺん 島近辺"
"しまぐに 島国"
"しまこ 志麻子"
"しまこうさく 島耕作"
"しまこうぞう 縞構造"
"しまさき 嶋崎 島崎"
"しまざき 嶋崎 島崎"
"しましま 縞々"
"しまじょう 縞状"
"しまじり 島尻"
"しまず 島津"
"しませ 島瀬"
"しません 島線"
"しませんき 島戦記"
"しまぜんぶ 島全部"
"しまたに 嶋谷 島谷"
"しまだ 嶋田 島田"
"しまつ 嶋津 始末"
"しまづ 嶋津 島津"
"しまてつ 島鉄"
"しまとう 島藤"
"しまなか 島中 嶋中"
"しまね 島根"
"しまの 嶋野 島野"
"しまのせき 島ノ関"
"しまばら 島原"
"しまばらこう 島原港"
"しまばらさん 島原山"
"しまひ 仕舞ひ"
"しまぶくろ 島袋"
"しまほうめん 島方面"
"しままき 島牧"
"しままと 島本"
"しまみや 嶋宮"
"しまむら 嶋村 島村"
"しまもと 島本"
"しまもよう 縞模様"
"しまもり 島森"
"しまや 島谷"
"しまり 締"
"しまわき 嶋脇"
"しまんとがわ 四万十川"
"しみ 染み 紙魚 汚点 衣魚"
"しみじみ 沁々 染々"
"しみず 紫水 志水 清水"
"しみずかわ 清水川"
"しみずさわ 清水沢"
"しみずしょう 清水商"
"しみずだいら 清水平"
"しみずだに 清水谷"
"しみずぬま 清水沼"
"しみずはら 清水原"
"しみずひがし 清水東"
"しみゃく 支脈"
"しみゅれーしょん シミュレーション"
"しみゅれーたー シミュレーター"
"しみん 嗜眠 市民"
"しみんぜい 市民税"
"しみんてきじゆう 市民的自由"
"しみんびょうどう 四民平等"
"しむかっぷ 占冠"
"しむけ 仕向"
"しむら 志村"
"しめ 締 志免 〆 締め 示"
"しめい 市名 紙名 死命 誌名 指命 使命 指名 氏名"
"しめきり 締め切り 〆切 締切"
"しめぐ 締具"
"しめつ 死滅"
"しめなわ 注連縄"
"しめの 示野"
"しめび 締日"
"しめりゆき 湿り雪"
"しめん 四面 誌面 紙面"
"しめんそか 四面楚歌"
"しも 霜 下"
"しもあがた 下県"
"しもあやし 下愛子"
"しもい 下位 下井"
"しもいぐさ 下井草"
"しもいだ 下井田"
"しもいち 下市 下一"
"しもいな 下伊那"
"しもいなば 下稲葉"
"しもう 刺毛"
"しもうさ 下総"
"しもうま 下馬"
"しもお 下尾"
"しもおちあい 下落合"
"しもかぬき 下香貫"
"しもかまがり 下蒲刈"
"しもかわ 下川"
"しもがも 下鴨"
"しもがもおんせん 下賀茂温泉"
"しもがれ 霜枯れ"
"しもき 下期"
"しもきた 下北"
"しもきたざわ 下北沢"
"しもきたざわしょ 下北沢署"
"しもぎょう 下京"
"しもくに 下國"
"しもくろかわ 下黒川"
"しもげ 下毛"
"しもこしき 下甑"
"しもごう 下郷"
"しもごおり 下郡"
"しもさくのべ 下作延"
"しもざ 下座"
"しもざと 下里"
"しもざわ 下沢"
"しもしき 下敷"
"しもしきりょう 下敷領"
"しもしん 下新"
"しもじ 下地"
"しもじま 下嶋"
"しもじも 下下 下々"
"しもじゅう 下重"
"しもじょう 下条 下城 下條"
"しもすわ 下諏訪"
"しもせわ 下世話"
"しもぞの 下薗 下園"
"しもたかい 下高井"
"しもたかいど 下高井戸"
"しもたかの 下高野"
"しもだ 下田"
"しもだいら 下平"
"しもだて 下館"
"しもちしま 下地島"
"しもちゃ 下家"
"しもつ 下津"
"しもつい 下津井"
"しもつが 下都賀"
"しもつき 霜月"
"しもつけ 下野"
"しもつじ 下辻"
"しもつま 下妻"
"しもづま 下妻"
"しもて 下手"
"しもとり 霜鳥 霜取 下鳥"
"しもなり 下成"
"しもにいかわ 下新川"
"しもにた 下仁田"
"しもねた 下ネタ"
"しもの 下野"
"しものく 下の句"
"しものせき 下関"
"しものせきみなみこう 下関南高"
"しものだふきん 下野田付近"
"しもはんき 下半期"
"しもばしら 霜柱"
"しもばやし 下林"
"しもひとけた 下一桁"
"しもふさ 下総"
"しもふり 霜降り"
"しもへい 下閉伊"
"しもべ 僕 下部 下僕"
"しもましき 下益城"
"しもまるこ 下丸子"
"しもみち 下道"
"しもみのち 下水内"
"しもむ 下無"
"しもむら 下村"
"しもめぐろ 下目黒"
"しもやけ 霜焼け"
"しもやなぎ 下柳"
"しもやま 霜山 下山"
"しもやまて 下山手"
"しもよし 下吉"
"しもれんじゃく 下連雀"
"しもん 子門 試問 指紋 諮問"
"しゃ 西 蔗 鷓 赭 舍 炙 瀉 洒 寫 娑 奢 冩 這 沙 砂 遮 赦 紗 捨 射 舎 煮 謝 斜 写 車 社 者"
"しゃーぷ シャープ"
"しゃあ 西"
"しゃい 斜位 謝意"
"しゃいん 社印 社員"
"しゃいんりょう 社員寮"
"しゃうん 社運"
"しゃえい 射影"
"しゃおく 社屋"
"しゃおん 遮音 謝恩"
"しゃか 社歌 釈迦"
"しゃかい 社会"
"しゃかいあく 社会悪"
"しゃかいこう 社会工"
"しゃかいぜんかんげん 社会全還元"
"しゃかいぞう 社会増"
"しゃかいとう 社会党"
"しゃかく 射角 車格"
"しゃかっこう 斜滑降"
"しゃかん 車間 舎監"
"しゃがい 車外 社外"
"しゃがいひ 社外秘"
"しゃがく 写楽"
"しゃき 社旗"
"しゃきゅう 社給"
"しゃきょう 写経"
"しゃきん 謝金"
"しゃぎょう 社業"
"しゃく 蜥 炸 蹟 鑠 釋 芍 綽 皙 癪 爍 斫 妁 嚼 笏 赤 石 勺 杓 灼 爵 酌 尺 錫 借 昔 釈"
"しゃくい 爵位"
"しゃくざい 借財"
"しゃくし 杓子"
"しゃくじ 借字"
"しゃくじい 石神井"
"しゃくじょう 錫杖"
"しゃくぜん 釈然"
"しゃくそん 釈尊"
"しゃくち 借地"
"しゃくとりむし 尺蠖 尺取虫"
"しゃくど 赤土 尺度"
"しゃくどう 赤銅"
"しゃくにゅう 借入"
"しゃくねつ 灼熱"
"しゃくはち 尺八"
"しゃくふ 酌婦"
"しゃくぶく 折伏"
"しゃくほう 釈放"
"しゃくま 借間"
"しゃくめい 綽名 釈明"
"しゃくや 借家"
"しゃくやく 芍薬"
"しゃくよう 借用"
"しゃくようねがい 借用願"
"しゃくりょう 酌量"
"しゃくん 社訓"
"しゃけ 鮭"
"しゃけいよう 写経用"
"しゃけつ 瀉血 冩血"
"しゃけん 写研 車検"
"しゃけんぎれ 車検切"
"しゃげき 射撃"
"しゃこ 蝦蛄 車庫"
"しゃこう 遮光 斜行 社交 車高"
"しゃこうざひょう 斜交座標"
"しゃこうし 斜行枝"
"しゃこうしん 射倖心 射幸心"
"しゃこく 社告"
"しゃこたん 積丹"
"しゃこたんはんとうおき 積丹半島沖"
"しゃさい 車載 社債"
"しゃさつ 射殺"
"しゃざい 謝罪"
"しゃし 奢肆 奢恣 奢侈 社史 斜視"
"しゃしつ 車室"
"しゃしゃく 車借"
"しゃしゅ 社主 射手 車種"
"しゃしゅごと 車種毎"
"しゃしゅつ 射出"
"しゃしょう 蔗漿 社章 捨象 車掌"
"しゃしょうしゃ 車掌車"
"しゃしょく 社食 写植"
"しゃしょくようげんこう 写植用原稿"
"しゃしょゆう 社所有"
"しゃしん 写真"
"しゃしんいり 写真入 写真入り"
"しゃしんうつり 写真写り"
"しゃしんか 写真家"
"しゃしんじゅく 写真塾"
"しゃしんてん 写真展"
"しゃじ 社寺 斜字 謝辞"
"しゃじく 車軸"
"しゃじたい 斜字体"
"しゃじつ 写実"
"しゃじゅう 車重"
"しゃじょう 車上 謝状"
"しゃせい 社製 写生 射精"
"しゃせつ 社説"
"しゃせん 斜線 車線"
"しゃせんごと 車線毎"
"しゃぜ 社是"
"しゃぜつ 謝絶"
"しゃそう 斜走 車窓 社葬"
"しゃそく 社則 社足 車速"
"しゃぞう 写像"
"しゃたい 斜体 車体"
"しゃたいうしろはし 車体後端"
"しゃたいへき 車体壁"
"しゃたく 社宅"
"しゃたんぶ 車端部"
"しゃだい 社台"
"しゃだつ 洒脱"
"しゃだん しゃ断 射断 遮断 社団"
"しゃだんぼう 遮断棒"
"しゃち 鯱"
"しゃちほこ 鯱 鯱鉾"
"しゃちゅう 社中 車中"
"しゃちょう 車長 社長"
"しゃっかん 借款"
"しゃっかんほう 尺貫法"
"しゃっきん 借金"
"しゃっきんおとこ 借金男"
"しゃっく 赤口"
"しゃっけい 借景"
"しゃっこう 赤光 灼光 笏康"
"しゃっこつ 尺骨"
"しゃったー シャッター"
"しゃつ シャツ"
"しゃてい 射程"
"しゃてき 射的"
"しゃとう 車頭 斜塔"
"しゃど 斜度"
"しゃどう 車道"
"しゃな 紗那"
"しゃない 車内 社内"
"しゃないとう 車内灯"
"しゃないほう 社内報"
"しゃないほじゅうけん 車内補充券"
"しゃないむけ 社内向"
"しゃにくさい 謝肉祭"
"しゃにむに 遮二無二"
"しゃにゅう 西入"
"しゃねつ 遮熱"
"しゃはば 車幅"
"しゃはん 社販 車販"
"しゃば 車馬 娑婆"
"しゃばくじょう 射爆場"
"しゃばん 社判 車番"
"しゃひ 社費"
"しゃび 奢靡"
"しゃふ 写譜"
"しゃふう 社風"
"しゃふく 車幅"
"しゃふつ 煮拂 煮沸"
"しゃぶんれつ 斜分裂"
"しゃへい 遮へい 遮蔽"
"しゃへいざい 遮蔽材"
"しゃへいたい 遮蔽体"
"しゃへいばん 遮蔽板"
"しゃへん 斜辺"
"しゃほ 社保"
"しゃほう 車砲"
"しゃほたん 社保短"
"しゃほん 写本"
"しゃまく 紗幕"
"しゃみせん 三味線"
"しゃみんれん 社民連"
"しゃむ 暹羅"
"しゃむしょ 社務所"
"しゃめい 社命 車名 社名"
"しゃめん 赦免 斜面"
"しゃも 軍鶏"
"しゃもん 沙門"
"しゃゆう 社有 社友"
"しゃよう 斜陽 社用"
"しゃらく 酒楽 写楽"
"しゃらそうじゅ 娑羅双樹"
"しゃり 斜里"
"しゃりき 車力"
"しゃりょう 車輌 車輛 車両"
"しゃりょうぐち 車両口"
"しゃりょうばんごうひょう 車両番号標"
"しゃりん 車輪"
"しゃれ 洒落 シャレ"
"しゃれい 車齢 謝礼"
"しゃれき 車歴 社歴"
"しゃれつ 斜列"
"しゃわー シャワー"
"しゃんはい 上海"
"しゃんはいかぶ 上海株"
"しゃんはいがに 上海蟹"
"しゃんぱん 三鞭酒"
"しゃんぷー シャンプー"
"しや 視野"
"しやかく 視野角"
"しやく 試訳 試薬"
"しやくしょ 市役所"
"しやけ 初宿"
"しゅ 撞 麈 鬚 銖 蛛 繻 洙 殳 椶 棕 娶 娵 侏 踵 殊 珠 腫 朱 狩 守 修 趣 酒 首 取 手 種 主"
"しゅーず シューズ"
"しゅーまい 焼売 シューマイ"
"しゅい 種衣 趣意 主意 首位"
"しゅいがため 首位固め"
"しゅいろ 朱色"
"しゅいん 手淫 主因"
"しゅう 鍬 鰍 聚 摺 驟 駲 鞦 銹 逎 遒 蹤 踵 讎 褶 螽 蓚 脩 羞 緝 綉 甃 溲 湫 泅 楫 楸 收 慴 慫 愀 岫 啾 售 萩 朱 執 嗅 繍 囚 宗 洲 蒐 酋 酬 就 蹴 輯 愁 舟 臭 祝 襲 讐 秀 周 醜 州 終 拾 衆 習 秋 収 修 集 週"
"しゅうあく 醜悪"
"しゅうあけ 週明け 週開け"
"しゅうい 修理 周位 衆意 拾遺 周囲"
"しゅういち 周一 秀一 修一 週一"
"しゅういちろう 修一郎 周一郎"
"しゅういっかい 週一回"
"しゅういつ 秀逸"
"しゅういん 執印 衆院"
"しゅういんせん 衆院選"
"しゅうう 驟雨"
"しゅうえい 秀英"
"しゅうえいしゃ 集英社"
"しゅうえき 就役 収益"
"しゅうえつ 収悦"
"しゅうえん 周縁 終鴛 終宴 終演 終焉"
"しゅうえんそうち 集煙装置"
"しゅうおん 集音 収音"
"しゅうおんらい 周恩来"
"しゅうか 衆寡 衆化 集荷"
"しゅうかい 醜怪 聚會 集塊 周回 集会"
"しゅうかいじょ 集会所"
"しゅうかいろ 周回路"
"しゅうかく 臭覚 嗅覚 収獲 収穫"
"しゅうかくさい 収穫祭"
"しゅうかん 終巻 終刊 収監 週刊 習慣 週間"
"しゅうかんごと 週間毎"
"しゅうかんし 週刊紙"
"しゅうかんようはんたいじ 習慣用繁体字"
"しゅうがく 就学 修学"
"しゅうがくいん 修学院"
"しゅうがくしょう 終楽章"
"しゅうき 終帰 秋気 秋期 臭気 終期 周忌 周期 秋季"
"しゅうきかい 周期解"
"しゅうきじ 集記事"
"しゅうきせつ 周期説"
"しゅうきほう 集気法"
"しゅうきゃく 集客"
"しゅうきゅう 週給 蹴球 週休"
"しゅうきょう 宗教"
"しゅうきょうか 宗教家"
"しゅうきょく 周極 褶曲 終局 終曲"
"しゅうきりつ 周期律"
"しゅうきん 集金"
"しゅうきんぶくろ 集金袋"
"しゅうぎ 衆議 祝儀"
"しゅうぎいん 衆議院"
"しゅうぎいんせんきょ 衆議員選挙"
"しゅうぎく 秋菊"
"しゅうぎょう 修業 終業 就業"
"しゅうぎょこうか 集魚効果"
"しゅうぐ 衆愚"
"しゅうぐん 州軍"
"しゅうけい 修景 集計"
"しゅうけつ 集結 終結"
"しゅうけん 集権"
"しゅうけんてき 集圏的"
"しゅうげき 襲撃"
"しゅうげん 祝言"
"しゅうこ 収子 修子"
"しゅうこう 秋向 修好 就航 周航 集光 周行"
"しゅうごう 集合"
"しゅうごうか 集合果"
"しゅうごうざい 集合材"
"しゅうごうたい 集合体"
"しゅうごろう 脩五郎 周五郎"
"しゅうさ 収差"
"しゅうさい 集載 収載 秀才"
"しゅうさく 周作 習作 秀策 秀作"
"しゅうさつ 集札"
"しゅうさん 蓚酸 衆参 集散"
"しゅうさんぎょうしゅぎ 集産業主義"
"しゅうざい 秋材 集材"
"しゅうざかい 州境"
"しゅうし 終止 宗旨 終始 収支 修士"
"しゅうしいちねん 修士壱年"
"しゅうしき 終式"
"しゅうしけい 終止形"
"しゅうしふ 終始符 終止符"
"しゅうしぼ 収支簿"
"しゅうしゃ 終車"
"しゅうしゅう 集収 啾啾 集輯 拾集 蒐集 収拾 収集"
"しゅうしゅうか 収集家"
"しゅうしゅうしゃ 収集車"
"しゅうしゅく 収縮"
"しゅうしゅくこん 収縮根"
"しゅうしょう 就床 周章 終章 修証 愁傷"
"しゅうしょく 修飾 就職"
"しゅうしょくぐち 就職口"
"しゅうしょくなん 就職難"
"しゅうしん 集信 修身 終身 執心 就寝"
"しゅうしんけい 終身刑"
"しゅうじ 秀次 修次 宗司 秀治 秀司 修二 修治 周二 修辞 習字 修司"
"しゅうじつ 週日 終日"
"しゅうじゅうろう 宗十郎"
"しゅうじゅく 習熟"
"しゅうじゅくてきほうほう 習熟的方法"
"しゅうじょうたい 終状態"
"しゅうじょし 終助詞"
"しゅうじん 衆人 囚人"
"しゅうじんき 集塵器"
"しゅうじんせん 囚人船"
"しゅうじんふく 囚人服"
"しゅうせい 輯成 終生 終世 集成 修整 習性 修正"
"しゅうせいあん 修正案"
"しゅうせいえき 修正液"
"しゅうせいずみ 修正済"
"しゅうせいなし 修正無"
"しゅうせいよう 修正要"
"しゅうせき 集積"
"しゅうせきたい 集積体"
"しゅうせん 鞦韆 集線 終戰 終戦 周旋"
"しゅうぜい 州税"
"しゅうぜん 修繕"
"しゅうそ 愁訴 臭素"
"しゅうそう 終相 愀愴 秋霜"
"しゅうそく 周速 終熄 終息 集束 収束"
"しゅうそくけい 収束形"
"しゅうそさん 臭素酸"
"しゅうぞう 脩三 修造 収蔵 秀三 収三 修三"
"しゅうぞく 習俗"
"しゅうたい 醜態"
"しゅうたいしょう 終対象"
"しゅうたいせい 集大成"
"しゅうたろう 終太郎"
"しゅうたん 愁嘆 終端"
"しゅうたんい 週単位"
"しゅうたんば 愁嘆場"
"しゅうだいすう 終代数"
"しゅうだん 終段 集団"
"しゅうち 周緻 衆知 習知 周智 羞恥 周知"
"しゅうちく 修築"
"しゅうちしん 羞恥心"
"しゅうちゃく 終着 執着"
"しゅうちゃくしん 執着心"
"しゅうちゅう 集中"
"しゅうちゅうやく 集中役"
"しゅうちょう 酋長 周長"
"しゅうづら 主面"
"しゅうてい 舟艇"
"しゅうていばん 修訂版"
"しゅうてん 秋天 終点"
"しゅうてんえん 周転円"
"しゅうでん 集電 終電"
"しゅうでんしゃ 終電車"
"しゅうと 舅 修斗 姑"
"しゅうとう 周東 秋冬 周到"
"しゅうとく 修徳 拾得 収得 習得 修得"
"しゅうとめ 姑"
"しゅうどう 摺動 修道"
"しゅうどういん 修道院"
"しゅうどうし 修道士"
"しゅうどうそう 修道僧"
"しゅうにゅう 収入"
"しゅうにゅうげん 収入源"
"しゅうにん 就任"
"しゅうにんほうどう 辞任報道"
"しゅうねん 執念 周年"
"しゅうのう 収納"
"しゅうのうぶくろ 収納袋"
"しゅうのうようぶくろ 収納用袋"
"しゅうは 秋波 周波 宗派"
"しゅうはい 集配"
"しゅうはいしん 集配信"
"しゅうはすうこうぞうかふぃるた 周波数構造化フィルタ"
"しゅうはすうじく 周波数軸"
"しゅうはすうひょうほんかこうぞうふぃるた 周波数標本化構造フィルタ"
"しゅうはすうまど 周波数窓"
"しゅうはつ 終発"
"しゅうばす 終バス"
"しゅうばん 終板 終盤"
"しゅうばんしゅ 終盤手"
"しゅうばんせん 終盤戦"
"しゅうひ 周皮"
"しゅうび 秀美 秀眉 愁眉"
"しゅうふ 呪符"
"しゅうふく 修復"
"しゅうふつ 修祓"
"しゅうふつか 週二日"
"しゅうぶん 醜聞 秋分"
"しゅうへい 州兵 修平 周平"
"しゅうへき 習癖"
"しゅうへん 周辺"
"しゅうへんし 周辺視"
"しゅうへんぞう 周辺像"
"しゅうほう 秋芳 秀芳 州法 週報"
"しゅうほうどう 秋芳洞"
"しゅうぼう 衆望"
"しゅうまく 終幕"
"しゅうまつ 終末 週末"
"しゅうみつ 周密"
"しゅうみん 就眠"
"しゅうめ 周目 週目"
"しゅうめい 襲名"
"しゅうもく 衆目"
"しゅうや 秀哉 終夜"
"しゅうやく 集約"
"しゅうゆう 周遊"
"しゅうゆうかん 修猷館"
"しゅうゆうけん 周遊券"
"しゅうゆうけんがいくかん 周遊券外区間"
"しゅうよう 数 修養 収用 収容"
"しゅうようじょ 収容所"
"しゅうら 修羅"
"しゅうらい 襲来"
"しゅうらく 聚落 集落"
"しゅうらん 秀蘭"
"しゅうり 修理"
"しゅうりざい 修理材"
"しゅうりつ 収率 州立"
"しゅうりひ 修理費"
"しゅうりょう 秋涼 収量 修了 終了"
"しゅうれい 週令 秀麗 秋冷"
"しゅうれっしゃ 終列車"
"しゅうれん 收斂 収斂 修練"
"しゅうろう 秀朗 就労 周郎"
"しゅうろく 集録 収録"
"しゅうろくさく 収録作"
"しゅうろくじゅん 収録順"
"しゅうろん 修論"
"しゅうわ 秀和"
"しゅうわい 収賄"
"しゅうわいざい 収賄罪"
"しゅえい 守衛"
"しゅえいじょ 守衛所"
"しゅえん 主煙 酒宴 主演"
"しゅおう 手応"
"しゅおん 主音"
"しゅか 酒家 種化"
"しゅかい 首魁"
"しゅかく 主客 主格"
"しゅかん 首巻 主管 主観 主幹"
"しゅが 主芽"
"しゅがー シュガー"
"しゅがん 主眼"
"しゅき 主機 朱記 首記 酒気 手記"
"しゅきゃく 主脚 主客"
"しゅきゅう 首級"
"しゅきょう 主教"
"しゅきん 手巾"
"しゅぎ 手技 主義"
"しゅぎょう 修業 修行"
"しゅぎょうどう 修行堂"
"しゅぎょく 珠玉"
"しゅく 蓿 菽 肅 倏 槭 俶 粥 珠久 蹙 叔 夙 粛 淑 縮 宿 祝"
"しゅくあ 宿痾"
"しゅくい 祝意"
"しゅくえん 祝宴"
"しゅくが 祝賀"
"しゅくがおんれつ 祝賀御列"
"しゅくがわ 夙川"
"しゅくがわら 宿河原"
"しゅくがん 宿願"
"しゅくぎ 祝儀"
"しゅくけいえん 縮景園"
"しゅくげん 縮減"
"しゅくこ 祝子"
"しゅくごう 宿業"
"しゅくさい 祝祭"
"しゅくさいじつ 祝祭日"
"しゅくさつ 縮刷"
"しゅくしゃ 縮写 宿舎"
"しゅくしゃく 縮尺"
"しゅくしゅ 宿主"
"しゅくしゅく 粛粛 粛々"
"しゅくしょう 縮少 縮小"
"しゅくしょうかい 祝勝会"
"しゅくじ 祝辞"
"しゅくじつ 祝日"
"しゅくじょ 淑女"
"しゅくず 縮図"
"しゅくせい 粛清 粛正"
"しゅくぜん 宿善"
"しゅくそつぎょう 祝卒業"
"しゅくたい 縮退"
"しゅくだい 宿題"
"しゅくちょく 宿直"
"しゅくてき 宿敵"
"しゅくてん 祝典"
"しゅくでん 祝電"
"しゅくとく 淑徳"
"しゅくにっちょく 宿日直"
"しゅくはい 祝杯"
"しゅくはく 宿泊"
"しゅくはくきゃく 宿泊客"
"しゅくはくけん 宿泊券"
"しゅくはくじょ 宿泊所"
"しゅくはくとう 宿泊棟"
"しゅくはくひ 宿泊費"
"しゅくば 宿場"
"しゅくふく 祝福"
"しゅくほう 祝砲"
"しゅくぼう 宿坊 宿望"
"しゅくまる 宿丸"
"しゅくめい 宿命"
"しゅくもくひょうたっせい 祝目標達成"
"しゅくやく 縮約"
"しゅくん 殊勲 主君"
"しゅけい 主計 主系"
"しゅけいかん 主計監"
"しゅけいせい 種形成"
"しゅけん 主権"
"しゅけんざいみん 主権在民"
"しゅげい 手芸"
"しゅげた 主桁"
"しゅげんどう 修験道"
"しゅこ 朱子"
"しゅこう 珠孔 首肯 酒肴 趣向"
"しゅこうぎょう 手工業"
"しゅこうげい 手工芸"
"しゅこん 主根 酒魂"
"しゅご 守護 主語"
"しゅごう 酒豪"
"しゅごしん 守護神"
"しゅごせい 守護星"
"しゅごれい 守護霊"
"しゅさ 主鎖 主査"
"しゅさい 主宰 主催"
"しゅさいじあい 主催試合"
"しゅざい 取材"
"しゅざいはん 取材班"
"しゅざん 珠算"
"しゅし 繻竢 種子 趣旨 主旨"
"しゅしがく 朱子学"
"しゅしさぎょう 手指作業"
"しゅししょくぶつもん 種子植物門"
"しゅしゃ 種車 取捨"
"しゅしゅ 種々"
"しゅしゅつ 収出"
"しゅしょ 朱書"
"しゅしょう 酒漿 首唱 殊勝 主唱 主将 首相"
"しゅしょく 主食"
"しゅしん 主神 珠心 主審"
"しゅしんか 種進化"
"しゅじ 主餌 主辞 主事"
"しゅじい 主治医"
"しゅじく 主軸"
"しゅじゃく 朱雀"
"しゅじゅ 侏儒 種々"
"しゅじゅう 主従"
"しゅじゅつ 手術"
"しゅじゅつあと 手術跡"
"しゅじょう 衆生"
"しゅじん 主人"
"しゅじんこう 主人公"
"しゅす 繻子"
"しゅすい 取水"
"しゅすう 種数"
"しゅせい 酒精 守勢"
"しゅせき 酒石 酒席 首席 主席"
"しゅせきえい 酒石英"
"しゅせきさん 酒石酸"
"しゅせつ 取説"
"しゅせん 主戦"
"しゅせんど 守銭奴"
"しゅぜい 酒税"
"しゅぜいきょく 主税局"
"しゅぜん 酒膳"
"しゅぜんじ 修善寺"
"しゅぜんたい 種全体"
"しゅそ 主訴"
"しゅそう 主相"
"しゅぞう 酒蔵 酒造"
"しゅぞうし 酒造史"
"しゅぞく 種族"
"しゅたい 主体"
"しゅだい 腫大 主代 主題"
"しゅだいか 主題歌"
"しゅだいけいじ 主題提示"
"しゅだん 手段"
"しゅち 恤 主値"
"しゅちせつ 主知説"
"しゅちにくりん 酒池肉林"
"しゅちゅう 手中"
"しゅちょ 主著"
"しゅちょう 腫脹 主徴 首長 主潮 主張"
"しゅちょうこくれんぽう 首長国連邦"
"しゅちょうちゅう 出張中"
"しゅっか 出火 出荷"
"しゅっかがく 出荷額"
"しゅっかん 出棺"
"しゅっきん 出金 出勤"
"しゅっきんぼ 出勤簿"
"しゅっけ 出家"
"しゅっけつ 出血 出欠"
"しゅっこ 出庫"
"しゅっこう 出稿 出港 出航 出向"
"しゅっこく 出国"
"しゅっこくぜい 出国税"
"しゅっさつがかり 出札係"
"しゅっさつぐち 出札口"
"しゅっさつほじゅうけん 出札補充券"
"しゅっさん 出産"
"しゅっし 出資"
"しゅっしゃ 出射 出社"
"しゅっしょ 出処 出所"
"しゅっしょう 出生"
"しゅっしょく 出食 出色"
"しゅっしん 出身"
"しゅっすい 出水"
"しゅっせ 出瀬 出世"
"しゅっせい 出征 出生"
"しゅっせいとどけ 出生届"
"しゅっせうお 出世魚"
"しゅっせき 出席"
"しゅっせきぼ 出席簿"
"しゅっせさく 出世作"
"しゅっせばらい 出世払い"
"しゅっそう 出槽 出走"
"しゅっそうしゃめいぼ 出走者名簿"
"しゅっそうば 出走馬"
"しゅっそうよていば 出走予定馬"
"しゅったい 出待"
"しゅったいきん 出退勤"
"しゅったつ 出立"
"しゅったん 出炭"
"しゅっちょう 出超 出張"
"しゅっちょうじょ 出張所"
"しゅっちょうひ 出張費"
"しゅってい 出艇 出廷"
"しゅってん 出店 出展 出典"
"しゅっとう 出頭"
"しゅっぱつ 出発"
"しゅっぱん 出帆 出版"
"しゅっぱんふ 出版譜"
"しゅっぴ 出費"
"しゅっぴみてい 出否未定"
"しゅっぴん 出品"
"しゅっぺい 出兵"
"しゅっぽん 出奔"
"しゅつ 恤 蟀 出"
"しゅつえき 出役"
"しゅつえん 出演"
"しゅつえんさく 出演作"
"しゅつえんしゃごと 出演者毎"
"しゅつがん 出願"
"しゅつげき 出撃"
"しゅつげん 出現"
"しゅつごく 出獄"
"しゅつじ 出自"
"しゅつじょう 出状 出場"
"しゅつじょうば 出場馬"
"しゅつじょうわく 出場枠"
"しゅつじん 出陣"
"しゅつだい 出題"
"しゅつど 出土"
"しゅつどう 出動"
"しゅつにゅう 出入"
"しゅつにゅうこしゃ 出入庫車"
"しゅつば 出馬"
"しゅつぼつ 出没"
"しゅつもくよそう 出目予想"
"しゅつらん 出藍"
"しゅつり 出離"
"しゅつりょう 出猟 出漁"
"しゅつりょく 出力"
"しゅつりょくし 出力紙"
"しゅつりょくじく 出力軸"
"しゅつるい 出塁"
"しゅてん 主点"
"しゅてんどうじ 酒呑童子 手天童子"
"しゅと 首都"
"しゅとう 手刀 種痘 首藤"
"しゅとく 取得"
"しゅとこう 首都高"
"しゅとこうした 首都高下"
"しゅとして 主として"
"しゅどう 衆道 首藤 主動 主導 手動"
"しゅにく 朱肉"
"しゅにん 主任"
"しゅのう 首脳"
"しゅはく 手搏"
"しゅはすうひょうほんか 周波数標本化"
"しゅはん 主犯"
"しゅばい 酒売"
"しゅひ 珠皮 種皮 守秘"
"しゅひつ 朱筆 主筆"
"しゅひん 主賓"
"しゅび 首尾 守備"
"しゅびょうほう 種苗法"
"しゅびよく 首尾よく"
"しゅふ 首府 主夫 主婦"
"しゅふぎょう 主婦業"
"しゅふく 首服"
"しゅふやく 主婦役"
"しゅぶん 主文"
"しゅぷーる シュプール"
"しゅへい 珠柄"
"しゅべつ 種別"
"しゅべつごと 種別毎"
"しゅべつじゅん 種別順"
"しゅほ 酒保"
"しゅほう 主砲 主峰 手法"
"しゅほうしゃ 首謀者"
"しゅぼう 首謀"
"しゅぼうしゃ 主謀者"
"しゅぼば 種牡馬"
"しゅまい 酒米"
"しゅみ 趣味"
"しゅみせん 須弥山"
"しゅみゃく 主脈"
"しゅむ 主務"
"しゅもく 撞木 種目"
"しゅもくぞり 撞木反り"
"しゅやく 主役"
"しゅやくかく 主役格"
"しゅゆ 須臾"
"しゅよう 腫瘍 主要"
"しゅよく 主翼"
"しゅら 修羅"
"しゅらおう 修羅王"
"しゅらば 修羅場"
"しゅらん 酒乱"
"しゅり 首里"
"しゅりけん 手裏剣"
"しゅりゅう 腫瘤 主流"
"しゅりゅうだん 手溜弾 手榴弾"
"しゅりょう 酒量 首領 狩猟"
"しゅりょうけん 狩猟犬"
"しゅりょうじゅう 狩猟獣 狩猟銃"
"しゅりょうほういはん 狩猟法違反"
"しゅりょく 主力"
"しゅるい 酒類 種類"
"しゅるいごと 種類毎"
"しゅろ 椶櫚 棕櫚"
"しゅわ 手話"
"しゅわん 手腕"
"しゅん 筍 雋 逡 蠢 蕣 皴 濬 浚 惷 悛 墫 儁 駿 竣 峻 舜 旬 俊 瞬 春"
"しゅんいち 峻一 俊一"
"しゅんいちろう 俊一朗 俊一郎"
"しゅんえい 俊英"
"しゅんか 春歌 春夏"
"しゅんかどう 春華堂"
"しゅんかん 春寒 瞬間"
"しゅんかんげい 瞬間芸"
"しゅんが 春画"
"しゅんき 峻輝 春季 春期"
"しゅんきち 駿吉"
"しゅんぎく 春菊"
"しゅんぎょ 旬魚"
"しゅんぎょう 春業"
"しゅんけん 峻険"
"しゅんげん 峻厳"
"しゅんこう 竣工"
"しゅんさい 俊才"
"しゅんざい 春材"
"しゅんしょう 春宵"
"しゅんしん 舜臣"
"しゅんじ 俊治 俊司 俊次 俊二 瞬時"
"しゅんじゅう 春秋"
"しゅんじゅん 逡巡"
"しゅんすい 旬粋"
"しゅんすけ 俊亮 俊輔 俊介"
"しゅんせい 俊成"
"しゅんせつ 浚渫 春節"
"しゅんそく 俊足 駿足"
"しゅんぞう 俊三"
"しゅんたろう 俊太郎"
"しゅんだん 春暖 瞬断"
"しゅんてい 瞬停"
"しゅんてつ 俊哲"
"しゅんでん 瞬電"
"しゅんとう 春闘"
"しゅんとうぐん 駿東郡"
"しゅんどう 蠢動 春藤"
"しゅんば 駿馬"
"しゅんぱつりょく 瞬発力"
"しゅんびん 俊敏"
"しゅんぶん 春分"
"しゅんぷう 春風"
"しゅんぷうたいとう 春風駘蕩"
"しゅんぷうてい 春風亭"
"しゅんべつ 峻別"
"しゅんみん 春眠"
"しゅんめ 駿馬"
"しゅんや 春夜"
"しゅんようぶんこ 春陽文庫"
"しゅんらい 春雷"
"しゅんれつ 峻烈"
"しゅんろう 春郎 俊朗 隼朗 隼郎"
"しゆう 市有 雌雄 私有"
"しょ 岨 黍 雎 蜍 蔗 苜 苴 胥 砠 嶼 墅 處 狙 渚 曙 薯 藷 処 庶 署 緒 暑 諸 初 所 書"
"しょー ショー"
"しょーと ショート"
"しょあく 諸悪"
"しょい 所謂 所為"
"しょいちねん 初一念"
"しょいり 初入"
"しょいん 署員 書院 所員"
"しょう 橡 憧 蛸 装 篠 錆 鍬 愀 愴 廂 聲 鷦 餉 顳 頌 韶 霎 霄 陞 鏘 銷 鈔 逍 證 誚 誦 觴 薔 蕭 艢 舂 聳 簫 筱 笙 竦 稱 稍 瘴 甞 獎 猩 猖 牆 爿 燒 炒 瀟 湫 淞 浹 殤 檣 橸 樅 椒 枩 敞 懾 憔 慯 悄 悚 庠 嶂 峭 將 妝 奬 墻 囁 嘯 燮 厰 劭 剿 倡 荘 鯖 鬆 ショウ 邵 牀 青 精 星 政 相 翔 哨 嘗 妾 娼 宵 廠 升 梢 樵 樟 蕉 湘 匠 抄 召 礁 唱 訟 償 蒋 菖 肖 招 庄 詔 醤 鍾 鉦 掌 鞘 璋 捷 紹 裳 生 奨 床 漿 硝 将 彰 晶 沼 商 昌 衝 承 昇 粧 姓 渉 症 鐘 象 上 昭 祥 省 焼 正 障 詳 消 性 尚 松 照 傷 焦 称 少 勝 笑 証 賞 小 章"
"しょうあく 性悪 掌握"
"しょうあくせつ 性悪説"
"しょうあつ 昇圧"
"しょうい 焼夷 傷痍 小尉 少尉 小異"
"しょういだん 燒夷彈 焼夷弾"
"しょういち 昭市 祥一 省一 昌一 小一 章一 昭一 昇一 彰一 庄一 正一"
"しょういちろう 昭一郎 正一郎"
"しょういん 証印 松蔭 勝因"
"しょうう 小雨"
"しょううん 勝運 昌運"
"しょうえ 庄衛"
"しょうえい 頌栄 昭栄 庄衛 庄栄 昌栄"
"しょうえき 漿液"
"しょうえね 省エネ"
"しょうえん 荘園 硝煙 招宴 小宴 鞘炎"
"しょうえんざい 消炎剤"
"しょうえんちんつうさよう 消炎鎮痛作用"
"しょうお 尚夫"
"しょうおう 勝央 照応"
"しょうおん 昇温 消音"
"しょうか 銷夏 漿果 頌歌 商科 商家 唱歌 昇華 消火 消化"
"しょうかい 小海 詳解 哨戒 商会 照会 紹介"
"しょうかいじょ 紹介所"
"しょうかいてい 哨戒艇"
"しょうかいわく 紹介枠"
"しょうかく 翔鶴 昇格"
"しょうかじあい 消化試合"
"しょうかせん 消火栓"
"しょうかそんじゅく 松下村塾"
"しょうかぼう 裳華房"
"しょうかわ 荘川"
"しょうかん 招喚 将官 商館 召還 松幹 小寒 召喚 償還"
"しょうかんしゅう 商慣習"
"しょうが 生姜"
"しょうがい 障碍 傷害 渉外 生涯 障害"
"しょうがいざい 傷害罪"
"しょうがいじ 障害児"
"しょうがいば 障害馬"
"しょうがいぶつなし 障害物無"
"しょうがく 商学 少額 小額 奨学 小学"
"しょうがくせいやく 小学生役"
"しょうがっかんぎょうしょ 小学館業書"
"しょうがつ 正月"
"しょうがもく ショウガ目"
"しょうがわ 庄川"
"しょうき 笑気 詳記 瘴気 鍾馗 商機 勝機 正気"
"しょうきち 正吉 昭吉"
"しょうきゃく 消却 焼却 償却"
"しょうきゃくじょ 焼却所"
"しょうきゃくろ 焼却炉"
"しょうきゅう 昇級 小球 昇給"
"しょうきょ 消去"
"しょうきょう 商況"
"しょうきょうれんごう 勝共連合"
"しょうきょく 小曲 消極"
"しょうきん 正金 償金 賞金"
"しょうきんおう 賞金王"
"しょうぎ 床几 牀几 娼妓 商議 将棋"
"しょうぎし 将棋史"
"しょうぎばん 将棋板"
"しょうぎまつり 将棋祭"
"しょうぎょう 商業"
"しょうぎょうせん 商業船"
"しょうぐん 将軍"
"しょうぐんづか 将軍塚"
"しょうけい 鐘形 憧憬 晶系 勝景 紹継 捷勁 捷径 商計 祥慶 祥啓 松径 昌慶 承継 正慶 少憩 少頃 小慧 小景 小経 小逕 小径 上卿 憧景 尚絅 象形 小憩 小計"
"しょうけつ 猖獗 燒結"
"しょうけん 商圏 證券 証券"
"しょうけんろう 笑犬樓 笑犬楼"
"しょうげき 衝撃"
"しょうげききゅうしゅうざい 衝撃吸収材"
"しょうげきは 衝撃波"
"しょうげん 象限 将監 証言"
"しょうこ 荘子 抄子 證拠 昌子 宵子 尚子 商賈 商估 省子 章子 聖子 晶子 しょう子 昌己 翔子 祥子 証拠"
"しょうこあつめ 証拠集め"
"しょうこう 銷耗 消耗 少考 焼光 商港 昭晃 焼香 昇降 将校 症候 小康 商工"
"しょうこうい 商行為"
"しょうこうぎょう 商工業"
"しょうこうぐち 昇降口"
"しょうこうぐん 症侯群"
"しょうこうし 小公子"
"しょうこうしゅ 紹興酒"
"しょうこうじょ 小公女"
"しょうこうだ 昇降舵"
"しょうこうつうしょう 昭光通商"
"しょうこうどう 昭晃堂"
"しょうこうねつ 猩紅熱"
"しょうこうほ 賞候補"
"しょうこうろう 小紅楼"
"しょうこく 小国"
"しょうこり 性凝り 性懲り"
"しょうこん 傷痕 商魂"
"しょうご 翔吾 小五 祥悟 昌吾 尚五 祥吾 正吾 省吾 昭吾 正午"
"しょうごいん 聖護院"
"しょうごう 稱號 商号 称号 照合"
"しょうごういん 照合印"
"しょうごうさくせん 捷号作戰"
"しょうごく 小国"
"しょうごまで 正午迄"
"しょうさ 証左 少佐 小差 照査"
"しょうさい 省際 商才 詳細"
"しょうさかん 小属"
"しょうさく 昇作"
"しょうさん 賞讃 硝酸 消散 賞賛 称賛 勝算"
"しょうさんえん 硝酸塩"
"しょうさんぎん 硝酸銀"
"しょうざき 庄崎"
"しょうざぶろう 正三郎"
"しょうざんかん 勝山館"
"しょうし 尚志 省資 昇志 証紙 焼死 尚士 笑止"
"しょうしげん 省資源"
"しょうしたい 焼死体"
"しょうしつ 銷失 焼失 消失"
"しょうしゃ 瀟洒 小社 照射 商社 勝者"
"しょうしゃかく 照射角"
"しょうしゅ 漿酒"
"しょうしゅう 消臭 招集 召集"
"しょうしゅうかん 商習慣"
"しょうしゅうごう 商集合"
"しょうしゅうだん 少集団"
"しょうしゅうれい 召集令"
"しょうしゅつ 抄出"
"しょうしゅん 頌春"
"しょうしょ 尚書 詔書 小暑 証書"
"しょうしょう 瀟湘 鏘鏘 蕭蕭 蕭牆 晶晶 彰彰 章章 商聖 悄悄 悚悚 将相 省掌 昭昭 昌昌 小小 少少 少小 小照 小祥 小哨 小升 詔召 小将 少将 少々"
"しょうしょく 小職 小食"
"しょうしん 焦心 小心 正真 焼身 傷心 昇進"
"しょうしんさいん 賞審査員"
"しょうしんもの 小心者"
"しょうしんよく 昇進欲"
"しょうじ 彰治 小児 正二 正治 正次 章司 昌二 小路 少時 章二 昇司 尚史 祥治 昇治 小事 将司 昭治 庄子 昇二 消磁 昭次 捷二 勝治 荘司 祥之 昭司 昭二 東海林 障子 庄司 尚司 商事"
"しょうじき 正直"
"しょうじきもの 正直者"
"しょうじこ 精進湖"
"しょうじま 生島"
"しょうじゃ 精舎"
"しょうじゃく 正雀"
"しょうじゅう 小銃"
"しょうじゅしょうしゃ 賞受賞者"
"しょうじゅつ 詳述"
"しょうじゅまんが 少女漫画"
"しょうじゅん 照準 昇順"
"しょうじょ 翔女 少女"
"しょうじょう 霄壌 掌状 清浄 猩猩 商状 小乗 賞状 症状"
"しょうじょうひ 猩々緋"
"しょうじょうみゃく 掌状脈"
"しょうじろう 象二郎 章治郎 正次郎 彰二郎"
"しょうじん 焼尽 精進"
"しょうじんあげ 精進揚"
"しょうすい 小水 将帥 消衰 憔悴"
"しょうすう 勝数 少数 小数"
"しょうすうしい 小四喜"
"しょうすけ 昭助 庄助 正助"
"しょうず 小豆"
"しょうずい 祥瑞"
"しょうせい 焼成 小成 招請 小生"
"しょうせき 鐘石"
"しょうせつ 章節 小雪 詳説 小節 小説"
"しょうせつか 小説家"
"しょうせん 省線 商戦 商船"
"しょうせんがくけんきゅうか 商船学研究科"
"しょうせんきょう 昇仙峡"
"しょうぜつ 勝絶"
"しょうぜん 悄然 性善 承前 哨然 小全"
"しょうそ 勝訴"
"しょうそう 焦躁 悄愴 傷愴 焦燥 尚早"
"しょうそういん 正倉院"
"しょうそく 消息"
"しょうそくすじ 消息筋"
"しょうそん 焼損"
"しょうぞう 正蔵 彰三 尚三 省造 捷三 勝三 正三 昭三 肖像 省三"
"しょうぞういん 正倉院"
"しょうぞうがてん 肖像画展"
"しょうぞく 装束"
"しょうた 翔太 章太 正太"
"しょうたい 消退 商体 小隊 小体 紹待 正体 招待"
"しょうたいきゃく 招待客"
"しょうたいけん 招待券"
"しょうたいば 招待馬"
"しょうたろう 章太郎 承太郎 正太郎 昭太郎"
"しょうたん 賞嘆"
"しょうたんい 章単位"
"しょうだ 掌打 庄田 正田"
"しょうだい 掌大 正代 小代"
"しょうだく 承諾"
"しょうだくいん 承諾印"
"しょうだて 章立て"
"しょうだん 昇段 商談"
"しょうち 招致 承知"
"しょうちく 松竹"
"しょうちくばい 松竹梅"
"しょうちゅう 小中 焼酎 掌中"
"しょうちゅうがくせいむけ 小中学生向け"
"しょうちょう 消長 省庁 小腸 象徴"
"しょうちょく 詔勅"
"しょうちん 銷沈 消沈"
"しょうてい 掌底"
"しょうていぎょくはく 鐘鼎玉帛"
"しょうてきほう 小滴法"
"しょうてん 小篆 衝天 昇天 笑点 商店 焦点"
"しょうてんしゅ 商店主"
"しょうでん 小伝 昭電"
"しょうでんしゃ 祥伝社"
"しょうでんりょく 省電力"
"しょうと 商都"
"しょうとう 消燈 消灯"
"しょうとく 聖徳"
"しょうとくてき 生得的"
"しょうとつ 衝突"
"しょうとつこん 衝突痕"
"しょうとりひき 商取引"
"しょうとりほう 証取法"
"しょうど 焦土 照度"
"しょうどう 章動 衝動"
"しょうどううり 衝動売り"
"しょうどく 抄読会 消毒"
"しょうどくかい 抄読会"
"しょうどくやく 消毒薬"
"しょうどけい 照度計"
"しょうどしま 小豆島"
"しょうどじま 小豆島"
"しょうない 省内 荘内 庄内"
"しょうなり ＜ ≦"
"しょうなん 沼南 湘南"
"しょうに 小児"
"しょうにかい 小児科医"
"しょうにゅう 鍾乳"
"しょうにゅうたい 鍾乳体"
"しょうにゅうどう 鐘乳洞 鍾乳洞"
"しょうにん 聖人 上人 昇任 小人 商人 証人 承認"
"しょうにんずう 少人数"
"しょうね 性根"
"しょうねつ 焦熱"
"しょうねん 少年"
"しょうねんいん 少年院"
"しょうねんがほうしゃ 少年画報社"
"しょうねんば 正念場"
"しょうねんぴ 少燃費"
"しょうねんぴしゃ 省燃費車"
"しょうねんもの 少年物"
"しょうねんやく 少年役"
"しょうの 笙野 庄野"
"しょうのう 樟脳 笑納 小脳"
"しょうのすけ 庄之助"
"しょうは 小破"
"しょうはい 賞杯 少牌 勝敗"
"しょうはいきりょう 少排気量"
"しょうはち 正八"
"しょうばい 商売"
"しょうばいがら 商売柄"
"しょうばいぎ 商売気"
"しょうばいもの 商売物"
"しょうばたけ 正畠"
"しょうばつ 賞罰"
"しょうばら 庄原"
"しょうばん 床版 相伴"
"しょうばんごう 章番号"
"しょうひ 消費"
"しょうひがく 消費額"
"しょうひざい 消費財"
"しょうひぜい 消費税"
"しょうひょう 証憑 証票 商標"
"しょうひょうとうりょくきょく 商標登録局"
"しょうひん 小品 賞品 商品"
"しょうひんけん 商品券"
"しょうび 賞美 焦眉"
"しょうびょう 傷病"
"しょうびょうへい 傷病兵"
"しょうふ 娼婦"
"しょうふく 妾腹 承伏 承服"
"しょうふくてい 笑福亭"
"しょうふだ 正札"
"しょうぶ 菖蒲 勝負"
"しょうぶごと 勝負事"
"しょうぶどころ 勝負所"
"しょうぶふく 勝負服"
"しょうぶん 小文 昌文 性分"
"しょうぶんかん 松文館"
"しょうぶんしゃ 昭文社 晶文社"
"しょうへい 昭平 省平 章平 昌平 小兵 招聘 招へい 笑瓶 正平 昇平"
"しょうへいこう 昌平黌"
"しょうへき 障壁"
"しょうへん 小片 掌編 掌篇"
"しょうべん 小便"
"しょうほう 唱法 捷報 小胞 勝報 詳報 商法"
"しょうほうじ 正法地 正法池"
"しょうほく 勝北"
"しょうほん 抄本"
"しょうぼう 消防"
"しょうぼうし 消防士"
"しょうぼうしゃ 消防車"
"しょうぼうしょ 消防署"
"しょうぼうちょう 消防庁"
"しょうま 消磨"
"しょうまく 漿膜"
"しょうまつ 章末"
"しょうまる 正丸"
"しょうまん 正満 小満"
"しょうみ 正味 賞味"
"しょうみつ 詳密"
"しょうみゃく 小脈"
"しょうみょう 声明"
"しょうむ 商務"
"しょうめい 證明 正銘 照明 証明"
"しょうめいおわり 証明終"
"しょうめいぎ 証明木"
"しょうめいだん 照明弾"
"しょうめいとう 照明灯 照明燈"
"しょうめつ 生滅 消滅"
"しょうめん 小面 生面 正面"
"しょうめんきって 正面切って"
"しょうめんぐち 正面口"
"しょうめんぞう 正面像"
"しょうめんまど 正面窓"
"しょうもう 消耗"
"しょうもうせん 消耗戦"
"しょうもうひんひ 消耗品費"
"しょうもん 小問 証文"
"しょうや 庄屋"
"しょうやく 生薬 小役 抄訳"
"しょうやま 庄山 正山"
"しょうゆ 醤油"
"しょうゆあじ 醤油味"
"しょうゆう 少輔"
"しょうゆがお 醤油顔"
"しょうよ 賞与"
"しょうよう 小葉 縦容 逍遥 称揚 従容 小用 商用"
"しょうようしゃ 商用車"
"しょうようじゅ 照葉樹"
"しょうようじゅりん 照葉樹林"
"しょうらい 招来 生来 将来"
"しょうらいぞう 将来像"
"しょうらん 笑覧 照覧"
"しょうり 捷利 勝利"
"しょうりき 正力"
"しょうりつ 勝率"
"しょうりゃく 商略 省略"
"しょうりゃくけい 省略形"
"しょうりゅう 昇龍 昇竜"
"しょうりゅうけん 昇竜拳 昇龍拳"
"しょうりょ 焦慮"
"しょうりょう 渉猟 聖霊 精霊 松陵 小量 少量"
"しょうりょうえ 聖霊会"
"しょうりょく 省力"
"しょうりん 少林"
"しょうりんじ 少林寺 小林寺"
"しょうれい 勝令 省令 症例 奨励"
"しょうろく 小六 抄録"
"しょうろん 小論 詳論"
"しょうわ 倡和 庄和 笑話 小話 唱和 昭和"
"しょうわうまれ 昭和生れ"
"しょうわかようし 昭和歌謡史"
"しょうわし 昭和史"
"しょうわしぇるせきゆ 昭和シェル石油"
"しょうわしんざん 昭和新山"
"しょうわり 章割り"
"しょうわる 性悪"
"しょうわん 小彎"
"しょえん 初演"
"しょか 書架 初夏"
"しょかい 所懷 初回 初会"
"しょかつ 諸葛 所轄"
"しょかつりょう 諸葛亮"
"しょかん 書館 所管 書簡 所感"
"しょかんばこ 書簡箱"
"しょが 書画"
"しょがい 所外"
"しょがいこくみん 諸外国民"
"しょがかり 諸掛"
"しょがくしゃ 初学者"
"しょき 書紀 暑気 所期 書記 初期"
"しょきしゃ 初期車"
"しょきそ 書記素"
"しょきばらい 暑気赦い"
"しょきゅう 初給 初級"
"しょきゅううち 初球打ち"
"しょぎ 所議"
"しょぎしょ 枌所"
"しょぎょう 所業 諸行"
"しょく 餝 軾 贖 謖 觸 蜀 穡 稷 禝 矚 昃 屬 寔 嗇 囑 喰 属 埴 嘱 蝕 飾 織 植 拭 殖 燭 触 色 職 食"
"しょくあい 食鹽"
"しょくあつ 触圧"
"しょくあん 職安"
"しょくい 職位"
"しょくいき 職域"
"しょくいん 職員"
"しょくいんぞう 職員増"
"しょくいんようしょくどう 職員用食堂"
"しょくえん 食塩"
"しょくえんすい 食塩水"
"しょくがい 食害"
"しょくぎょう 職業"
"しょくぎょうがら 職業柄"
"しょくぎょうびょう 職業病"
"しょくぎれ 食切れ"
"しょくぐん 職群"
"しょくご 食後"
"しょくさつ 喰殺"
"しょくさんこうぎょう 殖産興業"
"しょくさんじゅうたく 殖産住宅"
"しょくさんじん 蜀山人"
"しょくざい 食材 贖罪"
"しょくし 食指"
"しょくしゅ 蝕手 触手 職種"
"しょくしょう 食傷 職掌"
"しょくしょうがら 職掌柄"
"しょくしん 触診"
"しょくじ 植字 食餌 食事"
"しょくじけん 食事券"
"しょくじつき 食事付"
"しょくじどき 食事時"
"しょくじゅ 植樹"
"しょくじゅうせっきん 職住接近"
"しょくじょせい 織女星"
"しょくじんしゅ 食人種"
"しょくせい 食性 植生 職制"
"しょくせいかつ 食生活"
"しょくせき 職責"
"しょくぜん 食膳 食前"
"しょくぜんしゅ 食前酒"
"しょくそ 職組"
"しょくたい 飾帯"
"しょくたく 囑託 嘱託 食卓"
"しょくたん 職短"
"しょくだい 燭臺 燭台"
"しょくち 触知 諸口"
"しょくちゅう 食虫"
"しょくちゅうどく 食中毒"
"しょくちょう 職長"
"しょくつう 食通"
"しょくどう 食道 食堂"
"しょくどうけんだんわしつ 食堂兼談話室"
"しょくどうけんみんしゅく 食堂兼民宿"
"しょくどうしゃ 食堂車"
"しょくどうらくか 食道楽家"
"しょくにく 食肉"
"しょくにん 職人"
"しょくにんげい 職人芸"
"しょくのう 色濃 職能"
"しょくのうきゅう 職能給"
"しょくはこうしゅうにあり 食在広州"
"しょくはつ 触発"
"しょくば 職場"
"しょくばい 触媒"
"しょくひ 植皮 食費"
"しょくひん 食品"
"しょくひんうり 食品売"
"しょくひんがい 食品害"
"しょくひんてん 食品展"
"しょくぶつ 植物"
"しょくぶつし 食物誌"
"しょくぶつたい 植物体"
"しょくぶつゆ 植物油"
"しょくぶん 職分"
"しょくぶんか 食文化"
"しょくほう 織豊 触法"
"しょくぼう 嘱望"
"しょくみ 食味"
"しょくみん 植民"
"しょくみんせい 植民星"
"しょくみんせん 植民船"
"しょくむ 職務"
"しょくむきゅう 職務給"
"しょくめい 職名"
"しょくもう 植毛"
"しょくもく 属目"
"しょくもつ 食物"
"しょくゆう 贖宥"
"しょくよう 食用"
"しょくようあぶら 食用油"
"しょくようがえる 食用蛙"
"しょくよく 食欲"
"しょくりょう 食糧 食料"
"しょくりょうちょう 食糧庁"
"しょくりょうなん 食糧難"
"しょくりょうひんうり 食料品売"
"しょくりん 植林"
"しょくるいご 触塁後"
"しょくれき 職歴"
"しょくん 諸君"
"しょぐう 諸遇 処遇"
"しょけい 書経 処刑 諸兄"
"しょけん 諸賢 書見 初見 所見"
"しょげん 緒言 諸元"
"しょこ 書賈 書庫"
"しょこう 初更 曙光 初校 諸侯 初稿"
"しょこく 諸国"
"しょこくまんゆうき 諸国漫遊記"
"しょこん 初婚"
"しょご 諸語"
"しょごう 初号"
"しょさ 所作"
"しょさい 書債 所載 書斎"
"しょさん 所産"
"しょさんべつ 初山別"
"しょざ 初座"
"しょざい 所在"
"しょざん 初産"
"しょし 書士 諸誌 書肆 書司 書誌 初志 諸子 諸氏"
"しょしき 諸式 書式"
"しょしゃ 諸車 書写"
"しょしゅ 諸種"
"しょしゅう 所収 初秋"
"しょしゅつ 初出"
"しょしゅん 初春"
"しょしょ 所々 処暑 諸処"
"しょしょう 所掌 書証"
"しょしん 書信 所信 初診 初審 初心"
"しょしんりょう 初診療"
"しょじ 諸事 書字 所持"
"しょじゅん 初旬"
"しょじょ 処女"
"しょじょう 諸嬢 書状"
"しょじょさく 処女作"
"しょじょせん 処女戦"
"しょじょまく 処女膜"
"しょずみ 初炭"
"しょせい 初生 書生 処世"
"しょせき 書籍"
"しょせつ 所説 諸説"
"しょせん 緒戦 初戦 諸戦 書泉 所詮"
"しょぜい 諸税"
"しょそう 初相 諸相"
"しょそく 初速"
"しょぞう 所蔵"
"しょぞく 所属"
"しょぞん 所存"
"しょたい 所帯 書体"
"しょたいけん 初体験"
"しょたいぬし 所帯主"
"しょたいめん 初対面"
"しょためん 初対面"
"しょだい 書題 初台 初代"
"しょだな 書棚"
"しょだん 処断 初段"
"しょだんけい 処断刑"
"しょち 処置"
"しょちあん 処置案"
"しょちゅう 書中 暑中"
"しょちゅうおみまいもうしあげます 暑中お見舞い申し上げます"
"しょちゅうきゅう 初中級"
"しょちゅうとう 初中等 初・中等"
"しょちょう 初潮 署長 所長"
"しょっかい 職階"
"しょっかいきゅう 職階給"
"しょっかく 食客 触覚 触角"
"しょっかん 食感 食管 触感"
"しょっき 織機 食器"
"しょっきだな 食器棚"
"しょっきゅう 触球"
"しょっく ショック"
"しょっけん 職権 食券"
"しょっこう 職工"
"しょっと ショット"
"しょっぱな 初端 初っ端"
"しょっぴんぐ ショッピング"
"しょっぷ ショップ"
"しょて 初手"
"しょてい 所定"
"しょてん 諸点 書店"
"しょとう 蔗糖 初冬 初頭 初等 諸島"
"しょとく 所得"
"しょとくぜい 所得税"
"しょどう 初動 書道"
"しょどうか 書道家"
"しょない 所内"
"しょなのか 初七日"
"しょにち 初日"
"しょにゅう 初乳"
"しょにん 初任"
"しょにんきゅう 初任給"
"しょねん 初年"
"しょは 諸派"
"しょはつ 初発"
"しょはん 初犯 諸般 初版"
"しょばつ 処罰"
"しょばん 初盤"
"しょひ 諸費"
"しょひょう 諸表 書評"
"しょふう 書風"
"しょぶつ 諸仏"
"しょぶん 処分"
"しょへん 初編"
"しょほ 初歩"
"しょほう 諸方 書法 処方"
"しょほうせん 処方箋 処方せん"
"しょぼう 書房"
"しょみん 庶民"
"しょむ 庶務"
"しょむかかり 庶務掛"
"しょむがかり 庶務掛"
"しょめい 書名 署名"
"しょめいあつめ 署名集め"
"しょめん 書面"
"しょもう 所望"
"しょもつ 書物"
"しょや 初夜"
"しょゆう 所有"
"しょゆうしゃ 所有車"
"しょよ 所与"
"しょよう 所用 所要"
"しょり 処理"
"しょりえき 処理液"
"しょりけいごと 処理系毎"
"しょりじゅん 処理順"
"しょりょう 緒量 諸量 所領"
"しょりん 書林"
"しょるい 書類"
"しょろう 初老"
"しょろん 諸論 緒論 所論"
"しょわけ 諸訳"
"しよ 賜与"
"しよう 止揚 脂溶 子葉 飼養 飼葉 枝葉 試用 私用 仕様 使用"
"しようかいふく 信用回復"
"しようかていしゃ 使用過程車"
"しようき 使用記"
"しようしゃ 仕様車"
"しようしょう 子葉鞘"
"しようずみ 使用済"
"しようそ 篩要素"
"しようとどけ 使用届"
"しようぼ 使用簿"
"しよく 私欲"
"しら 白 調"
"しらい 白井"
"しらいし 白石"
"しらいち 白市"
"しらいと 白糸"
"しらうお 白魚"
"しらうめ 白梅"
"しらえ 白江"
"しらおい 白老"
"しらおか 白岡"
"しらかた 白方"
"しらかば 白樺"
"しらかばこ 白樺湖"
"しらかばばやし 白樺林"
"しらかべ 白壁"
"しらかみ 白神"
"しらかわ 白河 白川"
"しらが 白髪"
"しらがあたま 白髪頭"
"しらがみ 白神"
"しらき 白木"
"しらきばる 白木原"
"しらぎ 新羅"
"しらぎく 白菊"
"しらくら 白倉"
"しらこ 白子"
"しらさか 白坂"
"しらさき 白崎"
"しらさぎ 白鷺"
"しらさや 白鞘"
"しらさわ 白沢"
"しらじら 白々"
"しらす 白須 白州"
"しらず 不知 知らず"
"しらせ 知らせ"
"しらたか 白鷹"
"しらたき 白滝"
"しらたま 白珠"
"しらたまこ 白玉粉"
"しらと 白土 白都 白戸"
"しらとり 白取 白鳥"
"しらなみ 白浪 白波"
"しらぬい 不知火"
"しらぬいまい 不知火舞"
"しらぬか 白糠"
"しらぬひ 不知火"
"しらね 白根"
"しらは 白刃 白羽"
"しらはし 白橋"
"しらはた 白幡"
"しらはま 白浜 白濱"
"しらふ 素面"
"しらふじ 白藤"
"しらぶる シラブル"
"しらべ 調 調べ"
"しらほ 白保"
"しらほねおんせん 白骨温泉"
"しらみ 蝨 虱"
"しらみね 白峰"
"しらやき 白焼"
"しらゆき 白雪"
"しらゆきひめ 白雪姫"
"しらゆり 白百合"
"しり 臀 私利 尻"
"しりーず シリーズ"
"しりあい 知合 知合い 知り合い"
"しりある シリアル"
"しりうち 知内"
"しりうま 尻馬"
"しりお 尻尾"
"しりきしない 尻岸内"
"しりきれ 尻切れ"
"しりこん シリコン"
"しりごみ しり込み 尻込み 後込み"
"しりつ 市立 私立"
"しりてえき 尻手駅"
"しりびと 知り人"
"しりべ 後志"
"しりべし 後志"
"しりべつがわ 尻別川"
"しりめ 尻目 後目"
"しりめつれつ 支離滅裂"
"しりもち 尻餅"
"しりゃく 史略"
"しりゅう 支流"
"しりょ 思慮"
"しりょう 飼料 死霊 思量 史料 試料 資料"
"しりょうず 指了図"
"しりょうてきかち 資料的価値"
"しりょく 資力 死力 視力"
"しる 什 汁"
"しるえっと シルエット"
"しるく シルク"
"しるけ 汁気"
"しるこ 汁粉"
"しるし 標 印"
"しるばー シルバー"
"しるひと 知る人"
"しるびあ シルビア"
"しるべ 導 標"
"しれい 司令 指令"
"しれつ 歯列 熾烈"
"しれとこ 知床"
"しれとこごこ 知床五湖"
"しれん 試煉 試錬 試練"
"しろ 代 城 白"
"しろあと 城跡"
"しろあり 白アリ"
"しろい 白井"
"しろいし 白石"
"しろいと 白糸"
"しろいめ 白い目"
"しろいわ 白岩"
"しろう 詩郎 梔蝋 志郎 士朗 支朗 四朗 司郎 史郎 四郎 士郎 史朗 司朗"
"しろうず 白水"
"しろうと 素人"
"しろうとしゅう 素人衆"
"しろうとすじ 素人筋"
"しろうとてきしつもん 素人的質問"
"しろうとみ 素人見"
"しろうとむき 素人向"
"しろうま 白馬"
"しろおび 白帯"
"しろかぜ 城風"
"しろかっこ 『"
"しろかね 白金"
"しろかねそうあか シロカネソウ亜科"
"しろかわ 城川"
"しろかん 白缶"
"しろがそ 白画素"
"しろがね 銀 白銀 白金"
"しろき 白木"
"しろくじちゅう 四六時中"
"しろくばん 四六判"
"しろくま シロクマ"
"しろくら 白倉"
"しろくろ 白黒"
"しろぐみ 白組"
"しろけいとう 白系統"
"しろこっか 』"
"しろさき 白崎"
"しろさわ 白沢 代沢"
"しろさんかく 白三角"
"しろざけ 白酒"
"しろざとう 白砂糖"
"しろしか 白鹿"
"しろした 城下"
"しろしょうぞく 白装束"
"しろじ 白字 白地"
"しろすな 白砂"
"しろた 白田 城田"
"しろたえ 白妙"
"しろたけ 白武"
"しろたなせん 白棚線"
"しろたなてつどう 白棚鉄道"
"しろたに 城谷"
"しろたま 白珠"
"しろだ 白田"
"しろだま 白玉"
"しろぢ 白地"
"しろとり 白鳥"
"しろなまず 白癜"
"しろぬかちょう 白糠町"
"しろぬき 白抜き 白抜"
"しろね 白根"
"しろの 城野"
"しろはた 白旗"
"しろばかま 白袴"
"しろふだや 白札屋"
"しろぶち 白縁"
"しろへび 白蛇"
"しろぼし ○ 白星"
"しろま 城間"
"しろまく 白幕"
"しろまだら 白斑"
"しろまる ○ 〇 白丸"
"しろみ 城見 白身"
"しろみざかな 白身魚"
"しろみそ 白味噌"
"しろむく 白無垢"
"しろめ 白眼 白目"
"しろもの 代物"
"しろもん 白門"
"しろや 城谷"
"しろやなぎ 白柳"
"しろやま 城山"
"しろやまえき 白山駅"
"しろれんが 白煉瓦"
"しろん 詩論 試論 私論 史論"
"しわ 私話 紫波 襞 皴 皺"
"しわく 思惑"
"しわけ 仕分け 仕訳"
"しわけちょう 仕訳帳"
"しわざ 爲業 仕業"
"しわす 師走"
"しわひめ 志波姫"
"しわよせ 皺寄せ 皴寄せ しわ寄せ"
"しをさめ 爲納め 仕納め"
"しをり 栞"
"しん 槙 矧 津 甄 齔 鷏 鷆 駸 鍼 軫 讖 譛 譖 襯 袗 蜃 蔘 蓁 臻 脣 縉 簪 箴 瞋 畛 瀋 沁 晨 晉 斟 怎 忱 寢 宸 嗔 哂 呻 賑 滲 愼 岑 唇 娠 秦 榛 侵 清 浸 審 芯 疹 慎 震 薪 辰 紳 振 申 晋 針 臣 深 診 森 神 眞 辛 寝 伸 信 身 進 親 心 真 新"
"しんあい 信愛 親愛"
"しんあいなる 親愛なる"
"しんあさひ 新旭"
"しんあん 新案"
"しんい 瞋恚 襯衣 深意 真意"
"しんいち 新市 信市 真市 紳一 眞市 申一 眞一 震一 信一 晋一 慎一 真一 伸一 進一 新一"
"しんいちろう 眞一郎 辰一郎 進一郎 伸一郎 振一朗 真一郎 慎一郎 信一郎"
"しんいり 新入り"
"しんいん 神韻 心因"
"しんうおのめ 新魚目"
"しんうち 真打 真打ち"
"しんうんちんがく 新運賃額"
"しんえい 信栄 親英 神栄 新栄 親衛 新鋭"
"しんえき 新駅"
"しんえつ 信越"
"しんえん 真円 深淵 深遠"
"しんえんけい 真円形"
"しんおう 震央"
"しんおおひらした 新大平下"
"しんおん 心音 唇音"
"しんか 真果 臣下 深化 真価 進化"
"しんかい 神界 新貝 深回 深海 新開 新海"
"しんかいぎょ 深海魚"
"しんかく 真核 神格"
"しんかしゃ 新華社"
"しんかしょてん 新華書店"
"しんかぶ 心窩部 新株"
"しんかまはらえき 新蒲原駅"
"しんかわ 新川"
"しんかん 信管 震撼 深閑 森閑 神官 震憾 新刊 新館 新歓"
"しんかんえいじてん 新漢英字典"
"しんがー シンガー"
"しんがい 新谷 震駭 心外 侵害"
"しんがいかくめい 辛劾革命"
"しんがいねん 真概念"
"しんがお 新顔"
"しんがく 新学 神学 信学 進学"
"しんがくじゅく 進学塾"
"しんがた 新型"
"しんがたしゃ 新型車"
"しんがっかい 信学会"
"しんがぽーる 新嘉坡"
"しんがら 新柄"
"しんがり 殿"
"しんがん 真贋 心眼"
"しんき 新機 新期 辛気 神姫 心気 神器 蜃気 心機 新奇 新規"
"しんきち 進吉 真吉 新吉 信吉"
"しんきゅう 進級 新旧"
"しんきゅうめん 真球面"
"しんきょ 新居"
"しんきょう 新京 信教 新疆 新彊 心境"
"しんきょうせん 神京戦"
"しんきょく 神曲 新曲"
"しんきろう 蜃気楼"
"しんきん 真菌 親近 信金 伸筋 心筋"
"しんぎ 新技 信義 真疑 進木 真偽 審議"
"しんぎん 呻吟"
"しんく 真紅 深紅 辛苦"
"しんくう 真空"
"しんくうかん 真空管"
"しんくうけい 真空計"
"しんくうば 真空場"
"しんぐ 寝具"
"しんぐう 新宮 信宮"
"しんぐる シングル"
"しんぐん 進軍"
"しんけい 針形 唇形 神経"
"しんけいこん 神経根"
"しんけいしつ 神経質"
"しんけいせん 神経戦"
"しんけいそう 神経叢"
"しんけいだん 神経弾"
"しんけいつう 神経痛"
"しんけいぱるす 神経パルス"
"しんけつ 心血"
"しんけん 震研 神拳 親権 進研 真剣"
"しんけんせいじ 神権政治"
"しんげき 新劇 進撃"
"しんげつ 心月 新月"
"しんげん 箴言 震源 信玄 進言"
"しんげんこう 信玄公"
"しんこ 新香"
"しんこう 進講 侵行 侵寇 進攻 深更 深厚 辰功 神鋼 新晃 新光 真光 親好 侵攻 真興 新興 親交 信仰 振興 進行"
"しんこうき 神皇記"
"しんこうけい 進行形"
"しんこうしん 信仰心"
"しんこうは 進行波"
"しんこうはかい 進行波解"
"しんこうやく 進行役"
"しんこきゅう 深呼吸"
"しんこく 親告 申告 深刻"
"しんこくげき 新国劇"
"しんこくざい 申告罪 親告罪"
"しんこしゃ 新古車"
"しんこだ 新小田"
"しんこっちょう 真骨頂"
"しんこひん 新古品"
"しんこん 新婚"
"しんご 紳悟 進悟 真吾 晋午 慎吾 信悟 晋吾 真悟 新語 信吾 伸悟 新吾 伸吾"
"しんごう 神郷 新郷 信号"
"しんごうげん 信号源"
"しんごうとりあつかいじょ 信号取扱所"
"しんごうにゅうりょくじょうたい 記号入力状態"
"しんごうろ 信号路"
"しんごん 真言"
"しんごんしゅう 真言宗"
"しんさ 審査"
"しんさい 震災"
"しんさいばし 心斎橋"
"しんさく 晋作 進作 新作"
"しんさつ 新札 診察"
"しんさん 辛酸 新参"
"しんざい 心材 芯材"
"しんざき 新崎"
"しんざわ 新澤 新沢"
"しんざん 深山 新参"
"しんざんもの 新参者"
"しんし 進士 新史 振子 神士 紳士 真摯"
"しんしき 神式 新式"
"しんしさ 真摯さ"
"しんしっかん 心疾患"
"しんしつ 進出 心室 寝室"
"しんしのつ 新篠津"
"しんしふく 紳士服"
"しんしゃ 親炙 新社 深謝 新車"
"しんしゃく 斟酌"
"しんしゅ 新手 進取 新酒 新種"
"しんしゅう 神州 侵襲 新秋 真宗 信州"
"しんしゅく 伸縮"
"しんしゅくけい 伸縮計"
"しんしゅつ 滲出 浸出 侵出 神出 進出 新出"
"しんしゅつえき 滲出液"
"しんしゅどき 新酒時"
"しんしゅん 新春"
"しんしょ 親書 信書 新書"
"しんしょう 志ん生 財産 身上 心象 心証 辛勝"
"しんしょうしゃ 身障者"
"しんしょうひつばつ 信賞必罰"
"しんしょうぼうだい 針小棒大"
"しんしょく 新色 浸蝕 浸食 侵蝕 寝食 侵食"
"しんしょばん 新書判"
"しんしろ 新城"
"しんしん 新進 津々 心身 信心"
"しんしんどう 駸々堂"
"しんじ 晋二 宍道 神餌 愼二 晋司 新字 慎司 伸次 伸自 慎治 伸二 新治 信二 信次 伸司 神事 進士 信治 眞治 真治 真二 真司 慎二 新司 伸治 信司"
"しんじけーと シンジケート"
"しんじこ 宍道湖"
"しんじつ 真実"
"しんじつみ 真実味"
"しんじゃ 心者 信者"
"しんじゅ 真珠"
"しんじゅいり 真珠入り"
"しんじゅう 臣従 心中"
"しんじゅうろう 真十郎"
"しんじゅく 新宿"
"しんじゅくにししてん 新宿西支店"
"しんじゅわん 真珠湾"
"しんじゅん 浸潤"
"しんじょ 神助"
"しんじょう 真情 進上 身上 新條 新庄 心情 新城 信条"
"しんじょはら 新所原"
"しんじろう 慎次郎"
"しんじん 深甚 信心 新人"
"しんじんせん 新人戦"
"しんすい 侵水 進水 心酔 浸水"
"しんすう 芯数 進数"
"しんすけ 慎介 信輔 信介 紳介 紳助"
"しんずい 神髄 心髄 真髄"
"しんせい 新政 新姓 神性 新製 真正 新制 新生 神聖 真性 新星 申請"
"しんせいがく 申請額"
"しんせいしゃ 新製車 新声社"
"しんせいじ 新生児"
"しんせいとう 新生党"
"しんせいどう 新星堂"
"しんせいのうしゃ 新性能車"
"しんせいばんぐみ 申請番号"
"しんせかい 真世界"
"しんせき 親戚"
"しんせだいぐん 新世代軍"
"しんせつ 真説 新雪 新説 新設 親切"
"しんせつぎ 親切気"
"しんせつしん 親切心"
"しんせつはいし 新設改廃"
"しんせつひ 新設費"
"しんせん 新選 神饌 震顫 神泉 神仙 深浅 新線 振戦 芯線 新鮮"
"しんせんぐみ 新撰組"
"しんせんみ 新鮮味"
"しんぜん 親善 神前"
"しんぜんじあい 親善試合"
"しんそう 深窓 眞相 深層 新装 真相"
"しんそこ 真底 心底"
"しんそつ 新卒"
"しんぞう 心像 新三 新造 心臓"
"しんぞうし 心臓死"
"しんぞうしゃ 新造車"
"しんぞうびょう 心臓病"
"しんぞうへき 心臓壁"
"しんぞうやぶり 心臓破り"
"しんぞく 親族"
"しんた 新太 心太"
"しんたい 神体 進退 身体"
"しんたく 新宅 神託 信託"
"しんたっくす シンタックス"
"しんたに 新谷"
"しんたまけいゆう 新玉経由"
"しんたろう 辰太郎 信太郎 慎太郎"
"しんたん 心胆 薪炭"
"しんだい 神代 寝台 神大 新台 信大"
"しんだいけん 寝台券"
"しんだいしゃ 寝台車"
"しんだん 診断"
"しんち 心地 真値 深知 深智 新地 新治"
"しんちく 新築"
"しんちくいっこだて 新築一戸建"
"しんちゃく 新着"
"しんちゅう 鉐 真鍮 進駐 心中"
"しんちゅういた 真鍮板"
"しんちゅうぐん 進駐軍"
"しんちゅうぼう 真鍮棒"
"しんちょ 新著"
"しんちょう 志ん朝 清朝 深長 伸張 伸長 新調 新潮 慎重 身長"
"しんちょく 進捗"
"しんちん 新陳"
"しんつう 心痛"
"しんづ 新津"
"しんて 新手"
"しんてい 心底 新艇 新訂 進呈"
"しんてき 心的"
"しんてつ 神鉄"
"しんてら 新寺"
"しんてん 秦篆 伸展 親展 進展"
"しんてんちょう 新天町"
"しんでれら シンデレラ"
"しんでん 心電 新田 神殿"
"しんと 信徒"
"しんとう 真藤 榛東 神道 滲透 神東 親等 新党 心頭 浸透 新棟"
"しんとうあつ 浸透圧"
"しんとうき 神統記"
"しんとく 新得"
"しんとみ 新富"
"しんど 深度 進度 震度"
"しんどう 真藤 新堂 神道 伸銅 新藤 震動 進藤 神童 新道 振動"
"しんどうかい 振動解"
"しんどうきゅうしゅうざい 振動吸収材"
"しんどうけい 振動計"
"しんどうば 振動場"
"しんどうばん 振動板"
"しんどうまく 振動膜"
"しんなー シンナー"
"しんないがいめん 新内外綿"
"しんにち 新日 親日"
"しんにちか 親日家"
"しんにっこう 新日鉱"
"しんにってつ 新日鐵 新日本製鉄株式会社"
"しんにゅう 進入 浸入 侵入 新入"
"しんにゅうろ 侵入路"
"しんにょ 真如"
"しんにん 信認 新任 信任"
"しんにんとうひょうあん 信任投票案"
"しんぬり 真塗"
"しんね 心根 新値"
"しんねん 新年 信念"
"しんの 新野 神野"
"しんのう 心嚢 親王"
"しんのすけ 慎之介 進之助 信之介 新之助"
"しんはんにん 真犯人"
"しんば 新馬"
"しんばし 新橋"
"しんばしえんぶじょう 新橋演舞場"
"しんばしょう 新馬勝"
"しんばせん 新馬戦"
"しんばら 新原"
"しんばん 新盤 新版"
"しんぱ 新派"
"しんぱい 心肺 心配"
"しんぱいごと 心配事"
"しんぱく 心搏 心拍"
"しんぱくすう 心泊数"
"しんぱち 新八"
"しんぱつ 深発 進発"
"しんぱん 新版 審判 侵犯 信販"
"しんび 審美"
"しんびがん 審美眼"
"しんぴ 真皮 心皮 真否 神秘"
"しんぴつ 真筆"
"しんぴょう 信憑"
"しんぴょうろん 新評論"
"しんぴん 新品"
"しんふぜん 心不全"
"しんふり 進振 進振り"
"しんぶ 深部"
"しんぶきげん 神武紀元"
"しんぶつ 神仏"
"しんぶつしゅうごう 神仏習合"
"しんぶぶんこう 真部分項"
"しんぶぶんしゅうごう 真部分集合"
"しんぶぶんろんりしき 真部分論理式"
"しんぶん 新聞"
"しんぶんき 新聞記"
"しんぶんし 新聞紙"
"しんぶんすう 真分数"
"しんぶんだね 新聞種"
"しんぶんはいたつじょ 新聞配達所"
"しんぷ 神父 新婦 新譜"
"しんぷう 新風"
"しんぷく 心服 信服 振幅"
"しんぷる シンプル"
"しんべい 親米"
"しんぺい 神兵 慎平 晋平 新平"
"しんぺん 身辺"
"しんほう 進法"
"しんぼ 真保 新保"
"しんぼう 伸坊 深謀 心棒 心房 信望 辛棒 辛抱"
"しんぼうしゃ 信奉者"
"しんぼく 親睦"
"しんぼる シンボル"
"しんぽ 進歩"
"しんぽう 新報 新法 信奉"
"しんぽじうむ シンポジウム"
"しんぽん 新本"
"しんまい 新米"
"しんまく 心膜"
"しんまち 新町"
"しんまつ 新松"
"しんみ 新味 親身"
"しんみつ 親密"
"しんみなと 新湊"
"しんみょう 新名 神妙"
"しんみん 臣民"
"しんめ 新芽"
"しんめい 神明 深名 身命"
"しんめいだい 真命題"
"しんめん 新免"
"しんもつ 進物"
"しんもり 新森"
"しんもん 審問"
"しんや 真哉 眞哉 晋也 晋哉 新也 伸也 伸弥 信矢 進也 信也 信哉 真也 深夜"
"しんやく 新訳 新薬"
"しんやくせいしょ 新約聖書"
"しんやわく 深夜枠"
"しんゆう 親友"
"しんゆうやく 親友役"
"しんよう 信用"
"しんようがし 信用貸し"
"しんようじゅ 針葉樹"
"しんようじゅこう 針葉樹綱"
"しんら 森羅"
"しんらい 信頼"
"しんらつ 辛辣"
"しんらん 親鸞"
"しんり 審理 心理 真理"
"しんりきょう 真理教"
"しんりし 心理士"
"しんりせん 心理戦"
"しんりゃく 侵掠 侵略"
"しんりゃくざい 侵略罪"
"しんりゅう 神竜 神龍"
"しんりょ 深慮"
"しんりょう 新涼 診療"
"しんりょうじょ 診療所"
"しんりょく 真緑 深緑 新緑"
"しんりん 森林"
"しんりんよく 森林浴"
"しんるい 親類"
"しんるいぶん 進塁分"
"しんれい 心霊"
"しんれき 新暦"
"しんれつ 進列"
"しんろ 針路 進路"
"しんろう 心労 新郎"
"しんわ 新和 親和 神話"
"じ 迩 餌 祀 邇 辭 轜 膩 粫 畤 瓷 珥 恃 怩 峙 岻 尓 孳 塒 兒 弍 亊 爺 知 只 寿 士 嗣 史 茲 仁 至 司 以 侍 慈 路 似 璽 除 子 爾 而 寺 蒔 滋 児 示 磁 痔 耳 地 二 持 治 辞 事 自 次 字 時"
"じあい 地合い 慈愛 自愛"
"じあえんそさん 次亜塩素酸"
"じあえんそさんえん 次亜塩素酸塩"
"じあげ 地上"
"じあまり 字余り"
"じい 磁位 侍医 辞意 示威 爺 自慰"
"じいがたけ 爺ヶ岳"
"じいこう 時以降"
"じいさま 爺様"
"じいさん 爺さん"
"じいしき 自意識"
"じいぱん Ｇパン"
"じいろ 地色"
"じいん 寺院"
"じうん 時運"
"じぇっと ジェット"
"じぇらしー ジェラシー"
"じえい 自営 自衛"
"じえいぎょう 自営業"
"じえん 自演"
"じおう 地黄"
"じおん 字音"
"じか 磁荷 直 耳科 字化 磁化 自家 時価 時下"
"じかい 耳介 自戒 磁界 次会 次回"
"じかいさく 次回作"
"じかく 時隔 字画 痔核 自覚"
"じかず 字数"
"じかせん 耳下腺"
"じかだん 直談"
"じかだんぱん 直談判"
"じかつ 自活"
"じかづみ 直積"
"じかに 直に"
"じかびしき 直火式"
"じかようしゃ 自家用車"
"じかん 次官 字間 時間"
"じかんきゅう 時間休 時間給"
"じかんきれ 時間切れ"
"じかんぎれ 時間切れ"
"じかんごと 時間毎"
"じかんじく 時間軸"
"じかんせつ 時間説"
"じかんそう 時間走"
"じかんまち 時間待"
"じかんまど 時間窓"
"じかんわく 時間枠"
"じが 自画 自我"
"じがい 自害"
"じがく 自学"
"じがぞう 自画像"
"じがため 地固め"
"じがね 地金"
"じき 時宜 自記 自機 時季 磁器 食 喰 時機 自棄 磁気 直 次期 時期"
"じきあらし 磁気嵐"
"じきごと 時期毎"
"じきじき 直々"
"じきじきに 直々に"
"じきそ 直訴"
"じきそうしょう 時期早尚"
"じきだんぱん 直談判"
"じきでん 直伝"
"じきひつ 直筆"
"じきぼう 次期防"
"じきゅう 持久 時給 自給"
"じきゅうせん 持久戦"
"じきゅうそう 持久走"
"じきょ 辞去"
"じきょう 自供"
"じきょく 時局 磁極 自局"
"じぎ 児戯 辞儀 字義"
"じぎゃく 自虐"
"じぎょう 次行 事行 事業"
"じぎょうか 事業家"
"じぎょうかすいしんしつ 事業化推進室"
"じぎょうかすいしんぶ 事業化推進部"
"じぎょうしゅ 事業主"
"じぎょうぜい 事業税"
"じぎょうたい 事業体"
"じぎょうぬし 事業主"
"じぎょうようしゃ 事業用車"
"じく 衂 衄 忸 字句 竺 宍 軸"
"じくあし 軸足"
"じくう 時空"
"じくうい 時空意"
"じくうけ 軸受け 軸受"
"じくかん 軸間"
"じくがい 軸外"
"じくこてい 軸固定"
"じくさく 軸索"
"じくしゅつりょくきょくせん 軸出力曲線"
"じくじ 忸怩"
"じくじゅう 軸重"
"じくじょう 軸上"
"じくじょうほう 軸情報"
"じくすう 軸数"
"じくずれ 地崩れ"
"じくせいぶん 軸成分"
"じくせん 軸線"
"じくそうかん 軸相関"
"じくたいしょう 軸対称"
"じくない 軸内"
"じくばこ 軸箱"
"じくばり 字配り"
"じくほうこう 軸方向"
"じくまわり 軸回"
"じぐ 治具"
"じぐざぐ ジグザグ"
"じぐそー ジグソー"
"じぐん 自軍"
"じけい 字型 次兄 字形 慈恵 自警"
"じけいれつ 時系列"
"じけいれつじゅん 時系列順"
"じけつ 自決"
"じけん 事件"
"じけんちょう 事件帳"
"じけんぼ 事件簿"
"じげん 事言 示現 字源 時限 次元"
"じげんそう 次元窓"
"じこ 事故 自己"
"じこあい 自己愛"
"じこう 時好 時侯 時候 次項 自校 時効 事項"
"じこうしき 字光式"
"じこく 自国 時刻"
"じこくてん 持国天"
"じこくひょうみきさい 時刻表未記載"
"じこくみん 自国民"
"じこくりょう 自国領"
"じこけんじよく 自己顕示欲"
"じこし 事故死"
"じこしゃ 事故車"
"じこしんこくかあど 自己申告カード"
"じこむどうちゃく 自己無撞着"
"じこりゅう 自己流"
"じころ 時頃"
"じご 爾後 事後"
"じごう 自業 次号"
"じごえ 地声"
"じごく 地獄"
"じごくだに 地獄谷"
"じごくへん 地獄変"
"じごくみみ 地獄耳"
"じごろ 時頃"
"じごろう 滋悟郎"
"じさ 橲 時差"
"じさく 次作 自作"
"じさくのう 自作農"
"じさげ 字下げ"
"じさつ 自殺"
"じさばら 橲原"
"じさぶろう 治三朗"
"じさん 自讃 自賛 自参 持参"
"じざい 自在"
"じざけ 地酒"
"じし 次子"
"じしき 次式"
"じしつ 自失 自室"
"じしゃ 侍者 自車 自社"
"じしゃかぶ 自社株"
"じしゃく 磁石"
"じしゃはっちゅうしゃ 自社発注車"
"じしゃわく 自社枠"
"じしゅ 自首 字種 自主"
"じしゅう 次週 自習"
"じしゅうようきょうざい 自習用教材"
"じしゅく 自粛"
"じしょ 璽書 字書 地所 自署 辞書"
"じしょう 自象 自称 次章 事象"
"じしょうぎ 持将棋"
"じしょうさけつう 自称酒通"
"じしょく 辞職"
"じしょじゅん 辞書順"
"じしょもの 辞書物"
"じしん 時針 磁針 磁心 地震 自信 自身"
"じしんか 自信家"
"じしんがくし 地震学史"
"じしんけい 地震計"
"じしんげん 地震源"
"じしんさく 自信作"
"じしんどう 地震動"
"じしんなし 自信無"
"じしんは 地震波"
"じじ 時々 時事 爺"
"じじかい 次々回"
"じじく 耳軸"
"じじつ 事実"
"じじつこん 事実婚"
"じじゃく 自若"
"じじゅう 自重 侍従"
"じじゅん 次順"
"じじょ 自助 侍女 次女"
"じじょう 磁場 二乗 ２乗 自乗 事情"
"じじょうさよう 自浄作用"
"じじょうじばく 自縄自縛"
"じじょうだいいっこう 次条第一項"
"じじょうのうりょく 自浄能力"
"じじょうへいきい 二乗平均"
"じじょうわ ２乗和 二乗和"
"じじょでん 自叙伝"
"じじん 自刃 自陣"
"じすい 自炊"
"じすう 時数 次数 字数"
"じすべり 地滑り"
"じず 次図"
"じずめ 字詰め"
"じずら 字面"
"じずらどおり 字面通り、"
"じせい 辞世 自省 自生 時勢 自製 磁性 時世 自制 時制"
"じせいしん 自制心"
"じせいたい 磁性体"
"じせいふん 磁性粉"
"じせき 事跡 自責 次席 自席"
"じせきのねん 自責の念"
"じせつ 自説 時節 次節"
"じせつがら 時節柄"
"じせん 次戦 自選 自薦"
"じせんき 自戦記"
"じせんよう 耳栓用"
"じぜん 慈善 次善 事前"
"じそう 次走 自走 時相"
"じそく 磁束 時速 自足"
"じそくき 自速機"
"じそん 自尊 自存 自損"
"じそんしん 自尊心"
"じぞう 地蔵"
"じぞく 持続"
"じた 自他"
"じたい 字體 字体 辞退 事態 自体"
"じたく 自宅"
"じたくけんじむしょ 自宅兼事務所"
"じたすく 自タスク"
"じたつ 示達"
"じたとも 自他共"
"じたん 時短"
"じだ 次打 耳朶"
"じだい 事大 次代 地代 時代"
"じだいおくれ 時代後れ"
"じだいげき 時代劇"
"じだいじゅん 時代順"
"じだいもの 時代物"
"じだらく 自堕落"
"じだん 示談 次段"
"じち 自治"
"じちしょう 自治省"
"じちたい 自治体"
"じちょ 自著"
"じちょう 自嘲 自重 次長"
"じちりょう 自治領"
"じちろう 自治労"
"じちん 自沈"
"じっか 実家"
"じっかい 十誡 十階 十戒 実解"
"じっかいせきせい 実解析性"
"じっかん 十干 甲乙丙丁戊己庚辛壬癸 実感"
"じっき 実機"
"じっきょう 実況"
"じっきょうしゅっぱん 実教出版"
"じっきょうせき 実況席"
"じっけい 実兄 実刑"
"じっけん 實驗 実検 実権 実験"
"じっけんすい 実験水"
"じっけんずみ 実験済"
"じっけんせい 実験星"
"じっけんづくえ 実験机"
"じっけんとう 実験棟"
"じっけんろ 実験炉"
"じっこう 実効 実行"
"じっこうい 実行委"
"じっこうたい 実行体"
"じっこうはん 実行犯"
"じっこん 昵懇 入魂 実根"
"じっさい 実際"
"じっさいてきな 実際的な"
"じっさいに 実際に"
"じっさぎょう 実作業"
"じっし 十指 実姉 実視 実子 実施"
"じっしつ 実質"
"じっしつやく 実質役"
"じっしゃ 実車 実写"
"じっしゃかい 実社会"
"じっしゃもの 実写物"
"じっしゅ 十種"
"じっしゅう 実収 実習"
"じっしゅうねん 十周年"
"じっしょう 十漿 実証"
"じっしょうずみ 実証済"
"じっしん 十進 １０進 実身"
"じっすう 実数"
"じっすうかい 実数解"
"じっすうたい 実数体"
"じっすん 実寸"
"じっせい 実勢"
"じっせいかつ 實生活 実生活"
"じっせかい 実世界"
"じっせき 実績"
"じっせきあり 実績有"
"じっせきさく 実績作"
"じっせきば 実績馬"
"じっせん 実戦 実線 実践"
"じっせんけい 実戦形"
"じっそう 十層 実相 実装"
"じっそうしゃていぎ 実装者定義"
"じっそうじ 実相寺"
"じっそうほう 実装方"
"じっそく 実測"
"じったい 実態 実体"
"じったいきょう 実体鏡"
"じったいけん 実体験"
"じったいは 実体波"
"じっち 実地"
"じっちゅう 十中"
"じっちょうりょく 実張力"
"じっちょく 実直"
"じっつう 十通"
"じって 十手"
"じってい 実弟"
"じっていほう 実定法"
"じっとく 十徳"
"じっぱ 十把 十羽"
"じっぴ 実費"
"じっぴき 十匹"
"じっぷ 実父"
"じっぷん 十分"
"じっぽ 十歩"
"じっぽう 実包"
"じつ 昵 實 日 実"
"じつあっしゅくひ 実圧縮比"
"じつい 実委"
"じついん 実印"
"じつうんよう 実運用"
"じつえき 実益"
"じつえん 実演"
"じつえんか 実演家"
"じつおん 実音"
"じつおんげん 実音源"
"じつおんせい 実音声"
"じつおんぞう 実音像"
"じつかそくど 実加速度"
"じつかどう 実稼働"
"じつかんきょう 実環境"
"じつかんすう 実関数"
"じつがい 実害"
"じつがく 実学"
"じつがめん 実画面"
"じつきおく 実記憶"
"じつぎ 実技"
"じつぎょう 実業"
"じつぎょうか 実業家"
"じつぎょうのにほんしゃ 実業之日本社"
"じつくうかん 実空間"
"じつけいさんき 実計算機"
"じつけいすう 実係数"
"じつげつ 日月"
"じつげん 実現"
"じつげんみ 実現味"
"じつこうりつ 実効率"
"じつさぎょう 実作業"
"じつざい 実在"
"じつしよう 実使用"
"じつじ 実耳"
"じつじかん 実時間"
"じつじく 実軸"
"じつじゅ 実需"
"じつじょう 実情 実状"
"じつせかい 実世界"
"じつぞう 実像"
"じつぞん 実存"
"じつたいけん 実体験"
"じつたいしょう 実対称"
"じつだん 実弾"
"じつちえん 実遅延"
"じつづき 地続き"
"じつていすう 実定数"
"じつとうじょうじっせき 実搭乗実績"
"じつどう 実動 実働"
"じつどうさ 実動作"
"じつに 実に"
"じつねんぴ 実燃費"
"じつねんれい 実年齢"
"じつねんろん 実念論"
"じつは 実は"
"じつばい 実売"
"じつばりき 実馬力"
"じつひきすう 実引数"
"じつぶ 実部"
"じつぶつ 実物"
"じつぼ 地坪 実母"
"じつまい 実妹"
"じつむ 実務"
"じつむか 実務家"
"じつめい 実名"
"じつも 自模"
"じつもふ 自模符"
"じつやく 実役"
"じつよう 実用"
"じつようかどうむき 実用化動向"
"じつようしゃ 実用車"
"じつり 実利"
"じつりょく 実力"
"じつりょくば 実力馬"
"じつれい 実例"
"じつれん 実連"
"じつろう 実労"
"じつろく 実録"
"じつわ 実話"
"じづめ 字詰め"
"じづら 字面"
"じてい 時程"
"じていすう 時定数"
"じてき 自適"
"じてん 辭典 自転 次点 事典 字典 辞典 時点"
"じてんしゃ 自轉車 自転車"
"じてんしゃようくつ 自転車用靴"
"じてんじく 自転軸"
"じてんせつ 自転説"
"じでん 自伝"
"じでんてきさくひん 自伝的作品"
"じとう 字統 地頭"
"じとく 自得"
"じどう 耳道 児童 自動"
"じどうかいけつ 自動解結"
"じどうがほう 児童画報"
"じどうぎれ 自動切"
"じどうし 自動詞"
"じどうしゃ 自動車"
"じどうしゃしゅとくぜい 自動車取得税"
"じどうしゃぜい 自動車税"
"じどうしゃでんわ 自動者電話"
"じどうへんそくしゃ 自動変速車"
"じどうまど 自動窓"
"じどり 地鶏"
"じない 耳内"
"じなり 地鳴り"
"じなん 二男 次男"
"じなんぼう 次男坊"
"じにん 自認 自任 辞任"
"じにんせつ 辞任説"
"じぬし 地主"
"じねつ 地熱"
"じねん 自然"
"じはい 字牌"
"じはく 自白"
"じはだ 地肌"
"じはつ 次発 自発"
"じはん 次版 時半"
"じはんき 自販機"
"じはんころ 時半頃"
"じば 地場 磁場"
"じばいせき 自賠責"
"じばく 自縛 自爆"
"じばくれい 自縛霊"
"じばら 自腹"
"じばん 地盤"
"じぱい 字牌"
"じひ 慈悲 自費"
"じひつ 自筆"
"じひつふ 自筆譜"
"じひびき 地響き"
"じひょう 恃憑 次表 時評 辞表"
"じひょうじ 字表記"
"じび 耳鼻"
"じびき 辞引 字引"
"じびょう 持病"
"じふ 慈父 自負"
"じふく 地幅 地覆 自腹"
"じふぶき 地吹雪"
"じふへん 時不変"
"じふん 時分"
"じぶ 治部"
"じぶく 地幅 地覆"
"じぶつ 事物"
"じぶん 時分 自分"
"じぶんあて 自分宛"
"じぶんかつ 時分割"
"じぶんたち 自分たち"
"じぶんりゅう 自分流"
"じへいしょう 自閉症"
"じへいしょうじ 自閉症児"
"じへん 事變 時変 事変"
"じべた 地べた"
"じべん 自弁"
"じぺーじ 次頁"
"じほう 時報"
"じぼ 慈母 字母"
"じぼう 自暴"
"じま 嶌 縞 嶋 島"
"じまい 仕舞 仕舞い"
"じまえ 時前 自前"
"じまく 字幕"
"じまくいり 字幕入り"
"じまひ 仕舞い"
"じまん 自漫 自慢"
"じまんげ 自慢気"
"じまんばなし 自慢話"
"じみ 滋味 地味"
"じみち 地道"
"じみん 自民"
"じみんとう 自民党"
"じむ ジム 事務"
"じむききてん 事務機器展"
"じむきょくしようらん 事務局使用覧"
"じむしょく 事務職"
"じむとう 事務棟"
"じむひ 事務費"
"じめい 字名 自明"
"じめいかい 自明解"
"じめつ 自滅"
"じめん 字面 地面"
"じもく 耳目"
"じもくじ 甚目寺"
"じもと 地元"
"じもとし 地元紙"
"じもとしゃ 地元車"
"じもとぜい 地元勢"
"じもとみん 地元民"
"じもよう 地模様"
"じもん 字紋 自問 次問"
"じもんじとう 自問自答"
"じゃ 麝 闍 者 蛇 邪"
"じゃーなりすと ジャーナリスト"
"じゃーなる ジャーナル"
"じゃあく 邪悪"
"じゃき 邪鬼 邪気"
"じゃきょう 邪教"
"じゃく 鉐 搦 雀 若 惹 寂 弱"
"じゃくえんさん 弱塩酸"
"じゃくおん 弱音"
"じゃくかりょく 弱火力"
"じゃくきょうちゅう 弱強中"
"じゃくけいしき 弱形式"
"じゃくさん 弱酸"
"じゃくし 杓子 弱視"
"じゃくしゃ 弱者"
"じゃくしょう 弱小"
"じゃくしん 弱震"
"じゃくたい 弱体"
"じゃくちゅうきょう 弱中強"
"じゃくちょう 寂聴"
"じゃくちょうぼいん 弱長母音"
"じゃくてん 弱点"
"じゃくでん 弱電"
"じゃくどくすいとう 弱毒水痘"
"じゃくにくきょうしょく 弱肉強食"
"じゃくねん 若年"
"じゃくねんせいろうじんびょう 若年性老人病"
"じゃくねんれい 若年齢"
"じゃくはい 弱輩 若輩"
"じゃくはいもの 若輩者"
"じゃくはく 弱拍"
"じゃくやく 雀躍"
"じゃくれいしゃ 弱冷車"
"じゃくれいぼうしゃ 弱冷房車"
"じゃぐち 蛇口"
"じゃけっと ジャケット"
"じゃけん 邪慳 邪剣 邪険"
"じゃこう 麝香"
"じゃこういん 寂光院"
"じゃし 邪視"
"じゃしん 邪心 邪神"
"じゃじゃうま じゃじゃ馬"
"じゃすい 邪推"
"じゃすこ ジャスコ"
"じゃすと ジャスト"
"じゃすみん ジャスミン"
"じゃず ジャズ"
"じゃせい 邪正"
"じゃっか 弱化"
"じゃっかん 弱干 弱冠 若干"
"じゃっかんき 若干気"
"じゃっき 惹起"
"じゃっく 惹句"
"じゃどう 邪道"
"じゃねん 邪念"
"じゃばら 蛇腹"
"じゃま 邪魔"
"じゃまもの 邪魔物"
"じゃむ ジャム"
"じゃり 砂利"
"じゃりみち 砂利路"
"じゃりゅう 邪龍"
"じゃわ 爪哇"
"じゃん 雀"
"じゃんぐる ジャングル"
"じゃんごう 雀豪"
"じゃんし 雀師"
"じゃんそう 雀荘"
"じゃんたく 雀卓"
"じゃんぱー ジャンパー"
"じゃんぷ ジャンプ"
"じゃんぼ ジャンボ"
"じゃんる ジャンル"
"じゅ 愀 讐 讎 豎 襦 聚 戍 懦 孺 咒 濡 壽 嬬 珠 儒 呪 綬 授 需 寿 樹 受"
"じゅーくぼっくす ジュークボックス"
"じゅーす ジュース"
"じゅあつ 受圧"
"じゅあん 寿庵"
"じゅいち 寿一"
"じゅう 鞣 蹂 縱 絨 糅 獸 狃 澀 澁 揉 從 从 拾 戎 什 汁 充 中 縦 渋 獣 柔 銃 住 重 従 十"
"じゅうあつ 重圧"
"じゅうあつかん 重厚感"
"じゅうい 獣医 十位"
"じゅういせん 順位戦"
"じゅういち 十一"
"じゅういちがつ 霜月 １１月"
"じゅういっぴき 十一匹"
"じゅうえん 十円"
"じゅうえんだま 十円玉"
"じゅうおう 縦横 十王"
"じゅうおうか 縦横家"
"じゅうおく 十億"
"じゅうおん 重音"
"じゅうか 銃火 従価 住家"
"じゅうかい 重解"
"じゅうかく 縦隔"
"じゅうかぜい 従価税"
"じゅうかん 縦貫"
"じゅうかんきょう 住環境"
"じゅうがつ 神無月 十筑 十月 １０月"
"じゅうき 重機 銃器 什器"
"じゅうきこうへい 重機甲兵"
"じゅうきせい 銃規制"
"じゅうきち 重吉"
"じゅうきゅう 十九"
"じゅうきょ 住居"
"じゅうきょあと 住居跡"
"じゅうきょようせんざい 住居用洗剤"
"じゅうぎょう 従業"
"じゅうぐん 従軍"
"じゅうけい 重刑 従系 従兄"
"じゅうけいこう 重慶港"
"じゅうけいはんてん 重慶飯店"
"じゅうけつ 充血"
"じゅうけん 重検 住建 銃剣"
"じゅうげき 銃撃"
"じゅうげん 重言"
"じゅうこう 銃口 重厚 重工"
"じゅうこうげき 銃攻撃"
"じゅうこつ 獸骨"
"じゅうこん 重婚 重根"
"じゅうご 銃後 十五"
"じゅうごう 重合"
"じゅうごや 十五夜"
"じゅうさいぼう 柔細胞"
"じゅうさつ 銃殺"
"じゅうさつけい 銃殺刑"
"じゅうさん 十三"
"じゅうさんびき 十三匹"
"じゅうざい 重罪"
"じゅうし 獣脂 従祀 従姉 重視"
"じゅうしちにち 十七日"
"じゅうしてい 従姉弟"
"じゅうしまつ 十姉妹"
"じゅうしゃ 従者"
"じゅうしやま 十四山"
"じゅうしょ 住所"
"じゅうしょあて 住所宛"
"じゅうしょう 重賞 重傷 重症"
"じゅうしょく 重職 住職"
"じゅうしょとうろくきのう 住所録機能"
"じゅうしん 重臣 住心 獣身 銃身 重心"
"じゅうじ 十時 十字 従事"
"じゅうじか 十字架"
"じゅうじがた 十字形"
"じゅうじぐん 十字軍"
"じゅうじけい 十字形"
"じゅうじつ 充実"
"じゅうじつひ 充実費"
"じゅうじゅう 重々"
"じゅうじゅん 重巡 従順"
"じゅうじょう 十条 重畳"
"じゅうじょうせいし 十條製紙"
"じゅうじろ 十字路"
"じゅうじん 獣人 獣神"
"じゅうすい 重水"
"じゅうすう 十数"
"じゅうすうこ 十数戸"
"じゅうせい 銃声 獣性"
"じゅうせき 重責"
"じゅうぜい 重税"
"じゅうぜん 従前"
"じゅうそう 重秦 銃創 重装 十三 重曹 重層 重奏 縦走"
"じゅうそく 充足"
"じゅうそしき 柔組織"
"じゅうそつ 従卒"
"じゅうぞう 重像 十三"
"じゅうぞく 従属"
"じゅうぞくかのう 充足可能"
"じゅうたい 縦隊 重体 渋滞"
"じゅうたいほうていしき 状態方程式"
"じゅうたいろ 渋滞路"
"じゅうたく 住宅"
"じゅうたくけんせつひ 住宅建設費"
"じゅうたくひ 住宅費"
"じゅうたん 絨緞 絨毯"
"じゅうだい 十大 十代 重大"
"じゅうだいしゃ 従台車"
"じゅうだん 銃彈 銃弾 縦断"
"じゅうだんせん 十段戦"
"じゅうちん 重鎮"
"じゅうてん 充填 重点"
"じゅうでん 充電"
"じゅうでんち 充電池"
"じゅうとう 充当"
"じゅうとく 重篤"
"じゅうとこうだん 住都公団"
"じゅうど 重度"
"じゅうどう 柔道"
"じゅうどうか 柔道家"
"じゅうどうぎ 柔道着"
"じゅうななにち 十七日"
"じゅうなん 柔軟"
"じゅうなんかい 十何回"
"じゅうなんぎょう 十何行"
"じゅうなんにち 十何日"
"じゅうなんねん 十何年"
"じゅうなんまい 十何枚"
"じゅうなんれんしょう 十何連勝"
"じゅうに 十二 １２"
"じゅうにがつ 師走 極月"
"じゅうにく 獣肉"
"じゅうにし 子丑寅卯辰巳午未申酉戌亥 十二支"
"じゅうにしちょう 十二指腸"
"じゅうにひとえ 十二単"
"じゅうにん 重任 十人 住人"
"じゅうにんといろ 十人十色"
"じゅうねん 十年"
"じゅうねんいじょうあと 十年以上後"
"じゅうはち 十八"
"じゅうはん 重版 従犯"
"じゅうばいいじょう 十倍以上"
"じゅうばこ 重箱"
"じゅうばつ 重罰"
"じゅうばん 重版 十番"
"じゅうびょう 重病"
"じゅうびょうたんい 十秒単位"
"じゅうふく 重複"
"じゅうぶ 十分"
"じゅうぶん 重文 充分 十分"
"じゅうべえ 十平衛 十兵衛"
"じゅうほう 重砲 銃砲"
"じゅうほうでん 充放電"
"じゅうまい 十枚"
"じゅうまん 充満 十万"
"じゅうみん 住民"
"じゅうみんぜい 住民税"
"じゅうめい 十名"
"じゅうめん 従免 渋面"
"じゅうもう 絨毛"
"じゅうもうまく 絨毛膜"
"じゅうもんじ 十文字"
"じゅうやく 重役"
"じゅうゆ 重油"
"じゅうよう 充用 重要"
"じゅうようさく 重要作"
"じゅうようし 重要視"
"じゅうような 重要な"
"じゅうようるいだい 重要類題"
"じゅうよん 十四"
"じゅうらい 従来"
"じゅうらん 縦覧"
"じゅうりょう 十両 従量 重量"
"じゅうりょうけい 重量計"
"じゅうりょうしゃ 重量車"
"じゅうりょうぜい 重量税 従量税"
"じゅうりょく 重力"
"じゅうりょくけい 重力計"
"じゅうりょくげん 重力源"
"じゅうりょくは 重力波"
"じゅうりょくはほう 重力波砲"
"じゅうりょくふほうかい 重力負崩壊"
"じゅうりん 蹂躪 蹂躙"
"じゅうれつ 縦列"
"じゅうれん 重連"
"じゅうろう 十郎"
"じゅうろうた 十郎太"
"じゅうろく 十六"
"じゅうろくしん １６進"
"じゅうろくちゃ 十六茶"
"じゅうろくや 十六夜"
"じゅえき 樹液 受益"
"じゅおん 受音"
"じゅか 樹下 儒家 樹香"
"じゅかい 樹海"
"じゅかん 樹幹"
"じゅがく 儒学"
"じゅきゅう 需給 受給"
"じゅきょう 授亨 受教 儒教"
"じゅぎょう 授業"
"じゅぎょうは 授業"
"じゅく 孰 宿 塾 熟"
"じゅくいん 塾員"
"じゅくこう 塾講 塾高 熟考"
"じゅくご 熟語"
"じゅくし 熟視"
"じゅくじくん 熟字訓"
"じゅくじょ 熟女"
"じゅくすい 熟睡"
"じゅくせい 塾生 熟成"
"じゅくたつ 熟達"
"じゅくち 熟知"
"じゅくどく 熟読"
"じゅくない 塾内"
"じゅくねん 熟年"
"じゅくりょ 熟慮"
"じゅくれん 熟練"
"じゅくれんこう 熟練工"
"じゅけい 受刑"
"じゅけつしゃ 受血者"
"じゅけん 授権 受検 受験"
"じゅけんひ 受験費"
"じゅこう 受光 受講"
"じゅこん 樹根"
"じゅさつ 呪殺"
"じゅし 孺子 儒子 樹脂"
"じゅしゃ 儒者"
"じゅしゅ 樹種"
"じゅしょう 受章 授賞 受賞"
"じゅしょうさく 受賞作"
"じゅしん 受診 受身 受信"
"じゅしんとも 受信共"
"じゅじゅ 受授 授受"
"じゅじゅつ 呪術"
"じゅじょう 樹状"
"じゅすい 入水"
"じゅず 数珠"
"じゅせい 樹勢 授精 受精"
"じゅせいらん 受精卵"
"じゅそ 受訴 呪咀 呪詛"
"じゅそうしんかんど 受送信感度"
"じゅぞう 受贈 受像"
"じゅたい 受胎"
"じゅたく 受託"
"じゅだい 入内"
"じゅだく 受諾"
"じゅちゅう 受注"
"じゅちゅうざん 受注残"
"じゅちょう 受聴"
"じゅっかい 十誡 十階 述懐 十戒"
"じゅっかいき 十回忌"
"じゅっかいてん 十回転"
"じゅっかんじゅうにし 十干十二支"
"じゅっこ 十個"
"じゅっこう 熟考"
"じゅっさく 術策"
"じゅっしゅうねん 十周年"
"じゅっしん １０進 十進"
"じゅっちゅう 術中 十中"
"じゅっつう 十通"
"じゅって 十手"
"じゅっとく 拾得"
"じゅっぱ 十把 十羽"
"じゅっぴき 十匹"
"じゅっぷん 十分"
"じゅっぽ 十歩"
"じゅつ 戌 恤 朮 述 術"
"じゅつかい 述懐"
"じゅつご 術語 術後 述語"
"じゅつし 術師"
"じゅつしき 術式"
"じゅつしゃ 術者"
"じゅつぜん 術前"
"じゅつちゅう 術中"
"じゅつてき 術的"
"じゅつぶ 述部"
"じゅつほう 術法"
"じゅどう 受動"
"じゅどうたい 受動態"
"じゅなん 受難"
"じゅにあ ジュニア"
"じゅにゅう 授乳"
"じゅねーぶ 壽府"
"じゅのう 受納"
"じゅはい 受配"
"じゅばく 呪縛"
"じゅばん 襦袢"
"じゅひ 樹皮"
"じゅひょう 樹氷"
"じゅひょうげん 樹氷原"
"じゅふ 授付 呪符"
"じゅふん 受粉"
"じゅへい 寿平"
"じゅほう 呪法"
"じゅみょう 寿命"
"じゅもく 樹木"
"じゅもん 呪文"
"じゅよ 授与"
"じゅよう 受容 需要"
"じゅようか 需要家"
"じゅようたい 受容体"
"じゅようや 受容野"
"じゅらい 入来"
"じゅらいほう 従来法"
"じゅらく 聚楽"
"じゅらくだい 聚楽第"
"じゅり 寿理 樹理 樹里 珠理 朱里 ジュリ 受理"
"じゅりつ 樹立"
"じゅりみち 砂利道"
"じゅりょう 授領 受領"
"じゅりょういん 受領印"
"じゅりん 樹林"
"じゅれい 樹苓 樹齢"
"じゅわ 受話"
"じゅん 隼 閏 惇 諄 詢 蓴 荀 笋 筍 洵 恂 徇 凖 馴 篤 准 楯 循 殉 遵 醇 旬 盾 巡 淳 潤 準 純 順"
"じゅんあい 純愛"
"じゅんあつ 順圧"
"じゅんあんくうこう 順安空港"
"じゅんい 遵依 準尉 準位 准尉 順位"
"じゅんいじゅん 順位順"
"じゅんいち 遵一 准一 順一 潤一 純一 淳一"
"じゅんいちろう 順一郎 純一郎 潤一郎 淳一郎"
"じゅんいん 準員"
"じゅんうりあげ 純売上"
"じゅんえき 準駅 純益"
"じゅんえん 巡演 順延"
"じゅんおう 順応"
"じゅんおくり 順送り"
"じゅんおん 純音"
"じゅんか 馴化 順化 純化"
"じゅんかい 巡回"
"じゅんかがくてき 純科学的"
"じゅんかつ 潤滑"
"じゅんかつざい 潤滑材"
"じゅんかつゆ 潤滑油"
"じゅんかん 旬刊 准看 循環"
"じゅんきゅう 準急"
"じゅんきょ 準拠"
"じゅんきょう 殉教"
"じゅんきょうじゅ 准教授"
"じゅんきょすう 純虚数"
"じゅんきん 純金"
"じゅんぎゃく 順逆"
"じゅんぎょう 巡行 巡業"
"じゅんぎん 純銀"
"じゅんぐん 準群"
"じゅんけい 順慶"
"じゅんけつ 準決 純血 純潔"
"じゅんけん 巡検"
"じゅんこ 準子 惇子 潤子 淳子 ＪＵＮＫＯ 純子 順子 絢子"
"じゅんこう 巡幸 順光 巡行 純項 巡航"
"じゅんこくさん 純国産"
"じゅんさ 巡査"
"じゅんさい 蓴菜"
"じゅんさいあか ジュンサイ亜科"
"じゅんさつ 巡察"
"じゅんさんそ 純酸素"
"じゅんし 潤史 殉死 巡視"
"じゅんしかん 准士官"
"じゅんしゅ 順守 遵守"
"じゅんしょ 準処"
"じゅんしょう 順昭 准将"
"じゅんしょく 潤色 殉職"
"じゅんしん 順心 純心 純真"
"じゅんじ 順二 順司 純二 洵二 純治 純司 淳嗣 順治 淳司 淳二 純次 順次"
"じゅんじつ 旬日 閏日"
"じゅんじゅん 諄諄 順順 循循 恂恂 順々"
"じゅんじゅんけっしょう 準々決勝 凖凖決勝"
"じゅんじょ 順序"
"じゅんじょう 純情"
"じゅんじょづけ 順序付"
"じゅんすい 純水 純粋"
"じゅんせい 順清 純正"
"じゅんせいひん 純製品"
"じゅんせいりつ 純正律"
"じゅんせん 準線"
"じゅんせんりゃく 純戦略"
"じゅんぜん 純然"
"じゅんそう 順走"
"じゅんぞう 純増 淳三"
"じゅんたく 潤沢"
"じゅんだいすうてき 純代数的"
"じゅんだんせいこうさんらん 準弾性光散乱"
"じゅんちょう 順調"
"じゅんていこう 純抵抗"
"じゅんてん 順天"
"じゅんてんどう 順天堂"
"じゅんとう 順当"
"じゅんとうしょう 順当勝"
"じゅんとく 潤徳"
"じゅんど 純度"
"じゅんな 純名"
"じゅんなま 純生"
"じゅんのう 順応"
"じゅんのすけ 淳之介 順之介 純之介"
"じゅんばん 順番"
"じゅんぱい 潤肺"
"じゅんぱく 純白"
"じゅんひぶ 順日歩"
"じゅんび 順備 準備"
"じゅんびい 準備委"
"じゅんびこう 準備稿"
"じゅんびょう 閏秒"
"じゅんふどう 順不同"
"じゅんぶんがく 純文学"
"じゅんぷう 順風"
"じゅんへんせい 順編成"
"じゅんぺい 順平"
"じゅんほうこう 順方向"
"じゅんぼく 純朴"
"じゅんぽう 旬報 順法 遵法"
"じゅんまい 純米"
"じゅんまいしゅ 純米酒"
"じゅんめ 順目 巡目"
"じゅんもう 純毛"
"じゅんや 順彌 潤哉 潤也 純也"
"じゅんよう 巡洋 準用"
"じゅんら 巡邏"
"じゅんり 純利"
"じゅんりえき 純利益"
"じゅんりゅうさん 純硫酸"
"じゅんりょう 純量"
"じゅんりろんてき 純理論的"
"じゅんれい 巡礼"
"じゅんれいきゃく 巡礼客"
"じゅんれつ 順列"
"じゅんろ 順路"
"じゅんろちょう 順路帳"
"じゅんろんりてき 純論理的"
"じゆう 事由 自由"
"じゆうがおか 自由が丘"
"じゆうぎょう 自由業"
"じゆうせき 自由席"
"じゆうせきけん 自由席券"
"じゆうせきしゃ 自由席車"
"じゆうたん 自由端"
"じゆうちょう 自由帳"
"じゆうとう 自由党"
"じゆうは 自由波"
"じゆうば 自由場"
"じゆうふく 自由服"
"じゆうみんしゅとう 自由民主党"
"じゆうれん 自由練"
"じゆくうかん 自由空間"
"じょ 蜍 莇 茹 耡 絮 洳 敘 敍 抒 舒 汝 所 叙 恕 徐 鋤 助 序 如 除 女"
"じょーく ジョーク"
"じょい 女医"
"じょいなす ジョイナス"
"じょう 縄 瀞 貞 帖 茸 繩 驤 饒 靜 釀 遶 躡 讓 襄 蟐 蕘 聶 繞 絛 穰 禳 疂 疉 疊 烝 滌 淨 攘 拯 孃 嬲 嫋 壤 塲 剩 仗 仍 乘 星 静 盛 丞 擾 剰 穣 條 蒸 冗 壌 丈 醸 杖 浄 生 嬢 定 成 譲 錠 乗 畳 常 条 城 場 情 状 上"
"じょうい 攘夷 上意 譲位 上位"
"じょういうち 上意討ち"
"じょういち 譲一"
"じょういちゃくじゅんば 上位着順馬"
"じょういば 上位馬"
"じょういん 上院 乗員"
"じょうえい 上映"
"じょうえつ 上越"
"じょうえん 上演"
"じょうおう 女王"
"じょうおん 常温"
"じょうか 上下 城下 浄化"
"じょうかい 常会 場開 上階 上界"
"じょうかく 城閣 城郭"
"じょうかけん 情科研"
"じょうかそう 浄化槽"
"じょうかまち 城下街"
"じょうかん 情感 上官 上巻"
"じょうがい 場外"
"じょうがいせん 場外戦"
"じょうがくら 城ケ倉"
"じょうがさき 城ケ崎"
"じょうがしま 城ヶ島"
"じょうがんじがわ 常願寺川"
"じょうき 情機 蒸氣 条規 上気 常軌 蒸気 上記"
"じょうきあつ 蒸気圧"
"じょうきあて 上記宛"
"じょうきあん 上記案"
"じょうきおう 蒸氣王"
"じょうきげん 上喜元"
"じょうきせん 蒸気船"
"じょうきゃく 上客 乗客"
"じょうきゃくぞう 乗客増"
"じょうきゅう 上丘 上級"
"じょうきゅうしゃむけ 上級者向"
"じょうきゅうしょく 上級職"
"じょうきゅうしん 上級審"
"じょうきょう 情況 上京 情教 状況"
"じょうきょうてきにんち 状況的認知"
"じょうきん 常勤"
"じょうぎ 定規"
"じょうく 冗句"
"じょうくう 上空"
"じょうけい 常形 情景"
"じょうけん 情研 條件 条件"
"じょうけんせん 条件戦"
"じょうけんつき 条件付"
"じょうけんつきかつりつ 条件付確率"
"じょうけんづけ 条件付"
"じょうけんば 条件馬"
"じょうげ 上下"
"じょうげさゆう ↑↓→←"
"じょうげどう 上下動"
"じょうげん 上弦 上限"
"じょうげんがく 上限額"
"じょうこう 上向 情工 情交 乗降 上皇 条項"
"じょうこうきゃく 乗降客"
"じょうこうぐち 乗降口"
"じょうこうしゃ 乗工社"
"じょうこく 上告"
"じょうこん 乗根"
"じょうご 漏斗 上戸"
"じょうさい 城砦 条西 城西 城塞"
"じょうさし 状差 状差し"
"じょうさま 嬢様"
"じょうさん 乗算"
"じょうざい 常在 剰剤 浄財 錠剤"
"じょうざん 乗算"
"じょうざんけい 定山渓"
"じょうし 上肢 情子 城市 城址 上梓 上司"
"じょうしき 上式 常識"
"じょうしきか 常識家"
"じょうした 城下"
"じょうしつ 上質"
"じょうしつし 上質紙"
"じょうしゃ 盛者 乗車"
"じょうしゃきゃく 乗車客"
"じょうしゃぐち 乗車口"
"じょうしゃけん 乗車券"
"じょうしゃせん 乗車船"
"じょうしゃとびら 乗車扉"
"じょうしゅ 城主"
"じょうしゅう 常習 上州"
"じょうしゅうじ 上州路"
"じょうしゅうはん 常習犯"
"じょうしゅうや 上洲屋"
"じょうしょ 浄書 情緒 上書 情処"
"じょうしょう 常勝 丞相 上昇"
"じょうしょうおんけい 上昇音形"
"じょうしょうかく 上昇角"
"じょうしょうかん 上昇管"
"じょうしょく 常食"
"じょうしん 浄心 上新 上申"
"じょうしんでんてつ 上信電鉄"
"じょうじ 丈治 条二 常児 丈二 丈嗣 情事 譲二 常時"
"じょうじせいたいない 常磁性体内"
"じょうじつ 情実"
"じょうじま 城島"
"じょうじゅ 成就"
"じょうじゅう 常住"
"じょうじゅつ 上述"
"じょうじゅん 上旬"
"じょうじゅんごろ 上旬頃"
"じょうじょ 乗除"
"じょうじょう 穣穣 擾擾 畳畳 常情 常常 常状 烝烝 条条 上上 嫋嫋 情状 上乗 上場 上々"
"じょうじょさんめいれい 乗除算命令"
"じょうじょざん 乗除算"
"じょうじん 常人"
"じょうすい 定水 浄水 上水"
"じょうすう 剰数 常数 定数 乗数"
"じょうすうけん 情数研"
"じょうず 上図 上手"
"じょうせい 上澄 城西 上清 状勢 醸成 情勢"
"じょうせいほん 情制本"
"じょうせき 鐘石 上積 乗積 上席 定石 定跡"
"じょうせきけい 定石形"
"じょうせつ 常設"
"じょうせついん 浄雪院"
"じょうせつてん 常設展"
"じょうせん 情宣 乗船"
"じょうせんけん 乗船券"
"じょうぜつ 饒舌"
"じょうぜん 定禅"
"じょうぜんじ 定禅寺"
"じょうぜんじどおり 定禅寺通"
"じょうぜんみずのごとし 上善如水"
"じょうそ 上訴"
"じょうそう 情想 常総 上奏 情操 上層"
"じょうぞう 醸造"
"じょうぞうしゅ 醸造酒"
"じょうぞうじょ 醸造所"
"じょうたい 上体 常態 状態"
"じょうたつ 上達"
"じょうたん 上端"
"じょうだいかんとうご 上代関東語"
"じょうだま 上玉"
"じょうだん 上段 冗談"
"じょうだんぬき 冗談抜"
"じょうち 常置 上智"
"じょうちそつ 上智卒"
"じょうちゃく 蒸着"
"じょうちゃくまく 蒸着膜"
"じょうちゅう 静注 城中 常駐"
"じょうちゅうもの 常駐物"
"じょうちょ 情緒"
"じょうちょう 上長 情調 冗長"
"じょうつうけん 情通研"
"じょうてい 上帝 上程"
"じょうでんけん 情電研"
"じょうと 譲渡"
"じょうとう 上棟 城東 上道 上等 常套"
"じょうとうく 常套句"
"じょうとうへい 上等兵"
"じょうとぜい 譲渡税"
"じょうど 浄土"
"じょうどいん 浄土因"
"じょうどう 情動 常道"
"じょうどがはま 浄土ヶ浜"
"じょうどじ 浄土寺"
"じょうない 城内 場内"
"じょうなん 城南"
"じょうにん 常任"
"じょうねつ 情熱"
"じょうねん 情念"
"じょうの 上の"
"じょうのう 上納"
"じょうのうち 城之内"
"じょうのうやくもんだい 場農薬問題"
"じょうはつ 蒸発"
"じょうはつざら 蒸発皿"
"じょうはつせんねつ 蒸発潜熱"
"じょうはな 城端"
"じょうはん 畳半"
"じょうはんしんはだか 上半身裸"
"じょうば 乗馬"
"じょうばん 定盤 常磐"
"じょうばんかいそく 常盤快速"
"じょうばんじどうしゃどう 常盤自動車道"
"じょうばんせんえんせん 常盤線沿線"
"じょうばんせんたいらいき 常磐線平行"
"じょうばんせんたいらゆき 常磐線平行"
"じょうひ 上皮"
"じょうひん 上品"
"じょうび 常備"
"じょうびぶん 常微分"
"じょうびやく 常備薬"
"じょうふ 情婦 情夫"
"じょうぶ 上部 丈夫"
"じょうぶくろ 状袋"
"じょうぶつ 成仏"
"じょうぶん 条文"
"じょうへい 城兵"
"じょうへき 城壁"
"じょうへん 城辺 上編 上辺"
"じょうほ 譲歩"
"じょうほう 常法 定法 城寳 城宝 乗法 上方 情報"
"じょうほうぎじゅつだい 情報技術第"
"じょうほうげん 情報源"
"じょうほうこう 情報交 情報工"
"じょうほうじ 浄法寺"
"じょうほうすうりだい 情報数理第"
"じょうほうすじ 情報筋"
"じょうほうせん 情報戦"
"じょうほうだい 情報第"
"じょうほうとう 情報棟"
"じょうほうはっしんげん 情報発進源"
"じょうほうばん 情報板"
"じょうほうもう 情報網"
"じょうほく 常北 城北"
"じょうぼう 上房"
"じょうまえ 錠前"
"じょうみゃく 静脈"
"じょうみゃくけつ 静脈血"
"じょうみん 常民"
"じょうむ 乗務 常務"
"じょうめん 上面"
"じょうめんぞう 上面像"
"じょうもうでんてつ 上毛電鉄"
"じょうもの 上物"
"じょうもん 縄文 城門"
"じょうもんしきどき 縄文式土器"
"じょうもんすぎ 縄文杉"
"じょうやく 条約"
"じょうやとい 常雇い"
"じょうやとう 常夜燈"
"じょうやど 常宿"
"じょうよ 剩餘 譲与 剰余"
"じょうよう 上陽 乗用 常陽 常用 城陽"
"じょうようしゃ 乗用車"
"じょうよく 情欲"
"じょうらく 上洛"
"じょうらくかい 情洛会"
"じょうらん 擾乱 上覧"
"じょうらんずもう 上覧相撲"
"じょうり 条理"
"じょうりく 上陸"
"じょうりつ 乗率"
"じょうりゅう 蒸溜 蒸留 上流"
"じょうりゅうさいと 上流サイト"
"じょうりゅうしゅ 蒸留酒"
"じょうりゅうじょ 蒸留所"
"じょうりゅうすい 蒸留水"
"じょうりょく 常緑"
"じょうりょくじゅ 常緑樹"
"じょうるり 浄瑠璃"
"じょうれい 上例 条例 常例"
"じょうれいじゅつ 浄霊術"
"じょうれん 常連"
"じょうれんきゃく 常連客"
"じょうろ 如雨露"
"じょうろう 上臈"
"じょうわ 情話"
"じょうわん 上腕"
"じょえん 助演"
"じょおう 女王"
"じょおうあり 女王蟻"
"じょおうばち 女王蜂"
"じょかく 除核"
"じょがい 除外"
"じょがいたいしょうば 除外対象馬"
"じょがいば 除外馬"
"じょがくいん 女学院"
"じょがくえん 女学園"
"じょがくせい 女学生"
"じょがっかん 女学館"
"じょがっこう 女學校 女学校"
"じょきゃく 除却"
"じょきょ 除去"
"じょきょうじゅ 助教授"
"じょきょく 序曲"
"じょきょざい 除去材"
"じょきん 助勤"
"じょく 蓐 縟 溽 褥 辱"
"じょくそう 辱創 褥瘡"
"じょくふ 褥婦"
"じょくん 叙勲"
"じょけい 叙景"
"じょけつ 女傑"
"じょけん 女権"
"じょげん 序言 助言"
"じょこう 女工 徐行"
"じょさい 如才"
"じょさいぼう 助細胞"
"じょさん 除算"
"じょさんぷ 助産婦"
"じょざん 除算"
"じょし 序詞 女史 助詞 女子"
"じょしい 女子医"
"じょしこう 女子高"
"じょしだいせいむき 女子大生向"
"じょしだいせいやく 女子大生役"
"じょしちゅうせい 女子中生"
"じょしつ 除湿"
"じょしはつ 女子初"
"じょしび 女子美"
"じょしゃせきよう 助者席用"
"じょしゅ 助手"
"じょしゅう 徐州 女囚"
"じょしゅせき 助手席"
"じょしょう 女将 序章"
"じょしりょう 女子寮"
"じょしん 女真"
"じょじ 助辞 叙事 女児"
"じょじし 叙事詩"
"じょじゅつ 叙述"
"じょじょ 序々 除々 徐々"
"じょじょう 抒情 叙情"
"じょじょうし 叙情詩"
"じょじょに 徐々に"
"じょすい 如水"
"じょすう 助数 序数 除数"
"じょすうし 助数詞"
"じょせい 助勢 女声 助成 女性"
"じょせいあて 女性宛"
"じょせいがた 女性方"
"じょせいきゃく 女性客"
"じょせいぐん 女性軍"
"じょせいぞう 女性像"
"じょせいつりし 女性釣師"
"じょせいと 女生徒"
"じょせいび 女性美"
"じょせき 除籍"
"じょせつ 除雪 序説"
"じょせつしゃ 除雪車"
"じょそう 除装 助走 除草 序奏 女装"
"じょたい 除隊"
"じょたんぱく 除蛋白"
"じょちゅう 女中"
"じょちゅうぎく 除虫菊"
"じょちょう 助長"
"じょつう 除痛"
"じょてんいん 女店員"
"じょどうし 助動詞"
"じょにー ジョニー"
"じょにだん 序二段"
"じょにん 叙任"
"じょのくち 序の口"
"じょばす 女バス"
"じょばん 序番 序盤"
"じょばんせん 序盤戦"
"じょひ 女卑"
"じょひょう 除表 除票"
"じょぶ ジョブ"
"じょぶん 序文"
"じょへん 徐変"
"じょほう 除法"
"じょほうかがっか 情報科学科"
"じょまく 除幕 序幕"
"じょめい 助命 除名"
"じょや 除夜"
"じょやく 助役"
"じょやなべ 除夜鍋"
"じょゆう 女優"
"じょゆうやく 女優役"
"じょりゅう 女流"
"じょりょく 助力"
"じょれいし 除霊師"
"じょれつ 序列"
"じょろう 女郎"
"じょろん 序論"
"じよう 滋養 次葉"
"じらい 地雷"
"じらいげん 地雷原"
"じらいや 児雷也"
"じり 尻"
"じりき 自力"
"じりつ 自律 自立"
"じりつがたいどう 自立型移動"
"じりつしん 自立心 自律心"
"じりゅう 時流 自流"
"じりょく 恃力 磁力"
"じりょくかいそう 自力回送"
"じりょくけい 磁力計"
"じる 汁"
"じるい 字類"
"じるし 印"
"じれい 自励 辞礼 辞令 事例"
"じれつ 字列"
"じれん 自連"
"じれんま ジレンマ"
"じろ 字路"
"じろう 痔瘻 治朗 次朗 子郎 二朗 治郎 次郎 二郎"
"じろちょう 次郎長"
"じろん 持論"
"じわり 地割り"
"じわれ 地割れ"
"じん 靱 贐 蕁 糂 盡 燼 潯 恁 刄 仭 仞 進 塵 刃 壬 訊 臣 靭 神 腎 迅 仁 尋 甚 尽 陣 人"
"じんあい 塵埃 仁愛"
"じんい 人為"
"じんいち 塵一 仁一"
"じんいん 人員"
"じんう 腎盂"
"じんえい 陣営"
"じんえん 腎炎"
"じんか 人家"
"じんかい 塵芥 燼灰 人海"
"じんかいは 塵芥破"
"じんかく 人格"
"じんがい 人外"
"じんきょ 人居"
"じんぎ 神器 仁義 人技"
"じんぎすかん 成吉思汗"
"じんく 甚句"
"じんくす ジンクス"
"じんぐう 神功 神宮"
"じんぐうじ 神宮寺"
"じんけん 人絹 人件 人権"
"じんけんひ 人権費 人件費"
"じんこ 仁子"
"じんこう 沈香 人皇 櫁 樒 人口 人工"
"じんこううみ 人工海"
"じんこうえさ 人工餌"
"じんこうき 塵功記"
"じんこうこ 人工湖"
"じんこうしば 人工芝"
"じんこうじ 人工耳"
"じんこうすな 人工砂"
"じんこうぞう 人口増"
"じんこうにゅう 人工乳"
"じんこうへき 人工壁"
"じんこうゆき 人工雪"
"じんこうりん 人工林"
"じんこつ 人骨"
"じんごうき 塵劫記"
"じんごじ 神護寺"
"じんごろう 甚五郎"
"じんさい 人災"
"じんざい 人財 人材"
"じんざぶろう 甚三郎"
"じんしっかんかんじゃ 腎疾患患者"
"じんしゅ 人種"
"じんしん 人心 壬申 人身"
"じんじ 神事 人事"
"じんじいん 人事院"
"じんじがかり 人事掛"
"じんじゃ 神社"
"じんじゅつ 仁術"
"じんじょう 尋常"
"じんすけ 甚介"
"じんせい 人生"
"じんせいとうにょう 腎性糖尿"
"じんせき 人跡 神石"
"じんせん 仁川 仁山 人選"
"じんせんぬま 神仙沼"
"じんぜん 人前"
"じんぜんじ 秦泉寺"
"じんそく 迅速"
"じんぞう 人造 腎臓"
"じんぞうこ 人造湖"
"じんたい 靭帯 靱帯 人体"
"じんたん 仁丹"
"じんだい 神代 甚大"
"じんだいこ 陣太鼓"
"じんだいじ 深大寺"
"じんち 人智 人知 陣地"
"じんちく 人畜"
"じんちせんよう 陣地戦用"
"じんちゅう 陣中"
"じんちょうげ 沈丁花"
"じんつう 陣痛"
"じんつうがわ 神通川"
"じんつうりき 神通力"
"じんてい 人定"
"じんてき 人的"
"じんてん 人天"
"じんとう 人頭 陣頭"
"じんとうぜい 人頭税"
"じんとく 人徳"
"じんとり 陣取 神取"
"じんどう 人道"
"じんない 陣内"
"じんなん 神南"
"じんにく 人肉"
"じんば 神馬 陣場 人馬"
"じんばおり 陣羽織"
"じんぱち 甚八"
"じんぴ 靭皮 じん皮"
"じんぴん 人品"
"じんふぜん 腎不全"
"じんぶつ 人物"
"じんぶつぞう 人物像"
"じんぶん 人文"
"じんぶんけいかもく 人文系科目"
"じんぷう 陣風"
"じんぷく 尋腹"
"じんぷん 人糞"
"じんぺい 甚平 仁平"
"じんぼ 神保"
"じんぼあきら 神保彰"
"じんぼう 神保 人望"
"じんぽ 神保"
"じんましん 蕁麻疹"
"じんみゃく 人脈"
"じんみん 人民"
"じんみんぐん 人民軍"
"じんみんげん 人民元"
"じんみんだいかいどう 人民大会堂"
"じんみんへい 人民幣"
"じんむ 神武"
"じんむちょう 神武朝"
"じんめい 神名 神明 人命 人名"
"じんめいぼ 人名簿"
"じんめん 人面"
"じんめんいわ 人面岩"
"じんめんそ 人面疽"
"じんもん 訊問 尋問"
"じんよう 陣容"
"じんらい 人籟"
"じんりき 尽力 人力"
"じんりきしゃ 俥 人力車"
"じんりゅう 神竜"
"じんりょく 人力 尽力"
"じんるい 人類"
"じんるいあい 人類愛"
"す 簾 栖 棲 籔 壽 州 守 主 子 過 洲 笥 巣 寿 諏 酢 須 素"
"すーつ スーツ"
"すーぱー スーパー"
"すーぷ スープ"
"すあし 素足"
"すあな 巣穴"
"すい 穂 騅 隹 陲 醉 萃 翆 綏 粹 邃 瘁 燧 榱 捶 忰 悴 彗 埀 誰 出 膵 翠 炊 帥 粋 睡 錐 錘 推 酔 衰 垂 遂 吹 水"
"すいあつ 水圧"
"すいい 水位 推移"
"すいいき 水域"
"すいいりつ 推移律"
"すいう 水宇"
"すいうん 衰運"
"すいえい 水泳"
"すいえん 垂涎 膵炎"
"すいおん 水温"
"すいおんけい 水温計"
"すいか 水火 水瓜 垂下 西瓜 誰何"
"すいかん 酔漢 水管"
"すいがい 水害"
"すいがら 吸殻 吸いがら"
"すいがん 水眼 酔眼"
"すいきゅう 水球"
"すいきょ 推挙"
"すいきょう 酔狂"
"すいぎゅう 水牛"
"すいぎょうざ 水餃子"
"すいぎょく 翠玉"
"すいぎん 水銀"
"すいぎんちゅう 水銀柱"
"すいぎんとう 水銀灯"
"すいくち 吸い口"
"すいくん 垂訓"
"すいぐん 水軍"
"すいぐんせん 水郡線"
"すいけい 推計 水系"
"すいけん 酔拳 水圏 推件"
"すいげい 酔鯨"
"すいげつ 水月"
"すいげん 水源"
"すいげんちたい 水原地帯"
"すいこ 水滸 推古"
"すいこう 垂鉤 推考 推敲 遂行"
"すいこうしゃ 水光社"
"すいこでん 水滸伝"
"すいこみ 吸い込み"
"すいごう 水濠"
"すいごうちたい 水郷地帯"
"すいさい 水彩"
"すいさつ 推察"
"すいさん 炊爨 水酸 推算 水産"
"すいさんちょう 水産庁"
"すいし 水死"
"すいしつ 水質"
"すいしゃ 水車"
"すいしょう 水漿 推賞 水晶 推奨"
"すいしょうあん 推奨案"
"すいしょうたい 水晶体"
"すいしょうだま 水晶玉"
"すいしょうどう 水晶堂"
"すいしょうふく 推奨服"
"すいしん 水深 推進"
"すいしんやくけんきゅうしつ 推進薬研究室"
"すいじ 炊事"
"すいじば 炊事場"
"すいじゃく 垂迹 衰弱"
"すいじゅん 水準"
"すいじゅんかん 水循環"
"すいじょう 穂状 水上"
"すいじょうき 水蒸気"
"すいじょうは 水上葉"
"すいじん 粋人"
"すいす 瑞西"
"すいず 水津"
"すいせい 水生 水棲 水勢 彗星 水性 水星"
"すいせいがん 水成岩"
"すいせいこうきょうがく 翠星交響楽"
"すいせいぞう 彗星像"
"すいせいむし 酔生夢死"
"すいせん 水仙 水洗 垂線 推薦"
"すいせんじゅか スイセンジュ科"
"すいせんば 推薦馬"
"すいせんわく 推薦枠"
"すいぜん 垂涎"
"すいぜんじ 水前寺"
"すいそ 水素"
"すいそう 水そう 垂層 水層 水葬 水漕 吹奏 水槽"
"すいそうがく 吹奏楽"
"すいそうがくばたけ 吹奏楽畑"
"すいそく 推測"
"すいぞう 酔象 膵臓"
"すいぞくえん 水族園"
"すいぞくかん 水族館"
"すいた 吹田"
"すいたい 錘体 錐体 衰退"
"すいたいろ 錐体路"
"すいたしんごうじょ 吹田信号所"
"すいだし 吸出し"
"すいちゅう 水中"
"すいちゅうは 水中葉"
"すいちゅうよくせん 水中翼船"
"すいちょう 水鳥"
"すいちょく 垂直"
"すいっち スイッチ"
"すいっちんぐ スイッチング"
"すいづ 水津"
"すいてい 水底 推定"
"すいてき 水滴"
"すいてん 水天"
"すいてんぐう 水天宮"
"すいでん 水田"
"すいとう 水痘 水稲 出納 水筒"
"すいとうちょう 出納帳"
"すいとうぼ 出納簿"
"すいとん 水団"
"すいどう 隧道 水道"
"すいどうかん 水道管"
"すいどうぐち 水道口"
"すいどうすい 水道水"
"すいなん 水難"
"すいはん 垂範 炊飯"
"すいばく 水爆"
"すいばら 水原"
"すいばん 水盤"
"すいび 衰微"
"すいふ 水府 水夫 炊フ"
"すいふよう 酔芙蓉"
"すいぶん 水分"
"すいへい 水兵 水平"
"すいへいどう 水平動"
"すいへいばん 水平板"
"すいへん 水辺"
"すいほ 酔歩"
"すいほう 水胞 水疱 水泡"
"すいぼう 水防 衰亡"
"すいぼくが 水墨画"
"すいぼつ 水没"
"すいま 睡魔"
"すいみつ 水蜜 水密"
"すいみつとう 水蜜桃"
"すいみつひ 水密扉"
"すいみゃく 水脈"
"すいみん 睡眠"
"すいみんぼうすいは 睡眠紡錘波"
"すいみんやく 睡眠薬"
"すいめつ 衰滅"
"すいめん 水面"
"すいめんは 水面波"
"すいもく 水木"
"すいもの 吸物"
"すいもん 水門"
"すいよう 水溶 水曜"
"すいようえき 水溶液"
"すいよく 水浴"
"すいらい 水雷"
"すいらいせん 水雷戦"
"すいらいてい 水雷艇"
"すいらん 翠嵐"
"すいり 水利 推理"
"すいりく 水陸"
"すいりゅう 水竜 水流"
"すいりゅうし 水龍士"
"すいりょう 推量 水量"
"すいりょく 推力 水力"
"すいれい 水冷"
"すいれん 睡蓮"
"すいれんあか スイレン亜科"
"すいれんか スイレン科"
"すいろ 水路"
"すいろん 推論"
"すいんぐ スイング"
"すう 四 陬 鄒 菘 芻 樞 數 崇 嵩 枢 雛 趨 数"
"すうあんこ 四暗刻"
"すうあんこう 四暗刻"
"すうい 趨異"
"すうぇーでん 瑞典"
"すうえき 数駅"
"すうおく 数億"
"すうおん 数音"
"すうかい 数回"
"すうかいけん 数理解析研究所 数解研"
"すうかげつ 数か月"
"すうかん 数巻"
"すうがく 数学"
"すうがくきごう ∝ ¬ ∨ ∧ ∩ ∪ ⊃ ⊂ ⊇ ⊆ ∋ ≧ ≠ ± ∫ √ ∂ ∃ ∀ ⇔ ⇒ ∈ ∴ ∞ ≦ ÷"
"すうがくし 数学史"
"すうがくばたけ 数学畑"
"すうき 数機 数奇 数基 数期"
"すうききょう 枢機卿"
"すうきょうきょう 数教協"
"すうきょく 数局 数曲"
"すうぎょう 数行"
"すうけい 崇敬"
"すうけた 数桁"
"すうけん 数軒 数理解析研究所 数研 数件"
"すうげき 数撃"
"すうこ 数個"
"すうこう 崇高 数校 数項"
"すうこく 数刻"
"すうご 数語"
"すうごう 数号"
"すうさく 数作"
"すうさつ 数冊"
"すうし 数詞"
"すうしいほう 四喜和"
"すうしき 数式"
"すうしきもうど 数式モード"
"すうしゃ 数社"
"すうしゅ 数種"
"すうしゅう 数週 数周"
"すうしゅん 数瞬"
"すうじ 数次 数字"
"すうじく 樞軸 枢軸"
"すうじっかい 数十回"
"すうじっこ 数十個"
"すうじっぽん 数十本"
"すうじつ 数日"
"すうじゅう 数十"
"すうじゅうび 数十尾"
"すうじゅかっしょ 数十箇所"
"すうじゅっかい 数十回"
"すうじゅっき 数十機"
"すうじゅっさつ 数十冊"
"すうじゅっしゅるい 数十種類"
"すうじゅっぽん 数十本"
"すうじょう 数条"
"すうせい 趨勢"
"すうせみ 数セミ"
"すうせん 数戦 数千"
"すうだい 数台"
"すうだいまえ 数代前"
"すうだん 数段"
"すうだんうえ 数段上"
"すうち 数値"
"すうちかい 数値解"
"すうちきしょう 数値記象"
"すうつう 数通"
"すうて 数手"
"すうてき 数的 数滴"
"すうてん 数店 数点"
"すうとう 数頭"
"すうど 数度"
"すうにち 数日"
"すうにん 数人"
"すうねん 数年"
"すうねんほどまえ 数年程前"
"すうはい 崇拝"
"すうはつ 数発"
"すうば 数馬"
"すうばい 数倍"
"すうぱい 数牌"
"すうひき 数匹"
"すうひゃく 数百"
"すうひゃくぺーじ 数百頁"
"すうひゃっかい 数百階"
"すうひゃっき 数百機"
"すうひゅく 数百"
"すうひょう 数票 数表"
"すうびょう 数秒"
"すうふん 数分"
"すうぶつ 数物"
"すうぺいじ 数ページ"
"すうほん 数本"
"すうまい 数枚"
"すうまん 数万"
"すうみつ 枢密"
"すうめい 数名"
"すうもん 数問"
"すうり 数理情報科学 数理"
"すうりけん 数理解析研究所"
"すうりょう 数量"
"すうれい 数例"
"すうれつ 数列"
"すうろん 数論"
"すうわ 数話"
"すうわり 数割"
"すえ 須恵 裔 甄 陶 据 末"
"すえあし 末足"
"すえいし 末石"
"すえお 末男"
"すえおか 末岡"
"すえおきがた 据置形 据置型"
"すえき 末木"
"すえきち 末吉"
"すえごろ 末頃"
"すえざき 末崎"
"すえじ 末治"
"すえじま 末島"
"すえっこ 末っ子"
"すえつぐ 末次"
"すえつけ 据付"
"すえなが 末永"
"すえひろ 末広"
"すえまさ 末政"
"すえまつ 末松"
"すえみつ 末光"
"すえやす 末安"
"すえよし 末吉 末善"
"すおう 周防"
"すかーと スカート"
"すかーれっと スカーレット"
"すかいほーる スカイホール"
"すかうと スカウト"
"すかがわ 須賀川"
"すかさず 透かさず"
"すかゆ 酸ヶ湯 酢ケ湯"
"すから スカラ"
"すかんぴん 素寒貧"
"すが 須ヶ 管 須賀 菅"
"すがい 須貝 菅井"
"すがお 菅尾 素顔"
"すがさわ 菅澤"
"すがすが 清々"
"すがすがしさ 清々しさ"
"すがた 菅田 姿"
"すがたかたち 姿形"
"すがたみ 姿見"
"すがだいら 菅平"
"すがぬま 菅沼"
"すがの 菅野"
"すがはら 菅原"
"すがむら 管村"
"すがも 巣鴨"
"すがもと 菅本"
"すがや 菅谷"
"すがわ 須川"
"すがわら 管原 菅原"
"すき 数寄 犂 須木 漉 耒 鋤 鍬 好き 隙"
"すきー スキー"
"すきーやー スキーヤー"
"すきぎ 透木"
"すきぐし 篦"
"すきずき 好きずき"
"すきっぷ スキップ"
"すきま 透き間 すき間 隙間"
"すきまかぜ 隙間風"
"すきみ 透見"
"すきもの 好き者"
"すきゃん スキャン"
"すきゃんだる スキャンダル"
"すきや 数奇屋"
"すきやばし 数寄屋橋"
"すきる スキル"
"すぎ 過ぎ 杉 椙"
"すぎうち 杉内"
"すぎうら 杉浦"
"すぎえ 杉江"
"すぎおか 杉岡"
"すぎかふん 杉花粉"
"すぎがき 杉垣"
"すぎき 杉木"
"すぎさき 杉崎"
"すぎさわ 杉沢"
"すぎざい 杉材"
"すぎざき 杉崎"
"すぎした 杉下"
"すぎた 杉田"
"すぎたこ 杉タコ"
"すぎたに 杉谷"
"すぎつま 杉妻"
"すぎと 杉戸"
"すぎとう 杉藤"
"すぎなみ 杉並"
"すぎぬま 杉沼"
"すぎの 杉野"
"すぎのした 杉之下"
"すぎのはら 杉ノ原"
"すぎはら 杉原"
"すぎばやし 杉林"
"すぎまち 杉町"
"すぎむら 杉村"
"すぎもと 杉本"
"すぎやま 椙山 杉山"
"すぎりょうたろう 杉良太郎"
"すくーぷ スクープ"
"すくーる スクール"
"すくいなげ 掬い投げ"
"すくなくとも 少なくとも"
"すくなめ 少な目"
"すくも 糘 粭 宿毛"
"すくりーん スクリーン"
"すくろーる スクロール"
"すぐ 直"
"すぐさま 直ぐ樣"
"すぐる 英 俊 勝 卓"
"すけ 丞 亮 佑 甫 資 祐 輔 助 介"
"すけーと スケート"
"すけーる スケール"
"すけかつ 資勝"
"すけがわ 助川"
"すけさこ 助迫"
"すけじゅーる スケジュール"
"すけっち スケッチ"
"すけっと 助人 助っ人"
"すけのぶ 助信"
"すけべ スケベ"
"すけよし 祐好"
"すけろく 助六"
"すげ 菅"
"すげかわ 菅河"
"すげない 素気ない"
"すげぬま 菅沼"
"すこーぷ スコープ"
"すこあ スコア"
"すこし 少し"
"すこしも 少しも"
"すこっとらんど 蘇格蘭"
"すこぶる 頗る 頗"
"すこやか 健やか"
"すこら スコラ"
"すご 凄"
"すごい 凄い"
"すごう 菅生"
"すごうせん 菅生戦"
"すごうで 凄腕"
"すごさ 凄さ"
"すごしかた 過ごし方"
"すごみ 凄味"
"すごろく 双六"
"すさ 須佐"
"すさか 須坂"
"すさき 須崎"
"すさのおのみこと 須佐之男命"
"すさまじさ 凄まじさ"
"すさみ 須佐美"
"すざか 須坂"
"すざき 洲崎 寿崎"
"すざく 朱雀"
"すざわ 須沢"
"すし 鮓 鮨 寿司"
"すしめし 鮨飯"
"すしょうきゅう 水晶宮"
"すじ 筋"
"すじあい 筋合"
"すじかい 筋交い"
"すじがき 筋書 筋書き"
"すじがね 筋金"
"すじがねいり 筋金入り"
"すじこ 筋子"
"すじちがい 筋違い"
"すじみち 筋道"
"すじめ 筋目"
"すじゃく 朱雀"
"すじや 筋屋"
"すじゅうびょう 数十秒"
"すじょう 素場 巣状 素姓 素性"
"すじょうゆ 酢醤油"
"すす 煤"
"すすき 芒 薄"
"すすきた 薄田"
"すすきの 薄野"
"すすみかた 進み方"
"すすむ 奨 晉 進 晋"
"すすめかた 進め方"
"すすりなき 啜り泣き"
"すず 鑾 スズ 珠洲 錫 鈴"
"すずおき 鈴置"
"すずか 鈴香 鈴鹿"
"すずかぜ 涼風"
"すずき 鱸 鈴木"
"すずし 生絹"
"すずしま 鈴嶋"
"すずたに 鈴谷"
"すずたん 鈴丹"
"すずなり 鈴生り"
"すずのすけ 鈴之助"
"すずむし 鈴虫"
"すずむら 鈴村"
"すずめ 雀"
"すずめがおか 雀ヶ丘"
"すずや 鈴谷"
"すずやま 鈴山"
"すずよ 鈴世"
"すずらん 鈴蘭"
"すずり 碩 硯"
"すそ 裾"
"すそとり 裾取り"
"すその 裾野"
"すそはらい 裾払い"
"すそわけ 裾分け"
"すたー スター"
"すたーと スタート"
"すたーりん スターリン"
"すたいる スタイル"
"すたじお スタジオ"
"すたっふ スタッフ"
"すたでぃ スタディ"
"すたみな スタミナ"
"すたんだーど スタンダード"
"すたんど スタンド"
"すたんぷ スタンプ"
"すたんれーでんき スタンレー電気"
"すだ 須田"
"すだち 巣立ち"
"すだま 須玉"
"すだれ 簾"
"すちーる スチール"
"すちろーる スチロール"
"すっとんきょう 素頓狂"
"すっぱ 透波 素破"
"すてーしょん ステーション"
"すてーじ ステージ"
"すていし 捨て石"
"すてき 素的 素敵"
"すてご 捨て子"
"すてっかー ステッカー"
"すてっぷ ステップ"
"すてね 捨て値"
"すてはい 捨て牌"
"すてば 捨て場"
"すてぱい 捨牌"
"すてみ 捨て身"
"すてやく 捨役"
"すてれお ステレオ"
"すてんれす ステンレス"
"すで 已 素手 既"
"すでに 已に 既に"
"すと スト"
"すとーりー ストーリー"
"すとあ ストア"
"すとあー ストアー"
"すとう 周東 須藤"
"すとっきんぐ ストッキング"
"すとっく ストック"
"すとっぷ ストップ"
"すとらいき ストライキ"
"すとりーと ストリート"
"すとれす ストレス"
"すとろーく ストローク"
"すとろべりー ストロベリー"
"すどう 須藤"
"すどうふ 酢豆腐"
"すどおし 素通し"
"すどおり 素通り"
"すな 沙 砂"
"すなあらし 砂嵐"
"すなお 素直"
"すなおとこ 砂男"
"すなかけばばあ 砂掛婆"
"すなかわ 砂川"
"すなが 須永"
"すながわ 砂川"
"すなぎも 砂肝"
"すなくら 砂倉"
"すなけし 砂ケシ"
"すなけむり 砂煙"
"すなこ 砂子"
"すなじ 砂地"
"すなだ 砂田"
"すなち 砂地"
"すなっく スナック"
"すなっぷ スナップ"
"すなづるあか スナヅル亜科"
"すなどけい 砂時計"
"すなぬき 砂抜き"
"すなはち 即ち 則ち"
"すなはま 砂浜"
"すなはら 砂原"
"すなば 砂場"
"すなぶろ 砂風呂"
"すなぼこり 砂埃"
"すなみ 巣南 角南"
"すなむし 砂蟲"
"すなめり 砂滑 鯆"
"すなわち 曽ち 曾ち 則ち 即ち"
"すね 臑 脛"
"すねかじり 臑かじり"
"すねげ すね毛"
"すのこ 簀の子"
"すのはら 須野原 春原"
"すのまた 墨俣"
"すのもの 酢の物"
"すはだ 素肌"
"すはら 栖原 寿原"
"すばこ 巣箱"
"すばやさ 素早さ"
"すばらしい 素晴しい"
"すばる 昴"
"すぱーく スパーク"
"すぱい スパイ"
"すぱげってぃ スパゲッティ"
"すぱん スパン"
"すぴーか スピーカ"
"すぴーち スピーチ"
"すぴーど スピード"
"すぴん スピン"
"すべ 術"
"すべからく 須らく 須く"
"すべて 凡て 總 総て 総 全て"
"すべり 辷"
"すぺーす スペース"
"すぺあ スペア"
"すぺいん 西班牙 スペイン"
"すぺくとる スペクトル"
"すぺしゃりすと スペシャリスト"
"すぺりんぐ スペリング"
"すぺる スペル"
"すぽーつ スポーツ"
"すぽっと スポット"
"すぽんさ スポンサ"
"すぽんさー スポンサー"
"すま 須磨"
"すまーと スマート"
"すまい 住い 住居 営 住まい"
"すまた 寸又"
"すまたきょう 寸又峡"
"すみ 陬 濟 澂 須美 寿 炭 住 須見 角 澄 純 墨 隅 済"
"すみえ 澄江 墨絵 寿美江 スミ恵 純恵"
"すみお 純雄 澄夫 澄雄"
"すみか 住み処 棲み家 鈴美香 住処 住化 住み家 住みか"
"すみかわ 澄川"
"すみきん 住金"
"すみぎん 住銀"
"すみこ 純子 寿美子 澄子"
"すみごこち 住み心地"
"すみさわ 隅沢"
"すみしょう 住商"
"すみずみ 隅々"
"すみそ 酢味噌"
"すみぞめ 墨染"
"すみた 角田 住田"
"すみだ 住田 隅田 墨田"
"すみっこ 隅っこ"
"すみでん 住電"
"すみと 澄人"
"すみとも 住友"
"すみの 墨野 角野"
"すみのえ 住江 住之江"
"すみのどう 住道"
"すみひら 住平"
"すみび 炭火"
"すみびやき 炭火焼"
"すみません 済みません"
"すみもと 住本 住元"
"すみや 墨屋 住谷 隅谷"
"すみやか 速やか 澄みやか"
"すみやき 炭焼"
"すみよう 住用"
"すみよし 澄義 住吉"
"すみれ 菫"
"すみれもく スミレ目"
"すむ 住む"
"すめらぎ 天皇 皇"
"すもう 相撲"
"すもうけん 相撲券"
"すもうとり 相撲とり 相撲取"
"すもっぐ スモッグ"
"すもと 栖本 須本 洲本"
"すもも 李"
"すもん 守門"
"すやき 素焼"
"すやま 隅山 須山"
"すら ／"
"すらいす スライス"
"すらいど スライド"
"すり 掏摸 摺 刷"
"すりあがり 刷り上がり"
"すりえ 擂り餌"
"すりきず 擦り傷"
"すりこぎ 摺子木 擂粉木 擂り粉木"
"すりっと スリット"
"すりっとこう スリット光"
"すりっとぞう スリット像"
"すりっぷ スリップ"
"すりつぶ すり潰"
"すりばち 摺鉢 擂り鉢 擂鉢 すり鉢"
"すりみ 摺身"
"すりもの 刷り物"
"すりる スリル"
"する 駿"
"するーぷっと スループット"
"するが 駿河"
"するがだいした 駿河台下"
"するがわん 駿河湾"
"するどさ 鋭さ"
"するめ 鯣"
"するめいか するめイカ"
"すれすれ 摩々 擦々"
"すろーがん スローガン"
"すろうにん 素浪人"
"すろっとる スロットル"
"すわ 須羽 諏訪"
"すわこ 諏訪湖"
"すわみなみ 諏訪南"
"すん 寸"
"すんか 寸暇"
"すんけい 寸勁"
"すんげき 寸劇"
"すんげん 寸言"
"すんごう 寸毫"
"すんし 寸志"
"すんしゅう 駿州"
"すんじ 寸時"
"すんぜん 寸前"
"すんぜんしゃくま 寸善尺魔"
"すんだい 駿台"
"すんだん 寸断"
"すんてつ 寸鉄"
"すんで 既"
"すんとう 駿東"
"すんどめ 寸止め"
"すんひょう 寸評"
"すんぴょう 寸評"
"すんぶん 寸分"
"すんぷじょう 駿府城"
"すんぽう 寸法"
"すんわ 寸話"
"ず 豆 讐 讎 廚 圖 鶴 寿 厨 逗 津 頭 図"
"ずーむ ズーム"
"ずあん 図案"
"ずい 髓 隧 隨 蕋 蘂 膸 隋 惴 蕊 随 瑞 髄"
"ずいい 随意"
"ずいいすじ 随意筋"
"ずいいち 随一"
"ずいいん 随員"
"ずいうん 瑞雲 瑞運"
"ずいえん 隋圜"
"ずいかく 瑞鶴"
"ずいこう 随行"
"ずいしょ 隨處 随所"
"ずいしょう 瑞祥"
"ずいじ 随時"
"ずいじょう 髄状分裂組織"
"ずいじょうぶんれつそしき 髄状分裂組織"
"ずいせんじ 瑞泉寺"
"ずいそう 随想"
"ずいだい 隋代"
"ずいちょう 瑞兆"
"ずいどう 隧道"
"ずいはん 随伴"
"ずいひつ 隨筆 随筆"
"ずいひつか 随筆家"
"ずいぶん 隨分 随分"
"ずいぶんむかし 随分昔"
"ずいぶんれつそしき 髄分裂組織"
"ずいほうでん 瑞鳳殿"
"ずいまく 髄膜"
"ずいまくえん 髄膜炎"
"ずいむし 螟虫"
"ずうたい 図体"
"ずか 図化"
"ずかい 図解"
"ずかん 図鑑"
"ずが 図画"
"ずがい 頭蓋 頭骸"
"ずがいこつ 頭骸骨 頭蓋骨"
"ずがく 図学"
"ずがら 図柄"
"ずきん 頭巾"
"ずけ 附 付"
"ずけい ◆ 図形"
"ずけん 図研"
"ずこう 図功 図工"
"ずさくせい 図作成"
"ずさん 杜撰"
"ずし 鮨 寿司 逗子 図示"
"ずしき 図式"
"ずしこつぼこう 逗子小坪港"
"ずしょうりゃく 図省略"
"ずしょのかみ 図書頭"
"ずじ 図示"
"ずじょう 頭上 図上"
"ずせつ 図説"
"ずぞうがく 図像学"
"ずちゅう 図中"
"ずっきーに ズッキーニ"
"ずつう 頭痛"
"ずつき 頭突き"
"ずてき 図的"
"ずどり 図取り"
"ずのう 頭脳"
"ずはん 図版"
"ずばん 図番 図版"
"ずひょう 図表"
"ずふ 図譜"
"ずぶねり 頭捻り"
"ずほう 図法"
"ずぼし 図星"
"ずぼん ズボン"
"ずみ 済み 濟 桷 済"
"ずめ 詰"
"ずめん 図面"
"ずめんちょう 図面帳"
"ずり 刷"
"ずりょう 受領"
"ずる ズル"
"ずろく 図録"
"ずんどう 寸胴"
"せ 衰 脊 畆 丗 施 勢 畝 世 瀬 背"
"せーたー セーター"
"せーぬ 折奴 塞納"
"せーふ セーフ"
"せーぶ セーブ"
"せーる セール"
"せーるす セールス"
"せい 婿 瀞 鉦 錆 犀 歳 甥 井 韲 齏 靜 躋 齎 蜻 菁 萋 臍 腥 聲 筬 穽 睛 淒 晟 旌 擠 撕 掣 惺 悽 嘶 丗 所為 貰 情 鯖 齊 凄 征 栖 省 靖 晴 棲 逝 誓 政 斉 醒 盛 整 誠 請 牲 清 聖 静 勢 青 制 西 声 星 姓 成 精 世 製 正 生 性"
"せいあい 性愛"
"せいあく 性悪"
"せいあくせつ 性悪説"
"せいあつ 静圧 制圧"
"せいあん 西安 成案"
"せいい 凄異 征夷 誠意"
"せいいき 西域 聖域 整域 声域"
"せいいく 生育 成育"
"せいいち 誠市 誠一 精一 清一 正一 聖一"
"せいいちろう 誠一郎 精一郎 清一郎 晴一郎"
"せいいっぱい 精いっぱい 精一杯"
"せいいん 成因 正員 成員"
"せいう 晴雨"
"せいうち 海象"
"せいうん 盛運 星雲 青雲"
"せいうんまる 青雲丸"
"せいえい 精鋭 清栄"
"せいえき 精液"
"せいえつ 凄咽 誠悦"
"せいえん 正円 製塩 声援 西遠"
"せいえんぎょう 製塩業"
"せいおう 西欧"
"せいおうりゅう 西欧流"
"せいおん 整音 静穏 生温 清音"
"せいか 清華 惺窩 生化 聖歌 精化 正貨 正佳 成香 青果 製菓 聖火 盛夏 生花 生家 正課 正価 精華 西夏 成果"
"せいかい 青海 精解 制海 政界 盛会 正解"
"せいかいおうざ 世界王座"
"せいかぎょう 製菓業"
"せいかく 正格 製革 精確 性格 正確"
"せいかくづけ 性格付"
"せいかけん 製科研"
"せいかさんぎょう 西華産業"
"せいかじゅう 静荷重"
"せいかたいよう 聖歌隊用"
"せいかたんでん 臍下丹田"
"せいかつ 生活"
"せいかつかん 生活環"
"せいかつく 生活苦"
"せいかつひ 生活費"
"せいかつほごひ 生活保護費"
"せいかてん 成果展"
"せいかなし 成果無"
"せいかん 精管 精悍 製罐 製缶 生還 静観 青函"
"せいかんたい 性感帯"
"せいかんぶっしつ 星間物質"
"せいかんぶんし 星間分子"
"せいかんろん 征韓論"
"せいが 精華"
"せいがく 声楽 声学"
"せいがくいん 聖学院"
"せいがくてき 静学的"
"せいがん 青眼 正眼 西岸 請願"
"せいがんしゃ 晴眼者"
"せいがんのかまえ 青眼の構え"
"せいき 成樹 制機 西紀 製機 精器 誠紀 星紀 聖記 性器 精機 精気 生起 生気 世紀 正規"
"せいきぐん 正規軍"
"せいきけい 正規形"
"せいきし 聖騎士"
"せいきじゅん 正規順"
"せいきち 清吉"
"せいきまつ 世紀末 聖飢魔II"
"せいきゅう 性急 請求"
"せいきゅうがく 請求額"
"せいきゅうりょく 制球力"
"せいきょ 盛挙 逝去"
"せいきょう 生活協同組合 盛況 生協"
"せいきょうか 精強化"
"せいきょうぶんり 政教分離"
"せいきょく 政局"
"せいきょくかい 制極界"
"せいきん 精勤"
"せいぎ 性戯 声義 生技 正義"
"せいぎかん 正義漢"
"せいぎしん 正義心"
"せいぎゃく 正逆"
"せいぎょ 制禦 成魚 制御"
"せいぎょう 生業 正業 盛業 成業"
"せいぎょく 青玉"
"せいぎょしゃ 制御車"
"せいぎょじかん 制限時間"
"せいぎょぼう 制御棒"
"せいく 成句"
"せいくう 制空"
"せいくらべ 背比べ"
"せいけ 清家"
"せいけい 西経 成型 星系 成蹊 生計 政経 成形 整形"
"せいけつ 清潔"
"せいけん 精検 生検 正拳 聖剣 政見 生研 政権"
"せいけんだつしゅ 政権奪取"
"せいけんづき 正拳突き"
"せいけんとう 政権党"
"せいげん 正弦 制限"
"せいげんけい 制限形"
"せいげんは 正弦波"
"せいげんわく 制限枠"
"せいこ 聖子"
"せいこう 悽惶 生工 性向 正孔 精鋼 精工 精巧 性交 製鋼 成功"
"せいこううどく 晴耕雨読"
"せいこうさく 成功作"
"せいこうとうてい 西高東低"
"せいこうほう 正攻法"
"せいこうり 成功裡 成功裏"
"せいこく 正鵠"
"せいこつ 整骨"
"せいこん 聖痕 精根 精魂 成婚"
"せいご 正吾 清悟 成語 生後 正誤 清吾"
"せいごう 正剛 正合 整合"
"せいさ 精査 性差"
"せいさい 精彩 生彩 精細 正妻 制裁"
"せいさいぼう 精細胞"
"せいさく 清作 制作 政策 製作"
"せいさくき 制作記"
"せいさくじゅん 製作順"
"せいさくじょ 製作所"
"せいさくそうしき 制作総指揮"
"せいさくひ 制作費 製作費"
"せいさつよだつ 生殺与奪"
"せいさん 悽惨 製産 聖餐 正餐 青酸 成算 凄惨 清算 精算 生産"
"せいさんがく 精算額"
"せいさんきん 生産菌"
"せいさんぐち 清算口"
"せいさんしゃ 生産車"
"せいさんじょ 清算所 精算所"
"せいさんじれんど 生産時練度"
"せいさんだか 生産高"
"せいさんひ 生産費"
"せいさんふどまり 生産歩留り"
"せいざ 正座 星座"
"せいざい 製剤 製材"
"せいざえもん 清左衛門"
"せいざぶろう 征三郎 清三郎"
"せいし 誓詞 誓紙 誠史 西施 製糸 姓氏 製紙 清史 生死 正史 制止 静止 精子 正視"
"せいしかい 静止解"
"せいしき 整式 制式 正式"
"せいしつ 正室 声質 性質"
"せいしゃ 精射 生者"
"せいしゅ 清酒"
"せいしゅう 青州"
"せいしゅく 静肅 静淑 整粛 静粛"
"せいしゅん 静瞬 青春"
"せいしょ 整書 聖書 正書 成書 清書"
"せいしょう 精漿 西湘 政商 斉唱 清勝 清祥"
"せいしょうなごん 清少納言"
"せいしょうねん 青少年"
"せいしょく 生食 聖職 生殖"
"せいしょくし 生殖枝"
"せいしょくしゅーと 生殖シュート"
"せいしょくせん 生殖腺"
"せいしょしゃくぎ 聖書釈義"
"せいしろう 誠志郎"
"せいしん 星辰 誠信 西進 清新 制振 清心 誠心 聖心 精神"
"せいしんい 精神医"
"せいしんかい 精神科医"
"せいしんかん 正心館"
"せいしんかんおうぶっしつ 精神感応物質"
"せいしんし 精神史"
"せいしんしゃ 青心社"
"せいしんてきしょうがい 精神的損害"
"せいしんてん 精神的"
"せいしんびょう 精神病"
"せいしんぶんせきい 精神分析医"
"せいしんぶんせきか 精神分析家"
"せいしんやく 精神薬"
"せいじ 青児 聖二 征治 製磁 聖次 星史 整司 成二 征司 精二 青磁 誠司 斉次 聖司 誠二 誠治 清二 清治 清次 清司 征爾 斎次 征二 静二 正字 正時 征士 政治"
"せいじか 政治家"
"せいじし 政治史"
"せいじしゅう 政治囚"
"せいじだい 生時代"
"せいじつ 凄日 誠実"
"せいじてきじっせき 政治的業績"
"せいじは 静磁波"
"せいじはん 政治犯"
"せいじば 静磁場"
"せいじひょう 政治評"
"せいじゃ 正邪 聖者"
"せいじゃく 静寂"
"せいじゃくしゃこ 正雀車庫"
"せいじゅ 誠樹"
"せいじゅう 西戎 聖獣"
"せいじゅく 成熟"
"せいじゅくらん 成熟卵"
"せいじゅん 正準 正順 清純"
"せいじゅんけい 正準形"
"せいじょ 聖女 成女"
"せいじょう 星状 性状 星条 政情 清浄 成城 正常"
"せいじょうき 星条旗"
"せいじょうたい 星状体 正常体"
"せいじょうもう 星状毛"
"せいじろう 征二郎 清次郎"
"せいじん 星人 聖人 成人"
"せいじんだんしむけ 成人男子向け"
"せいじんびょう 成人病"
"せいすい 静水 聖水 盛衰"
"せいすいき 製水器 清水器 整水器"
"せいすいせき 青水石"
"せいすう 正数 整数"
"せいすうかい 整数解"
"せいすけ 誠亮 清助"
"せいず 製図 星図"
"せいずい 精髄"
"せいずこう 製図工"
"せいずばん 製図板"
"せいせい 悽悽 凄凄 正声 生々 精製 清々 正々 生成"
"せいせいえん 精製塩"
"せいせいげん 生成元"
"せいせいこうこう 悽悽惶惶"
"せいせいさんさん 凄凄惨惨"
"せいせいせつせつ 凄凄切切"
"せいせいりょうりょう 凄凄涼涼"
"せいせいるてん 生生流転"
"せいせき 聖石 成績"
"せいせきじゅん 成績順"
"せいせつ 正節"
"せいせん 性腺 井泉 聖戰 精線 聖戦 精選 生鮮 清泉"
"せいぜつ 凄絶 悽絶"
"せいぜつさ 凄絶さ"
"せいぜん 悽然 凄然 性善 正善 生前 整然"
"せいぜんせつ 性善説"
"せいそ 精粗 凄楚 清楚 整礎"
"せいそう 精巣 悽愴 凄愴 星霜 盛装 政争 成層 正装 清掃"
"せいそうしゃ 清掃車"
"せいそうねん 青荘年"
"せいそうひ 清掃費"
"せいそく 悽惻 栖息 正則 生息 棲息"
"せいそくげん 正則元"
"せいぞう 誓三 清蔵 清三 製造"
"せいぞうぎょう 製造業"
"せいぞうじゅん 製造順"
"せいぞうじょ 製造所"
"せいぞうぬし 製造主"
"せいぞく 聖俗"
"せいぞろい 勢揃い 勢ぞろい"
"せいぞん 生存"
"せいた 清田 清太"
"せいたい 成体 整体 静態 政体 正対 声帯 生体 生態"
"せいたいは 声帯波"
"せいたいまく 生体膜"
"せいたぼうたい 正多胞体"
"せいたろう 清太郎"
"せいたん 西端 生誕"
"せいだい 正大 盛大"
"せいだく 清濁"
"せいだん 清談 星団 政談"
"せいち 正置 静置 精緻 生地 正値 整地 聖地"
"せいちゃ 製茶"
"せいちゅう 精虫 掣肘 成虫 正中"
"せいちょう 成鳥 声調 清張 清帳 生長 正調 静聴 整調 成長"
"せいちょうかぶ 成長株"
"せいちょうせき 成長石"
"せいつう 精通"
"せいてい 制定"
"せいていし 斉停止"
"せいていすう 整定数"
"せいてき 政敵 性的 静的"
"せいてつ 製鐵 製鉄"
"せいてつぎょう 製鉄業"
"せいてつじょ 製鉄所"
"せいてん 征典 青天 聖典 性典 盛典 晴天"
"せいてんたいせい 斉天大聖"
"せいてんのへきれき 青天の霹靂"
"せいでん 星電 正殿 静電"
"せいでんき 静電気"
"せいと 成都 生徒"
"せいとう 精糖 製糖 正統 正答 政党 正当"
"せいとうぎょう 製糖業"
"せいとうほうしゃせん 制"
"せいとく 政徳 聖徳 成徳 生得"
"せいとくせつ 生得説"
"せいとん 整頓"
"せいど 制度 精度"
"せいどう 青銅 聖堂 正堂 制動 声道 正道"
"せいどうとう 制動灯"
"せいどうにゅう 制導入"
"せいどく 西独 精読"
"せいどしゃ 青土社"
"せいどみにこ 聖ドミニコ"
"せいなん 西南 勢南"
"せいなんせい 西南西"
"せいにく 精肉"
"せいねん 成年 生年 青年"
"せいの 清野"
"せいのう 西濃 性能"
"せいのすけ 誠之助"
"せいは 制覇 征覇"
"せいはい 成敗 聖杯"
"せいはく 製箔 精白 精薄"
"せいはちめんたい 正八面体"
"せいはつ 整髪"
"せいはん 整版 正反 製版"
"せいばい 成敗"
"せいばつ 征伐"
"せいばん 製番"
"せいぱん 製パン"
"せいひ 西彼 性比 西肥 成否 正否"
"せいひこ 聖彦"
"せいひつ 静謐"
"せいひょう 製氷"
"せいひょうい 生標委"
"せいひょうこ 製氷庫"
"せいひょうざら 製氷皿"
"せいひん 清貧 製品"
"せいひんごと 製品毎"
"せいひんふどまり 製品歩留り"
"せいび 星美 整備"
"せいびきろくぼ 整備記録簿"
"せいびこう 整備工"
"せいびし 整備士"
"せいびじょうまえ 整備場前"
"せいびづくえ 整備机"
"せいびどうしゅっぱん 成美堂出版"
"せいびひ 整備費"
"せいびへい 整備兵"
"せいびょう 性病"
"せいふ 正負 政府"
"せいふあん 政府案"
"せいふう 西風 清風"
"せいふかんこうちょう 政府観光庁"
"せいふく 正副 征服 制服"
"せいふくすがた 制服姿"
"せいふぐん 政府軍"
"せいふさき 請負先"
"せいふすじ 政府筋"
"せいふまい 政府米"
"せいふより 政府寄り"
"せいふん 製粉"
"せいぶ 声部 西部 西武"
"せいぶげき 西部劇"
"せいぶせん 西武戦"
"せいぶつ 静物 生物"
"せいぶん 正文 成文 成分"
"せいぶんどうしんこうしゃ 誠文堂新光社"
"せいへい 精兵"
"せいへき 性癖"
"せいへん 政変"
"せいべつ 性別"
"せいほ 生保"
"せいほう 西方 製法 正方"
"せいほく 西北"
"せいほくせい 西北西"
"せいほん 正本 製本"
"せいほんき 製本噐"
"せいぼ 聖母 生母 歳暮"
"せいぼう 制帽"
"せいぼつねん 生没年"
"せいま 製麻"
"せいまい 精米"
"せいまいじょ 精米所"
"せいまく 成膜"
"せいまさつ 静摩擦"
"せいみつ 精密"
"せいみや 清宮"
"せいみょう 精妙"
"せいむ 政務"
"せいめい 清明 声明 姓名 生命"
"せいめいけん 生命工学工業技術研究所"
"せいめいたい 生命体"
"せいめん 製麺"
"せいもう 製網"
"せいもん 声門 声紋 正門"
"せいや 青夜 星矢 靖也 生也 聖矢 星谷 誠也 聖夜"
"せいやく 成約 製薬 誓約 制約"
"せいゆ 精油 製油"
"せいゆう 西友 声優"
"せいよう 西洋 静養"
"せいようがたかがく 西洋型科学"
"せいようけん 精養軒"
"せいようし 西洋史"
"せいようてつがくし 西洋哲学史"
"せいよく 性欲"
"せいら 聖良"
"せいらい 生来"
"せいらん 青蘭 晴嵐"
"せいり 生理 整理"
"せいりけん 整理券"
"せいりつ 正立 成立"
"せいりゃく 政略"
"せいりゅう 青龍 青竜 成龍 清流 整流"
"せいりゅうばん 整流板"
"せいりょう 凄寥 凄涼 星稜 青陵 清陵 星陵 清涼 声量"
"せいりょく 精力 勢力"
"せいりょくしょく 青緑色"
"せいりん 青林"
"せいりんどう 青林堂"
"せいれい 正例 悽戻 蜻蛉 聖霊 生霊 精励 精霊 政令 聖隷"
"せいれき 西暦"
"せいれつ 清冽 整列"
"せいれつじゅん 整列順"
"せいれん 清簾 製練 精練 清廉 精錬"
"せいれんじこ 青蓮寺湖"
"せいれんじょ 精錬所"
"せいろ 蒸籠 征露"
"せいろう 蒸籠 聖篭 蒸篭 晴朗 精蝋"
"せいろがん 正露丸 征露丸"
"せいろく 西麓"
"せいろん 正論"
"せいわ 清和 勢和"
"せう 詔 肖 紹 笑 照 焦 焼 消 招 抄 召"
"せお 妹尾 瀬尾"
"せおりー セオリー"
"せかい 世界"
"せかいいち 世界一"
"せかいし 世界史"
"せかいじゅ 世界樹"
"せかいせん 世界戦 世界選"
"せかいぞう 世界像"
"せかいはつ 世界初"
"せかいぶっさんてん 世界物産展"
"せがみ 瀬上"
"せがれ 悴 伜 倅"
"せがわ 瀬河 瀬川"
"せき 汐 威 錫 鶺 關 迹 蹐 跖 裼 螫 蜥 藉 蓆 磧 皙 瘠 淅 晢 勣 × 瀬木 蹠 赫 堰 咳 斥 脊 惜 戚 隻 蹟 碩 晰 績 析 責 跡 赤 石 夕 寂 昔 関 籍 積 席"
"せきい 赤緯"
"せきうち 関内"
"せきうら 関浦"
"せきうん 積雲"
"せきえい 石英"
"せきお 世紀夫"
"せきか 石果 赤化 石化"
"せきかえ 席替え"
"せきかわ 関川"
"せきがい 赤外"
"せきがいこう 赤外光"
"せきがえ 席替え"
"せきがきゅう 赤芽球"
"せきがく 碩学"
"せきがね 関金"
"せきがはら 関ヶ原 関ケ原"
"せきがわ 関川"
"せきがん 赤岩 隻眼"
"せきくうかん 積空間"
"せきぐち 関口"
"せきぐん 赤軍"
"せきこう 積項 赤光"
"せきさい 積載"
"せきさいぼう 石細胞"
"せきさん 積算"
"せきざい 石材"
"せきざわ 関沢"
"せきし 積志"
"せきしま 関島"
"せきしゅうごう 積集合"
"せきしゅつ 析出"
"せきしょ 関所"
"せきしょう 石勝"
"せきしょく 赤色"
"せきしょくけいこうとう 赤色警光灯"
"せきしょくこう 赤色光"
"せきしょくとう 赤色燈 赤色灯"
"せきしん 赤心"
"せきじ 席次"
"せきじま 関島"
"せきじゅうじ 赤十字"
"せきじゅうじき 赤十字旗"
"せきじゅん 石筍 席順"
"せきじょう 関城 関上 惜譲 席上"
"せきすい 積水"
"せきすう 隻数"
"せきずい 脊髄"
"せきせいいんこ セキセイインコ"
"せきせつ 積雪"
"せきせつろ 積雪路"
"せきぜん 関前"
"せきぜんかい 責善会"
"せきそう 積層"
"せきぞう 石像"
"せきた 関田"
"せきたに 関谷"
"せきたん 石炭"
"せきちゅう 石柱 脊柱"
"せきつい 脊椎"
"せきついがわわんしょう 脊椎側湾症"
"せきづか 関塚"
"せきてい 石庭"
"せきとう 石塔"
"せきとり 関取"
"せきど 関戸"
"せきどう 赤道"
"せきどうぎ 赤道儀"
"せきにん 責任"
"せきにんばらい 責任払い"
"せきね 関根"
"せきねつ 赤熱"
"せきねん 積年"
"せきの 関野"
"せきのみや 関宮"
"せきはい 惜敗"
"せきはん 赤飯"
"せきばく 寂寞 寂莫"
"せきばらい 咳払い"
"せきばん 石盤 石板 石版"
"せきひ 石碑"
"せきひん 赤貧"
"せきぶつ 石仏"
"せきぶん ∫ 積分"
"せきぶんかん 積文館"
"せきぶんろ 積分路"
"せきべ 関部"
"せきべつ 惜別"
"せきほく 石北"
"せきぼく 石墨"
"せきまち 関町"
"せきみず 関水"
"せきむ 責務"
"せきめ 関目"
"せきめん 石綿 赤面"
"せきもと 関本"
"せきもり 関守"
"せきや 関谷"
"せきやきねん 関屋記念"
"せきやど 関宿"
"せきやま 関山"
"せきゆ 石油"
"せきゆおう 石油王"
"せきらら 赤裸裸"
"せきらんうん 積乱雲"
"せきり 赤痢"
"せきりつ 積率"
"せきりゅう 石榴"
"せきりょう 席料 寂寥"
"せきりょく 赤緑 斥力"
"せきりん 赤燐"
"せきれい 鶺鴒"
"せきわ 積和"
"せきわけ 関脇"
"せぎょう 施行 施業"
"せぎん 世銀"
"せくしょん § セクション"
"せくたすう セクタ数"
"せくとしゅぎ セクト主義"
"せぐち 瀬口"
"せけん 世間"
"せけんぎ 世間気"
"せけんずれ 世間擦れ"
"せけんてい 世間体"
"せけんばなし 世間話"
"せこ 瀬虎 瀬古 世古"
"せこう 施行 施工"
"せこうぬし 施工主"
"せこうれい 施行令"
"せこぐち 世古口"
"せしゅ 施主"
"せしゅう 世襲"
"せしりあ セシリア"
"せじ 世事 世辞"
"せじざい 世自在"
"せじざいおうぶつ 世自在王仏"
"せじょう 世情 施錠"
"せじん 世人"
"せすじ 背筋"
"せそう 世相"
"せぞく 世俗"
"せた 勢多 瀬田"
"せたい 世帯"
"せたいごと 世帯毎"
"せたいにんじょう 世態人情"
"せたいぬし 世帯主"
"せたか 瀬高"
"せたがや 世田谷"
"せたけ 背丈"
"せたな 瀬棚"
"せだ 瀬田"
"せだい 世代"
"せち 折 褻 窃 世智 世知"
"せちばる 世知原"
"せぢか 瀬近"
"せっ 接"
"せっか 叱呵 石火"
"せっかい 雪塊 石灰 切開 節介"
"せっかいがん 石灰岩"
"せっかく 切角 折角"
"せっかん 石棺 折檻 切換"
"せっき 節気 石器"
"せっきゃく 接客"
"せっきょう 説教"
"せっきょく 積極"
"せっきん 接近"
"せっきんせん 接近戰 接近戦"
"せっく 節句"
"せっくす セックス"
"せっけい 切形 雪溪 雪渓 設計"
"せっけいか 設計家"
"せっけいがくせんこう 設計学専攻"
"せっけいし 設計士"
"せっけいひ 設計費"
"せっけっきゅう 赤血球"
"せっけん 席捲 席巻 接見 石鹸"
"せっけんえき 石鹸液"
"せっけんすい 石鹸水"
"せっけんばこ 石鹸箱"
"せっけんまく 石鹸膜"
"せっこう 斥候 浙江 拙稿 石膏"
"せっこうせっこく 窃鉤窃国"
"せっこうぞう 石膏像"
"せっこつ 接骨"
"せっさ 切磋"
"せっさく 切削 拙作"
"せっさたくま 切瑳琢磨"
"せっし 摂氏 ℃"
"せっしゃ 接写 拙者"
"せっしやくわん 切歯扼腕"
"せっしゅ 接種 摂取"
"せっしゅう 雪舟 接収"
"せっしょう 摂政 殺生 折衝"
"せっしょく 接觸 摂食 節食 接触"
"せっしょくあつ 接触圧"
"せっしょん セッション"
"せっすい 節水"
"せっせい 摂制 拙生 節制 摂生"
"せっせん 切線 接線 接戦"
"せっそう 拙僧 節操"
"せっそく 拙速"
"せっそくどうぶつ 節足動物"
"せっそん 折損"
"せったい 接待"
"せったいひ 接待費"
"せったく 拙宅"
"せっち 接地 設置"
"せっちあつ 接地圧"
"せっちそうだいすう 設置総台数"
"せっちゃく 接着"
"せっちゃくざい 接着材"
"せっちゅう 折中 雪中 折衷"
"せっちゅうあん 折衷案"
"せっちょ 拙著"
"せっちょう 折衝"
"せっちん 雪隠"
"せっつ 摂津"
"せっつう 切通"
"せってい 設定"
"せっていへんこうなし 設定変更無し"
"せってん 節点 接点"
"せっと セット"
"せっとう 竊盜 窃盗 接頭"
"せっとうじ 接頭辞"
"せっとく 説得"
"せっぱ 切羽"
"せっぱく 切迫"
"せっぱん 折半"
"せっぴ 切皮 雪庇"
"せっぶく 折伏"
"せっぷう 雪風"
"せっぷく 切腹"
"せっぷん 接吻"
"せっぺん 切片"
"せっぽう 説法"
"せつ 屑 鱈 セツ 褻 薛 緤 絏 紲 竊 渫 浙 楔 椄 晰 晢 攝 截 啜 卩 § 泄 拙 窃 摂 雪 接 折 設 切 説 節"
"せつえい 雪影 設営"
"せつえん 節煙"
"せつお 節雄 節男 節夫"
"せつかん 節間"
"せつがい 雪害"
"せつがん 接岸 接眼"
"せつくうかん 接空間"
"せつけいしき 節形式"
"せつけいもじ 楔形文字"
"せつげん 雪原 節減"
"せつこ 説乎 節子"
"せつこうぞう 節構造"
"せつごう 接合"
"せつごうたい 接合体"
"せつしゅうごう 節集合"
"せつじ 接辞"
"せつじつ 切実"
"せつじゅ 接受"
"せつじょ 切除"
"せつじょう 雪上"
"せつじょうしゃ 雪上車"
"せつじょく 雪辱"
"せつじょくせん 雪辱戦"
"せつぜい 節税"
"せつぜん 切前"
"せつぞく 接続"
"せつぞくし 接続詞"
"せつぞくずみ 接続済"
"せつぞくもう 接続網"
"せつたんい 節単位"
"せつだん 切断"
"せつてん 節点"
"せつでん 節電"
"せつど 節度"
"せつどう 摂動"
"せつな 刹那 殺那"
"せつなしん 刹那心"
"せつなん 摂南"
"せつび 折尾 接尾 設備"
"せつびじ 接尾辞"
"せつびひ 設備費"
"せつぶん 説文 拙文 節分"
"せつへいめん 接平面"
"せつぼう 切望"
"せつめい 説明"
"せつめいしょあり 説明書有り"
"せつめいしょなし 説明書無し"
"せつめん 雪面"
"せつもん 説文 設問"
"せつや 摂也"
"せつやく 拙訳 節約"
"せつやくがく 節約額"
"せつゆ 説諭"
"せつようすい 雪溶水"
"せつり 切離 摂理"
"せつりつ 設立"
"せつれつ 拙劣"
"せつろん 拙論"
"せつわ 説話"
"せと 瀬戸"
"せとう 瀬藤"
"せとうち 瀬戸内"
"せとうちさん 瀬戸内産"
"せとぎわ 瀬戸際"
"せとぐち 瀬戸口"
"せとせ 瀬戸瀬"
"せとだ 瀬戸田"
"せともの 瀬戸物"
"せどうか 旋頭歌"
"せな 瀬女"
"せなか 背中"
"せなかげり 背中蹴り"
"せの 瀬野"
"せのう 瀬能"
"せのお 妹尾"
"せのび 背伸 背伸び"
"せばた 瀬端"
"せばんごう 背番号"
"せひょう 世評"
"せびょうし 背表紙"
"せびれ 背鰭"
"せびろ 背広"
"せびろすがた 背広姿"
"せぴあ セピア"
"せふ 渉 捷 妾"
"せふり 背振"
"せぶみ 瀬踏み"
"せぼね 背骨"
"せま 瀬間"
"せみ 蝉"
"せみころん セミコロン"
"せみな セミナ"
"せみなー セミナー"
"せみね 瀬峰"
"せむし 傴僂"
"せむら 瀬村"
"せめ 責"
"せめんと セメント"
"せもじ 背文字"
"せや 瀬谷"
"せやま 瀬山"
"せら 世羅 世良"
"せらにし 世羅西"
"せり 糶 競 芹"
"せりいち 競り市"
"せりか 芹香"
"せりざわ 芹澤 芹沢"
"せりふ 科白 セリフ 台詞"
"せりもく セリ目"
"せる セル"
"せるおおとまとん セルオートマトン"
"せれなーど セレナード"
"せろん 世論"
"せわ 世話"
"せわびと 世話人"
"せわもの 世話物"
"せわやく 世話役"
"せん 亘 苫 揃 釧 斬 饌 顫 韆 陝 阡 闡 鐫 錢 銛 銓 踐 跣 贍 賤 譫 蟾 蘚 荐 舩 翦 羶 纎 纖 綫 籖 籤 簽 筅 筌 磚 瞻 癬 痊 疝 甎 牋 燹 濺 濳 潛 潺 湶 淺 涎 沾 氈 殱 殲 槫 槧 栫 暹 旃 擶 擅 戰 巛 孱 尠 專 孅 嬋 吮 剪 刋 僣 僭 僊 僉 倩 仟 蝉 ― 栴 栓 撰 餞 尖 宣 扇 煎 煽 羨 舛 閃 詮 銑 賎 専 浅 箋 箭 穿 潜 仙 染 旋 腺 薦 泉 鮮 遷 践 銭 川 占 繊 選 船 洗 先 戦 千 線"
"せんい 船医 瞻依 戦意 線維 繊維 遷移"
"せんいし 繊維糸"
"せんいしつ 繊維質"
"せんいしょう 線維"
"せんいそ 線維素"
"せんいそく 繊維束"
"せんいん 船員"
"せんえい 尖鋭 千映 先鋭"
"せんえき 戦役"
"せんえつ 僭越"
"せんえん 千円"
"せんえんさつ 千円札"
"せんえんなり 千円也"
"せんおう 擅横 専横"
"せんおくえん 千億円"
"せんか 戰火 戰果 戦禍 線化 戦火 戦果 専科"
"せんかい 先回 旋回 千回"
"せんかく 先覚 線画"
"せんかじゅう 線荷重"
"せんかた 爲ん方 詮方 為ん方"
"せんかわ 千川 仙川"
"せんかん 戰艦 線間 選管 戦艦"
"せんが 千賀 線画"
"せんがい 船外 選外"
"せんがく 浅学 先学"
"せんがくじ 泉岳寺"
"せんがくひさい 浅学非才"
"せんがぞう 線画像"
"せんがん 腺癌 洗眼 洗顔"
"せんき 先期 戦旗 戦記"
"せんきち 詮吉"
"せんきゃく 船客 先客"
"せんきゃくばんらい 千客万来"
"せんきゅうがん 選球眼"
"せんきゅうはく 船中泊"
"せんきょ 占居 占拠 選挙"
"せんきょう 船橋 泉郷 戦況 宣教"
"せんきょく 選局 戦局 選曲"
"せんきょせん 選挙戦"
"せんきょみん 選挙民"
"せんきん 千金"
"せんぎ 詮議 先議"
"せんぎく 千菊"
"せんぎょ 鮮魚"
"せんぎょう 専業"
"せんぎり 千切り"
"せんく 線区 先駆"
"せんぐ 船具"
"せんぐん 線群"
"せんけ 千家"
"せんけい 戦形 扇形 線形 線型"
"せんけいえんこうだあねっとわあく 線形エンコーダーネットワーク"
"せんけいわ 線形和"
"せんけつ 潜血 鮮血 先決"
"せんけつごう 線結合"
"せんけん 擅権 先遣 浅見 仙建 選鉱精錬研究所 選研 淺見 先件 先験 先見"
"せんけんさそうち 線検査装置"
"せんけんじこう 専権事項"
"せんけんのめい 先見の明"
"せんげつ 先月"
"せんげつまつ 先月末"
"せんげん 線源 浅間 ∨ 選言 宣言"
"せんげんだい 千間台"
"せんこ 千古"
"せんこう せん孔 踐行 潜航 染工 戦功 選鉱 潜降 閃光 選好 先攻 潜行 穿孔 線香 専攻 選考 先行"
"せんこうげん 線光源"
"せんこうし 先行詞"
"せんこうしゃ 先行車"
"せんこうじゅん 選考順"
"せんこうば 先行馬"
"せんこく 先刻 宣告"
"せんこつ 仙骨"
"せんこのせいじゃく 千古の静寂"
"せんご 戰後 選語 戦後"
"せんごく 戰國 仙石 千石 戦国"
"せんごし 戦後史"
"せんごばん 先後番"
"せんさ 千差"
"せんさい 浅才 先妻 戦災 繊細"
"せんさく 穿鑿 詮索 詮策"
"せんざい 前栽 千載 洗剤 潜在"
"せんざん 仙山"
"せんし 擅恣 戰死 千士 戦志 戦史 穿刺 戦死 先史 戦士"
"せんしきめん 線織面"
"せんしたい 戰死體 戦死体"
"せんしつ 線質 船室"
"せんしつけん 船室券"
"せんしゃ 戰車 戦車 洗車"
"せんしゃせん 戦車戦"
"せんしゃへい 戦車兵"
"せんしやく 戦士役"
"せんしゅ 僭主 船首 専守 線種 先取 選手"
"せんしゅう 千秋 選集 専修 泉州 先週"
"せんしゅうまつ 先週末"
"せんしゅうらく 千秋楽"
"せんしゅかい 千趣会"
"せんしゅけんじあい 選手権試合"
"せんしゅつ 選出"
"せんしゅつば 選出馬"
"せんしょ 選書"
"せんしょう 戰捷 僭上 僭称 戦捷 戦勝 戦賞 先勝"
"せんしょく 染色 染織"
"せんしょくたい 染色体"
"せんしん 線審 専心 千進 先進"
"せんじ 戰時 潜時 戦時"
"せんじいない 千字以内"
"せんじつ 先日"
"せんじつらい 先日来"
"せんじもん 千字文"
"せんじゃ 撰者 選者"
"せんじゅ 千種 千住 仙寿"
"せんじゅう 先住 専従"
"せんじゅうじ 千手寺"
"せんじゅうみん 先住民"
"せんじゅかんのん 千手観音"
"せんじゅつ 占術 戰術 先述 仙術 戦術"
"せんじゅつか 戦術家"
"せんじゅんい 先順位"
"せんじょう 煽情 戰場 洗滌 千丈 仙丈 船上 扇状 洗浄 戦場 線状 線上"
"せんじょうえき 洗浄液"
"せんじょうじき 千畳敷"
"せんじょうだん 扇状弾"
"せんじん 先陣 千尋 先人"
"せんす センス 扇子"
"せんすい 線錐 仙水 潜水"
"せんすいし 潜水士"
"せんすいてい 潜水艇"
"せんすいびょう 潜水病"
"せんすいふく 潜水服"
"せんすうひゃく 千数百"
"せんず 線図"
"せんずけい 線図形"
"せんせーしょん センセーション"
"せんせい 専政 専制 占星 先制 宣誓 先生"
"せんせいがた 先生方"
"せんせいぞう 先生像"
"せんせいだ 先制打"
"せんせいてきじえいけん 先制的自衛権"
"せんせいひょう 賛成票"
"せんせいやく 先生役"
"せんせき 船籍 仙石 戦績"
"せんせきぶん 線積分"
"せんせん 戰線 戰々 宣戰 宣戦 戦線 戦々 先々"
"せんせんげつ 先先月 先々月"
"せんせんしゅう 先先週"
"せんせんじつ 先先日"
"せんせんじゅつ 占星術"
"せんぜん 戰前 戦前"
"せんぜんがたきゅうこく 戦前型旧国"
"せんそ 践祚 線素"
"せんそう 船艙 戰爭 船倉 先走 戦争"
"せんそうじ 浅草寺"
"せんそく 線束 栓塞 戦速 洗足"
"せんぞ 先祖"
"せんぞい 線沿"
"せんぞう 仙三 線増"
"せんぞく 洗足 専属"
"せんぞくいけ 洗足池"
"せんた センタ"
"せんたー センター"
"せんたい 蘚苔 船体 戦隊"
"せんたいしょう 線対称"
"せんたいもの 戦隊物"
"せんたく 撰択 洗濯 選択"
"せんたくいた 洗濯板"
"せんたくし 選択枝 選択肢"
"せんたくもの 洗濯物"
"せんたくわく 選択枠"
"せんたろう 煎太郎"
"せんたん 尖端 戦端 先端"
"せんたんい 千単位"
"せんだ 仙田 千田"
"せんだい 千台 川内 先代 仙台"
"せんだいいち 仙台一"
"せんだいがき 仙台牡蛎"
"せんだいこう 仙台港"
"せんだいざか 仙台坂"
"せんだいだいにこう 仙台第二高"
"せんだいでんしゃくさい 仙台電車区祭"
"せんだいまつど 専大松戸"
"せんだがや 千駄谷 千駄ヶ谷"
"せんだぎ 千駄木"
"せんだち 先達"
"せんだつ 先達"
"せんだん 旃檀 剪断 栴檀 船団"
"せんだんりょく せん断力"
"せんち 戦地 センチ"
"せんちぐらむ 甅"
"せんちめーとる 糎"
"せんちゃ 煎茶"
"せんちゃく 先着"
"せんちゃくしゃゆうせん 先着者優先"
"せんちゃくじゅん 先着順"
"せんちゅう 線虫 船中 戦中"
"せんちょう 船長 線長"
"せんちりっとる 竰"
"せんつう 疝痛"
"せんて 先手"
"せんてい 剪定 選定"
"せんていば 選定馬"
"せんてつ 鮮鉄 仙鉄 銑鉄"
"せんてん 先天 千点"
"せんでき 洗滌"
"せんでん 宣伝"
"せんでんひ 宣伝費"
"せんと 仙都 セント 遷都"
"せんとう 千頭 尖塔 戰闘 銭湯 戦闘 先頭"
"せんとうごしょ 仙洞御所"
"せんとうしゃ 先頭車"
"せんとうはん 戦闘班"
"せんとらるがらす セントラル硝子"
"せんとらるぱーく セントラルパーク"
"せんど 先途 鮮度"
"せんどう 千同 扇動 船頭 煽動 千堂 仙道 先導"
"せんどうし 線同士"
"せんどうしゃ 先導車"
"せんどうやく 先導役"
"せんない 線内 船内"
"せんなん 仙南 泉南"
"せんにち 千日"
"せんにちて 千日手"
"せんにちどう 千日堂"
"せんにゅう 潜入"
"せんにゅうかん 先入観"
"せんにゅうかんねん 先入観念"
"せんにん 先任 選任 千人 仙人 専任"
"せんねん 先年 千年 専念"
"せんのう 洗脳"
"せんはた 千畑"
"せんはば 線幅"
"せんはら 千原"
"せんば 仙葉 千羽 船場 仙波"
"せんばい 専売"
"せんばいいじょう 千倍以上"
"せんばがん 選馬眼"
"せんばしょ 先場所"
"せんばつ 選抜"
"せんばづる 千羽鶴"
"せんばやしかん 千林間"
"せんばりき 千馬力"
"せんばん 先番 旋盤 千万"
"せんぱい 先輩"
"せんぱいがた 先輩方"
"せんぱく 銭帛 浅薄 船舶"
"せんぱつ 染髪 洗髪 先発"
"せんぱつし 先発枝"
"せんぱん 戰犯 戦犯 先般"
"せんひき 線引き 線引"
"せんび 船尾"
"せんびき 線引き"
"せんびん 先便 船便"
"せんぴょう 選評 線表"
"せんぶん 千分 線分"
"せんぷ 先負 戦斧"
"せんぷう 旋風"
"せんぷうき 扇風機"
"せんぷく 船腹 線幅 潜伏"
"せんぷくが 潜伏芽"
"せんべい 煎餅"
"せんべつ 餞別 選別"
"せんべん 先鞭"
"せんべんばんか 千変万化"
"せんぺい 尖兵"
"せんぺんばんか 千変万化"
"せんほく 泉北"
"せんぼう 羨望"
"せんぼうきょう 潜望鏡"
"せんぼく 仙北 泉北"
"せんぼつ 戦没"
"せんぼん 千本"
"せんぼんざくら 千本桜"
"せんぼんはま 千本浜"
"せんぽう 先鋒 旋法 戦法 先方"
"せんぽく 泉北"
"せんまい 洗米 千枚"
"せんまいだ 千枚田"
"せんまや 千厩"
"せんまん 千万"
"せんみつど 線密度"
"せんみん 選民"
"せんみんかいきゅう 賎民階級"
"せんむ 専務"
"せんめい 線名 鮮明"
"せんめつ 殱滅 剪滅 殲滅"
"せんめん 線面 洗面"
"せんめんじょ 洗面所"
"せんもう 腺毛 剪毛 譫妄 繊毛 線毛"
"せんもうせん 釧網線"
"せんもうほんせん 釧網本線"
"せんもん 専門"
"せんもんい 専門医"
"せんもんか 専門家"
"せんもんし 専門紙"
"せんもんしょく 専門職"
"せんもんわく 専門枠"
"せんや 千夜"
"せんやく 先約"
"せんゆう 戦友 専有 占有"
"せんよう 宣揚 専用"
"せんようきどうあと 専用軌道跡"
"せんようしゃ 専用車"
"せんようそ 線要素"
"せんようば 専用馬"
"せんらん 戦乱"
"せんり 戦利 千里"
"せんりがん 千里眼"
"せんりつ 戦慄 旋律"
"せんりはまかいがん 千里浜海岸"
"せんりゃく 戦略"
"せんりゅう 潜龍 千流 川柳"
"せんりょ 千慮 浅慮"
"せんりょう 千両 染料 線量 占領"
"せんりょうか センリョウ科"
"せんりょうけい 線量計"
"せんりょうみん 占領民"
"せんりょく 戦力"
"せんりょのいっし 千慮の一矢"
"せんりん 線輪"
"せんりんかく 線輪郭"
"せんれい 先例 洗礼"
"せんれき 戦歴"
"せんれつ 戦列 鮮烈"
"せんれん 洗錬 洗練"
"せんれんけつ 線連結"
"せんろ 線路"
"せんろあと 線路跡"
"せんろぎわ 線路際"
"せんろしき 線路敷"
"せんろした 線路下"
"せんろぞい 線路沿"
"せんろよこ 線路横"
"せんわく 煽惑"
"ぜ 是"
"ぜい 筮 噬 説 贅 勢 脆 税"
"ぜいかん 税関"
"ぜいがく 税額"
"ぜいきん 税金"
"ぜいげん 贅言 税源"
"ぜいこみ 税込 税込み"
"ぜいしゅう 税収"
"ぜいしゅうぞう 税収増"
"ぜいしゅうにゅう 税収入"
"ぜいじゃく 脆弱"
"ぜいせい 税制"
"ぜいたく 贅沢"
"ぜいちょう 税調"
"ぜいにく 贅肉 ぜい肉"
"ぜいぬき 税抜"
"ぜいびきまえとうきりえき 税引前当期利益"
"ぜいふたん 税負担"
"ぜいぶつ 贅物"
"ぜいべつ 税別"
"ぜいほう 税法"
"ぜいむ 税務"
"ぜいむしょ 税務署"
"ぜいめい 喘鳴"
"ぜいり 税理 税吏"
"ぜいりし 税理士"
"ぜいりつ 税率"
"ぜえた Ζ"
"ぜがひでも 是が非でも"
"ぜき 關 関"
"ぜげん 女衒"
"ぜせい 是正"
"ぜぜ 膳所"
"ぜぜこう 膳所高"
"ぜっか 舌禍"
"ぜっかい 絶海"
"ぜっきょう 絶叫"
"ぜっく 絶句"
"ぜっけい 絶景"
"ぜっこう 絶交 絶好"
"ぜっこうきゅう 絶好球"
"ぜっこつ 舌骨"
"ぜっさん 絶讚 絶讃 絶賛"
"ぜっしょう 絶唱"
"ぜっしょく 絶食"
"ぜっせい 絶世"
"ぜっせん 舌戦"
"ぜったい 舌苔 絶体 絶対"
"ぜったいかく 絶対格"
"ぜったいし 絶対視"
"ぜったいそん 絶対損"
"ぜったいまけ 絶対負"
"ぜったいむせいやく 絶対無制約"
"ぜったん 舌端"
"ぜっちょう 絶頂"
"ぜっとへんかん Ｚ変換"
"ぜっぱん 絶版"
"ぜっぴつ 絶筆"
"ぜっぴん 絶品"
"ぜっふうん 絶不運"
"ぜっふちょう 絶不調"
"ぜっぺき 絶壁"
"ぜっぽう 舌鋒"
"ぜつ 説 舌 絶"
"ぜついん 舌咽"
"ぜつえん 絶縁"
"ぜつえんざい 絶縁材"
"ぜつえんたい 絶縁体"
"ぜつおん 舌音"
"ぜつご 絶後"
"ぜつだい 絶大"
"ぜつぼう 絶望"
"ぜつみょう 絶妙"
"ぜつむ 絶無"
"ぜつめい 絶命"
"ぜつめつ 絶滅"
"ぜつりん 絶倫"
"ぜに 錢 銭"
"ぜにがた 銭形"
"ぜにたかぐみ 錢高組"
"ぜにばこ 銭箱 銭函"
"ぜにん 是認"
"ぜねすと ゼネスト"
"ぜねらるせきゆ ゼネラル石油"
"ぜひ 是非"
"ぜひよく 是非欲"
"ぜみ ゼミ"
"ぜみなーる ゼミナール"
"ぜめ 攻め"
"ぜろ 〇 零 ゼロ"
"ぜろいんし 零因子"
"ぜろくうかん 零空間"
"ぜろげん 零元"
"ぜろじ ０次"
"ぜろせん 零戦"
"ぜろてん 零点"
"ぜん 嶄 蝉 髯 蠕 苒 譱 禪 喘 冉 千 漸 繕 善 禅 膳 然 前 全"
"ぜんあく 善悪"
"ぜんあつ 前圧"
"ぜんい 前位 善意"
"ぜんいき 全域"
"ぜんいち 善一"
"ぜんいん 全員"
"ぜんえい 前衛 全英"
"ぜんえいおんがっか 前衛音楽家"
"ぜんえき 全駅"
"ぜんえん 前縁 全縁"
"ぜんおう 全欧"
"ぜんおん 全音"
"ぜんか 全科 漸化 前科"
"ぜんかい 全潰 全階 全回 全壊 全会 全解 全快 全開 前回"
"ぜんかいまで 前回迄"
"ぜんかく 前核 全角"
"ぜんかもの 前科者"
"ぜんかん 前巻 全艦 全巻 全館"
"ぜんがく 全額 全学"
"ぜんき 全機 全期 前記 前期"
"ぜんきしゃ 前期車"
"ぜんきち 善吉"
"ぜんきゃく 前脚"
"ぜんきゅう 全休"
"ぜんきょく 全局 全極 全曲"
"ぜんきん 前金 漸近"
"ぜんぎ 前戯"
"ぜんぎょう 前行"
"ぜんぎん 全銀"
"ぜんぎんきょう 全銀協"
"ぜんく 全区 前駆"
"ぜんくたい 前駆体"
"ぜんくつ 前屈"
"ぜんくろう 善九郎"
"ぜんぐん 前群 全郡 全軍"
"ぜんけい 前景 全系 前傾 全景 全形 前掲"
"ぜんけん 全県 全権 前件"
"ぜんげつ 前月"
"ぜんげん 漸減 前言"
"ぜんこ 全戸"
"ぜんこう 全高 善行 全校 前項"
"ぜんこうじ 善光寺"
"ぜんこく 全国"
"ぜんこくいち 全国一"
"ぜんこくし 全国紙"
"ぜんこくはつ 全国初"
"ぜんこっく 全国区"
"ぜんこていえき 前固定液"
"ぜんこみぞう 前古未曾有"
"ぜんご 善吾 善後 前後"
"ぜんごう 全豪 前号"
"ぜんごぎゃく 前後逆"
"ぜんごじく 前後軸"
"ぜんごどう 前後動"
"ぜんさい 前菜"
"ぜんさく 前作"
"ぜんさりん 前左輪"
"ぜんざ 前座"
"ぜんざい 善哉"
"ぜんざじあい 前座試合"
"ぜんざん 前残"
"ぜんし 前肢 禅師 全姉 全紙 全市"
"ぜんしつ 前室"
"ぜんしつきんえん 全室禁煙"
"ぜんしゃ 全車 全射 前車 全社 前者"
"ぜんしゃく 前借"
"ぜんしゃふべん 善者不辯"
"ぜんしゅ 髯鬚"
"ぜんしゅう 全州 禅宗 全周 前週 全集"
"ぜんしゅうもの 全集物"
"ぜんしゅつ 前出"
"ぜんしょ 全所 全書 善処"
"ぜんしょう 全章 ∀ 前哨 全焼 全勝 全称 前章"
"ぜんしょうせん 前哨戦"
"ぜんしょうば 全勝馬"
"ぜんしょく 前職"
"ぜんしろう 善四郎"
"ぜんしん 前震 前身 漸進 全身 前進"
"ぜんじ 善司 漸次 漸時"
"ぜんじく 全軸"
"ぜんじたい 前時代"
"ぜんじつ 全日 前日"
"ぜんじつらい 前日来"
"ぜんじゅつ 前述"
"ぜんじょ 全女"
"ぜんじょう 禅定 禅譲 前条 善場"
"ぜんじろう 善二郎 善次郎"
"ぜんじん 前人"
"ぜんじんかいぎ 善人会議"
"ぜんじんみとう 全人未踏"
"ぜんすう 全数"
"ぜんず 全図"
"ぜんせ 前世"
"ぜんせい 前世 善政 全勢 全盛"
"ぜんせき 全席"
"ぜんせつ 前節"
"ぜんせん 全線 善戦 前線"
"ぜんせんほうそう 全戦放送"
"ぜんぜん 全々 前前 前々 全然"
"ぜんぜんげつ 前々月"
"ぜんぜんじつ 前々日"
"ぜんそ 髯蘇"
"ぜんそう 全奏 禅僧 前走 前奏"
"ぜんそうしゃ 前走車"
"ぜんそうなみ 前走並"
"ぜんそく 全速 喘息"
"ぜんそん 全村 全損"
"ぜんぞう 漸増"
"ぜんたい 全体"
"ぜんたいぞう 全体像"
"ぜんたろう 善太郎"
"ぜんたん 前端"
"ぜんだい 前代"
"ぜんだて 膳立て"
"ぜんだま 善玉"
"ぜんだん 前段"
"ぜんち 全地 全知 前置 全治"
"ぜんちし 前置詞"
"ぜんちゅううら 全中裏"
"ぜんちょ 前著"
"ぜんちょう 前兆 全長"
"ぜんつう 全通"
"ぜんつうじ 善通寺"
"ぜんてい 前庭 前提"
"ぜんてん 全点 前転 全店"
"ぜんてんしゅう 全天周"
"ぜんてんせんぶん 全天線分"
"ぜんと 全都 前途"
"ぜんとう 全島 前頭"
"ぜんとうぶじょは 前頭部徐波"
"ぜんど 髯奴 全土"
"ぜんどう 蠕動 善導"
"ぜんなんぜんにょ 善男善女"
"ぜんにち 全日"
"ぜんにん 前任 善人"
"ぜんねん 前年"
"ぜんのう 全脳 全農 全納 前納 全能"
"ぜんのすけ 善之助"
"ぜんはい 前胚 全廃"
"ぜんはん 全版 前半"
"ぜんはんせん 前半戦"
"ぜんば 前場 全馬"
"ぜんばん 全判"
"ぜんぱい 全敗 全廃"
"ぜんぱく 全泊 前泊"
"ぜんぱん 前半 全般"
"ぜんひょう 全表 全票"
"ぜんびん 全便 前便"
"ぜんぴん 全品"
"ぜんふくじこうえん 善福寺公園"
"ぜんふくじじょうすいじょう 善福寺浄水場"
"ぜんふつ 全仏"
"ぜんふれんけつ 全不連結"
"ぜんぶ 前部 全部"
"ぜんぶりゃく 全部略"
"ぜんぶん 前文 全文"
"ぜんぷく 全幅"
"ぜんへいじ 全閉時"
"ぜんべい 全米"
"ぜんべいいち 全米一"
"ぜんぺい 全閉"
"ぜんぺき 前壁"
"ぜんぺん 前篇 前編 全編"
"ぜんぼう 全貌"
"ぜんぽう 前方"
"ぜんぽうじ 善宝寺"
"ぜんぽうやく 前方約"
"ぜんまい 發条 発条 全妹 薇"
"ぜんまく 善悪"
"ぜんめつ 全滅"
"ぜんめん 前面 全面"
"ぜんもう 全毛 全盲"
"ぜんもん 前門 全問 前問"
"ぜんもんどう 禅問答"
"ぜんや 善也 前夜"
"ぜんやく 善役 全訳"
"ぜんやさい 前夜祭"
"ぜんゆうれん 全遊連"
"ぜんよう 前葉 善用 全容"
"ぜんよく 前翼"
"ぜんら 全裸"
"ぜんりつせん 前立腺"
"ぜんりゃく 全略 前略"
"ぜんりょう 全量 善良"
"ぜんりょうせい 全寮制"
"ぜんりょく 全力"
"ぜんりん 善隣 前輪"
"ぜんれい 全零 全例 全霊 前例"
"ぜんれいちゅう 全冷中"
"ぜんれき 前歴"
"ぜんれつ 全裂 前列"
"ぜんろうさい 全労済"
"ぜんわ 全話"
"ぜんわん 全湾 前弯 前腕"
"そ 酢 齟 鼡 麁 醋 酥 踈 詛 蘓 蔬 胙 祚 甦 爼 溯 沮 泝 愬 徂 囎 咀 俎 疽 姐 岨 曾 疏 塑 噌 措 租 楚 狙 鼠 阻 蘇 疎 曽 遡 訴 礎 祖 粗 組 素"
"そーす ソース"
"そーだ 曹達"
"そーぷ ソープ"
"そあく 粗悪"
"そあん 素案"
"そい 添い"
"そいずみ 祖泉"
"そいね 添寝"
"そいん 訴因 素因"
"そう 崇 湊 蚤 葱 爪 贈 庄 桑 鯵 曽 曾 竃 竈 漿 廂 然 髞 騷 輳 躁 踪 蹌 赱 譟 諍 裝 蔟 菷 莊 艸 艚 艙 總 籔 簇 筝 箒 笊 窗 爭 炒 澡 漱 滄 淙 歃 樔 梍 搶 插 掫 搜 抓 懆 愡 怱 弉 帚 崢 屮 孀 嫂 妝 奘 壯 嗽 嗾 叟 雙 匆 勦 剏 偬 瘡 繰 艘 愴 聰 宗 叢 喪 糟 捜 匝 箏 爽 窓 葬 槍 巣 掻 曹 燥 痩 創 惣 藻 綜 噪 双 宋 壮 僧 倉 鎗 遭 奏 掃 蒼 操 霜 聡 槽 挿 漕 走 争 草 騒 荘 早 装 想 送 相 層 総"
"そうあい 相愛"
"そうあん 創案 草案"
"そうい 創痍 総意 創意 相異 相違"
"そういち 壮一 聡一 宗市 宗一"
"そういちろう 惣一郎 壮一郎 宗一郎 聡一郎"
"そういん 挿引 総員 僧院"
"そううつ 躁鬱"
"そううつびょう 躁鬱病"
"そううん 曾雲 層雲"
"そううんきょう 層雲峡"
"そうおう 相応"
"そうおん 宋音 噪音 騒音"
"そうおんけい 騒音計"
"そうおんげん 騒音源"
"そうか 層化 創価 僧伽 痩果 送荷 草加 総科 相加"
"そうかい 掃海 壮快 爽快 総会"
"そうかいじょう 層階状"
"そうかいじょうざい 層階状材"
"そうかいてい 掃海艇"
"そうかく 双角 総画"
"そうかつ 総轄 総括"
"そうかつはん 総括班"
"そうかん 挿菅 送棺 総監 層間 送還 創刊 相姦 壮観 相関"
"そうが 装画 挿画 総画"
"そうがい 窓外"
"そうがく 総額"
"そうがくどう 奏楽堂"
"そうがん 双眼"
"そうき 総記 想起 早期"
"そうきがん 早期癌"
"そうきば 双牙"
"そうきゅう 蒼穹 送球 早急"
"そうきゅうるい 双弓類"
"そうきょ 壮挙"
"そうきょく 双極 箏曲 総局 双曲"
"そうきん 送金"
"そうきんがく 送金額"
"そうきんしゃすう 送金者数"
"そうきんしゃふたん 送金者負担"
"そうぎ 争議 葬儀"
"そうぎょう 早暁 操業 創業"
"そうぎょうひょう 総合表"
"そうく 走狗 痩躯"
"そうくう 蒼空"
"そうくうかん 相空間"
"そうくつ 巣窟"
"そうくん 宗薫"
"そうぐ 装具"
"そうぐう 遭遇"
"そうぐん 総軍"
"そうけ 宗家"
"そうけい 早慶 早計 総計"
"そうけいせん 早慶戦"
"そうけいめい 早慶明"
"そうけつ 総結"
"そうけん 創建 送検 双肩 壮健 総研"
"そうげい 送迎"
"そうげつ 草月"
"そうげん 荘厳 創元 草原"
"そうこ 倉庫"
"そうこう 走向 送稿 相好 曹洪 奏効 霜降 操行 装甲 壮行 草稿 走行"
"そうこうあんていせい 走行安全性"
"そうこうしゃ 走行車 装甲車"
"そうこうしゅ 走攻守"
"そうこうばん 装甲鈑 装甲板"
"そうこうりゅうほうしき 相交流方式"
"そうこうろ 走行路"
"そうこく 相剋 相克"
"そうこしょう 双虎掌"
"そうこん 愴恨 早婚"
"そうご 総吾 總吾 双吾 壮語 相互"
"そうごう 相互 相好 綜合 総合"
"そうごうききてん 総合機器展"
"そうごうしょく 総合職"
"そうごうしれいじょ 総合指令所"
"そうごん 荘厳"
"そうさ 捜査 走査 操作"
"そうさい 総裁 葬祭 相殺"
"そうさいせん 総裁選"
"そうさく 捜索 創作"
"そうさたく 操作卓"
"そうさつ 相殺"
"そうさてきかち 創作的価値"
"そうざい 惣菜"
"そうざん 早産"
"そうし 宗祀 双紙 壮志 壮士 総司 荘子 草紙 相思 創始"
"そうしき 葬式"
"そうしち 惣七"
"そうしつ 喪失"
"そうしゃ 掃射 壮者 操車 走者 双射 奏者"
"そうしゃえき 総社駅"
"そうしゅ 双手"
"そうしゅう 総集"
"そうしゅこく 宗主国"
"そうしゅつ 走出 創出 送出"
"そうしゅつし 走出枝"
"そうしゅん 早春"
"そうしゅんふ 早春賦"
"そうしょ 叢書 双書 草書"
"そうしょう 創傷 相生 相称 争訟 総称"
"そうしょく 草食 装飾"
"そうしょたい 草書体"
"そうしょだい 叢書第"
"そうしん 喪心 装身 痩身 送信"
"そうしんぐ 装身具"
"そうしんじょ 送信所"
"そうじ 走時 挿耳 荘司 送辞 相似 掃除"
"そうじけい 相似形"
"そうじつ 桑実"
"そうじつはい 桑実胚"
"そうじでら 総持寺"
"そうじふ 掃除婦"
"そうじゃ 総社"
"そうじゅ 双樹 送受"
"そうじゅう 操縦"
"そうじゅうかん 操縦竿 操縦桿"
"そうじゅうきいがい 操縦機以外"
"そうじゅうし 操縦士"
"そうじゅうせき 操縦席"
"そうじゅうりょくせい 走重力性"
"そうじゅく 早熟"
"そうじゅくば 早熟馬"
"そうじゅしん 送受信"
"そうじゅとも 送受共"
"そうじゅわ 送受話"
"そうじょう 総状 相生 奏上 僧正 早場 相乗 層状 僧上"
"そうじょうたい 躁状態"
"そうじろう 宗次郎"
"そうすい 送水 総帥"
"そうすいかん 送水管"
"そうすう 曹嵩 層数 総数"
"そうず 索子 挿図"
"そうせい 簇生 創製 早逝 早世 創生 創成"
"そうせいき 創世紀 創世記"
"そうせいじ 双生児"
"そうせいねんだんし 青壮年男子"
"そうせき 踪跡 漱石"
"そうせきちんりゅう 漱石枕流"
"そうせつ 総説 創設"
"そうせつひ 創設費"
"そうせん 操船"
"そうぜい 総勢"
"そうぜつ 壮絶"
"そうぜん 愴然 蒼然 騒然"
"そうそ 曾祖"
"そうそう 然う然う 鏘鏘 蹌蹌 簇簇 蒼蒼 総総 層層 滄桑 喪葬 淙淙 送葬 草叢 草草 匆匆 怱怱 早早 愴愴 壮々 錚錚 怱々 草創 曹操 葬送 草々 早々"
"そうそく 総則"
"そうそふ 曾祖父"
"そうそぼ 曾祖母"
"そうそん 曾孫"
"そうぞう 送像 創造 想像"
"そうぞうしゅ 創造主"
"そうぞうしん 創造神"
"そうぞうせつ 創造説"
"そうぞく 相續 相続"
"そうぞくあいてさき 接続相手先"
"そうぞくぜい 相続税"
"そうたい 総隊 総体 双対 早退 相対"
"そうたつ 送達"
"そうたん 操短"
"そうだ 崇田 早田 宗田 左右田 曹達 操舵"
"そうだい 早稲田大学 総代 早大 壮大"
"そうだいいん 早大院"
"そうだいしょう 総大将"
"そうだいせん 早大戦"
"そうだおれ 総倒れ"
"そうだか 総高"
"そうだち 総立ち"
"そうだつ 争奪"
"そうだつせん 争奪戦"
"そうだん 装弾数 早弾 相談"
"そうだんじょ 相談所"
"そうだんすう 装弾数"
"そうだんやく 相談役"
"そうち 送致 装置"
"そうちゃく 早着 装着"
"そうちゃくえき 装着液"
"そうちゃくしゃ 装着車"
"そうちょう 宗澄 曹長 双調 荘重 総長 早朝"
"そうつい 相対 双対"
"そうてい 遭艇 装幀 送呈 装釘 装丁 想定"
"そうてつ 蒼鉄 相鉄"
"そうてん 総点 蒼天 操典 装填 争点"
"そうてんい 層転移 相転移"
"そうで 総出"
"そうでん 相伝 叢伝 送電"
"そうでんもう 送電網"
"そうと 壮途 壮図"
"そうとう 掃討 総当 総統 双頭 争闘 相当"
"そうとうがく 相当額"
"そうとうざん 相当算"
"そうとうしゅう 曹洞宗"
"そうとうすう 相等数"
"そうとうせい 相等性"
"そうとく 総督"
"そうとめ 早乙女"
"そうどう 相同 騒動"
"そうない 層内"
"そうなん 遭難"
"そうにゅう 総入 挿入"
"そうにゅうか 挿入歌"
"そうにゅうく 挿入句"
"そうにゅうぐち 挿入口"
"そうねん 壮年"
"そうは 掻爬 走破 争覇"
"そうはい 送配"
"そうはく 蒼白"
"そうはくそ 曾伯祖"
"そうはち 壮八"
"そうはつ 双発 創発"
"そうはん 相反"
"そうば 相場"
"そうばつ 挿抜"
"そうばな 総花"
"そうばん 早晩"
"そうひょう 総評"
"そうび 装備"
"そうびしゃ 創美社 装備車"
"そうびょう 躁病"
"そうふ 総譜 奏譜 送付"
"そうふう 送風"
"そうふうこう 送風口"
"そうぶ 創部 総武"
"そうぶだい 相武台"
"そうへい 僧兵"
"そうへき 双壁 双璧"
"そうべつ 層別 壮瞥 送別"
"そうほ 相補"
"そうほう 総苞 総包 宗豊 双峰 走法 奏法 双方"
"そうほさ 相補鎖"
"そうほん 草本"
"そうぼう 蒼茫 相貌 双眸 蒼氓"
"そうぼうきん 僧帽筋"
"そうぼうべん 僧帽弁"
"そうま 相馬"
"そうまとう 走馬灯 走馬燈"
"そうむ 双務 総務 創夢"
"そうむかかり 総務掛"
"そうむがかり 総務掛"
"そうむはん 総務班"
"そうむひ 総務費"
"そうむら 荘村"
"そうめい 聡明 早明 聰明"
"そうめいせん 早明戦"
"そうめん 索麺 素麺"
"そうもく 草木"
"そうもん 桑門 艸門"
"そうや 宗谷"
"そうやく 創薬"
"そうやま 相山"
"そうやみさき 宗谷岬"
"そうゆう 曾遊"
"そうよう 掻痒 装用"
"そうらく 相楽"
"そうらん 争乱 騒乱 総覧"
"そうり 總理 総理"
"そうりつ 総立 創立"
"そうりふれい 総理府令"
"そうりゅう 宗留 蒼龍 蒼竜 総流 双龍"
"そうりゅうでん 創竜伝"
"そうりゅうよく 層流翼"
"そうりゅうよくけい 層流翼形"
"そうりょ 僧侶"
"そうりょう 総領 惣領 総量 送料"
"そうりょうこみ 送料込"
"そうりょく 走力 総力"
"そうりょくせん 総力戦"
"そうりん 総輪 叢林"
"そうるい 走塁 藻類 草類"
"そうれい 壮麗"
"そうれつ 葬列 壮烈"
"そうれん 操練"
"そうろ 走路"
"そうろう 早漏 候"
"そうろうぶん 候文"
"そうろん 争論 総論"
"そうわ 送話 挿話 総和"
"そうわぐち 送話口"
"そうわん 双腕"
"そえ 貮 儲 副 添え 添"
"そえかみ 添上"
"そえがき 添え書き"
"そえき 素液"
"そえじ 添字"
"そえじま 副島"
"そえだ 添田"
"そえの 添野"
"そえや 添谷"
"そえん 疎遠"
"そお 囎唹"
"そかい 租界 疎開"
"そかく 素核 組閣 疎隔"
"そが 曾我 曽我 蘇我"
"そがい 阻碍 疎外 阻害"
"そがべ 曽我部"
"そがん 訴願"
"そきゅう 遡求 遡及"
"そきゅうりょく 訴求力"
"そぎ 枌"
"そぎょうれつ 疎行列"
"そく 蔟 熄 惻 喞 仄 塞 促 息 測 捉 束 則 足 側 即 速"
"そくい 測位 即位"
"そくいはん 即違反"
"そくいん 惻隠"
"そくおう 即応"
"そくおん 促音"
"そくかんばい 即完売"
"そくが 側芽"
"そくき 測器"
"そくこん 側根"
"そくさ 側鎖"
"そくさい 息災"
"そくさいばんざた 即裁判沙汰"
"そくざ 即座"
"そくし 即死"
"そくしこう 即施行"
"そくしゃ 速射 即車 速写"
"そくしゃほう 速射砲"
"そくしゅうせい 即修正"
"そくしん 促進"
"そくじ 即時"
"そくじく 側軸"
"そくじっこう 即実行"
"そくじつ 即日"
"そくじょ 息女"
"そくせい 側生 速成 促成"
"そくせき 足跡 即席"
"そくせこう 即施行"
"そくせん 測線 塞栓 側線"
"そくせんりょく 即戦力"
"そくそう 惻愴"
"そくそく 測々 惻惻 促促"
"そくたいばつ 即体罰"
"そくたいほ 即逮捕"
"そくたいほこう 側帯歩行"
"そくたつ 速達"
"そくだく 即諾"
"そくだん 速断 即断"
"そくち 測地 即値"
"そくちゅうせいし 速中性子"
"そくづみ 即詰"
"そくづめ 即詰"
"そくてい 足底 測定"
"そくていし 即停止"
"そくてん 側転 測点"
"そくとう 足刀 側倒 速答 側頭 即答"
"そくとうにゅう 即投入"
"そくとうよう 側頭葉"
"そくど 束度 測度 速度"
"そくどう 側道 速動"
"そくどく 速読"
"そくどけい 速度計"
"そくどば 速度場"
"そくのう 即納"
"そくは 側波"
"そくはく 束帛"
"そくはっしん 速発進"
"そくはつ 即発"
"そくはら 束原"
"そくはん 測範"
"そくはんかい 即販会"
"そくばい 即買 即売"
"そくばいきゃく 即売却"
"そくばいじょ 即売所"
"そくばく 束縛"
"そくばん 測板"
"そくばんこうかん 側板交換"
"そくび 足尾"
"そくぶ 側部"
"そくぶつてき 即物的"
"そくぶん 仄聞"
"そくへき 側壁"
"そくほう 側方 速報"
"そくまく 側膜"
"そくみゃく 側脈"
"そくめつ 熄滅"
"そくめん 側面"
"そくよくせい 側抑制"
"そくりゅう 測流"
"そくりょう 測量"
"そくりょうし 測量士"
"そくりょく 速力"
"そくろ 側路"
"そくろう 足労"
"そくろにゅうろん 側路ニューロン"
"そくろん 束論"
"そくわん 側弯"
"そけっと ソケット"
"そけつごう 疎結合"
"そけん 訴権"
"そげき 狙撃"
"そこ 其所 其処 底"
"そこあげ 底上げ"
"そこいじ 底意地"
"そこいれ 底入れ"
"そこう 遡行 遡航 粗鋼 素行 粗稿"
"そこく 祖国"
"そこじゃり 底砂利"
"そこせんよう 底専用"
"そこち 底地"
"そこぢから 底力"
"そこつ 粗忽"
"そこなし 底なし"
"そこぬけ 底抜け"
"そこね 底値"
"そこびえ 底冷え"
"そこびき 底引 底引き"
"そご 齟齬"
"そさい 蔬菜"
"そさつ 粗擦"
"そざい 素材"
"そざつ 粗雑"
"そし 粗視 素子 阻止"
"そしがや 祖師ヶ谷"
"そしき 素式 組織"
"そしきたい 組織体"
"そしつ 素質"
"そして 然して 而して"
"そしな 粗品"
"そしのう 阻止能"
"そしゃく 咀嚼 租借"
"そしょう 酢漿 粗鬆 訴訟"
"そしょく 粗食"
"そしり 誹り 謗り"
"そじ 素地"
"そじょう 爼上 祖上 俎上 訴状 遡上"
"そすい 疎水"
"そすう 素数"
"そせい 甦生 蘇生 組成 粗製 塑性 素性"
"そせき 礎石"
"そせん 祖先"
"そぜい 租税"
"そそ 楚々 素々 楚楚"
"そそう 楚愴 沮喪 阻喪 粗相"
"そそぎ 曽々木"
"そそん 祖孫"
"そぞう 塑像"
"そぞろ 漫"
"そた 曽田"
"そだ 粗朶 曽田"
"そだい 粗大"
"そだち 育ち"
"そち 埣 措置"
"そちゃ 粗茶"
"そっき 速記 測器"
"そっきしゃ 測機舎"
"そっきゅう 速球"
"そっきょ 測距"
"そっきょう 即興"
"そっきん 即金 側近"
"そっけ 素気"
"そっけつ 即決"
"そっこう 即興 速効 側溝 測光 即効 速攻"
"そっこうじょ 測候所"
"そっこうやく 即効薬"
"そっこく 即刻"
"そっせん 率先"
"そっちゅう 卒中"
"そっちょく 率直 卒直"
"そって 沿って"
"そっとう 卒倒"
"そっぱ 反歯"
"そつ 猝 卆 率 卒"
"そつい 訴追"
"そつう 疏通 疎通"
"そつぎょう 卒業"
"そつけん 卒研"
"そつぶ 卒部"
"そつろん 卒論"
"そてつあこう ソテツ亜綱"
"そてつこう ソテツ綱"
"そてつしだもく ソテツシダ目"
"そてん 素点"
"そで 袖"
"そでがうら 袖ヶ浦"
"そでき 袖木"
"そでぐち 袖口"
"そでぐり 袖刳り"
"そでまく 袖幕"
"そでやま 袖山"
"そでんか 素電荷"
"そと 外"
"そとあし 外足"
"そといた 外板"
"そとう 蘇東 粗糖"
"そとうら 外浦"
"そとかいてん 外回転"
"そとかわ 外皮"
"そとかん 外環"
"そとがけ 外掛け"
"そとがわ 外側"
"そとくぼ 外久保"
"そとこば 外木場"
"そとこまた 外小股"
"そとぜい 外税"
"そとたすきぞり 外襷反り"
"そとづけ 外付 外付け"
"そとづつ 外筒"
"そとで 外出"
"そとば 外刃 率塔婆 率堵婆 卒塔婆 卒都婆"
"そとばき 外履き"
"そとばこ 外箱"
"そとばこいり 外箱入り"
"そとぼう 外房"
"そとぼり 外堀"
"そとま 外間"
"そとまき 外巻"
"そとまわり 外回り"
"そとみ 外見"
"そとむそう 外無双"
"そとめ 外海 外目"
"そとやま 外山"
"そとわく 外枠"
"そどく 素読"
"そなえ 備え 供え"
"そなえつけ 備付 備え付け"
"そなえもの 供物"
"そなた ソナタ"
"そに 曾爾"
"そにちは 疎日派"
"そね 曽祢 埣 曾根 曽根"
"そねおか 曽根岡"
"そねざき 曽根崎"
"そねつ 粗熱"
"その 其の 曾野 瀬能 苑 薗 其 園"
"そのあと その後"
"そのかわ 園川"
"そのかん その間"
"そのぎ 彼杵"
"そのぐち 薗口 園口"
"そのこ 苑子 その子 園子"
"そのころ その頃"
"そのご その後"
"そのた その他"
"そのだ 苑田 園田 薗田"
"そのつき 其月"
"そのて その手"
"そのてん その点"
"そのとき その時"
"そのな その名"
"そののち その後"
"そのば その場"
"そのへん その辺"
"そのべ 園部"
"そのほう その方"
"そのほか その他"
"そのまえ その前"
"そのむら 園村"
"そのやま 園山"
"そはん 組版"
"そはんのう 素反応"
"そば 蕎麦 傍 側"
"そばお 曽場尾"
"そばこ 蕎麦粉"
"そばちゃ 蕎麦茶"
"そばや そば屋"
"そびょう 素描"
"そびょうしゅうなど 素描集等"
"そびょうばんが 素描版画"
"そふ 祖父"
"そふぃあ ソフィア"
"そふえ 祖父江"
"そふけん ソフ研"
"そふと ソフト"
"そふとうぇあ ソフトウェア"
"そふぼ 祖父母"
"そぶえ 祖父江"
"そぶり 素振り"
"そへん 素片"
"そほう 粗放"
"そほうか 素封家"
"そぼ 祖母"
"そぼう 粗暴"
"そぼく 素朴"
"そま 杣"
"そまつ 粗末"
"そまみち 杣道"
"そみつ 粗密 疎密"
"そむく 乖"
"そめ 染"
"そめい 染井"
"そめたろう 染太郎"
"そめち 染地"
"そめのすけ 染乃助"
"そめもの 染物"
"そめや 染谷"
"そや 粗野"
"そよう 蘇陽 素養"
"そよかぜ そよ風"
"そら 空"
"そらいろ 空色"
"そらぞらしい 空々しい"
"そらち 空知"
"そらに 空似"
"そらほうこう 空方向"
"そらみみ 空耳"
"そらみみのおか 空耳の丘"
"そらもよう 空模様"
"そり 轌 艝 橇 反り"
"そりた 返田"
"そりのこし 剃り残し"
"そりまち 反町"
"そりみ 反り身"
"そりゃく 粗略"
"そりゅうし 素粒子"
"そりゅうしばたけ 素粒子畑"
"そりゅうど 粗粒度"
"それ 其"
"それい 租霊"
"それがし 某"
"それぞれ 夫夫 其其 夫々"
"それとなく 其と無く"
"それどころ 其処"
"それゆえ それ故"
"それん 蘇連 ソ連"
"それんへい ソ連兵"
"そろう 疎漏 粗漏"
"そろばん 十露盤 算盤"
"そわ 曽和"
"そん 噂 邨 蹲 拵 忖 孫 尊 遜 村 存 損"
"そんえい 村営"
"そんえき 損益"
"そんかい 村会 損壊"
"そんがい 損害"
"そんがいほしょうせきにん 損害賠償責任"
"そんがん 尊顔"
"そんきょ 蹲踞"
"そんきん 損金"
"そんぐ ソング"
"そんけい 尊敬"
"そんげん 尊厳"
"そんげんし 尊厳死"
"そんこう 損耗"
"そんごくう 孫悟空"
"そんざい ∃ 存在"
"そんざいいしき 存在意義"
"そんし 孫子"
"そんしつ 損失"
"そんしゅ 尊守"
"そんしょう 尊称 損傷"
"そんしょく 遜色"
"そんじゅく 村塾"
"そんぜい 村税"
"そんぞく 尊属 存続"
"そんたく 忖度"
"そんだい 尊大"
"そんち 存置"
"そんちょう 村長 尊重"
"そんてん 尊天"
"そんとく 損得"
"そんどう 村道"
"そんない 村内"
"そんのう 尊王 尊皇"
"そんぱい 存廃"
"そんぴ 村費 存否"
"そんぶ 孫武"
"そんぶん 孫文"
"そんぷ 尊父"
"そんぷうし 村夫子"
"そんぼう 存亡"
"そんぽ 損保"
"そんみん 村民"
"そんもう 損耗"
"そんゆう 村有"
"そんらく 村落"
"そんりつ 村立 存立"
"そんりょう 損料"
"ぞ 曽 曾 祖"
"ぞう 噌 曽 曾 雜 襍 賍 贓 藏 臧 臟 梍 慥 僧 雑 三 憎 増 象 贈 造 臓 蔵 像"
"ぞうあく 増悪"
"ぞういん 増員"
"ぞうえい 造営 造影"
"ぞうえき 増益"
"ぞうえん 造園 増援"
"ぞうお 憎悪"
"ぞうか 造化 造花 増加"
"ぞうかん 増感 増刊"
"ぞうかんし 増感紙"
"ぞうかんすう 像関数"
"ぞうがく 増額"
"ぞうがん 造龕 象眼 象嵌"
"ぞうき 造機 臓器"
"ぞうきばやし 雑木林"
"ぞうきょう 増強"
"ぞうきん 雑巾"
"ぞうけい 造型 造形 造詣"
"ぞうけつ 造血 増結"
"ぞうげ 象牙"
"ぞうげん 増減"
"ぞうご 造語"
"ぞうごん 雑言"
"ぞうさ 雑作 造作"
"ぞうさく 造作 増作"
"ぞうさつ 増刷"
"ぞうさん 増産"
"ぞうざい 造材"
"ぞうし 造詣 増資"
"ぞうしき 雑色"
"ぞうしゅう 贈収 増収"
"ぞうしゅうわい 贈収賄"
"ぞうしょ 蔵書"
"ぞうしょう 蔵相"
"ぞうしょく 増殖 増植"
"ぞうしん 増進"
"ぞうじ 造字 造次"
"ぞうじょうじ 増上寺"
"ぞうじるし 象印"
"ぞうすい 増水 雑炊"
"ぞうせい 増生 増勢 造成"
"ぞうせつ 増設"
"ぞうせつとびら 増設扉"
"ぞうせん 造船"
"ぞうせんじょ 造船所"
"ぞうぜい 増勢 増税"
"ぞうだい 増大"
"ぞうちく 増築"
"ぞうちょう 増長"
"ぞうてい 増訂 贈呈"
"ぞうてん 像点"
"ぞうとう 贈答"
"ぞうどしてい 像度指定"
"ぞうに 雑煮"
"ぞうは 増派"
"ぞうはい 増配"
"ぞうはつ 増発"
"ぞうはん 増版"
"ぞうばい 増倍"
"ぞうばいかん 増倍管"
"ぞうひょうたち 雑兵達"
"ぞうび 増備"
"ぞうびしゃ 増備車"
"ぞうびん 増便"
"ぞうふ 臓腑"
"ぞうふく 増幅"
"ぞうぶつしゅ 造物主"
"ぞうぶん 増分"
"ぞうへい 造幣"
"ぞうほ 増補"
"ぞうほう 増俸"
"ぞうまえ 像前"
"ぞうめんろこうりょう 像面露光量"
"ぞうめんわんきょく 像面湾曲"
"ぞうもつ 臓物"
"ぞうよ 贈与"
"ぞうよぜい 贈与税"
"ぞうり 草履"
"ぞうりょう 増量"
"ぞうりょく 増力"
"ぞうりん 造林"
"ぞうわい 贈賄"
"ぞうわいざい 贈賄罪"
"ぞえ 添"
"ぞく 屬 續 足 束 俗 賊 続 族 属"
"ぞくあく 俗悪"
"ぞくえん 続演"
"ぞくか 俗化"
"ぞくかい 続開 俗界"
"ぞくがら 続柄"
"ぞくぐん 賊軍"
"ぞくご 俗語"
"ぞくし 賊子"
"ぞくしゅう 俗臭"
"ぞくしゅつ 続出"
"ぞくしょう 俗称"
"ぞくしん 続伸"
"ぞくじ 俗字 俗事"
"ぞくじょう 俗情"
"ぞくじん 俗塵 俗人"
"ぞくせい 族生 俗世 属性"
"ぞくせかい 俗世界"
"ぞくせつ 俗説"
"ぞくぞく 続々"
"ぞくとう 続投 続騰"
"ぞくはく 粟帛"
"ぞくはつ 続発"
"ぞくぶつ 俗物"
"ぞくへん 続篇 続編"
"ぞくほう 続報"
"ぞくみょう 俗名"
"ぞくめい 属名"
"ぞくらく 続落"
"ぞくりゅう 粟粒"
"ぞくりょう 属領"
"ぞくろん 続論 俗論"
"ぞっか 俗化"
"ぞっかい 俗界"
"ぞっこう 続行"
"ぞっこく 属国"
"ぞの 薗"
"ぞろめ ゾロ目"
"ぞん 存"
"ぞんがい 存外"
"ぞんじ 存じ 存知"
"ぞんぢ 存知"
"ぞんぶん 存分"
"ぞんめい 存命"
"た 朶 躱 岔 它 咤 侘 佗 詫 夛 汰 詑 太 多 田 他"
"たーげっと ターゲット"
"たーとる タートル"
"たーびん タービン"
"たーぼ ターボ"
"たーみなる ターミナル"
"たーん ターン"
"たあい 他愛"
"たあちゃ 他家"
"たあはい 多牌"
"たい 台 汰 載 碓 タイ 體 駘 颱 頽 靆 隶 軆 躰 褪 紿 玳 滯 抬 擡 帶 對 殆 諦 田井 岱 戴 耐 堆 鯛 黛 貸 腿 胎 苔 太 待 替 怠 逮 滞 他意 泰 代 帯 袋 態 大 退 隊 体 対"
"たいあたり 体当り"
"たいあつ 耐圧"
"たいあん 対案 大安"
"たいあんきちにち 大安吉日"
"たいい 大尉 退位 体位 大意"
"たいいき 大域 帯域"
"たいいく 体育"
"たいいくさい 体育祭"
"たいいち 対一 太一"
"たいいほう 対位法"
"たいいん 隊員 退院"
"たいいんたいようれき 太陰太陽暦"
"たいいんれき 太陰暦"
"たいえい 大栄"
"たいえき 退役 体液"
"たいえん 退園"
"たいおう 對應 対欧 対応"
"たいおうしゃ 対応車"
"たいおうずみ 対応済"
"たいおん 体温"
"たいおんけい 体温計"
"たいか 耐過 袋果 大廈 大厦 大火 対価 滞貨 大化 耐火 大過 大家 退化"
"たいかい 退会 大海 大会"
"たいかいへん 大会篇"
"たいかく 対格 対角 体格"
"たいかざい 耐火材"
"たいかん 対艦 戴冠 耐寒 体幹 体感 退官"
"たいかんきかんちゅう 大会期間中"
"たいかんみんこく 大韓民国"
"たいが 胎芽 大河"
"たいがい 大外 体外 対外 大概"
"たいがいじあい 対外試合"
"たいがく 退学"
"たいがん 大願 対岸"
"たいき 対気 大樹 大器 大気 待機"
"たいきあつ 大気圧"
"たいきけんさいとつにゅう 大気圏再突入"
"たいきこう 大気光"
"たいきしゃ 大氣社"
"たいきゃく 退却"
"たいきゅう 耐久"
"たいきょ 退却 退去 大挙"
"たいきょうよう 胎教用"
"たいきょく 大極 大局 対局 太極 対極"
"たいきょくけん 大極拳 太極拳"
"たいきん 退勤 大金"
"たいきんてつせん 対近鉄戦"
"たいぎ 大儀 大義"
"たいぎご 対義語"
"たいぎょう 怠業"
"たいく 体躯"
"たいくう 滞空 体腔 対空"
"たいくうだん 対空弾"
"たいくつ 退屈"
"たいくつおとこ 退屈男"
"たいくん 大君"
"たいぐ 大愚"
"たいぐう 対偶 待遇"
"たいぐん 大軍 大群"
"たいけい 腿頚 大系 隊型 大慶 体形 体型 体系"
"たいけつ 対決"
"たいけん 大権 大圏 体験"
"たいけんき 体験記"
"たいげん 大言 体言 体現"
"たいげんどめ 体言止め"
"たいこ 大古 鯛子 太鼓 太古"
"たいこう 体育講義 体講 帯鉤 大功 大興 大綱 大公 太閣 退行 対向 対抗"
"たいこうき 太閤記 太閣記"
"たいこうさく 対抗作"
"たいこうしゃ 対行車 対抗車 対向車"
"たいこうしん 対抗心"
"たいこうじあい 対抗試合"
"たいこうせい 耐候性"
"たいこうはんしゃ 対光反射"
"たいこうば 対抗馬"
"たいこうぼう 太公望"
"たいこく 大国"
"たいこばん 太鼓判"
"たいこやき 太鼓焼"
"たいご 隊伍"
"たいさ 大佐 大差"
"たいさいぼう 体細胞"
"たいさく 大作 対策"
"たいさくあん 対策案"
"たいさくひ 対策費"
"たいさなし 大差無"
"たいさん 退散"
"たいざ 胎座 対座"
"たいざい 帯在 大罪 滞在"
"たいざいがたりょこう 滞在型旅行"
"たいざいひ 滞在費"
"たいざん 大山 鯛山 泰山"
"たいし 対し 大師 太子 大志 大使 大史"
"たいした 大した"
"たいしつ 退室 体質"
"たいしどう 大師堂 太子堂"
"たいしぼう 体脂肪"
"たいしゃ 大社 大赦 代謝 退社"
"たいしゃく 帝釈 貸借"
"たいしゃくきょう 帝釈峡"
"たいしゃくてん 帝釈天"
"たいしゅう 大周 大衆 体臭"
"たいしゅうかん 大修館"
"たいしゅつ 体出 退出 貸出"
"たいしょ 大所 大書 大暑 対蹠 対処"
"たいしょあん 対処案"
"たいしょう 代償 大捷 大笑 大勝 隊商 対症 対照 大将 対称 大正 大賞 対象"
"たいしょういけ 大正池"
"たいしょうけい 対称形"
"たいしょうごと 大正琴"
"たいしょうしゃ 対象車"
"たいしょうじく 対称軸"
"たいしょうりつ 対称律"
"たいしょく 褪色 退色 大食 退職"
"たいしょくかん 大食漢"
"たいしょりょうほう 対症療法"
"たいしん 大信 太信 耐震"
"たいじ 胎仔 太地 泰司 泰二 帯磁 対峙 泰次 胎児 退治"
"たいじく 体軸"
"たいじゅ 大樹"
"たいじゅう 体重"
"たいじゅうけい 体重計"
"たいじゅつ 体術"
"たいじゅん 泰淳"
"たいじょう 退場"
"たいじょうかい 帯状回"
"たいじょうじゅん 退場順"
"たいじょうほうしん 帯状疱疹"
"たいじん 大人 泰人 退陣 対人"
"たいすい 耐水"
"たいすう 大数 対数"
"たいすうじく 対数軸"
"たいすうぶん 帯分数"
"たいすけ 泰祐 退助 泰佑 泰介"
"たいする 対する"
"たいずし 鯛鮨"
"たいせい 大政 対生 胎生 体勢 体性 大成 耐性 大勢 態勢 体制"
"たいせいどう 大盛堂"
"たいせいまる 大成丸"
"たいせいよう 大西洋"
"たいせいようがん 大西洋岸"
"たいせき 対蹠 滞積 堆積 退席 体積"
"たいせきがん 堆積岩"
"たいせきじ 大石寺"
"たいせきは 体積波"
"たいせつ 体節 大雪 大切"
"たいせつさ 大切さ"
"たいせん 大戰 対潜 大戦 対戦"
"たいぜん 大全 泰然"
"たいそう 大葬 大喪 体操 大層"
"たいそうふく 体操服"
"たいそしき 体組織"
"たいぞう 退蔵 諦三 大蔵 泰蔵 泰造 大造 泰三 太造"
"たいだ 怠惰"
"たいだん 退団 対談"
"たいち 多一 対置 太一 対地"
"たいちょ 大著"
"たいちょう 退庁 体長 隊長 体調"
"たいちょうかく 対頂角"
"たいちよう 退治用"
"たいちろう 太一郎"
"たいてい 退廷 大帝 大抵"
"たいてき 大敵"
"たいてん 退店"
"たいでん 帯電"
"たいと タイト 泰斗"
"たいとう 帯刀 擡頭 台糖 体当 台頭 台東 対等"
"たいとく 体得"
"たいとる タイトル"
"たいど 態度"
"たいどう 帯同 胎動"
"たいない 隊内 対内 胎内 体内"
"たいにし 対西"
"たいにち 滞日 対日"
"たいにん 大任 退任"
"たいねつ 耐熱"
"たいねつようせっちゃくざい 耐熱用接着剤"
"たいねん 耐年"
"たいのう 怠納 滞納"
"たいは 大破"
"たいはい 頽廢 頽廃 退廃 大敗"
"たいはく 太白"
"たいはくさん 太白山"
"たいはん 大半"
"たいばつ 体罰"
"たいばん 胎盤"
"たいひ 待避 堆肥 対比 退避"
"たいひじょ 待避所 退避所"
"たいひょうめん 体表面"
"たいひょうめんせき 体表面積"
"たいびょう 大病"
"たいぴすと タイピスト"
"たいふ 大夫"
"たいふう 颱風 台風"
"たいぶ 体部 大部 退部"
"たいぶつ 対物"
"たいぶん 大分"
"たいぶんすう 帯分数"
"たいぷ タイプ"
"たいへい 大平 泰平 太平"
"たいへいき 大平記 太平記"
"たいへいざん 太平山"
"たいへいよう 太平洋"
"たいへん 対辺 大変"
"たいべい 滞米 対米"
"たいべつ 大別"
"たいぺい 台北"
"たいほ 退歩 逮捕"
"たいほう 大鵬 大豊 大峰 大砲"
"たいほく 台北"
"たいぼう 大望 耐乏 待望"
"たいぼく 大木"
"たいま 当麻 タイマ 大麻"
"たいまー タイマー"
"たいまい 玳瑁 大枚"
"たいまつ 松明"
"たいまん 怠慢"
"たいみんぐ タイミング"
"たいむ タイム"
"たいめい 岱明"
"たいめいがっき 体鳴楽器"
"たいめし 鯛飯"
"たいめん 泰緬 体面 対面"
"たいもう 大網 大望 体毛"
"たいや タイヤ"
"たいやく 大役 対訳"
"たいゆう 大雄 大邑 大勇"
"たいよ 貸与"
"たいよう 太洋 大陽 耐用 大洋 太陽 大要"
"たいようけいしょうてんたい 太陽系小天体"
"たいようこう 太陽光"
"たいようこうさいにゅうまど 太陽光採入窓"
"たいようしゅう 大洋州"
"たいようしん 太陽神"
"たいようせいもうまくえん 太陽性網膜炎"
"たいようせん 大洋戦"
"たいようねつ 太陽熱"
"たいようれき 太陽暦"
"たいら 平"
"たいらけいりんじょう 平競輪場"
"たいらのきよもり 平清盛"
"たいり 大利"
"たいりく 大陸"
"たいりくさん 大陸産"
"たいりくだな 大陸棚"
"たいりつ 対立"
"たいりゃく 大略"
"たいりゅう 滞留 対流"
"たいりょう 大漁 退寮 大量"
"たいりょく 体力"
"たいりん 大輪"
"たいる タイル"
"たいれい 胎齢"
"たいれつ 隊列"
"たいろ 退路"
"たいろん 対論"
"たいわ 対和 大和 対話"
"たいわへん 対話篇"
"たいわん 台湾"
"たいわんさん 台湾産"
"たう τ Τ 多雨"
"たうえ 田上 田植え"
"たうち 田内"
"たうら 田浦"
"たうん タウン"
"たえ 栲 妙"
"たえこ 多恵子 妙子"
"たえず 絶えず"
"たえだえ 絶え絶え"
"たえま 絶え間 絶えま"
"たお 嵶 垰 田尾"
"たおか 田岡"
"たおやめ 手弱女"
"たおる タオル"
"たか 任 嵩 崇 臣 尚 敬 尭 宇 孚 多寡 多価 亨 孝 貴 鷹 隆 高"
"たかあき 学聡 貴章 孝明 貴昭 隆明"
"たかい 他界 高井"
"たかいし 高石"
"たかいずみ 高泉"
"たかいち 隆一 高市"
"たかいど 高井戸"
"たかいびき 高鼾"
"たかうじ 尊氏"
"たかうち 高内"
"たかえだ 高枝"
"たかお 貴夫 貴生 貴朗 崇夫 孝雄 孝男 貴雄 隆雄 孚夫 高夫 高雄 孝夫 隆男 尚夫 隆夫 貴男 高尾"
"たかおか 高岳 高岡 高丘"
"たかおさん 高尾山"
"たかおさんぐち 高尾山口"
"たかおざん 高尾山"
"たかおの 高尾野"
"たかか 多花果"
"たかかげ 隆景"
"たかかず 剛和 剛一"
"たかかわ 高河"
"たかがみね 鷹峯"
"たかき 孝紀 高来 高木 高樹"
"たかぎ 喬木 高来 鷹木 高城 高樹 高木"
"たかぎあきみつ 高木彬光"
"たかぎし 高岸"
"たかぎわ 高際"
"たかく 多角 高久"
"たかくら 高蔵 高倉"
"たかくらけん 高倉健"
"たかくわ 高桑 高鍬"
"たかこ 隆子 堂子 高子 多賀子 敬子 多香子 孝子 貴子"
"たかこう 高高"
"たかさ 高さ"
"たかさか 高坂"
"たかさき 高崎"
"たかさきはまがわ 高崎浜川"
"たかさご 高砂"
"たかさと 高郷"
"たかさわ 高澤 高沢"
"たかざわ 高沢"
"たかし 高司 貴士 隆資 卓 高師 大 崇史 崇 高 降 洪 貴司 岳史 高史 尚志 尚司 隆史 尚 高士 孝志 孝史 孝司 敬史 敬 恭士 貴 隆司 敬士 隆志 貴志 卓史 孝 隆 喬 高志 尚史 貴史"
"たかしお 高汐 高潮"
"たかしな 高科 高品"
"たかしま 鷹島 高島 高嶋"
"たかしまだいら 高島平"
"たかしみず 高清水"
"たかしろ 鷹城"
"たかじょう 高城"
"たかす 鷹栖 高鷲 高須"
"たかすが 高須賀"
"たかすぎ 高杉"
"たかすみ 高住"
"たかずみ 敬済"
"たかせ 高瀬"
"たかた 田方 高田"
"たかだ 高田"
"たかだい 高台"
"たかだか 高々"
"たかだて 高館"
"たかだま 高玉"
"たかちほ 高千穂"
"たかちほきょう 高千穂峡 高千穂峽"
"たかっけい 多角形"
"たかつ 高津"
"たかつか 高塚"
"たかつき 高月 高槻"
"たかつぐ 高嗣"
"たかとう 高藤 高遠"
"たかとうりき 貴闘力"
"たかとし 孝寿 隆利 孝利 隆俊 孝俊"
"たかとび 高飛び"
"たかとみ 高富 孝富"
"たかとも 鷹友"
"たかとり 高鳥 高取"
"たかとりこうじょう 鷹取工場"
"たかどの 楼"
"たかな 高菜"
"たかなお 高直 高尚"
"たかなか 高中"
"たかなし 高梨"
"たかなべ 高鍋"
"たかなみ 高浪 高波"
"たかなわ 高輪"
"たかなわぐち 高輪口"
"たかに 高荷"
"たかね 高根 高嶺 高値"
"たかねざわ 高根沢"
"たかの 鷹野 高乃 高野"
"たかのす 鷹巣"
"たかのぞみ 高望み"
"たかのつめ 鷹の爪"
"たかのは 鷹羽"
"たかのはな 貴ノ花"
"たかのはら 高の原"
"たかのばし タカノ橋"
"たかのふじ 孝乃富士"
"たかのぶ 孝信 敬信"
"たかのり 崇徳 孝典 孝規 敬則 隆典 孝憲 隆則 孝徳 孝則 高徳"
"たかは 高羽"
"たかはぎ 高萩"
"たかはし 高梁 高橋"
"たかはしみちつな 高橋三千綱"
"たかはた 高畠 高畑"
"たかはたふどう 高幡不動"
"たかはな 高鼻"
"たかはなだ 貴花田"
"たかはなだぜき 貴花田関"
"たかはま 高濱 高浜"
"たかはら 高原"
"たかはる 高春 高原"
"たかばたけ 高畠"
"たかばやし 高林"
"たかひこ 高彦 隆彦 貴彦 孝彦"
"たかひさ 隆久 高尚 貴久"
"たかひで 貴英"
"たかひと 貴仁 隆人 隆仁"
"たかひら 高平 高比良"
"たかひろ 孝洋 貴大 高裕 孝宏 隆浩 隆啓 貴宏 隆広 隆宏 隆寛 崇博 孝浩 貴浩 隆博 高広 敬弘 貴裕 貴広 孝広 隆弘 貴博 高宏"
"たかびしゃ 高飛車"
"たかふみ 隆史 孝史 貴史 孝文 隆文 貴文"
"たかべ 高部"
"たかまがはら 高天原"
"たかまさ 孝昌 隆征 隆政 高政"
"たかまつ 高松"
"たかまつこう 高松港"
"たかまつしょう 高松商"
"たかまつのみやはい 高松宮盃 高松宮杯"
"たかまのはら 高天原"
"たかまる 鷹丸"
"たかみ 孝美 高見"
"たかみさわ 高見沢"
"たかみざわ 高見沢"
"たかみす 高見州"
"たかみすぎ 隆三杉"
"たかみち 孝通 隆道 尊道"
"たかみつ 隆充 貴光"
"たかみね 高嶺 嵩嶺 高峰"
"たかみや 高宮"
"たかむしろ 簟"
"たかむね 高宗"
"たかむら 篁 高村"
"たかめ 高目"
"たかもと 高本"
"たかもり 鷹森 隆盛 高森"
"たかや 隆弥 高谷 隆也"
"たかやす 高安 貴康"
"たかやなぎ 高柳"
"たかやま 鷹山 高山"
"たかゆかしきえきしゃ 高床式駅舎"
"たかゆき 貴幸 敬之 隆幸 能之 崇之 孝幸 隆之 孝行 高行 貴之 孝之 隆行 高之"
"たかよし 高良 高好 孝允 貴良 隆義 隆克 隆吉 孝義"
"たから 財 寳 寶 宝"
"たからがいけ 宝が池"
"たからくじ 宝くじ"
"たからしゅぞう 寳酒造 宝酒造"
"たからじま 宝島"
"たからずか 宝塚"
"たからずかきねんば 宝塚記念馬"
"たからずかだいげきじょう 宝塚大劇場"
"たからだ 宝田"
"たからだま 宝玉"
"たからづか 宝塚"
"たからづかきねんば 宝塚記念馬"
"たからづかだいげきじょう 宝塚大劇場"
"たからばこ 宝箱"
"たからぶね 宝船"
"たからべ 財部"
"たからまち 宝町"
"たからもの 宝物"
"たかん 多環 多感"
"たが 箍 多賀"
"たがい 互 違い 互い"
"たがいに 互いに"
"たがき 田垣"
"たがぎ 高木"
"たがく 多額"
"たがた 田方"
"たがね 鏨"
"たがひ 互 違ひ"
"たがみ 田上"
"たがや 多賀谷"
"たがりゅう 多賀竜"
"たがわ 田河 多川 田川"
"たがん 多眼"
"たき 多肢 多喜 瀑 竜 多紀 多岐 瀧 滝"
"たきい 滝井"
"たきうち 滝内 瀧内"
"たきお 多喜夫 滝尾"
"たきかわ 瀧川 滝川"
"たきがわ 瀧川 滝川"
"たきぎ 薪"
"たきぐち 滝口 瀧口"
"たきさわ 滝沢 滝澤"
"たきざわ 瀧沢 滝澤 滝沢"
"たきしーど タキシード"
"たきた 瀧田 滝田"
"たきだ 瀧田"
"たきだし 炊き出し 炊出し"
"たきつぼ 滝壷"
"たきなみ 滝波"
"たきね 滝根"
"たきの 滝野 瀧野 多喜乃"
"たきはら 滝原"
"たきび 焚き火 焚火"
"たきもと 瀧本 滝本"
"たきや 滝谷"
"たきやま 滝山 瀧山"
"たきゅう 田久"
"たきょう 田京 他郷"
"たきょく 多極 他局"
"たきれんたろう 滝廉太郎"
"たぎ 多義"
"たぎょう タ行"
"たぎり 田切"
"たく 擢 柘 魄 鈬 謫 柝 擇 拆 戳 啅 倬 澤 托 啄 択 鐸 卓 琢 沢 拓 託 宅 濯"
"たくあき 卓明"
"たくあん 沢庵"
"たくい 宅井"
"たくいつ 択一"
"たくえつ 卓越"
"たくお 卓夫 拓雄 卓雄"
"たくき 琢己"
"たくけい 磔刑"
"たくさん 沢山"
"たくし 拓志 卓史"
"たくしー タクシー"
"たくしゅつ 卓出"
"たくしょく 拓殖"
"たくしろう 卓四郎"
"たくじ 琢爾 拓史 卓司 託児 卓治"
"たくじしょけん 託児所券"
"たくじじょ 託児所"
"たくじょう 卓上"
"たくせつ 卓説"
"たくせん 託宣"
"たくぜつ 卓絶"
"たくそう 拓宋 託送"
"たくぞう 卓三 卓造"
"たくだいいちこう 拓大一高"
"たくち 宅地"
"たくちなみかぜい 宅地並課税"
"たくと 琢人"
"たくないよう 宅内用"
"たくはい 宅配"
"たくはつ 托鉢"
"たくほん 拓本"
"たくぼ 田久保 田窪"
"たくぼく 啄木"
"たくま 詫間 託間 琢磨 宅間"
"たくみ 巧 琢巳 卓己 琢美 拓美 内匠 匠"
"たくや 卓哉 拓哉 琢也 拓也 卓弥 卓也"
"たくよう 托葉"
"たくら 田倉"
"たくろう 拓郎 卓朗"
"たくわえ 貯え 蓄え"
"たぐい 畴 疇 類い 類"
"たぐす 田楠"
"たぐち 田口"
"たぐり 田栗"
"たぐん 多群"
"たけ 嶽 雄 斌 毅 他家 威 岳 健 丈 武 茸 竹"
"たけい 竹居 竹井 多形 武井 武居"
"たけいし 武石"
"たけいち 竹市 武一 武市"
"たけうち 武内 竹内"
"たけうま 竹馬"
"たけお 武朗 健生 丈生 健郎 毅雄 武夫 武男 竹雄 竹夫 竹尾 竹男 竹生 丈夫 健夫 岳生 威雄 岳男 武雄"
"たけおか 竹岡"
"たけおかせん 竹岡戦"
"たけかず 丈和"
"たけかわ 竹川 武川"
"たけかんむり 竹冠"
"たけがた 竹形"
"たけがはら 竹ヶ原"
"たけがり 茸狩"
"たけき 健樹"
"たけくに 武邦"
"たけぐち 竹口"
"たけこし 竹腰"
"たけさか 竹坂"
"たけざわ 竹沢"
"たけし 豪 武石 剛志 武士 岳 英 威志 武嗣 竹志 健史 武史 剛史 岳史 武司 剛 健志 健 武 威 丈司 毅 武志 猛"
"たけした 竹下"
"たけしたのぼる 竹下登"
"たけしば 竹芝"
"たけしま 竹島"
"たけしょぼう 竹書房"
"たけじ 武治"
"たけじろう 竹次郎"
"たけすえ 武居"
"たけぞえ 竹添"
"たけぞの 竹園"
"たけた 竹田"
"たけたに 竹谷"
"たけだ 竹田 武田"
"たけだけしい 猛々しい"
"たけち 武市 武智"
"たけつぐ 健嗣"
"たけと 竹人 岳人 丈人 健人"
"たけとし 武俊"
"たけとみ 竹富 武富"
"たけとみじま 竹富島"
"たけとも 斌友"
"たけとよ 武豊"
"たけとりものがたり 竹取物語"
"たけなお 武直"
"たけなか 武中 竹中"
"たけなみ 竹並"
"たけなり 雄成 丈成"
"たけなわ 闌 酣 武縄"
"たけの 武野 竹野"
"たけのこ 笋 筍 竹の子"
"たけのはま 竹野浜"
"たけのぶ 武信 健伸"
"たけのり 武憲 健雅"
"たけはし 竹橋"
"たけはな 竹花"
"たけはら 武原 竹原"
"たけはる 毅治 丈晴"
"たけばし 竹箸 竹橋"
"たけばやし 竹林"
"たけひこ 剛彦 建彦 雄彦 竹彦 武彦"
"たけひご 竹籤"
"たけひさ 武久 竹久"
"たけひで 武秀 武英"
"たけひと 雄人 武人 武仁"
"たけひら 竹平"
"たけひろ 武裕 武大 竹広 威博 威裕 雄洋"
"たけふ 竹生 武生"
"たけぶえ 竹笛"
"たけべ 建部 武部 竹部"
"たけぼうき 竹箒"
"たけみ 武見 武三"
"たけみつ 竹光 武満"
"たけみや 竹宮 武宮"
"たけむら 武村 竹村"
"たけもち 威望"
"たけもと 武本 竹本"
"たけもり 竹森"
"たけや 竹屋 武谷"
"たけやぶ 竹薮"
"たけやま 竹山 武山"
"たけやり 武鑓 竹槍"
"たけゆき 岳之 健幸"
"たけよし 建美 武吉"
"たけん 他県"
"たげい 多芸"
"たげん 他言 多言 多元"
"たこ 多古 鱆 胼胝 胝 鮹 凧 蛸"
"たこう 多項 多孔 多幸 他校"
"たこうしつ 多孔質"
"たこうしつざい 多孔質材"
"たこく 他国"
"たこくせきぐん 多国籍軍"
"たこじま 蛸島"
"たこのきもく タコノキ目"
"たこやき 蛸焼"
"たご 多語 多胡 多湖 田子"
"たごのうら 田子の浦"
"たごん 他言"
"たさい 多才 多彩"
"たさいぼうもう 多細胞毛"
"たさか 田坂"
"たさつ 他殺"
"たさん 多産"
"たざき 田崎"
"たざけ 田酒"
"たざわ 田沢 田澤"
"たざわこ 田沢湖"
"たざわぬま 田沢沼"
"たざん 他山"
"たし 他誌 他紙 多肢 足し"
"たしか 確か"
"たしかに 確かに"
"たしこむ 足し込む"
"たしざん 足算 足し算"
"たしせいせい 多士済済"
"たしつ 咤叱 多湿"
"たしま 田嶋"
"たしゃ 多謝 他車 他者 他社"
"たしゃく 他借"
"たしゅ 他種 多種"
"たしゅう 他州"
"たしゅつ 他出"
"たしょ 他諸 他書 他所"
"たしょう 多生 多祥 他称 多少"
"たしょうなん 多少難"
"たしょく 多色"
"たしょくずり 多色刷 他色刷"
"たしろ 田代"
"たしん 多芯"
"たじ 多事 他事"
"たじか 田近"
"たじつ 他日"
"たじま 田嶌 但馬 田嶋 田島"
"たじみ 多治見"
"たじゅう 多重"
"たじゅうこ 多重呼"
"たじゅうは 多重波"
"たじょう 多情"
"たじり 田尻"
"たじん 多人"
"たす ＋ 足す"
"たすう 多数"
"たすうけつ 多数決"
"たすうとう 多数党"
"たすき 襷"
"たすきがけ 襷掛け"
"たすきぞり 襷反り"
"たすく 相 匡"
"たすけ 多助 太助 助け"
"たすけあい 助け合い"
"たせん 他薦"
"たぜい 多勢"
"たそーと 多ソート"
"たそう 多層 多相"
"たそうこうぞうなべ 多層構造鍋"
"たそうなべ 多層鍋"
"たそがれ 黄昏"
"たそく 多足"
"たぞえ 田添"
"たた 多々"
"たたい 田々井 田多井 多態 多体"
"たたいた 多対多"
"たたかい 戦い"
"たたき 三和土"
"たたきあげ 叩き上げ"
"たたきだい 叩き台"
"たたすく 他タスク"
"たたど 多々戸"
"たたに 田谷"
"たたません 田玉線"
"たたみ 疂 疉 畳 疊"
"たたみこみ 畳み込み"
"たたみじき 畳敷"
"たたみはんぶん 畳半分"
"たたみべや 畳部屋"
"たたみま 畳間"
"たたら 蹈鞴 多田羅 多々良"
"たたり 祟"
"たたん 多端 他端"
"ただ 無料 匡 維 但 惟 正 忠 唯 只 多田"
"ただあき 忠明 理顕"
"ただい 他大 多大"
"ただいま 唯今 ただ今 只今"
"ただお 維男 忠雄 忠夫 忠男"
"ただおか 忠岡"
"ただおき 忠興"
"ただき 但木 只木"
"ただくま 只熊"
"ただけん 只券"
"ただごと 唯事"
"ただし 禎 惟史 理 忠史 匡 尚志 貞 直 忠志 忠司 忠 匡史 正 但し"
"ただしがき 但書"
"ただしく 正しく"
"ただす 匡"
"ただせん 太多線"
"ただたか 匡孝"
"ただち 直"
"ただちに 直ちに"
"ただとし 正利 忠利"
"ただなか 只中"
"ただの 唯野 只野"
"ただのぶ 忠信"
"ただのり 匡孝 忠則"
"ただはる 忠治"
"ただひこ 忠彦"
"ただひさ 正久"
"ただひとつ 唯一つ"
"ただひとり 唯一人"
"ただひら 忠平"
"ただひろ 忠広 忠博 忠弘 忠浩 忠宏"
"ただふみ 能文 忠文"
"ただまさ 忠正"
"ただみ 只見線 只見"
"ただみち 直道"
"ただもと 忠元"
"ただもの 只者"
"ただゆき 忠行"
"ただよし 忠儀 忠良 忠央 忠義"
"ただわか 唯若"
"ただん 多段"
"たち 城 質 性質 逹 館 太刀 多値 舘 立 達"
"たちあい 立ち合い 立会 立ち会い 立合"
"たちあがり 立上り 立ち上がり"
"たちあげ 立ち上げ"
"たちい 起ち居 立居 立ち居"
"たちいり 立入 立入る 立ち入り"
"たちうお 太刀魚"
"たちうち 太刀打ち"
"たちうり 立売"
"たちおうじょう 立ち往生 立往生"
"たちかけ 太刃掛 太刀掛"
"たちかわ 立川"
"たちがみ 舘上"
"たちき 立木"
"たちぎ 立木"
"たちぎえ 立ち消え"
"たちぎき 立ち聞き"
"たちぐい 立ち食い"
"たちぐいそば 立ち食いそば"
"たちさがり 立ち下がり"
"たちざわ 立澤"
"たちせきじょうしゃ 立席乗車"
"たちせきとっきゅうけん 立席特急券"
"たちはら 立原"
"たちば 立場"
"たちばな 立花 橘"
"たちばなし 立ち話"
"たちばなわん 橘湾"
"たちひ 立飛"
"たちまち 怱ち 忽 立待ち 立町"
"たちみ 立見 立ち見"
"たちみけん 立見券"
"たちみせき 立見席"
"たちもり 館盛"
"たちや 達谷"
"たちやく 立役"
"たちよみ 立読み"
"たちより 立ち寄り"
"たっかん 達観"
"たっきゅう 宅急 卓球"
"たっけい 磔刑"
"たっけん 宅建 卓見"
"たっけんぎょう 宅建業"
"たっし 達し"
"たっしゃ 達者"
"たっせい 達成"
"たった 立田"
"たっち タッチ"
"たっちゅう 塔頭"
"たっぴ 竜飛"
"たっぴつ 達筆"
"たっぴみさき 竜飛岬"
"たつ 斬 韃 闥 燵 撻 逹 竜 立 龍 辰 達"
"たつあき 達明"
"たついち 辰一"
"たつお 達郎 竜生 龍夫 龍男 立雄 竜雄 竜夫 辰雄 辰夫 辰男 達雄 達男 龍雄 達夫"
"たつおか 立岡 竜岡 龍岡"
"たつおかもん 龍岡門 竜岡門"
"たつかわ 立川 達川"
"たつき 立木"
"たつきち 辰吉"
"たつきよ 達清"
"たつくち 辰口"
"たつぐち 辰口"
"たつごう 竜郷"
"たつし 達史 辰史 達志"
"たつしま 立嶋"
"たつじ 辰二 辰司 達治 龍司 達司"
"たつじん 達人"
"たつた 立田 龍田"
"たつたあげ 竜田揚げ"
"たつたか 辰敬"
"たつとし 達俊 達利"
"たつどし 辰年"
"たつなみ 立浪"
"たつなり 達就"
"たつにしき 龍錦"
"たつの 辰野 龍野 竜野"
"たつのくち 竜ノ口 辰口"
"たつのにし 竜野西"
"たつのり 達徳 辰徳 達就 辰則"
"たつひこ 龍彦 達彦"
"たつひろ 達弘"
"たつぶん 達文"
"たつま 竜馬"
"たつまき 竜巻"
"たつみ 竜実 辰己 辰巳 辰爾 立見 巽"
"たつや 立哉 辰也 辰哉 達哉 立矢 竜也 龍也 達也"
"たつやま 竜山 龍山"
"たつゆき 達之 達行"
"たつるはま 田鶴浜"
"たつろう 達朗 達郎"
"たつんど 達人"
"たづこ 田鶴子"
"たづな 覊 手綱"
"たて 殺陣 蓼 縱 ┃ 建 楯 館 舘 盾 │ 竪 立 縦"
"たてあき 賢明"
"たていし 建石 立石"
"たていち 縦位置"
"たていちれつ 縦一列"
"たていと 經 縦糸"
"たていわ 館岩"
"たてうち 舘内 館内"
"たてうま 立馬"
"たてうり 建売り"
"たてお 建郎 建夫"
"たておか 楯岡"
"たておき 縦置"
"たてかえ 立替"
"たてかた 立て方"
"たてかわ 立川"
"たてかん 立て看 立看"
"たてかんばん 立看板"
"たてがき 縦書き"
"たてがた 縦型"
"たてがたしんごう 縦形信号"
"たてがみ 鬣"
"たてがめん 縦画面"
"たてき 建樹"
"たてぎょうじ 立行司"
"たてぐ 建具"
"たてけい 縦系"
"たてけいしき 縦形式"
"たてこう 竪坑"
"たてこし 館腰"
"たてごと 竪琴"
"たてさわ 立澤"
"たてしな 立科 蓼科"
"たてじく 縦軸"
"たてじま 縦縞"
"たてじょう 楯状"
"たてじょうよう 楯状葉"
"たてすじ 縦筋"
"たてせん ｜ 縦線"
"たてつけ 建付 立付け"
"たてつぼ 建坪"
"たてなが 縦長"
"たてなみ 縦波"
"たての 舘野 館野 立野"
"たてはば 縦幅"
"たてはら 立原"
"たてばい 縦倍"
"たてばいかく 縦倍角"
"たてばやし 館林"
"たてひこ 建彦"
"たてふ 縦歩"
"たてふだ 立て札 立札"
"たてぶえ 縦笛"
"たてべ 建部"
"たてほうこう 縦方向"
"たてほり 縦堀"
"たてぼう 縦棒"
"たてまえ 立前 建前"
"たてまさ 建正"
"たてまし 建て増し 建増し"
"たてまつ 立松"
"たてむら 舘村"
"たてめ 縦目"
"たてもの 建物"
"たてもよう 縦模様"
"たてや 建屋"
"たてやくしゃ 立役者"
"たてやま 楯山 館山 立山"
"たてやまでらおんせん 舘山寺温泉"
"たてやまわん 館山湾"
"たてよこ 縦横"
"たてわき 帯刀"
"たてわり 縦割り"
"たてわりぎょうせい 縦割行政"
"たてん 他店 多点"
"たで 蓼"
"たでか タデ科"
"たでもく タデ目"
"たとうしょうめい 多灯照明"
"たとうはっこう 多灯発光"
"たとえ 譬え 喩え 例え"
"たとえば 例えば"
"たとえばなし 例え話"
"たとへば 例へば"
"たとみ 田富"
"たど 多度"
"たどころ 田所"
"たどつ 多度津"
"たどん 炭団"
"たな 店 柵 棚"
"たなあげ 棚上げ"
"たないた 棚板"
"たなうえ 棚上"
"たなえ 田苗"
"たなおろし 棚卸し"
"たなおろししさん たな卸資産"
"たなか 田仲 田中"
"たなかきぬよ 田中絹代"
"たなかだて 田中館"
"たなき 棚木"
"たなくら 棚倉"
"たなぐら 棚倉"
"たなこ 店子"
"たなごころ 掌"
"たなざわ 棚沢"
"たなし 田無"
"たなだ 棚田"
"たなはし 棚橋"
"たなばた 七夕"
"たなべ 田邉 田辺"
"たなみ 棚見"
"たなん 多難"
"たに 溪 渓 谷"
"たにあし 谷脚"
"たにあしかじゅう 谷足加重"
"たにい 溪井 谷井"
"たにうち 谷内"
"たにえ 谷江"
"たにえき 谷駅"
"たにおおつか 谷大塚"
"たにおか 谷岡"
"たにかわ 谷川"
"たにがき 谷垣"
"たにがみ 谷上"
"たにがわ 谿 谷側 谷川"
"たにく 多肉"
"たにくけい 多肉茎"
"たにくふじつかちょう 谷区藤塚町"
"たにぐち 谷口"
"たにぐみ 谷汲"
"たにざき 谷崎"
"たにざわ 谷沢"
"たにし 田螺"
"たにしげ 谷繁"
"たにじま 谷島"
"たにすじ 谷筋"
"たにせ 谷瀬"
"たにぞこ 谷底"
"たにた 谷田"
"たにだ 谷田"
"たにはら 谷原"
"たにま 渓間 谷間"
"たにまち 谷町"
"たにまちきゅうちょうめ 谷町九丁目"
"たにむら 谷村"
"たにもと 谷本"
"たにやま 谷山"
"たにわき 谷脇"
"たにん 他人"
"たにんごと 他人事"
"たにんどん 他人丼"
"たぬき 貍 田貫 狸"
"たぬきおしょう 狸和尚"
"たぬきこうじ 狸小路"
"たぬきざか 狸坂"
"たぬきじる 狸汁"
"たぬま 田沼"
"たね 胤 多根 種子 種"
"たねあかし 種明し"
"たねあき 種明"
"たねいち 種市"
"たねうし 種牛"
"たねうま 種馬"
"たねおみ 種臣"
"たねがしま 種子島"
"たねぎれ 種切れ"
"たねつけりょう 種付料"
"たねとし 種敏"
"たねび 種火"
"たねほん 種本"
"たねまき 種蒔き 種まき"
"たねむら 種村"
"たねん 多年"
"たねんそう 多年草"
"たの 他の 田野 多野"
"たのう 多能"
"たのうえ 田上"
"たのうら 田浦"
"たのしさ 愉しさ"
"たのしそう 楽しそう"
"たのしみ 愉しみ 楽しみ"
"たのなか 田野中"
"たのはた 田野畑"
"たはた 田畑"
"たはつ 多発"
"たはら 田原"
"たば 他馬 田場 束"
"たばい 多売"
"たばこ 莨 タバコ 煙草"
"たばた 太幡 田端 田畑"
"たばやま 丹波山"
"たばら 田原"
"たばる 田原"
"たばるざか 田原坂"
"たひら 田平"
"たび 足袋 旅 度"
"たびげいにん 旅芸人"
"たびさき 旅先"
"たびじ 旅路"
"たびたび 度々"
"たびだち 旅立ち"
"たびびと 旅人"
"たびら 田平"
"たふ 佗負"
"たぶ 他部 椨 タブ"
"たぶー タブー"
"たぶせ 田布施"
"たぶち 田淵 田渕"
"たぶふ タブ譜"
"たぶん 多聞 他聞 多分"
"たぶんわたし 多分私"
"たべ 田部 多辺"
"たべかた 食べ方"
"たべのこし 食べ残し"
"たべほうだい 食べ放題"
"たべもの 食物 食べ物"
"たべん 多弁"
"たほう 多峰 他方"
"たぼ 髱"
"たぼう 多忙"
"たま 靈 霊 彈 田万 珪 珠 球 弾 多摩 玉"
"たまい 玉井"
"たまいれ 玉入れ"
"たまえ 玉恵"
"たまお 玉緒"
"たまおき 玉置"
"たまかし 玉柏"
"たまかしき 玉貸機"
"たまかず 玉数"
"たまかわ 玉川"
"たまがわ 玉川"
"たまがわぐち 玉川口"
"たまがわさきこ 玉川沙巳子"
"たまがわだいこう 玉川大工"
"たまき 玉城 玉置 環 玉木"
"たまぐすく 玉城"
"たまこし 玉越"
"たまご 玉子 卵"
"たまごがた 卵型"
"たまごやき 卵焼き 卵焼"
"たまごりょうり 卵料理"
"たまさと 玉里"
"たまさぶろう 玉三郎"
"たましい 魂"
"たましま 玉島"
"たまじゃり 玉砂利"
"たますじ 球筋 玉筋"
"たまたいしょう 玉大賞"
"たまたま 偶 偶々"
"たまだ 玉田"
"たまち 田町"
"たまつき 玉突 玉突き"
"たまつくり 玉造"
"たまつつみ 玉堤"
"たまてばこ 玉手箱"
"たまな 玉名"
"たまなわ 玉那覇 玉縄"
"たまねぎ タマネギ 玉葱"
"たまの 玉野"
"たまのうら 玉之浦"
"たまのお 玉の緒"
"たまのこし 玉の輿"
"たまはら 玉原"
"たまひめ 玉姫"
"たまほ 玉穂"
"たまほり 玉堀"
"たままき 玉牧"
"たまみ 珠美"
"たまむし 玉虫"
"たまむら 玉村"
"たまもと 玉本"
"たまもの 賚 賜 賜物"
"たまや 玉屋"
"たまやま 玉山"
"たまゆ 玉湯"
"たまよ たま代 多満代"
"たまり 玉里 澑 溜 玉利"
"たまる 田丸"
"たみ 多美 民"
"たみあき 民朗"
"たみえ 民江"
"たみお 民夫 民雄 民男"
"たみおか 民岡"
"たみき 民喜"
"たみくさ 民草"
"たみこ たみ子"
"たみや 田宮"
"たむら 田邑 田村"
"たむろ 屯"
"ため 爲 澑 溜 為"
"ためいき 溜め息 ため息 溜息"
"ためいけ 溜池 溜め池"
"ためうち 溜め撃ち"
"ためきよ 為清"
"ためぐち タメ口"
"ためし 樣 例 試し"
"ためしげ 爲成"
"ためす 試す"
"ためひろ 為広"
"ためん 他面 多面"
"たも 玉網"
"たもつ 保"
"たもと 袂 田本"
"たもやちだけ 田茂谷地岳"
"たもり 田守 田森 タモリ"
"たもん 大紋 多聞"
"たや 多屋 田谷"
"たやま 田山"
"たゆ 斬"
"たゆう 大輔 大夫 太夫"
"たよう 多用 多様"
"たようたい 多様体"
"たより 便り"
"たら 太良 鰔 膤 鱈"
"たらい 盥"
"たらぎ 多良木"
"たらこ 鱈子"
"たらじる 鱈汁"
"たらま 多良間"
"たらみ 多良見"
"たりき 他力"
"たりつ 他律"
"たりょう 多量"
"たる 樽"
"たるい 垂井"
"たるがた 樽型"
"たるき 榱 椽"
"たるなま 樽生"
"たるほ 足穂"
"たるみ 弛み 垂水"
"たるみず 垂水"
"たれ 誰 垂れ"
"たれいしき 他励式"
"たれつ 多列"
"たれつき タレ付き"
"たれまく 垂れ幕 垂幕"
"たれみず 垂水"
"たれんと タレント"
"たろう 田老 多郎 太良 太朗 太郎"
"たわ 嵶"
"たわー タワー"
"たわい 他愛"
"たわごと 戯言"
"たわし 束子"
"たわだいら 多和平"
"たわむれ 戯"
"たわら 太原 田原 俵"
"たわらまち 俵万智"
"たわらまちおおくさ 田原町大草"
"たん 椴 但 檀 餤 靼 酖 鄲 賺 譚 覃 褝 襌 袒 膽 緞 站 眈 痰 猯 澹 潭 湍 毯 殫 槫 攤 摶 擔 憺 憚 慱 彖 單 啗 啖 亶 疸 嘆 歎 湛 箪 坦 耽 蛋 炭 胆 担 綻 探 丹 鍛 淡 反 誕 旦 端 短 単"
"たんあな 単穴"
"たんい 単為 單位 単位"
"たんいきゅう 単位球"
"たんいげん 単位元"
"たんいち 単一"
"たんいつ 単一"
"たんいつたい 単一体"
"たんいふ 単位符"
"たんおん 短音 単音"
"たんか 單價 単果 譚歌 啖呵 炭化 担架 短歌 単価"
"たんかー タンカー"
"たんかか 単花果"
"たんかく 短角"
"たんかだいがく 単科大学"
"たんかひ 単花被"
"たんかん 胆管 単館 単漢"
"たんかんきょう 単環境"
"たんがん 歎願 嘆願 単眼"
"たんがんきょう 単眼鏡"
"たんがんし 単眼視"
"たんき 単機 単記 単騎 短気 短期"
"たんきぎょう 単企業"
"たんきとう 単気筒"
"たんきのう 単機能"
"たんきゃく 単脚"
"たんきゅう 単球 探求 探究"
"たんきゅうしん 探究心"
"たんきょく 端局"
"たんきょり 単距離"
"たんきょりば 短距離馬"
"たんきん 単金"
"たんぎょく 単玉"
"たんく 短躯 タンク"
"たんくかんまど 短区間窓"
"たんぐすてん タングステン"
"たんぐつ 単靴"
"たんけい 短形"
"たんけん 短剣 探険 探検"
"たんけんふ 短剣符 ‡ †"
"たんげ 丹下"
"たんげい 端倪"
"たんげん 単元"
"たんげんしぶんし 単原子分子"
"たんこう 単向 単鉤 鍛鋼 単溝 単孔 鍛工 炭鑛 短光 炭鉱 単行 炭坑 単項"
"たんこうほんみしゅうろく 単行本未収録"
"たんころ 単コロ"
"たんこんたい 担根体"
"たんご 端午 丹後 単語"
"たんごちょう 単語帳"
"たんさ 探査"
"たんさい 淡彩"
"たんさいぼう 単細胞"
"たんさいぼうもう 単細胞毛"
"たんさく 探策 探索"
"たんさくぎ 探索木"
"たんさわこ 丹沢湖"
"たんさん 単三 炭酸"
"たんさんいり 炭酸入"
"たんさんえん 炭酸塩"
"たんさんすい 炭酸水"
"たんざ 単座 端座"
"たんざく 短冊"
"たんざわ 丹沢"
"たんざわこほうめん 丹沢湖方面"
"たんざん 湛山"
"たんし 単子 短枝 譚詩 端子"
"たんしき 単式"
"たんしこしょう 箪食壺漿 箪食壷漿"
"たんしばん 単篩板"
"たんしゃ 単射 単車 単写"
"たんしゅく 短縮"
"たんしゅくけい 短縮茎 短縮形"
"たんしゅん 探春"
"たんしょ 端緒 短所"
"たんしょう 探勝 短小 単勝"
"たんしょうそうひょうすう 単勝総票数"
"たんしょうてん 単焦点"
"たんしょうとう 探照燈"
"たんしょうはんだん 単称判断"
"たんしょく 単色"
"たんしょくこう 単色光"
"たんしょくし 探触子"
"たんしよう 単子葉"
"たんしようしょくぶつこう 単子葉植物綱"
"たんしん 短針 単身"
"たんしんし 単振子"
"たんしんどう 単振動"
"たんじ 単耳 丹治"
"たんじき 単時期"
"たんじきょく 単磁極"
"たんじく 短軸 単軸"
"たんじじつ 短時日"
"たんじつ 短日"
"たんじゅう 胆汁 短銃"
"たんじゅん 単順 単純"
"たんじょう 誕生"
"たんじょうけん 端条件"
"たんじょうせき 誕生石"
"たんじん 炭塵"
"たんす 箪笥"
"たんすい 淡水"
"たんすいかぶつ 炭水化物"
"たんすいぎょ 淡水魚"
"たんすう 単数"
"たんすうけい 単数形"
"たんせい 端整 淡青 嘆声 端正 単性 丹青 丹精"
"たんせいか 単性花"
"たんせいど 単精度"
"たんせき 胆石"
"たんせん 単線"
"たんせんこう 単せん孔 単穿孔"
"たんせんりつ 単旋律"
"たんぜん 丹前"
"たんそ 炭疽 炭素"
"たんそう 単相 単走 単層"
"たんそうさんせんしき 単相三線式"
"たんそく 歎息 嘆息 短足"
"たんそさ 炭素鎖"
"たんそぼう 炭素棒"
"たんぞう 胆臓 鍛造"
"たんたい 担体 単体"
"たんたかばし 反高橋"
"たんたん 眈眈 眈々 淡淡 淡々"
"たんだ 単打"
"たんだい 短大"
"たんち 丹治 探知"
"たんちょ 端緒 単著"
"たんちょう 単頂 短調 単調"
"たんつぼ 痰壷"
"たんてい 単蹄 端艇 探偵"
"たんていちょう 探偵帖"
"たんていもの 探偵物"
"たんていやく 探偵役"
"たんてき 胆摘 端的"
"たんてん 端点"
"たんでき 耽溺"
"たんでん 炭田"
"たんでんか 単電荷"
"たんとう 但東 短刀 担当"
"たんとうい 担当医"
"たんとうがかりめい 担当係名"
"たんとうしょく 担当職"
"たんとうちょくにゅう 単刀直入"
"たんどう 胆道"
"たんどく 單獨 耽読 単独"
"たんな 丹那"
"たんなる 単なる"
"たんなん 丹南"
"たんに 単に 歎異"
"たんにしょう 嘆異抄 歎異抄"
"たんにゅうかん 単乳管"
"たんにん 担任"
"たんねん 丹念"
"たんねんどしゅぎ 単年度主義"
"たんの 端野 丹野"
"たんのう 胆嚢 堪能"
"たんのはら 旦野原"
"たんば 丹波 丹羽"
"たんばい 単売"
"たんばぐち 丹波口"
"たんばら 丹原"
"たんぱ 短波"
"たんぱく 淡泊 タンパク 淡白 蛋白"
"たんぱくげん 蛋白源"
"たんぱくしつ 蛋白質 タンパク質"
"たんぱつ 短髪 単発"
"たんぱつよみきり 単発読切"
"たんび 耽美"
"たんぴょう 単票 短評"
"たんぴん 単品"
"たんふく 単複"
"たんぶ 端部 反歩"
"たんぶん 単文 短文"
"たんぷく 単複"
"たんべんか 単弁花"
"たんぺん 短辺 短篇 短編"
"たんぺんせいか 短編成化"
"たんほう 探訪"
"たんほうこう 単方向"
"たんほうせい 単峰性"
"たんぼ 田圃 田んぼ"
"たんぼいん 単母音"
"たんぼう 探訪"
"たんぼく 単木"
"たんぽ 担保"
"たんまち 反町"
"たんまつ 端末"
"たんまつまど 端末窓"
"たんみつど 単密度"
"たんみん 短眠"
"たんむ 坦務"
"たんめい 短命"
"たんめん 単面 湯麺"
"たんめんよう 単面葉"
"たんもうしゅ 短毛種"
"たんもの 反物"
"たんよう 単葉"
"たんらく 短絡"
"たんらん 貪婪"
"たんり 単離 単利"
"たんりょ 短慮"
"たんりょく 胆力"
"たんれい 端麗"
"たんれつ 単列"
"たんれん 単連 鍛錬 鍛練"
"たんれんけつ 単連結"
"たんわく 単枠"
"たんわくしていば 単枠指定馬"
"だ 雫 佗 荼 鴕 駝 陏 沱 橢 拿 拏 懦 娜 墮 兌 蛇 出 惰 唾 堕 朶 妥 柁 舵 楕 陀 田 打 騨 駄"
"だい 梯 廼 弟 岱 戴 餒 迺 臺 醍 内 題 代 台 大 第"
"だいある ダイアル"
"だいあん 代案"
"だいい 代位 大尉 題意"
"だいいき 大域"
"だいいち ダイイチ 第１ 第1 第一"
"だいいちこうしょう 第一興商"
"だいいちだん 第一弾 第１弾"
"だいいちほうきかん 第一法規刊"
"だいいっかん 第一款 第一勘 第一感"
"だいいっしゅ 第1種"
"だいいっしょう 第1章"
"だいいっせい 第一声"
"だいいっぱ 第一波"
"だいいっぱん 第1版"
"だいいとくみょうおう 大威徳明王"
"だいいん 代員 代印"
"だいうん 大運"
"だいえー ダイエー"
"だいえい 大映 大栄"
"だいえいていこく 大英帝国"
"だいえいはくぶつかん 大英博物館"
"だいえっと ダイエット"
"だいえん 大円"
"だいおう 大王"
"だいおんじょう 大音声"
"だいか 代価"
"だいかあん 代価案"
"だいかいしょう 大海嘯"
"だいかいれい 大海令"
"だいかえ 代替"
"だいかくじ 大覚寺"
"だいかつ 大喝"
"だいかん 大寒 代官"
"だいかんきょほう 大艦巨砲"
"だいかんこうくう 大韓航空"
"だいかんそう 大観荘"
"だいかんみんこく 大韓民国"
"だいかんみんこくせき 大韓民国籍"
"だいがえ 代替"
"だいがえしゃ 代替車"
"だいがく 大學 大学"
"だいがくせん 大学戦"
"だいがくぜい 大学勢"
"だいがくで 大学出"
"だいき 大機 代機"
"だいきぎょうびょう 大企業病"
"だいきち 大吉"
"だいきぼへいれつねっとわあく 大規模並列ネットワーク"
"だいきゅう 代休"
"だいきょう 大京 大凶"
"だいきん 大金 代金"
"だいきんこうぎょう ダイキン工業"
"だいぎ 代議"
"だいぎし 代議士"
"だいぎん 大吟"
"だいく 大工 第九"
"だいぐさく 大愚作"
"だいけい 大型計算機 大計センター 大型計算機センター 台形 大計"
"だいけん 大建"
"だいこう 大幸 乃公 代行"
"だいこうぎょう 代行業"
"だいこうだいこう 大工大高"
"だいこく 大黒"
"だいこくちょう 大国町"
"だいこくどう 大黒堂"
"だいこくばしら 大黒柱"
"だいこん 大根"
"だいこんおろし 大根下ろし"
"だいこんは 大根葉"
"だいご 大子 大悟 大吾 第５ 第五 醍醐"
"だいごじ 醍醐寺"
"だいごせん 第五戦"
"だいごぶだいにか 第五部第二課"
"だいごみ 醍醐味"
"だいさ 大佐"
"だいさい 大祭"
"だいさく 大作"
"だいさん 第III 第3 第３ 第三"
"だいさんかん 第三款"
"だいさんせん 第三戦"
"だいさんだん 第３弾 第三弾"
"だいさんぶだい 第三舞台"
"だいざ 台座"
"だいざい 題材"
"だいざいちゅう 滞在中"
"だいし 第四 大師 台紙"
"だいしだい 大市大"
"だいしどう 大師堂"
"だいしゃ 台車 代車"
"だいしゃわく 台車枠"
"だいしゅうしゃ 大衆車"
"だいしょ 代書"
"だいしょう 代償 大小"
"だいしょうざん 大翔山"
"だいしょうじ 大聖寺"
"だいしょうだい 大商大"
"だいしょうてん 大賞典"
"だいしょうほう 大翔鳳"
"だいじ 大字 大弐 大治 題字 大事"
"だいじぇすと ダイジェスト"
"だいじゃ 大蛇"
"だいじゅういっこう 第十一項"
"だいじょう 大嘗 大丈"
"だいじょうさい 大嘗祭"
"だいじょうぶっきょう 大乗仏教"
"だいじりん 大辞林"
"だいじん 大神 大尽 大臣"
"だいじんぐうした 大神宮下"
"だいじんどう 大仁堂"
"だいす 台子"
"だいすう 大数 代数 台数"
"だいすうかい 代数解"
"だいすうたい 代数体"
"だいすうてきかい 代数的解"
"だいすけ 大助 大祐 大亮 大輔 大介"
"だいず 大豆"
"だいせつ 大雪"
"だいせつざん 大雪山"
"だいせん 大山"
"だいそう 体操 代走 代奏"
"だいそうげんのちいさないえ 大草原の小さな家"
"だいそうしょう 大僧正"
"だいそつ 大卒"
"だいぞう 大蔵"
"だいた 代田 台田"
"だいたい 大隊 大腿 代替 大体"
"だいたいあん 代替案"
"だいたいこつ 大腿骨"
"だいたん 大胆"
"だいだ 代打"
"だいだい 代々 大々 橙"
"だいだいいろ 橙色 だいだい色"
"だいだんえん 大団圓 大団円"
"だいち 代地 大値 台地 大地"
"だいちぼしん 大地母神"
"だいちゅう 大中"
"だいちゅうおう 台中央"
"だいちょう 大腸 台帳"
"だいちょうきん 大腸菌"
"だいてん 題点"
"だいてんし 大転子"
"だいてんもく 台天目"
"だいと 大都"
"だいとう 大東"
"だいとくじ 大徳寺"
"だいどう 大道 大同"
"だいどうけおり 大同毛織"
"だいどうげい 大道芸"
"だいどうこうはん 大同鋼板"
"だいどく 代読"
"だいどころ 台所"
"だいなし 台無 台無し"
"だいなな 第七"
"だいななかい 第７回"
"だいなみっくす ダイナミックス"
"だいなり ＞"
"だいなりいこーる ≧"
"だいに 第2 第２ 第二"
"だいにかん 第二款"
"だいにさく 第二作"
"だいにじゅうろくじょう 第二六条"
"だいにだん 第二弾"
"だいにち 大日"
"だいにちざかり 大日盛"
"だいにゅう 代入"
"だいにん 代人"
"だいのう 代納 大脳"
"だいのおとこ 大の男"
"だいのじ 大の字"
"だいのはら 台原"
"だいはいきりょうしゃ 大排気量車"
"だいはちしあい 第八試合"
"だいはちへんせい 第八編成"
"だいはつこうぎょう ダイハツ工業"
"だいば 台場"
"だいばかり 台秤"
"だいひきゅう 大飛球"
"だいひつ 代筆"
"だいひゃくじゅうにじょう 第百十二条"
"だいひゃくじょう 第百条"
"だいひょう 代表"
"だいひょうかく 代表格"
"だいひょうげん 大氷原"
"だいひょうさく 代表作"
"だいひょうさんこま 代表産駒"
"だいひょうば 代表馬"
"だいひん 代品"
"だいびき 代引 代引き"
"だいふく 大福"
"だいふくじ 大福寺"
"だいふだ 台札"
"だいぶ 大分 大部"
"だいぶつ 大仏"
"だいぶむかし 大分昔"
"だいぶん 大分"
"だいへん 代返"
"だいへんらく 大変楽"
"だいべん 大便 代弁"
"だいほうけんせつ 大豊建設"
"だいほん 台本"
"だいぼう 大坊"
"だいま 大間"
"だいまる 大丸"
"だいみてい 題未定"
"だいみょう 大名"
"だいみんていこく 大明帝国"
"だいめ 代目 台目"
"だいめい 大明 題名"
"だいめいし 代名詞"
"だいもく 題目"
"だいもん 大問 代紋 大門"
"だいや 大谷 ダイヤ"
"だいやく 代役"
"だいやもんど ダイヤモンド"
"だいやる ダイヤル"
"だいよう 大葉 代用"
"だいよん 第4 第４ 第四"
"だいよんかん 第四款"
"だいよんかんひょうき 第四間氷期"
"だいよんぺん 第四辺"
"だいら 平"
"だいらく 大楽"
"だいり 内裏 大利 代理"
"だいりくれい 大陸令"
"だいりせき 大理石"
"だいりびな 内裏雛"
"だいりょうはいきしゃかい 大量廃棄社会"
"だいりょうふくせい 大量複製"
"だいれん 大連"
"だいろうさ 大労作"
"だいろく 第六 第６"
"だいろっかい 第六回 第６回"
"だいろっかん 第六感"
"だいろっき 第六期"
"だいろっきょく 第六局"
"だいわ 大和"
"だいわく 台枠"
"だいわん 大彎"
"だう ダウ"
"だうん ダウン"
"だうんひる ダウンヒル"
"だえき 唾液"
"だえきせん 唾液腺"
"だえん 橢圓 橢円 楕円"
"だえんけい 楕円形"
"だえんこ 楕円弧"
"だえんたい 楕円体"
"だか 高"
"だかい 打開"
"だかつ 蛇蠍 蛇蝎"
"だかん 打感 兌換"
"だかんけん 兌換券"
"だがし 駄菓子"
"だがっき 打楽器"
"だき 唾棄"
"だきあわせ 抱き合わせ"
"だきみょうが 抱茗荷"
"だきゅう 打球"
"だきょう 妥協"
"だきょうあん 妥協案"
"だぎょう ダ行"
"だく 濁 諾"
"だくおん 濁音"
"だくすい 濁水"
"だくてん 濁点 ゛"
"だくと ダクト"
"だくひ 諾否"
"だくりゅう 濁流"
"だけ 嶽 岳"
"だけつ 妥結"
"だけん 打鍵"
"だげき 打撃"
"だげきせん 打撃戦"
"だげきわざ 打撃技"
"だげん 打弦"
"だこう 蛇行"
"だこうとうてい 打高投低"
"だこく 打刻"
"ださ 打差"
"ださく 駄作"
"ださん 打算"
"だざい 太宰"
"だざいおさむ 太宰治"
"だし 山車"
"だしいれ 出し入れ"
"だしかた 出し方"
"だしもの 出し物"
"だしゃ 打者"
"だしん 打診"
"だじゃれ 駄洒落"
"だじゅん 打順"
"だじょうかんれい 太政官令"
"だすう 打数"
"だせい 惰性"
"だせいしん 惰性心"
"だせき 打席"
"だせん 打線"
"だそく 蛇足"
"だたい 堕胎"
"だたいざい 堕胎罪"
"だだ 駄々"
"だだゆき 忠幸"
"だち 逹 達"
"だちょう 鴕鳥 駝鳥"
"だちん 駄賃"
"だっ 脱"
"だっかい 奪回 脱会"
"だっかいせん 奪回戦"
"だっかん 奪還"
"だっき 妲妃 妲己"
"だっきゃく 脱却 脱脚"
"だっきゅう 脱臼"
"だっこ 抱っこ"
"だっこう 脱稿"
"だっこく 脱穀"
"だっし 脱脂"
"だっしめん 脱脂綿"
"だっしゅ 奪取 ダッシュ"
"だっしゅう 脱臭"
"だっしゅつ 脱出"
"だっしょく 脱色"
"だっすい 脱水"
"だっすいそう 脱水槽"
"だっせん 脱線"
"だっそう 脱走"
"だったい 奪胎 脱退"
"だったん 韃靼"
"だっちゃく 脱着"
"だっちょう 脱調 脱腸"
"だっと 脱兎"
"だっとう 脱党"
"だっぴ 脱皮"
"だっぷん 脱糞"
"だっぽう 脱法"
"だつ 獺 怛 妲 奪 脱"
"だつい 脱衣"
"だついじょ 脱衣場 脱衣所"
"だつごく 脱獄"
"だつさら 脱サラ"
"だつさんしん 奪三振"
"だつさんしんおう 奪三振王"
"だつしゅりつ 奪取率"
"だつじ 脱字"
"だつせぞくしゃかい 脱世俗社会"
"だつぜい 脱税"
"だつぞく 脱俗"
"だつぶんか 脱分化"
"だつほうこうい 脱法行為"
"だつぼう 脱帽"
"だつもう 脱毛"
"だつらく 脱落"
"だつらくしゃ 脱落車"
"だつり 脱離"
"だつりゃく 奪掠 奪略"
"だつりゅう 脱硫"
"だつりょく 脱力"
"だつりん 脱輪"
"だて 点 舘 伊達 館"
"だておとこ 伊達男"
"だてがた 伊達方"
"だてん 打点"
"だてんおう 打点王"
"だてんし 堕天使"
"だでん 打電"
"だとう 打倒 妥当"
"だな 棚"
"だに 壁蝨 谷"
"だは 打破"
"だはく 打拍"
"だひつ 惰筆"
"だび 荼毘"
"だびんぐ ダビング"
"だぶつ 陀仏"
"だぶる ダブル"
"だぶるくりっく ダブルクリック"
"だぶん 駄文"
"だほ 拿捕"
"だほう 打法"
"だぼう 打忘"
"だぼく 打撲 打僕"
"だま 玉"
"だましうち 騙し討ち"
"だみー ダミー"
"だみん 惰眠"
"だむ ダム"
"だめ ダメ 駄目"
"だめーじ ダメージ"
"だらく 堕落"
"だりつ 打率"
"だりょく 惰力"
"だりん 舵輪"
"だるま 達磨"
"だれ 誰"
"だれあて 誰宛"
"だれか 誰か"
"だれかさん 誰かさん"
"だれかば 誰カバ"
"だれかれ 誰彼"
"だれだれ 誰々 誰誰"
"だれひとり 誰一人"
"だん 灘 椴 旦 騨 煖 斷 彈 團 壇 檀 暖 男 団 断 弾 談 段"
"だんあつ 彈壓 弾圧"
"だんい 段位"
"だんいん 団員"
"だんおち 檀越"
"だんおつ 檀越"
"だんおんたい 暖温帯"
"だんか 壇家 檀家"
"だんかい 団塊 段階"
"だんかん 段間"
"だんがい 彈劾 断崖 弾劾"
"だんがん 彈丸 弾丸"
"だんき 団旗 暖気 暖機"
"だんきゅう 段級 檀弓 段丘"
"だんきん 断金 断琴 弾琴"
"だんぎ 談義 談議"
"だんくみ 段組"
"だんぐみ 段組"
"だんけつ 団結"
"だんげん 断言"
"だんこ 断乎 断固"
"だんこう 団交 断行 断交"
"だんこん 弾痕 男根"
"だんご 団子"
"だんごう 談合"
"だんごうざか 談合坂"
"だんごばな だんご鼻"
"だんさ 段差"
"だんさい 断裁"
"だんざい 斬罪 断罪"
"だんし 檀紙 談志 弾指 男子"
"だんしこう 男子高"
"だんしはつ 男子初"
"だんしゃ 檀車"
"だんしゃく 男爵"
"だんしゅ 断首 断種"
"だんしょう 男娼 断章 談笑"
"だんしょく 男色 暖色"
"だんしりょう 男子寮"
"だんしん 弾芯"
"だんじ 男児"
"だんじき 断食"
"だんじく 段軸"
"だんじて 断じて"
"だんじゅうろう 團十郎"
"だんじょ 男女"
"だんじょう 壇上"
"だんじょそうほうむき 男女双方向"
"だんじょとも 男女共"
"だんす ダンス"
"だんすい 断水"
"だんすう 段数 弾数"
"だんせい 弾性 男声 男性"
"だんせいがた 男性形"
"だんせいきゃく 男性客"
"だんせいぞう 男性像"
"だんせいたい 弾性体"
"だんせいは 弾性波"
"だんせいばん 弾性板"
"だんせいむけ 男性向"
"だんせん 断線"
"だんぜつ 断絶"
"だんぜん 断然"
"だんそう 男装 断層"
"だんそん 男尊"
"だんぞく 断続"
"だんぞくへいこうせつ 断続平衡説"
"だんたい 暖帯 彈帶 弾帯 団体"
"だんたいきゃく 団体客"
"だんたいせん 団体戦"
"だんたいりょこうきゃく 団体旅行客"
"だんたいわく 団体枠"
"だんたにさんぎょう 段谷産業"
"だんだ 段田"
"だんだん 段々"
"だんち 暖地 団地"
"だんちゃく 彈着 弾着"
"だんちょう 断腸 団長"
"だんてい 断定"
"だんと 檀徒"
"だんとう 彈頭 弾頭 暖冬"
"だんとうだい 断頭台"
"だんとつ 断突"
"だんどう 彈道 弾道"
"だんどり 段取り"
"だんな 旦那"
"だんねつ 断熱"
"だんねつざい 断熱材"
"だんねつふく 断熱服"
"だんねん 断念"
"だんのうら 壇ノ浦"
"だんばん 檀板"
"だんぱつ 断髪"
"だんぱん 談判"
"だんびら 段平"
"だんぴつ 断筆"
"だんふみ 檀ふみ 壇ふみ"
"だんぷ ダンプ"
"だんぺん 断片"
"だんぼーる 段ボール"
"だんぼう 煖房 暖房"
"だんぼうひ 暖房費"
"だんまく 彈幕 弾幕"
"だんまつま 断末摩 断末魔"
"だんみん 断眠"
"だんめ 段目"
"だんめん 断面"
"だんめんせき 断面積"
"だんやく 彈藥 弾薬"
"だんゆう 男優"
"だんらく 談楽 段落"
"だんらくわく 段落枠"
"だんらん 檀欒 団らん 団欒"
"だんりゅう 暖流"
"だんりょく 弾力"
"だんりん 檀林"
"だんれいぼう 暖冷房"
"だんれいぼうひ 暖冷房費"
"だんれつ 断裂"
"だんろ 煖炉 煖爐 暖炉"
"だんろんぽう 段論法"
"だんわ 談話"
"ち 黹 黐 遲 輊 躓 踟 褫 胝 耻 笞 穉 癡 岻 夊 夂 緻 薙 魑 治 弛 稚 池 痴 千 蜘 茅 馳 智 置 致 遅 血 恥 知 地 値"
"ちーず チーズ"
"ちーふ チーフ"
"ちーむ チーム"
"ちあき 千章 千明 千昌 千晶 千秋"
"ちあゆ 稚鮎"
"ちあん 治安"
"ちい 地異 地衣 地位"
"ちいき 値域 地域"
"ちいく 知育"
"ちいじょうはんてい 地上判定"
"ちいといつ 七対子"
"ちいほう 地和"
"ちぇーん チェーン"
"ちぇあまん チェアマン"
"ちぇこすろばきあ 捷克"
"ちぇす チェス"
"ちぇっかー チェッカー"
"ちぇっく チェック"
"ちぇんじ チェンジ"
"ちえ 千枝 知慧 知惠 智慧 知重 知江 千英 知衣 智恵 知枝 千絵 知恵"
"ちえこ 智恵子 知恵子 千枝子 千恵子"
"ちえねつ 知恵熱"
"ちえぶくろ 知恵袋"
"ちえみ 智恵美 智栄美 千恵美 智枝美 千絵美"
"ちえり 智恵理"
"ちえん 地縁 遅延"
"ちえんは 遅延波"
"ちおんいん 知恩院"
"ちか 智佳 智加 千夏 親 治下 智香 知可 値化 知夏 知華 知佳 近 地価 地下"
"ちかい 近井 邇 地階"
"ちかお 親雄 周夫 知馨夫"
"ちかく 地穀 知覚 地殻"
"ちかくぞう 知覚像"
"ちかけい 地下茎"
"ちかこ 睦子 千加子 知可子 智香子 千賀子 千嘉子 渠睦子 ちか子 智加子 千香子"
"ちかごろ 近頃"
"ちかざわ 近澤"
"ちかし 迩"
"ちかじか 近々"
"ちかすい 地下水"
"ちかずみ 近角"
"ちかだ 近田"
"ちかぢか 近々"
"ちかてつ 地下鉄"
"ちかてつもう 地下鉄網"
"ちかば 近場"
"ちかひろ 近廣 近広"
"ちかま 近間"
"ちかまつ 近松"
"ちかみち 近道"
"ちかやま 近山"
"ちから 千賀良 主税 力"
"ちからいがい 力以外"
"ちからいっぱい 力一杯"
"ちからいと 力糸"
"ちからおとし 力落とし"
"ちからかげん 力加減"
"ちからかんけい 力関係"
"ちからこぶ 力瘤"
"ちからさ 力差"
"ちからしごと 力仕事"
"ちからじこく 力時刻"
"ちからじまん 力自慢"
"ちからせいぎょ 力制御"
"ちからせいぶん 力成分"
"ちからぞえ 力添え"
"ちからてき 力的"
"ちからぶそく 力不足"
"ちからもち 力餅 力持ち"
"ちからわざ 力技"
"ちかろう 地下牢"
"ちかん 弛緩 置喚 痴漢 置換"
"ちが 千賀 違"
"ちがい 違い"
"ちがいほうけん 治外法権"
"ちがく 地学"
"ちがさき 茅ヶ崎"
"ちがっか 地学科"
"ちがや 茅"
"ちき 稙 飭 知己"
"ちきゅう 恥丘 地球"
"ちきゅうぎ 地球儀"
"ちきゅうぐん 地球軍"
"ちきゅうせん 地球船"
"ちきゅうてきけんち 地球的見地"
"ちきゅうみさき 地球岬"
"ちきょう 地峡"
"ちきん チキン"
"ちぎ 杠"
"ちぎょ 稚魚"
"ちぎょうち 知行地"
"ちぎり 千切 契"
"ちく 矗 畜 築 筑 竹 蓄 地区 逐"
"ちくあん 竹安"
"ちくい 築井"
"ちくいち 遂一 逐一"
"ちくおんき 蓄音機"
"ちくかん 竹簡"
"ちくきょう 地区協"
"ちくご 築後 筑後 逐語"
"ちくさ 千種"
"ちくさつ 畜殺"
"ちくさん 畜産"
"ちくざい 蓄財"
"ちくし 筑紫"
"ちくしぐち 筑紫口"
"ちくしじ 筑紫路"
"ちくしの 筑紫野"
"ちくしょう 畜生"
"ちくじ 遂次 逐次"
"ちくじょう 逐条 築城 築上"
"ちくせき 蓄積"
"ちくせん 地区戦"
"ちくぜん 筑前 竹善"
"ちくぞう 築造"
"ちくてん 逐電"
"ちくでん 逐電 蓄電"
"ちくでんち 蓄電池"
"ちくなんねん 築何年"
"ちくねつ 蓄熱"
"ちくねん 逐年"
"ちくのうしょう 蓄膿症"
"ちくは 竹葉"
"ちくはく 竹帛"
"ちくば 竹馬"
"ちくひ 竹扉"
"ちくひせん 筑肥線"
"ちくび 乳首"
"ちくほ 筑穂"
"ちくほう 筑豊"
"ちくま 筑摩"
"ちくまがわ 千曲川"
"ちくら 千倉"
"ちくりん 竹林"
"ちくれいねつ 蓄冷熱"
"ちくわ 竹輪"
"ちくわふ 竹輪麩"
"ちくん 治勲"
"ちぐさ 千草 千種"
"ちけい 地形"
"ちけっと チケット"
"ちけん 地圏 地検 知見"
"ちけんしゃ 地権者"
"ちこう 地皇 恥垢"
"ちこうせい 遅効性"
"ちこうふう 地衡風"
"ちこく 遅刻"
"ちこつ 恥骨"
"ちこつけつごうえん 恥骨結合炎"
"ちご 稚児 稚子"
"ちさ 知砂 智佐"
"ちさい 地裁"
"ちさく 千咲"
"ちさこ 千佐子 知紗子"
"ちさと 千里"
"ちさん 遅参 地産 治山"
"ちざいけん 知財権"
"ちざいぶ 知財部"
"ちし 智歯 致仕 致死"
"ちしお 血潮"
"ちしき 知識"
"ちしきげん 知識源"
"ちしきよく 知識欲"
"ちしつ 知悉 地質"
"ちしつずさくいんず 地質図索引図"
"ちしぶき 血飛沫"
"ちしま 千島"
"ちしゃ 苣 知者"
"ちしょ 地所"
"ちしょう 致傷 知将"
"ちしろ 千代"
"ちしん 地心"
"ちじ 知事"
"ちじき 地磁気"
"ちじく 地軸"
"ちじせん 知事選"
"ちじつ 遅日"
"ちじゅんほう 置閏法"
"ちじょう 笞杖 痴情 地上"
"ちじょうけい 地上茎"
"ちじょうさくてきのう 地上索敵能"
"ちじょうせん 地上戦"
"ちじょうは 地上波"
"ちじょうわざ 地上技"
"ちじょく 恥辱"
"ちじん 地人 痴人 知人"
"ちじんたく 知人宅"
"ちすい 治水"
"ちすいかふう 地水火風"
"ちすじ 血筋"
"ちず 智頭 千寿 地図"
"ちずこ 知寿子 千鶴子 千寿子"
"ちずちょう 地図帳"
"ちずばんじょう 地図板上"
"ちせ 知世"
"ちせい 痴性 地勢 治世 知性"
"ちせいがく 地政学"
"ちせいたい 知性体"
"ちせこ 智勢子"
"ちせつ 稚拙"
"ちそう 地層 馳走"
"ちそく 遅速"
"ちた 知多"
"ちたい 遅滞 地帯"
"ちたね 千種"
"ちだ 千田"
"ちだい 地代"
"ちち 義父 遅々 乳 父"
"ちちうえ 父上"
"ちちうし 乳牛"
"ちちおや 父親"
"ちちおやに 父親似"
"ちちかた 父方"
"ちちがた 父方"
"ちちぎみ 父君"
"ちちけんり 父権制"
"ちちじま 父島"
"ちちぶ 秩父"
"ちちぶさん 秩父山"
"ちちぶのみや 秩父宮"
"ちちまつ 千々松"
"ちちむすめ 父娘"
"ちちゅう 地中"
"ちちゅうかい 地中海"
"ちちょう 地調"
"ちぢ 千々"
"ちぢみ 縮"
"ちぢわ 千々石"
"ちっきょ 蟄居"
"ちっこう 築港"
"ちっそ 窒素"
"ちっそく 窒息"
"ちっそくし 窒息死"
"ちっと 些と"
"ちっとも 些とも"
"ちっぷ チップ"
"ちっぷべつ 秩父別"
"ちつ 蟄 腟 帙 膣 窒 秩"
"ちつじょ 秩序"
"ちつせん 膣栓"
"ちつぶんぴつえき 膣分泌液"
"ちつみ 千津美"
"ちづ 地図"
"ちづこ 千鶴子"
"ちづる 千鶴"
"ちてい 地底"
"ちていこ 地底湖"
"ちてき 知的"
"ちてきび 知的美"
"ちてつ 地鉄"
"ちてん 地点"
"ちと 少と 些と"
"ちとせ 千登世 千歳"
"ちとせづる 千歳鶴"
"ちどうせつ 地動説"
"ちどり 鵆 千鳥"
"ちどりあし 千鳥足"
"ちどりがふち 千鳥ヶ淵"
"ちな 知名"
"ちなつ 千夏"
"ちなみ 因"
"ちにちは 知日派"
"ちねつ 地熱"
"ちねん 知念"
"ちの 千野 茅野"
"ちのう 智能 知能"
"ちのうはん 知能犯"
"ちのけ 血の気"
"ちのね 茅根"
"ちのり 血糊"
"ちはい 遅配"
"ちはや 千早"
"ちはら 千原 茅原"
"ちはる 智春 千春"
"ちば 地場 千葉"
"ちばな 知花"
"ちばひがし 千葉東"
"ちばん 地番"
"ちひつ 遅筆"
"ちひょう 地表"
"ちひょうすい 地表水"
"ちひょうは 地表波"
"ちひろ 知宏 千裕 馳浩 千紘 千尋"
"ちふみ 千文"
"ちふゆ 千冬"
"ちぶ 知夫 恥部"
"ちぶくろ 血袋"
"ちぶさ 乳房"
"ちぶつ 地球物理 地物"
"ちへい 地平"
"ちへん 地変"
"ちべん 智辯"
"ちほ 地歩 智保 千穂"
"ちほう 痴呆 地方"
"ちほうこうふぜい 地方交付税"
"ちほうごと 地方毎"
"ちほうし 地方紙"
"ちほうぜい 地方税"
"ちほうば 地方馬"
"ちぼう 智謀 知謀"
"ちぼつご 沈没後"
"ちまき 粽 粡"
"ちまた 巷"
"ちまつり 血祭 血祭り"
"ちまなこ 血眼"
"ちみ 魑魅 地味"
"ちみつ 緻密"
"ちむさーちょい 尖沙咀"
"ちむら 地村"
"ちめい 知名 致命 地名"
"ちめいしょう 致命傷"
"ちもう 恥毛"
"ちもく 地目"
"ちもよう 血模様"
"ちゃ 咤 茶"
"ちゃーしゅー 叉焼 焼豚"
"ちゃーしゅーめん 叉焼麺"
"ちゃーじ チャージ"
"ちゃーたー チャーター"
"ちゃーちすくえぁー チャーチスクエァー"
"ちゃーと チャート"
"ちゃーはん チャーハン 炒飯"
"ちゃあはん 炒飯"
"ちゃいな チャイナ"
"ちゃいれ 茶入"
"ちゃいろ 茶色"
"ちゃいろじ 茶色地"
"ちゃうけ 茶請け"
"ちゃうす 茶臼"
"ちゃお 找 チャオ"
"ちゃおず 餃子"
"ちゃか 茶菓 茶化"
"ちゃかい 茶会"
"ちゃかっしょく 茶褐色"
"ちゃがし 茶菓子"
"ちゃき 茶木 茶器"
"ちゃきん 茶巾"
"ちゃく 摘 嫡 着"
"ちゃくい 着衣"
"ちゃくえき 着駅"
"ちゃくかくにん 着確認"
"ちゃくがい 着外"
"ちゃくがん 着岸 着眼"
"ちゃくこう 着工"
"ちゃくさ 着差"
"ちゃくさいこうぞうが 着彩構造画"
"ちゃくざ 着座"
"ちゃくし 嫡子"
"ちゃくしつ 嫡室"
"ちゃくしゅ 着手"
"ちゃくしゅつ 嫡出"
"ちゃくしょう 着床"
"ちゃくしょく 着色"
"ちゃくしん 着信"
"ちゃくしんにんばらい 着信人払い"
"ちゃくじ 着磁"
"ちゃくじこく 着時刻"
"ちゃくじつ 着実"
"ちゃくじつに 着実に"
"ちゃくじゅん 着順"
"ちゃくすい 着水"
"ちゃくせい 着生"
"ちゃくせいこん 着生根"
"ちゃくせき 着席"
"ちゃくそう 着装 着想"
"ちゃくだつ 着脱"
"ちゃくだん 着彈 着弾"
"ちゃくち 着地"
"ちゃくちゃく 着着 着々"
"ちゃくてい 着挺"
"ちゃくでん 着電"
"ちゃくにん 着任"
"ちゃくはつ 着発"
"ちゃくば 着馬"
"ちゃくばらい 着払い 着払"
"ちゃくふく 着服"
"ちゃくみ 茶くみ"
"ちゃくもく 着目"
"ちゃくよう 着用"
"ちゃくりく 着陸"
"ちゃくりくちょくぜん 着地直前"
"ちゃしつ 茶室"
"ちゃしゃく 茶杓"
"ちゃじ 茶事"
"ちゃせき 茶席"
"ちゃせん 茶筅 茶せん"
"ちゃたん 北谷"
"ちゃだい 茶代"
"ちゃちゃ 茶茶 茶々"
"ちゃちゃまる 茶々丸"
"ちゃっか 着火"
"ちゃっかん 着艦"
"ちゃっけん 着剣"
"ちゃっこ 着呼"
"ちゃっこう 着工"
"ちゃづけ 茶漬"
"ちゃづつ 茶筒"
"ちゃどうぐ 茶道具"
"ちゃない 茶内"
"ちゃのはら 茶之原"
"ちゃのま 茶の間"
"ちゃのみ 茶飲み"
"ちゃばたけ 茶畠 茶畑"
"ちゃばん 茶番"
"ちゃばんげき 茶番劇"
"ちゃぶだい 茶袱台 卓袱台"
"ちゃぺる チャペル"
"ちゃぼうず 茶坊主"
"ちゃま 茶魔"
"ちゃみ 茶見 茶美"
"ちゃめ 茶目"
"ちゃめっけ 茶目っ気"
"ちゃや 茶屋"
"ちゃやま 茶山"
"ちゃやみち 茶屋道"
"ちゃりてぃ チャリティ"
"ちゃれんじ チャレンジ"
"ちゃわん 茶碗"
"ちゃわんむし 茶碗蒸"
"ちゃんす チャンス"
"ちゃんすう 昌洙"
"ちゃんねる チャンネル"
"ちやこ 千夜子"
"ちゅ 丶"
"ちゅーとりある チュートリアル"
"ちゅーな チューナ"
"ちゅーぶ チューブ"
"ちゅう 紐 肘 紬 丑 寵 冢 廚 鑄 鍮 誅 胄 綢 紂 籀 籌 稠 畴 疇 晝 惆 冲 冑 儔 厨 沖 ※ 躊 蟲 仲 衷 抽 酎 鋳 柱 註 忠 虫 駐 昼 宙 注 中"
"ちゅうあつ 中厚"
"ちゅうい 中位 中尉 注意"
"ちゅういがき 注意書き"
"ちゅういき 中域"
"ちゅういげんじ 注意現示"
"ちゅういち 忠一 中一"
"ちゅういほう 注意報"
"ちゅうえい 中映 中衛"
"ちゅうえつせんそう 中越戦争"
"ちゅうおう 紂王 中央"
"ちゅうおういり 中央入"
"ちゅうおうぐち 中央口"
"ちゅうおうぐん 中央軍"
"ちゅうおうぐんい 中央軍委"
"ちゅうおうした 中央下"
"ちゅうおうば 中央馬"
"ちゅうおうひがしせん 中央東線"
"ちゅうおうみゃく 中央脈"
"ちゅうおうよこ 中央横"
"ちゅうおん 中音"
"ちゅうか 中華"
"ちゅうかい 厨芥 注解 仲介"
"ちゅうかがし 中華菓子"
"ちゅうかく 中隔 中核"
"ちゅうかっこ 中かっこ"
"ちゅうかどん 中華丼"
"ちゅうかなべ 中華鍋"
"ちゅうかはん 中華飯"
"ちゅうかめん 中華麺"
"ちゅうから 中辛"
"ちゅうかん 中環 昼間 中間"
"ちゅうかんぎ 中間木"
"ちゅうかんしゃ 中間車"
"ちゅうかんだな 中間棚"
"ちゅうかんとびら 中間扉"
"ちゅうがい 中外 虫害"
"ちゅうがえり 宙返り"
"ちゅうがく 中学"
"ちゅうがた 中形 中型"
"ちゅうがたぎょ 中型魚"
"ちゅうがたけん 中型犬"
"ちゅうがっこうまで 中学校迄"
"ちゅうき 駐機 注記 中期"
"ちゅうきち 忠吉"
"ちゅうきゅう 誅求 中級"
"ちゅうきゅうしゃむけ 中級者向"
"ちゅうきょう 中京"
"ちゅうきょうしば 中京芝"
"ちゅうきょりば 中距離馬"
"ちゅうきん 忠勤 駐禁"
"ちゅうぎ 忠義"
"ちゅうくう 宙空 中空"
"ちゅうくうしまく 中空糸膜"
"ちゅうくん 忠君"
"ちゅうけい 中繼 中継"
"ちゅうけいじょ 中継所"
"ちゅうけいは 中継波"
"ちゅうけん 忠犬 中堅 中研"
"ちゅうけんしゅ 中堅手"
"ちゅうけんほ 駐建保"
"ちゅうげん 忠言 中元"
"ちゅうこ 中古"
"ちゅうこう 鋳鋼 昼行 中耕 忠孝 中高 中興 中公"
"ちゅうこうだいいん 中高大院"
"ちゅうこうれつしゃ 昼行列車"
"ちゅうこく 忠告"
"ちゅうこくふぁんど 中国ファンド"
"ちゅうこしゃ 中古車"
"ちゅうごく 中國 中国"
"ちゅうごくかがくいん 中国科学院"
"ちゅうごくき 中国旗"
"ちゅうごくぐん 中国軍"
"ちゅうごくけん 中国拳"
"ちゅうごくさん 中国産"
"ちゅうごくし 中国史"
"ちゅうごくせき 中国籍"
"ちゅうごくはけんぐん 中国派遣軍"
"ちゅうごくぶっさんひんてん 中国物産品店"
"ちゅうごくへい 中国兵"
"ちゅうごくりゅう 中国流"
"ちゅうごくりょう 中国領"
"ちゅうごし 中腰"
"ちゅうさ 中佐"
"ちゅうさい 仲裁"
"ちゅうさかん 中属"
"ちゅうさつ 誅殺 駐箚"
"ちゅうさん 中三 昼餐 注参"
"ちゅうざ 中座"
"ちゅうざい 駐在"
"ちゅうし 注視 中止"
"ちゅうしゃ 注射 駐車"
"ちゅうしゃく 注釈 註釈"
"ちゅうしゃけん 駐車券"
"ちゅうしゃじょうした 駐車場下"
"ちゅうしゃとう 注射筒"
"ちゅうしゃばり 注射針"
"ちゅうしゃわく 駐車枠"
"ちゅうしゅう 仲秋 中秋 中周"
"ちゅうしゅつ 抽出"
"ちゅうしょ 中所"
"ちゅうしょう 中将 中小 中傷 抽象"
"ちゅうしょく 昼食"
"ちゅうしょくどき 昼食時"
"ちゅうしょくひ 昼食費"
"ちゅうしょじま 中書島"
"ちゅうしん 注進 中震 忠臣 衷心 中心"
"ちゅうしんかく 中心格 中心角"
"ちゅうしんぐら 忠臣蔵"
"ちゅうしんじく 中心軸"
"ちゅうしんちゅう 中心柱"
"ちゅうじ 忠二 中耳 忠治 忠司"
"ちゅうじえん 中耳炎"
"ちゅうじく 中軸"
"ちゅうじつ 忠実"
"ちゅうじゅん 中旬"
"ちゅうじゅんごろ 中旬頃"
"ちゅうじょ 中所"
"ちゅうじょう 中条 哀情 衷情 中将 中條"
"ちゅうじょっき 中ジョッキ"
"ちゅうすい 虫垂 注水"
"ちゅうすいえん 虫垂炎"
"ちゅうすう 中枢"
"ちゅうすけ 忠輔"
"ちゅうず 中主"
"ちゅうせい 中正 忠誠 中性 中世"
"ちゅうせいし 中性紙"
"ちゅうせいしげん 中性子源"
"ちゅうせいしせい 中性子星"
"ちゅうせいしそく 中性子束"
"ちゅうせいしば 中性子場"
"ちゅうせいしん 忠誠心"
"ちゅうせいびし 中性微子"
"ちゅうせき 柱石 沖積"
"ちゅうせつ 忠節"
"ちゅうせん 抽籤 抽選"
"ちゅうせんけん 抽選券"
"ちゅうせんば 抽籤馬"
"ちゅうぜい 中背"
"ちゅうぜつ 中絶"
"ちゅうぜんじ 中禅寺"
"ちゅうぜんじこ 中禅寺湖"
"ちゅうそ 註疏"
"ちゅうそう 抽送 中層"
"ちゅうそうすい 中層水"
"ちゅうそく 中速"
"ちゅうそくしゃ 中速車"
"ちゅうそつ 中卒"
"ちゅうそんじ 中尊寺"
"ちゅうぞう 鑄像 宙三 鋳造 忠三"
"ちゅうた 宙太"
"ちゅうたい 柱体 中隊 中退"
"ちゅうだい 中大"
"ちゅうだん 中団 中段 中断"
"ちゅうち 中置"
"ちゅうちゅうごくたいし 駐中国大使"
"ちゅうちゅうたいし 駐中大使"
"ちゅうちょ 躊躇"
"ちゅうてい 中低"
"ちゅうていしゃ 駐停車"
"ちゅうてつ 鋳鉄"
"ちゅうてん 冲点 沖点 宙天 ・ 中点"
"ちゅうでん 中伝 中電"
"ちゅうと 中途"
"ちゅうとう 柱頭 仲冬 中等 中東"
"ちゅうとん 駐屯"
"ちゅうど 中度"
"ちゅうどう 中道"
"ちゅうどうじ 中堂寺"
"ちゅうどく 中毒"
"ちゅうなん 仲南"
"ちゅうに 中２"
"ちゅうにち 駐日 中日"
"ちゅうにちせん 中日戦"
"ちゅうにゅう 注入"
"ちゅうにゅうぐち 注入口"
"ちゅうねん 中年"
"ちゅうねんおとこ 中年男"
"ちゅうのう 中脳"
"ちゅうは 中波"
"ちゅうばいか 虫媒花"
"ちゅうばち 中鉢"
"ちゅうばん 注番 中判 中盤"
"ちゅうばんせん 中盤戦"
"ちゅうひ 中皮"
"ちゅうび 中火"
"ちゅうふく 中腹"
"ちゅうぶ 中風 中部"
"ちゅうぶう 中風"
"ちゅうぶぜい 中部勢"
"ちゅうぶらりん 宙ぶらりん"
"ちゅうぶん 中文"
"ちゅうへん 中編 中篇 中辺"
"ちゅうべい 駐米 中米"
"ちゅうぼう 厨房"
"ちゅうま 中馬"
"ちゅうみつ 稠密"
"ちゅうめん 中免 柱面"
"ちゅうもく 注目"
"ちゅうもくかぶ 注目株"
"ちゅうもくさく 注目作"
"ちゅうもん 中門 注文"
"ちゅうもんぬし 注文主"
"ちゅうや 昼夜 中也"
"ちゅうゆ 注油"
"ちゅうゆう 忠勇"
"ちゅうよう 中葉 中庸"
"ちゅうりき 中力"
"ちゅうりきこ 中力粉"
"ちゅうりつ 中立"
"ちゅうりゃく 中略"
"ちゅうりゅう 駐留 中流"
"ちゅうりょうゆそうきかん 中量輸送機関"
"ちゅうりょく 中力 注力"
"ちゅうりょくこ 中力粉"
"ちゅうりん 駐輪"
"ちゅうるい 忠類"
"ちゅうれい 昼礼"
"ちゅうれつ 中裂"
"ちゅうろく 中肋"
"ちゅうわ 中和"
"ちゅつ 黜"
"ちゅん 中"
"ちゅんりー 春麗"
"ちゆ 治癒"
"ちゆう 知友"
"ちゆき 千幸"
"ちょ 箸 緒 豬 紵 竚 潴 墸 佇 儲 躇 樗 瀦 苧 猪 貯 著"
"ちょーく チョーク"
"ちょう 微 蔦 冢 鼎 澂 挺 澄 齠 鵈 髫 雕 迢 輙 輒 貂 誂 萇 膓 聽 糶 窕 疔 甼 漲 樢 楪 晁 昶 悵 廰 廳 佻 貼 趙 釣 鬯 稠 凋 帖 寵 懲 彫 牒 眺 喋 脹 跳 諜 銚 蝶 丁 嘲 徴 暢 潮 挑 肇 朝 兆 鳥 聴 腸 頂 弔 張 重 町 調 庁 帳 超 長"
"ちょうあい 帳合い 帳合 丁合い 丁合 寵愛"
"ちょうあく 懲悪"
"ちょうあつ 調圧"
"ちょうあん 長安"
"ちょうい 潮位 弔慰 弔意"
"ちょういち 長一"
"ちょういちろう 長一郎"
"ちょういん 調印"
"ちょうえい 町営"
"ちょうえき 懲役"
"ちょうえきけい 懲役刑"
"ちょうえつ 超越"
"ちょうえん 腸炎 兆円"
"ちょうえんけい 長円形"
"ちょうおん ー 聴音 調音 長音"
"ちょうおんぷ 長音符"
"ちょうか 長靴 釣果 超過"
"ちょうかい 嘲詼 町会 潮解 朝会 鳥海 懲戒"
"ちょうかいさん 鳥海山"
"ちょうかいりょく 聴解力"
"ちょうかく 長角 聴覚"
"ちょうかん 腸管 長巻 鳥瞰 聴感 朝刊 長官"
"ちょうかんかく 聴感覚"
"ちょうかんまく 腸間膜"
"ちょうが 頂芽"
"ちょうがい 鳥害"
"ちょうがいさんかしゃ 町外参加者"
"ちょうき 寵姫 長期"
"ちょうきせん 長期戦"
"ちょうきち 長吉"
"ちょうきゅう 超球"
"ちょうきゅうけいさつ 超級警察"
"ちょうきょう 調教"
"ちょうきょり 長距離"
"ちょうきょりきゃく 長距離客"
"ちょうきょりせん 長距離戦"
"ちょうきょりば 長距離馬"
"ちょうきょりほう 長距離砲"
"ちょうきん 彫金 超勤"
"ちょうぎ 嘲戯 町議"
"ちょうぎゃく 嘲謔"
"ちょうくうかん 聴空間"
"ちょうけい 長形 蝶形 長兄"
"ちょうけいか 蝶形花"
"ちょうけし 帳消し"
"ちょうけつ 長欠"
"ちょうけん 長剣 聴検"
"ちょうげん 超弦 調弦 超限"
"ちょうこう 嘲詬 釣鉤 釣行 長江 調光 兆候 超高 長考 聴講 徴候"
"ちょうこうぜつ 長広舌"
"ちょうこうそく 超攻速"
"ちょうこく 超克 彫刻"
"ちょうこくか 彫刻家"
"ちょうこくとう 彫刻刀"
"ちょうこつ 腸骨"
"ちょうこんか 長恨歌"
"ちょうご 長後"
"ちょうごう 調合"
"ちょうさ 潮差 調査"
"ちょうさい 兆載"
"ちょうさひ 調査費"
"ちょうさやく 調査役"
"ちょうさんど 長三度"
"ちょうさんぼし 朝三暮四"
"ちょうさんわおん 長三和音"
"ちょうざい 調剤"
"ちょうざんぞう 長残像"
"ちょうし 冢祀 聴視 銚子 長子 調子"
"ちょうしぶえ 調子笛"
"ちょうしもの 調子者"
"ちょうしゃ 聴者 庁舎"
"ちょうしゃく 長尺"
"ちょうしゃてい 長射程"
"ちょうしゅ 聴取"
"ちょうしゅう 懲収 長州 長洲 聴衆 徴収"
"ちょうしゅうかく 聴衆各"
"ちょうしゅうがく 徴収額"
"ちょうしゅうき 長周期"
"ちょうしゅりつちょうさ 聴取率調査"
"ちょうしゅん 長春"
"ちょうしょ 長所 調書"
"ちょうしょう 弔鐘 嘲笑"
"ちょうしょく 調色 朝食"
"ちょうしょくつき 朝食付"
"ちょうしん 寵臣 長針 聴診 長身"
"ちょうしんけい 聴神経"
"ちょうじ 寵児 弔辞 長治"
"ちょうじかん 長時間"
"ちょうじかんそう 長時間走"
"ちょうじく 長軸"
"ちょうじつせい 超日性"
"ちょうじゃ 長者"
"ちょうじゃがさき 長者ヶ崎"
"ちょうじゃくかん 長尺管"
"ちょうじゅ 長寿"
"ちょうじゅう 鳥獣"
"ちょうじゅうせんしゃ 超重戦車"
"ちょうじゅうろう 長十郎"
"ちょうじゅみょう 長寿命"
"ちょうじゅん 超準"
"ちょうじょ 長女"
"ちょうじょう 超常 長城 重畳 頂上 長上"
"ちょうじり 張尻 帳尻"
"ちょうじろう 長次郎"
"ちょうじん 鳥人 超神 超人"
"ちょうすけ 長介"
"ちょうず 手水"
"ちょうずばち 手水鉢"
"ちょうせあめ 朝鮮飴"
"ちょうせい 頂生 調声 町政 長征 調製 長生 調性 調整"
"ちょうせいがく 調整額"
"ちょうせいきゅう 調整給"
"ちょうせいやく 調整役"
"ちょうせき 潮汐 長石"
"ちょうせつ 調節"
"ちょうせん 貂蝉 朝鮮 挑戦"
"ちょうせんき 挑戦記"
"ちょうぜい 町税 徴税"
"ちょうぜつ 超絶"
"ちょうぜん 超然"
"ちょうそ 彫塑"
"ちょうそかべ 長宗我部"
"ちょうそがべ 長宗我部"
"ちょうそく 長足"
"ちょうそん 町村"
"ちょうぞう 彫像 長蔵"
"ちょうたきゃくき 超多客期"
"ちょうたつ 調達"
"ちょうたろう 長太郎"
"ちょうたん 頂端 長短"
"ちょうたんい 兆単位"
"ちょうたんさいぼうせつ 頂端細胞説"
"ちょうだ 長打 長蛇"
"ちょうだい 鳥大 朝大 頂載 頂戴 長大"
"ちょうちかく 聴知覚"
"ちょうちゃく 打擲"
"ちょうちゅう 頂肘"
"ちょうちょう 蝶蝶 蝶々 町長 長調"
"ちょうちょうはっし 丁々発止"
"ちょうちん 提灯"
"ちょうつがい 蝶番"
"ちょうづめ 腸詰"
"ちょうてい 調定 超低 朝廷 調停"
"ちょうていやく 調停役"
"ちょうてき 朝敵"
"ちょうてじゅん 長手順"
"ちょうてん 長点 頂点"
"ちょうでん 弔電"
"ちょうと 長途"
"ちょうど 調度 丁度"
"ちょうどう 町道"
"ちょうな 鐇"
"ちょうない 腸内 町内"
"ちょうなん 嘲難 長南 長男"
"ちょうにん 町人"
"ちょうの 蝶野"
"ちょうのうりょくしゃ 超脳力者"
"ちょうのつぼ 町坪"
"ちょうは 長波 調波"
"ちょうはつ 調髪 挑撥 徴発 挑発 長髪"
"ちょうはんげんき 長半減期"
"ちょうば 嘲罵 帳場"
"ちょうばいか 鳥媒花"
"ちょうばつ 懲罰"
"ちょうひょう 帳票 帳表"
"ちょうふ 長府 貼付 調布"
"ちょうふく 重複"
"ちょうふさい 調布祭"
"ちょうぶ 頂部"
"ちょうぶつ 長物"
"ちょうぶん 長文"
"ちょうへい 長平 徴兵"
"ちょうへき 腸壁"
"ちょうへん 長辺 長篇 長編"
"ちょうへんせい 長編成"
"ちょうほ 調歩"
"ちょうほう 長方 諜報 重宝"
"ちょうほうけい 長方形"
"ちょうほんにん 張本人 帳本人"
"ちょうぼ 張簿 帳簿"
"ちょうぼいん 長母音"
"ちょうぼう 眺望"
"ちょうまる 朝丸"
"ちょうみ 調味"
"ちょうみつ 稠密"
"ちょうみりょうひ 調味料費"
"ちょうみん 町民"
"ちょうめ 丁目"
"ちょうめい 長命 町名"
"ちょうめいれいご 長命令語"
"ちょうめん 帖面 帳面"
"ちょうめんづら 帳面面"
"ちょうもく 鳥目"
"ちょうもん 聴聞 長門 弔問"
"ちょうや 聴野"
"ちょうやく 超訳 跳躍"
"ちょうゆう 町有"
"ちょうよう 重用 町陽 重陽 徴用"
"ちょうらく 凋落"
"ちょうり 嘲詈 蝶理 調理"
"ちょうりつ 町立 調律"
"ちょうりなべ 調理鍋"
"ちょうりば 調理場"
"ちょうりゅう 潮流"
"ちょうりゅうまい 長粒米"
"ちょうりょう 跳梁"
"ちょうりょく 聴力 張力"
"ちょうるい 鳥類"
"ちょうれい 朝礼"
"ちょうれいか 張麗華"
"ちょうれいぼかい 朝令暮改"
"ちょうれん 長連"
"ちょうろう 嘲弄 長老"
"ちょうわ 調和"
"ちょうわおん 長和音"
"ちょきん 貯金"
"ちょきんばこ 貯金箱"
"ちょく 陟 躅 稙 敕 飭 勅 捗 直"
"ちょくえい 直衛 直営"
"ちょくえん 直掩"
"ちょくおん 直音"
"ちょくか 直下"
"ちょくげき 直撃"
"ちょくげきだん 直撃弾"
"ちょくげん 直言"
"ちょくこうりょうようでんしゃ 直交両用電車"
"ちょくご 勅語 直後"
"ちょくさいてき 直截的"
"ちょくし 勅旨 勅使 直視"
"ちょくしゃ 直射"
"ちょくしゅつ 直出"
"ちょくしょ 勅書"
"ちょくしょう 勅詔"
"ちょくしょうてん 直焦点"
"ちょくしん 直進"
"ちょくしんしゃ 直進車"
"ちょくじ 直示"
"ちょくじょう 直情 直上"
"ちょくせい 直生"
"ちょくせき 直積"
"ちょくせつ 直截 直接"
"ちょくせつこう 直接光"
"ちょくせつせん 直接戦"
"ちょくせつぜい 直接税"
"ちょくせつは 直接波"
"ちょくせつばち 直接鉢"
"ちょくせつひ 直接費"
"ちょくせん 勅撰 直線"
"ちょくせんび 直線美"
"ちょくぜい 直税"
"ちょくぜん 直前"
"ちょくそう 直送"
"ちょくぞく 直属"
"ちょくたつ 直達"
"ちょくたつは 直達波"
"ちょくちょう 直腸"
"ちょくつう 直通"
"ちょくで 直出"
"ちょくとう 勅答 直答"
"ちょくどう 直動"
"ちょくにゅう 直入"
"ちょくにん 勅任"
"ちょくはん 直販"
"ちょくばい 直売"
"ちょくふ 直付"
"ちょくほう 直方"
"ちょくほうたい 直方体"
"ちょくめん 直面"
"ちょくやく 直訳"
"ちょくゆ 直喩"
"ちょくゆしゅつ 直輸出"
"ちょくゆにゅう 直輸入"
"ちょくりつ 直立"
"ちょくりつけい 直立茎"
"ちょくりつし 直立枝"
"ちょくりゅう 直流"
"ちょくりゅうがわでんあつ 直流側電圧"
"ちょくれい 直隷 勅令"
"ちょくれつ 直列"
"ちょくわ 直和"
"ちょげん 緒言"
"ちょこ 猪口 チョコ"
"ちょこう 著効"
"ちょこざい 猪口才"
"ちょこれーと 貯古齢糖"
"ちょさく 著作"
"ちょさくけんぽうじょう 著作権法上"
"ちょしゃ 著者"
"ちょしゃあて 著者宛"
"ちょしゃめいじゅん 著者名順"
"ちょしょ 著書"
"ちょじゅつ 著述"
"ちょじゅつか 著述家"
"ちょすい 貯水"
"ちょすいそう 貯水槽"
"ちょすいち 貯水池"
"ちょすかべ 長宗我部"
"ちょせつけい 調節系"
"ちょせん 緒戦"
"ちょぞう 貯蔵"
"ちょぞうこ 貯蔵庫"
"ちょぞうこん 貯蔵根"
"ちょぞうしゅ 貯蔵酒"
"ちょちく 貯蓄"
"ちょっか 直下"
"ちょっかい 直快"
"ちょっかく 直角 直覚"
"ちょっかっこう 直滑降"
"ちょっかつ 直轄"
"ちょっかん 直管 直感 直観"
"ちょっかんひりつ 直間比率"
"ちょっき 直帰"
"ちょっきゅう 直球"
"ちょっきん 直近"
"ちょっけい 直系 直径"
"ちょっけいやく 直径約"
"ちょっけつ 直結"
"ちょっこう 直航 直行 直交"
"ちょっこうわ 直交和"
"ちょっと 一寸"
"ちょとつ 猪突"
"ちょはっかい 猪八戒"
"ちょへん 著変"
"ちょぼく 貯木"
"ちょめい 著明 著名"
"ちょりつ 佇立"
"ちょりゅう 貯留"
"ちょろん 緒論"
"ちょんがけ 丁斧掛け"
"ちょんぼ 錯和 チョンボ"
"ちょんまげ 丁髷"
"ちょんりま 千里馬"
"ちよ 千代"
"ちようだ 千代"
"ちよかわ 千代川"
"ちよくら 千代倉"
"ちよこ 千代子"
"ちよだ 千代田"
"ちよの 千代乃"
"ちよまる 千代丸"
"ちよろず 千万"
"ちらく 地落"
"ちらし チラシ"
"ちらん 知覧"
"ちり 智利 塵 地理"
"ちりあくた 塵芥"
"ちりいん 地理院"
"ちりはま 千里浜"
"ちりめん 縮緬"
"ちりゃく 智略 知略"
"ちりゅう 知立"
"ちりょう 治療"
"ちりょうたいせい 診療体制"
"ちりょうちゅう 治寮中"
"ちりょうひ 治療費"
"ちりょうやく 治療薬"
"ちりょく 地力 知力"
"ちれい 地霊"
"ちわ 地和 痴話"
"ちわく 地惑"
"ちん 鴆 闖 鎭 趁 碪 珎 狆 抻 枕 チン 砧 朕 珍 沈 椿 鎮 陳 賃"
"ちんあげ 賃上げ"
"ちんあつ 鎮圧"
"ちんあん 珍案"
"ちんか 鎮火 沈下"
"ちんかきょう 沈下橋"
"ちんがし 賃貸し"
"ちんがり 賃借り"
"ちんき 丁幾 珍奇"
"ちんきゃく 珍客"
"ちんきゅう 陳宮"
"ちんきろく 珍記録"
"ちんきん 沈金"
"ちんぎん 賃金"
"ちんげい 珍芸"
"ちんこう 沈香 沈降"
"ちんこん 鎮魂"
"ちんこんか 鎮魂歌"
"ちんさ 沈渣"
"ちんさげ 賃下げ"
"ちんざ 鎮座"
"ちんざんそう 椿山荘"
"ちんし 沈思"
"ちんしゃ 陳謝"
"ちんしゃく 賃借"
"ちんしゅ 珍手 珍種"
"ちんじ 珍事"
"ちんじゃく 賃借"
"ちんじゅ 鎮守"
"ちんじゅう 珍重 珍獣"
"ちんじゅつ 陳述"
"ちんじょう 陳情"
"ちんすい 沈水"
"ちんせい 鎮静"
"ちんせき 枕席 珍石"
"ちんせつ 珍説"
"ちんせん 沈船"
"ちんぜい 鎮西"
"ちんたい 沈滞 賃貸"
"ちんたいぎょう 賃貸業"
"ちんたいしゃく 賃貸借"
"ちんだん 沈檀"
"ちんだんきだん 珍談奇談"
"ちんちゃく 沈着"
"ちんちょう 珍重"
"ちんちょうげ 沈丁花"
"ちんつう 鎮痛"
"ちんつうやく 鎮痛薬"
"ちんてい 鎮定"
"ちんでん 沈澱 沈殿"
"ちんとう 枕頭"
"ちんとうびょう 沈頭鋲"
"ちんどうしき 沈胴式"
"ちんどうちゅう 珍道中"
"ちんにゅう 闖入"
"ちんねん 珍念"
"ちんばめん 珍場面"
"ちんばん 珍盤"
"ちんぱん 青幇"
"ちんぴん 珍品"
"ちんぶ 鎮撫"
"ちんぶん 珍聞"
"ちんぷ 陳腐"
"ちんぼつ 沈没"
"ちんぼつせん 沈没船"
"ちんぽう 珍宝"
"ちんぽこ 似指"
"ちんみ 珍味"
"ちんみょう 珍妙"
"ちんめい 珍名"
"ちんめん 沈湎"
"ちんもく 沈黙"
"ちんりつ 賃率"
"ちんりょう 賃料"
"ちんりろん 珍理論"
"ちんれつ 陳列"
"ちんれつだな 陳列棚"
"ぢ 地 痔"
"ぢあけ 地上げ"
"ぢか 直 近"
"ぢくぢ 忸怩"
"ぢぐち 地口"
"ぢごく 地獄"
"ぢさん 持参"
"ぢざけ 地酒"
"ぢしん 地震"
"ぢぞく 持続"
"ぢだい 地代"
"ぢとり 地鶏"
"ぢどり 地鶏"
"ぢば 地場"
"ぢばく 地縛"
"ぢひびき 地響き"
"ぢふぶき 地吹雪"
"ぢみ 地味"
"ぢみち 地道"
"ぢめん 地面"
"ぢもと 地元"
"ぢゅう 中"
"つ 柘 晦 積 付 都 津"
"つーりすと ツーリスト"
"つーりんぐ ツーリング"
"つーる ツール"
"つあー ツアー"
"つい 縋 對 築 遂 堆 墜 槌 椎 鎚 追 対"
"ついおく 追憶"
"ついか 追加"
"ついかとうりょくりょう 追加登録料"
"ついかんばん 椎間板"
"ついき 築城 立木 追記"
"ついきえききんぺん 立木駅近辺"
"ついきゅう 追給 追究 追求 追及"
"ついきん 追金"
"ついく 対句"
"ついげき 追撃"
"ついこうちゅう 遂行中"
"ついこつ 椎骨"
"ついご 対語"
"ついし 墜死 追試"
"ついしけん 追試験"
"ついしょう 追従"
"ついしん 追信 追伸"
"ついじっけん 追実験"
"ついじゅう 追従"
"ついじゅく 追熟"
"ついすう 対数"
"ついずい 追随"
"ついせいせい 対生成"
"ついせき 追跡"
"ついそ 追訴"
"ついそう 追想 追走"
"ついたい 椎体"
"ついたいけん 追体験"
"ついたち 朔日 １日 一日"
"ついたて 衝立"
"ついちょう 追徴"
"ついちょうがく 追徴額"
"ついで 尋いで 序 次いで 序で"
"ついとう 追悼"
"ついとつ 追突"
"ついに 遂に 終に"
"ついにん 追認"
"ついび 追尾"
"ついふく 追復"
"ついほ 追補"
"ついほう 追放"
"ついぼ 追慕"
"ついらく 墜落"
"ついらくし 墜落死"
"ついろく 追録"
"ついん ツイン"
"つう 痛 通"
"つういいそう 字一色"
"つういん 痛飲 通院"
"つううん 通運"
"つうえん 通園"
"つうか 通貨 通過"
"つうかい 通快 痛快"
"つうかきゃく 通過客"
"つうかく 痛覚"
"つうかん 通巻 通関 痛感"
"つうがく 通学"
"つうがくろ 通学路"
"つうき 通気"
"つうきこう 通気孔 通気口"
"つうきん 通勤"
"つうきんかいとく 通勤快特"
"つうきんきゃく 通勤客"
"つうきんしゃ 通勤車"
"つうきんひ 通勤費"
"つうきんろ 通勤路"
"つうぎょう 通暁"
"つうけん 東北大学電気通信研究所 電気通信研究所 通研"
"つうげき 痛撃"
"つうこう 通好 通交 通工 通行"
"つうこうけん 通行券"
"つうこうしゃ 通行車"
"つうこうどめ 通行止"
"つうこく 通告"
"つうこん 痛恨"
"つうごのみ 通好み"
"つうさん 通算 通産"
"つうさんぎかん 通商産業技官"
"つうさんげつ 通算月"
"つうさんしょう 通商産業省 通産相 通産省"
"つうし 通史"
"つうしょう 通商 通称"
"つうしん 通信"
"つうしんがたじゅしんき 通信型受信機"
"つうしんけいいっぱん 通信系一般"
"つうしんし 通信士"
"つうしんひ 通信費"
"つうしんへい 通信兵"
"つうしんぼ 通信簿"
"つうしんもう 通信網"
"つうしんろ 通信路"
"つうじ 通時"
"つうじかい 通字解"
"つうじょう 通常"
"つうじょうこん 通常婚"
"つうじょうだん 通常弾"
"つうすい 通水"
"つうせつ 痛切 通説"
"つうそうけん 通総研"
"つうそうていおん 通奏低音"
"つうそく 通則"
"つうぞく 通俗"
"つうたつ 通達"
"つうだ 痛打"
"つうち 通知"
"つうちょう 通牒 通帳"
"つうてん 痛点"
"つうてんかく 通天閣"
"つうでん 通電"
"つうどう 通導"
"つうどく 通読"
"つうねん 通念 通年"
"つうはん 通販"
"つうはんてん 通版店"
"つうばん 通番"
"つうぱい 字牌"
"つうひ 通臂 通費"
"つうふう 痛風 通風"
"つうふうこう 通風口"
"つうぶん 通分"
"つうほう 通報"
"つうめ 通目"
"つうや 通夜"
"つうやく 通訳"
"つうよう 痛痒 通用"
"つうようぐち 通用口"
"つうようもん 通用門"
"つうらい 通来"
"つうらん 通覧"
"つうれい 通例"
"つうれつ 痛烈"
"つうろ 通路"
"つうろん 通論"
"つうわ 通話"
"つえ 拐 杖"
"つか 冢 柄 束 塚"
"つかい 使い"
"つかいすて 使い捨て 使い棄て"
"つかいみち 使い途 使い道"
"つかいもの 使い物 使いもの"
"つかくち 塚口"
"つかぐち 塚口"
"つかこし 塚越"
"つかごし 塚越"
"つかさ 曹 元 司"
"つかしま 塚島"
"つかしん ツカシン"
"つかたに 塚谷"
"つかだ 束田 塚田"
"つかの 塚野"
"つかのま 束の間"
"つかのめ 塚目"
"つかはら 塚原 束原"
"つかみ 掴み"
"つかみなげ 掴み投げ"
"つかむ 攫 搏"
"つかもと 塚本"
"つかれ 疲れ"
"つかわれかた 使われ方"
"つが 都賀 栂"
"つがい 津飼"
"つがいけ 栂池"
"つがる 津軽"
"つがるじゃみせん 津軽三味線"
"つがるわん 津軽湾"
"つがわ 対川 津川"
"つき 憑き 突き 欟 付き 築 槻 付 月"
"つきあい 付き合い 付合"
"つきあう 付き合う"
"つきあげ 突き上げ"
"つきあげぐん 築上郡"
"つきあたま 月頭"
"つきいち 月一"
"つきおか 月岡"
"つきおとし 突き落とし"
"つきおろしね 月卸値"
"つきかいひ 月会費"
"つきかげ 月影"
"つきがけ 月掛け"
"つきがせ 月ヶ瀬"
"つきがた 月形"
"つききち 月基地"
"つきぎめ 月極め"
"つきぎり 月限"
"つきこ 月子"
"つきこうはん 月後半"
"つきごと 月毎"
"つきさっぷ 月寒"
"つきさむ 月寒"
"つきしま 月島"
"つきしょじゅん 月初旬"
"つきじ 築地"
"つきじぐち 築地口"
"つきすう 月数"
"つきすうかいくらい 月数回位"
"つきずえ 月末"
"つきせかい 月世界"
"つきそい 付添い 付添"
"つきそいかんごひ 付添看護費"
"つきたおし 突き倒し"
"つきたて 月舘"
"つきだし 突き出し"
"つきだて 築館 月舘"
"つきづき 月々"
"つきていど 月程度"
"つきなみ 槻並 月並"
"つきなんにち 月何日"
"つきの 月野"
"つきのき 槻木"
"つきのはら 月野原"
"つきばらい 月払い"
"つきひ 月日"
"つきひめ 月姫"
"つきびと 付き人"
"つきへいきん 月平均"
"つきべつ 月別"
"つきぼし 月星"
"つきみ 月見"
"つきみそう 月見草"
"つきもの 憑き物 付物 付き物 つき物"
"つきやく 月役"
"つきやま 築山"
"つきよ 月夜"
"つきよだ 月夜田"
"つきよの 月夜野"
"つきわり 月割"
"つぎ 次"
"つぎお 次雄 次夫 次男"
"つぎき 接木 継木 継ぎ木"
"つぎきれ 継切"
"つぎつぎ 次々"
"つぎて 継ぎ手"
"つぎのすけ 継之助"
"つぎめ 継目"
"つく 津久 筑"
"つくい 津久井"
"つくいこ 津久井湖"
"つくいはま 津久井浜"
"つくえ 机"
"つくえがた 机型"
"つくし 土筆 筑紫"
"つくだ 附田 佃"
"つくだいびょういん 筑大病院"
"つくだじま 佃島"
"つくだに 佃煮"
"つくづく 熟"
"つくで 作手"
"つくと 津久戸"
"つくば 筑波"
"つくばさん 筑波山"
"つくばし つくば市"
"つくばだいがくだい 筑波大学第"
"つくばだいしゃこう 筑波大社工"
"つくばね 筑波嶺"
"つくばはく 筑波博"
"つくみ 津久見"
"つくも 九十九"
"つくもがみ 九十九髪 付喪神"
"つくよみ 月讀み"
"つくり 旁 傍 作り"
"つくりて 作り手"
"つくろい 繕"
"つぐ 津具 嗣"
"つぐお 嗣雄"
"つぐとし 次利"
"つぐとも 嗣朋 嗣智"
"つぐのぶ 嗣信"
"つぐみ 鶫"
"つぐも 津雲"
"つけ 漬 漬け 付"
"つけかえ 付替"
"つけかた 付け方"
"つけたし 付け足し"
"つけち 付知"
"つけづめ 付け爪"
"つけね 付け根"
"つけもの 漬け物 漬物"
"つけやきば 付け焼刃"
"つける 付ける"
"つげ 都祁 拓殖 柘植 柘"
"つげぐち 告げ口"
"つごう 都合"
"つさか 津坂"
"つざき 津崎"
"つし 都志 津市"
"つしま 津嶋 対馬 津島"
"つしまかなめ 津島要"
"つじ 辻"
"つじい 辻井"
"つじうら 辻占"
"つじうらない 辻占い"
"つじおか 辻岡"
"つじかわ 辻川"
"つじがどう 辻ヶ堂"
"つじぎみ 辻君"
"つじさわ 辻沢"
"つじした 辻下"
"つじた 辻田"
"つじつま 辻褄"
"つじどう 辻堂"
"つじの 辻野"
"つじばしゃ 辻馬車"
"つじむら 辻村"
"つじもと 辻元 辻本"
"つずき 都築"
"つた 樢 蔦"
"つたき 津滝"
"つだ 津田"
"つだじゅく 津田塾"
"つだぬま 津田沼"
"つち 椎 壌 鎚 槌 土"
"つちい 土居 土井"
"つちうら 土浦"
"つちかべ 土壁"
"つちかわ 土川"
"つちくれ 土塊 土くれ"
"つちぐも 蝪"
"つちけいろ 土気色"
"つちけむり 土煙"
"つちこ 土子"
"つちた 土田"
"つちだ 槌田 土田"
"つちとい 土樋"
"つちとりもちもく ツチトリモチ目"
"つちのえ 戊"
"つちのえいぬ 戊戌"
"つちのえうま 戊午"
"つちのえさる 戊申"
"つちのえたつ 戊辰"
"つちのえとら 戊寅"
"つちのえね 戊子"
"つちのと 己"
"つちのとい 己亥"
"つちのとう 己卯"
"つちのとうし 己丑"
"つちのととり 己酉"
"つちのとひつじ 己未"
"つちのとみ 己巳"
"つちはし 土橋"
"つちぼこり 土埃"
"つちもと 土本"
"つちや 土谷 土家 土屋"
"つちやま 土山"
"つちゆ 土湯"
"つっけんどん 突慳貪"
"つっこみ 突込み"
"つつ 砲 筒"
"つつい 筒井"
"つつが 筒賀 恙"
"つつがむし 恙虫"
"つつぐち 筒口"
"つつしんで 謹んで"
"つつじ 躑躅 榴"
"つつじがおか つつじヶ丘 榴ヶ岡 榴岡"
"つつじもく ツツジ目"
"つつじょう 筒状"
"つつなか 筒中"
"つつみ 愼 恙 堤 包 筒見 提"
"つつみがみ 包み紙"
"つつみまち 堤町"
"つつもたせ 美人局"
"つづ 通津"
"つづき 都築 綴喜 続き"
"つづみ 鼓 皷"
"つづらおり 九十九折り"
"つづらふじか ツヅラフジ科"
"つづり 綴"
"つづりかたきょうしつ 綴方教室"
"つづりじ 綴り字"
"つて 伝手"
"つと 衝と"
"つとに 夙に"
"つとむ 力 勤 努 勉 務"
"つとめ 勤め"
"つとめて 努めて"
"つど 津戸 都度"
"つどい 集"
"つな 津名 綱"
"つなお 綱男"
"つなぎ 津奈木 繋"
"つなしま 綱嶋 綱島"
"つなみ 津波"
"つなわたり 綱渡 綱渡り"
"つなん 津南"
"つね 桓 経 恆 典 恒 常"
"つねあき 常明"
"つねお 常雄 常夫 常男 恒雄 恒夫 恒男"
"つねかわ 恒川"
"つねきち 常吉"
"つねこ 恒子"
"つねじ 常次"
"つねずみ 常澄"
"つねたけ 典武 恒毅"
"つねづね 常々"
"つねとう 恒任 恒藤"
"つねとし 恒敏"
"つねとよ 常豊"
"つねなが 常長"
"つねに 常に"
"つねのり 恒憲"
"つねひこ 恒彦"
"つねひごろ 常日頃"
"つねひら 恒平"
"つねひろ 常広 常廣 恒博 恒宏"
"つねまさ 恒正"
"つねもり 常森"
"つねやす 経康 常安"
"つねゆき 常幸 恒行"
"つねよ 常与"
"つねよし 常吉 恒美 恒吉"
"つの 都農 津野 都濃 角"
"つのおか 角岡"
"つのがい 角皆"
"つのごろう 角五郎"
"つのだ 角田"
"つのぶえ 角笛"
"つはもの 兵"
"つはら 津原"
"つば 鐔 唾 鍔"
"つばい 椿井"
"つばき 椿"
"つばきい 椿井"
"つばきか ツバキ科"
"つばきさんじゅうろう 椿三十郎"
"つばきしゅぞう 椿酒造"
"つばきはら 椿原"
"つばきひめ 椿姫"
"つばきもとちえいん 椿本チエイン"
"つばきやま 椿山"
"つばさ 翅 翼"
"つばた 津幡"
"つばめ 燕"
"つばめざわ 燕沢"
"つひに 遂に 終に"
"つぶ 粒"
"つぶさき 粒崎"
"つぶさに 備に 悉に 具に"
"つぶす 潰"
"つぶて 礫"
"つぶやき 呟き"
"つぶら 円"
"つぶらや 円谷"
"つべつ 津別"
"つぼ 壺 坪 壷"
"つぼい 壷井 坪井"
"つぼうち 坪内"
"つぼかわ 坪川"
"つぼくら 坪倉"
"つぼさき 坪崎"
"つぼすう 坪数"
"つぼた 坪田"
"つぼだけ 坪岳"
"つぼね 局"
"つぼはち つぼ八"
"つぼみ 莟 蕾"
"つま 都万 褄 嬬 妻"
"つまい 妻井"
"つまお 妻夫"
"つまごい 妻恋 嬬恋 つま恋"
"つまさき つま先 爪先"
"つまどり 褄取り"
"つまびき 爪弾き"
"つまびらか 審らか 詳らか"
"つまみぐい 摘み食い 撮み食い つまみ食い"
"つみ 詰み 辟 罪"
"つみあげ 積み上げ"
"つみいしき 罪意識"
"つみかえ 積み替え"
"つみかさね 積み重ね"
"つみき 積木"
"つみきん 積み金"
"つみこみ 積み込み"
"つみたて 積立て 積立"
"つみに 積み荷 積荷"
"つみほろぼし 罪滅ぼし"
"つむがり 都牟刈"
"つむぎ 紡 紡木 紬"
"つむじかぜ 旋風"
"つむら 津村"
"つめ 爲 爰 爬 爭 詰め 詰 爪"
"つめあわせ 詰合せ"
"つめえり 詰襟"
"つめご 詰碁"
"つめさき 爪先"
"つめしょ 詰所"
"つめしょうぎ 詰将棋"
"つめすじ 詰筋"
"つめもの 詰め物"
"つも 模"
"つもあがり 自模和了"
"つもほう 自模和"
"つもり 津守"
"つや 艷 艶 通夜"
"つやけし 艶消"
"つやざき 津屋崎"
"つやだし 艶出"
"つやま 津山"
"つゆ 露 梅雨"
"つゆあけ 梅雨明"
"つゆいり 梅雨入"
"つゆき 露木"
"つゆくさもく ツユクサ目"
"つゆこ 露子"
"つゆごろ 梅雨頃"
"つゆぞら 梅雨空"
"つゆどき 梅雨時"
"つゆはし 露橋"
"つゆはらい 露払い"
"つよき 強気"
"つよさ 強さ"
"つよし 津義 毅師 剛士 強 剛 毅"
"つよび 強火"
"つよみ 強味"
"つら 面"
"つらがまえ 面構え"
"つらなり 連なり"
"つらら 氷柱"
"つり 吊 釣"
"つりあい 釣り合い 釣合"
"つりいと 釣糸"
"つりおとし 吊り落とし"
"つりかた 釣り方"
"つりかわ 釣り革 吊革 吊り皮"
"つりかんけいしゃ 釣関係者"
"つりがき 釣書"
"つりがけでんしゃ 釣掛電車"
"つりがね 釣鐘 釣り鐘"
"つりがねがた 釣鐘形"
"つりぐ 釣具 釣り具"
"つりこうこく 吊り広告"
"つりざお 釣竿"
"つりしょ 釣書"
"つりせん 釣銭"
"つりたに 釣谷"
"つりだし 吊り出し"
"つりば 釣り場"
"つりばし 吊橋"
"つりびと 釣人 釣り人"
"つりぶね 釣船"
"つりほう 釣法"
"つりぼり 釣堀"
"つる 敦 寉 蔓 都留 弦 鶴"
"つるい 鶴居"
"つるいち 鶴一"
"つるえ 鶴江 鶴枝"
"つるおか 鶴岡"
"つるかめ 鶴亀"
"つるかめざん 鶴亀算"
"つるかわ 鶴川"
"つるが 鶴我 鶴賀 敦賀"
"つるがこう 敦賀港"
"つるがしま 鶴ヶ島"
"つるがみね 鶴ヶ峰"
"つるがや 鶴ヶ谷"
"つるきえき 鶴来駅"
"つるぎ 釼 剱 劒 劔 劍 鶴来 剣"
"つるぎざき 剣崎"
"つるこう 鶴光"
"つるさき 鶴崎"
"つるしま 鶴島"
"つるじろう 鶴次郎"
"つるぞう 鶴蔵"
"つるた 鶴田"
"つるたろう 鶴太郎"
"つるだ 鶴田"
"つるはぎ 鶴脛"
"つるはし 鶴嘴 鶴橋"
"つるふじ 鶴藤"
"つるべ 鶴瓶"
"つるま 鶴間"
"つるまい 鶴舞"
"つるまき 鶴巻"
"つるみ 鶴見"
"つるみず 鶴水"
"つるや 鶴屋 鶴谷"
"つるやま 鶴山"
"つれ 連れ"
"つれづれ 徒然"
"つれづれぐさ 徒然草"
"つわの 津和野"
"つわもの 兵 強者"
"つんどく 積ん読 積讀"
"つんぼ 聾"
"づ 津 図"
"づか 冢 塚"
"づかい 使い"
"づくえ 机"
"づくし 尽くし"
"づくり 作り"
"づけ 付け 付"
"づつう 頭痛"
"づのう 頭腦"
"づま 妻"
"づみ 詰み"
"づめ 詰め 詰"
"づれ 連れ"
"て 〒 弖 手"
"てーぶる テーブル"
"てーぷ テープ"
"てーま テーマ"
"てあい 手合"
"てあか 手垢"
"てあし 手足"
"てあしくちびょう 手足口病"
"てあたりしだい 手当たり次第"
"てあて 手当て 手当"
"てあぶり 手焙り"
"てあみ 手編み 手編"
"てあら 手荒"
"てあらい 手洗 手洗い"
"てぃー ティー"
"てぃしゅ ティシュ"
"てぃしゅー ティシュー"
"てぃじろ Ｔ字路"
"てぃっしゅ ティッシュ"
"てい 滞 鵜 綴 體 騁 酲 遞 遉 逞 軆 躰 詆 觝 羝 碵 睇 眤 牴 渟 涕 楴 棣 柢 幀 嚏 嚔 啼 叮 酊 薙 第 体 掟 丁 偵 剃 亭 悌 貞 汀 碇 梯 禎 挺 呈 堤 廷 庭 帝 袋 停 底 弟 抵 鄭 蹄 逓 釘 鼎 諦 提 訂 締 艇 程 邸 定 低"
"ていあつ 低圧"
"ていあん 提案"
"ていい 低位 定位"
"ていいき 低域"
"ていいち 定位置 禎一 貞一"
"ていいん 定員"
"ていいんせいかいそく 定員制快速"
"ていいんわれ 定員割"
"ていうん 低運"
"ていえん 定演 庭園"
"ていおう 帝王"
"ていおん 定温 低音 低温"
"ていか 定價 定価 低下"
"ていかい 低徊"
"ていかかくしゃ 低価格車"
"ていかく 定格"
"ていかん 帝冠 定感 定款"
"ていかんかく 定間隔"
"ていかんし 定冠詞"
"ていが 定芽"
"ていがく 低額 定額 停学"
"ていき 提起 定期"
"ていきいれ 定期入"
"ていきかいいんけん 定期会員券"
"ていききゃく 定期客"
"ていきけん 定期券"
"ていきせん 定期戦"
"ていきつえんしゃ 定喫煙者"
"ていきてんけんぼ 定期点検簿"
"ていきゅう 定休 庭球 低級"
"ていきょう 貞享 帝京 提供"
"ていきょじゅう 挺拳銃"
"ていぎ 提議 定義"
"ていぎたい 定義体"
"ていぎん 帝銀"
"ていくう 低空"
"ていけい 梯形 定形 定型 提携"
"ていけつ 挺傑 締結"
"ていけん 定見 定検"
"ていげん 低弦 低限 低減 提言"
"ていげんめいほう 定言命法"
"ていこ 艇庫 挺庫 貞子"
"ていこう 低高 定項 抵抗"
"ていこうがいしゃ 低公害車"
"ていこく 帝國 定刻 帝国"
"ていこくぐん 帝国軍"
"ていさい 体裁"
"ていさつ 偵察"
"ていさん 帝産"
"ていざいは 定在波"
"ていざん 定残 低山"
"ていざんぎょう 定残業"
"ていざんけい 定山溪"
"ていし 手石 定詞 停止"
"ていしえき 停止液"
"ていしき 定式"
"ていしつ 廷叱 低質 低湿"
"ていしつごしょうてん 帝室御賞典"
"ていしゃ 停車"
"ていしゅ 亭主"
"ていしゅう 挺秀"
"ていしゅうにゅう 定収入"
"ていしゅうはすう 低周波数域"
"ていしゅく 貞淑"
"ていしゅつ 挺出 堤出 提出"
"ていしゅつじょ 提出所"
"ていしゅつよう 低出葉"
"ていしょ 低所"
"ていしょう 提唱"
"ていしょく 牴触 停職 定職 定食 抵触"
"ていしん 遞信 挺進 逓信 挺身 定進"
"ていじ 丁字 禎二 禎治 悌二 貞二 貞治 貞次 低次 呈示 定時 提示"
"ていじごと 定時毎"
"ていじゅう 定住"
"ていじょ 貞女"
"ていじょう 堤上 呈上 定常"
"ていじょうこう 定常光"
"ていじょうたい 定常態"
"ていじょうは 定常波"
"ていじん 帝人"
"ていすう 艇数 定数"
"ていすうかしゅほう 定式化手法"
"ていせい 帝制 低声 帝政 貞静 定性 訂正"
"ていせいいん 訂正印"
"ていせき 艇積 定石"
"ていせきぶん 定積分"
"ていせつ 挺節 貞節 定説"
"ていせつほうほう 締切方法"
"ていせん 停船 停戦"
"ていぜん 挺然"
"ていそ 提訴"
"ていそう 底層 低層 貞操"
"ていそうりゅう 底層流"
"ていそく 低速"
"ていそくかいてん 定速回転"
"ていそくしゃ 低速車"
"ていそくじ 定速時"
"ていそくすう 定足数"
"ていそくそうこう 定速走行"
"ていそくど 定速度"
"ていそしき 定礎式"
"ていぞう 貞蔵"
"ていぞく 低俗"
"ていたい 定退 堤体 停滞"
"ていたく 邸宅"
"ていたらく 為体"
"ていだい 帝大"
"ていだん 鼎談"
"ていち 定値 定置 低地"
"ていちあみ 定置網"
"ていちそうこうねんぴ 定地走行燃費"
"ていちゃく 定着"
"ていちゃくえき 定着液"
"ていちょう 鄭重 低潮 丁重 低調"
"ていちょく 挺直"
"ていっぱい 手一杯"
"ていてつ 蹄鉄"
"ていてん 定点"
"ていでん 遞傳 停電"
"ていでんあつ 定電圧"
"ていでんあつげん 定電圧源"
"ていでんりゅう 定電流"
"ていでんりゅうげん 定電流源"
"ていでんりょくふか 定電力負荷"
"ていと 帝都"
"ていとう 低頭 提灯 抵当"
"ていとく 提督"
"ていど 程度"
"ていね 手稲"
"ていねい 丁寧"
"ていねこうざん 手稲砿山"
"ていねん 定年 停年"
"ていねんごろ 定年頃"
"ていのう 低能"
"ていはく 停泊"
"ていはつ 剃髪"
"ていばいき 逓倍器"
"ていばつ 挺抜"
"ていばん 定版 定番"
"ていひょう 定評"
"ていぶ 底部"
"ていへん 底辺"
"ていほん 底本 定本"
"ていぼう 堤防"
"ていぼく 低木"
"ていまい 弟妹"
"ていめい 低迷"
"ていめん 底面"
"ていもう 剃毛"
"ていやく 締約"
"ていやねしゃ 低屋根車"
"ていゆうせん 艇優先"
"ていよう 堤要"
"ていよく 低翼"
"ていらく 低落"
"ていり 低利 定理"
"ていりき 禎力"
"ていりつ 挺立 鼎立 定率 低率 定立"
"ていりゅう 底流 停留"
"ていりゅうじょ 停留所"
"ていりょう 定量"
"ていりょうせん 定量戦"
"ていれ 手入れ"
"ていれい 定例"
"てうす 手薄"
"てうち 手打"
"ておくれ 手遅れ"
"ておち 手落ち"
"ておの 手斧"
"ており 手織"
"てかげん 手加減"
"てかず 手数"
"てかせ 手枷"
"てが 手賀"
"てがかり 手掛り 手がかり"
"てがき 手書き 手書"
"てがた 手形"
"てがたな 手刀"
"てがぬま 手賀沼"
"てがみ 手紙"
"てがら 手柄"
"てがる 手軽"
"てがわ 手側"
"てき 嫡 逖 迪 躑 覿 糴 狄 擲 彳 廸 剔 俶 摘 擢 笛 滴 鏑 敵 適 的"
"てきあいて 敵相手"
"てきい 敵意"
"てきえい 敵影"
"てきおう 適応"
"てきおうふくぶんかつ 適応副分割"
"てきおん 適温"
"てきか 滴下 適価"
"てきかく 適格 的確"
"てきかた 敵方"
"てきかん 敵艦"
"てきがいしん 敵愾心"
"てきがわ 敵側"
"てきき 適期 敵機"
"てききどうへいき 敵機動兵器"
"てききょてん 敵拠点"
"てきぎ 適宜"
"てきぐん 敵軍"
"てきこく 敵国"
"てきごう 適合"
"てきごうしゃ 適合車"
"てきざい 適材"
"てきし 敵視"
"てきしゃ 敵車 適者"
"てきしゅつ 剔出 摘出"
"てきしょ 適所"
"てきしょく 適職"
"てきじ 適時"
"てきじだ 適時打"
"てきじょ 滌除 摘除"
"てきじょうしさつ 敵状視察"
"てきじん 敵陣"
"てきすと テキスト"
"てきせい 敵性 適性 適正"
"てきせつ 適切"
"てきせんしゃ 敵戦車"
"てきせんとうき 敵戦闘機"
"てきぜんとうぼう 敵前逃亡"
"てきそん 劇村"
"てきたい 敵対"
"てきたいし 敵対視"
"てきだん 擲彈 擲弾 敵弾"
"てきち 敵地 適地"
"てきちゅう 適中 的中"
"てきちょく 躑躅"
"てきてい 滴定"
"てきとう 適当"
"てきど 適度"
"てきどうし 敵同士"
"てきにん 適人 適任"
"てきはかいりつ 敵破壊率"
"てきはつ 摘発"
"てきばくげきき 敵爆撃機"
"てきひ 適否"
"てきふてき 適不適"
"てきへい 敵兵"
"てきほう 適法"
"てきほんきょち 敵本拠地"
"てきめん 覿面"
"てきやく 適訳 敵役 適役"
"てきよう 摘要 適用"
"てきようずみ 適用済"
"てきりょう 適量"
"てきれい 適例 適齢"
"てぎれ 手切れ"
"てぎわ 手際"
"てくせ 手くせ"
"てくだ 手管"
"てくにっく テクニック"
"てくの テクノ"
"てくのろじー テクノロジー"
"てくび 手首"
"てぐさり 手鎖"
"てぐち 手口"
"てけいさん 手計算"
"てこ 梃子 挺子 梃"
"てこいれ 梃入れ"
"てごたえ 手応え"
"てごま 手駒"
"てごめ 手籠"
"てごろ 手ごろ 手頃"
"てさき 手先"
"てさぎょう 手作業"
"てさぐり 手探り"
"てさげ 手提 手下げ"
"てさし 手差し"
"てざいく 手細工"
"てざき 手崎"
"てざし 手差し"
"てざわり 手触り"
"てしお 天塩 手塩"
"てしかが 弟子屈"
"てしがわら 勅使河原"
"てしくつちょう 弟子屈町"
"てした 手下"
"てしば 手柴"
"てしま 手嶋 手島"
"てしゅうせい 手修正"
"てしろぎ 手代木"
"てじか 手近"
"てじな 手品"
"てじま 手嶋 手島"
"てじめ 手締め"
"てじゅん 手順"
"てじょう 手錠"
"てすう 手数"
"てすじ 手筋"
"てすと テスト"
"てすり 手摺り"
"てずか 手塚"
"てせい 手製"
"てぜま 手狭"
"てぜんたい 手全体"
"てそう 手相"
"てぞん 手損"
"てたれ 手タレ"
"てだし 手出し"
"てだすけ 手助け"
"てだて 手立て"
"てだま 手玉"
"てだれ 手練"
"てちがい 手違い"
"てちょう 手帖 手帳"
"てぢか 手近"
"てっ 徹"
"てっかい 徹回 撤回"
"てっかめん 鉄仮面"
"てっかん 鉄管"
"てっき 適期 敵機 鉄器"
"てっきゅう 鉄球"
"てっきょ 剔去 撤去"
"てっきょう 鉄橋"
"てっきょうした 鉄橋下"
"てっきん 鉄琴 鉄筋"
"てっけん 鉄建 鉄拳"
"てっこう 手甲 鐵鋼 鐵鉱 鐵工 鉄工 鉄鉱 鉄鋼"
"てっこうぎょう 鉄鋼業"
"てっこうしょ 鐵綱所"
"てっこうじょ 鐵工所 鉄工所"
"てっこうせき 鉄鉱石"
"てっこうせん 鉄甲船"
"てっこうだん 徹甲弾"
"てっこつ 鉄骨"
"てっさく 鉄柵"
"てっしゅう 撤收 撤収"
"てっしょう 鉄漿 哲章"
"てっせい 哲西 鉄製"
"てっせん 鉄線"
"てっそく 鉄則"
"てったい 撤退"
"てっちゅう 鉄柱"
"てっつい 鉄鎚 鉄槌"
"てってい 徹底"
"てっとう 鉄塔"
"てっぱい 徹廃 撤廃"
"てっぱん 鉄鈑 鉄板"
"てっぱんやき 鉄板焼"
"てっぴ 鉄扉"
"てっぴつ 鉄筆"
"てっぷん 鉄粉 鉄紛"
"てっぺい 鉄平 撤兵"
"てっぺき 鉄壁 鉄璧"
"てっぺん 天辺"
"てっぽう 鉄砲"
"てっぽうだま 鉄砲玉"
"てつ 餮 鐡 銕 輟 跌 耋 屮 垤 咥 姪 綴 鐵 迭 撤 轍 徹 哲 鉄"
"てつあき 哲明"
"てついち 鉄一"
"てつお 哲臣 徹男 哲郎 哲生 鉄雄 鉄夫 鉄男 哲男 哲夫 哲雄"
"てつか 手塚"
"てつかいしょく 鉄灰色"
"てつかず 手着かず"
"てつがく 哲学"
"てつがくばたけ 哲学畑"
"てつがくろん 哲学的"
"てつき 哲樹 手付"
"てつきどう 鉄軌道"
"てつくず 鉄屑"
"てつけいたい 鉄警隊"
"てつけきん 手付金"
"てつけん 鉄研"
"てつこ 哲子 徹子"
"てつごうし 鉄格子"
"てつざい 鉄材"
"てつし 哲資 哲士 哲史"
"てつしゃりん 鉄車輪"
"てつしん 鉄芯"
"てつじ 哲士 轍次 哲至 哲志 哲嗣 哲二 哲司"
"てつじょうぎ 鉄定規"
"てつじょうもう 鉄条網"
"てつじろう 哲治郎"
"てつじん 哲人 鉄人"
"てつせい 鉄製"
"てつた 哲多"
"てつたろう 哲太郎 鉄太郎"
"てつだい 手伝い"
"てつづき 手続 手続き"
"てつづち 鉄鎚"
"てつどう 鐵道 鉄道"
"てつどうおう 鉄道王"
"てつどうぎょう 鉄道業"
"てつどうしがっかい 鉄道史学会"
"てつどうしょう 鉄道省"
"てつどうせいびぜい 鉄道整備税"
"てつどうふっけん 鉄道復建"
"てつなべ 鉄鍋"
"てつのり 哲憲"
"てつひと 鉄人 鉄一"
"てつひろ 哲宏 哲弘"
"てつびん 鉄瓶"
"てつぶろ 鉄風炉"
"てつぶん 鉄分"
"てつぶんか 鉄文化"
"てつぼう 鉄棒"
"てつまど 鉄窓"
"てつまん 徹マン"
"てつみ 哲美"
"てつめん 鉄面"
"てつめんぴ 鉄面皮"
"てつや 鉄弥 鉄也 哲哉 哲弥 哲也 徹夜"
"てつゆき 徹行 徹之"
"てつり 哲理"
"てつろ 鉄路"
"てつろう 鉄郎 徹郎 哲朗 哲郎"
"てつわん 鉄椀 鉄腕"
"てづか 手塚"
"てづかさとみ 手塚理美"
"てづかみ 手掴み"
"てづくり 手作り"
"てづまり 手詰り"
"てづめ 手詰"
"てづる 手蔓"
"てどうさ 手動作"
"てどり 手取 手取り"
"てなおし 手直し"
"てなみ 手並み"
"てならい 手習い"
"てにす テニス"
"てにもつ 手荷物"
"てにゅうりょく 手入力"
"てにをは 天爾遠波"
"てぬき 手抜き"
"てぬぐい 手拭い 手ぬぐい"
"てのひら 手の平 掌"
"てはい 手牌 手配"
"てはじめ 手始め"
"てはず 手筈"
"てはら 手原"
"てばさき 手羽先"
"てばた 手旗"
"てびき 手引き 手引"
"てびきあん 手引案"
"てびきだい 手引第"
"てびょうし 手拍子"
"てふだ 手札"
"てぶくろ 手袋"
"てぶり 手振"
"てべんとう 手弁当"
"てほん 手本"
"てま 手間"
"てまえ 点前 手前"
"てまき 手巻"
"てまくら 手枕"
"てまちん 手間賃"
"てまね 手真似"
"てまねき 手招き"
"てまひま 手間暇"
"てまり 手鞠 手毬"
"てまりうた 手鞠歌 手鞠唄 手毬唄"
"てまわし 手回し"
"てみじか 手短か 手短"
"てみやげ 手土産"
"てもち 手持 手持ち"
"てもと 手許 手元"
"てやき 手焼"
"てゆび 手指"
"てら 地球 寺"
"てらい 寺井"
"てらうち 寺内"
"てらお 寺尾"
"てらおか 寺岡"
"てらおとこ 寺男"
"てらかわ 寺川"
"てらがいと 寺垣内"
"てらがわ 寺側"
"てらくら 寺倉"
"てらこや 寺子屋"
"てらごや 寺小屋"
"てらさか 寺坂"
"てらさき 寺崎"
"てらさわ 寺澤 寺沢"
"てらした 寺下"
"てらしま 寺嶋 寺島"
"てらしょう 寺庄"
"てらじま 寺島"
"てらだ 寺田"
"てらどまり 寺泊"
"てらにし 寺西"
"てらの 寺野"
"てらまえ 寺前"
"てらまち 寺町"
"てらまちどおり 寺町通"
"てらむら 寺村"
"てらもと 寺元 寺本"
"てらやま 寺山"
"てり 輝"
"てりかえし 照り返し"
"てりやき 照り焼き"
"てりやす 輝泰"
"てりょうり 手料理"
"てる テル 照 輝"
"てるあき 輝明"
"てるい 照井"
"てるお 晃夫 光男 照雄 照夫 照男 輝夫 輝雄 晃央 輝男"
"てるき 輝樹"
"てるこ てる子 照子 輝子"
"てるたか 照貴"
"てると 照人"
"てるのぶ 照信 晧史 輝暢"
"てるのり 照則"
"てるひこ 照彦 輝彦 照比古"
"てるひさ 照久"
"てるひろ 照洋"
"てるみ 照美 輝美"
"てるみな テルミナ"
"てるもと 輝元"
"てるやす 輝泰"
"てるゆき 輝幸 輝之"
"てれあさ テレ朝"
"てれっくす テレックス"
"てれぱしー テレパシー"
"てれび テレビ"
"てれびじょん テレビジョン"
"てれや 照れ屋"
"てれん 手練"
"てわけ 手分け"
"てわざ 手技"
"てわたし 手渡し"
"てん 貼 點 鷏 鷆 靦 霑 轉 輾 躔 貂 諂 覘 腆 纒 篆 碾 癲 殄 梃 恬 忝 廛 巓 奠 壥 囀 辿 テン ， 丶 … 、 纏 殿 填 甜 添 顛 ． 展 典 転 天 店 ・ 点"
"てんあんもん 天安門"
"てんい 典韋 転位 転移"
"てんいがい 点以外"
"てんいち 天一"
"てんいむほう 天衣無縫"
"てんいり 点入"
"てんいん 転院 店員"
"てんえい 天栄"
"てんおう 天王"
"てんおんげん 点音源"
"てんか 転科 転訛 転化 添加 点火 天下 転嫁"
"てんかい 天界 転回 天海 展開"
"てんかいけい 展開形"
"てんかいちぶどうかい 天下一武道会"
"てんかしん 点加振"
"てんかす 天滓"
"てんかてい 点過程"
"てんかびと 天下人"
"てんかふん 天花粉"
"てんかれいじ 添加励磁"
"てんかわ 添川"
"てんかん 癲癇 点間 転換"
"てんが 天下 典雅"
"てんがい 天蓋 天外"
"てんがいこどく 天涯孤独"
"てんがじゃやかん 天下茶屋間"
"てんがん 点眼"
"てんがんえき 点眼液"
"てんがんやく 点眼薬"
"てんき 天氣 転機 転記 天気"
"てんきあめ 天気雨"
"てんきゅう 天球"
"てんきゅうぎ 天球儀"
"てんきょ 典拠 転居"
"てんきょう 癲狂"
"てんきん 転勤"
"てんきんひ 転勤費"
"てんぎく 天菊"
"てんぎょう 転業"
"てんくう 天空"
"てんぐ 天狗"
"てんぐう 天宮"
"てんぐだいら 天狗平"
"てんぐまい 天狗舞"
"てんけい 天啓 典型"
"てんけつ 点穴"
"てんけつごう 点結合"
"てんけん 点検"
"てんげん 点源"
"てんげんだい 天元台"
"てんこ 点呼"
"てんこう 典孝 天功 転向 転校 天候"
"てんこうげん 点光源"
"てんこうりつ 点効率"
"てんこく 篆刻 転告"
"てんご 点５"
"てんごく 天国"
"てんさ 点差"
"てんさい 甜菜 天災 天才 転載"
"てんさいじ 天才児"
"てんさく 添削"
"てんざい 点在"
"てんざん 天山"
"てんし 天子 覘視 天使"
"てんしき 点式"
"てんしげ 天繁"
"てんしじ 点支持"
"てんしゃ 転社 転写"
"てんしゃく 転借"
"てんしゃだい 転車台"
"てんしやく 天使役"
"てんしゅ 店主"
"てんしゅうごう 点集合"
"てんしゅかく 天守閣"
"てんしゅつ 転出"
"てんしゅどう 天主堂"
"てんしょ 転所 典書 篆書 添書"
"てんしょう 天昇 転生"
"てんしょうどう 天賞堂"
"てんしょく 天職 転職"
"てんしん 点心 天津 転進 転身"
"てんしんこう 天津港"
"てんしんはん 天津飯"
"てんしんらんまん 天真爛漫"
"てんじ 添字 点字 展示"
"てんじく 天竺"
"てんじしゃ 展示車"
"てんじつ 天日"
"てんじつえん 天日塩"
"てんじゅ 天寿"
"てんじょう 纏繞 添乗 天壤 天壌 天上 点状 天井"
"てんじょううら 天井裏"
"てんじょうけい 纏繞茎"
"てんじょうつり 天井吊"
"てんじん 天神"
"てんじんだいら 天神平"
"てんすい 天水"
"てんすう 点数"
"てんせい 転成 転生 天性"
"てんせいじんご 天声人語"
"てんせき 転石 転籍"
"てんせっしょく 点接触"
"てんせん 転線 転戦 点線"
"てんせんげん 点線源"
"てんぜん 恬然"
"てんそう 転送"
"てんそうろ 転送路"
"てんそく 纏足 典則 纒足 天測"
"てんそば 天蕎麦"
"てんそる テンソル"
"てんそんこうりん 天孫降臨"
"てんぞう 点像"
"てんぞく 転属"
"てんたい 転貸 天体"
"てんたいしゃく 転貸借"
"てんたいしょう 点対称"
"てんたん 恬淡"
"てんだい 天台"
"てんだいしゅう 天台宗"
"てんち 転置 転地 天地"
"てんちゅう 天諌 天誅"
"てんちゅうさつ 天中殺"
"てんちょう 天頂 店長 転調"
"てんつい 点対"
"てんてき 点滴 天敵"
"てんてきちゅう 点的中"
"てんてん ： 短点 ．．． 点々 ‥ ・・・ … 転々"
"てんてんはんそく 輾転反側"
"てんと テント"
"てんとう 天道 顛倒 点燈 転倒 点灯 店頭"
"てんとうむし てんとう虫"
"てんどう 天動 天道 天童"
"てんどうせつ 天動説"
"てんどうぼうし 転動防止"
"てんどん 天丼"
"てんない 店内"
"てんに 点２"
"てんにゅう 転入"
"てんにゅうとどけ 転入届"
"てんにょ 天女"
"てんにん 天人 転任"
"てんねん 天然"
"てんねんがき 天然牡蠣"
"てんねんしば 天然芝"
"てんねんすい 天然水"
"てんねんとう 天然痘"
"てんねんもの 天然物"
"てんねんゆき 天然雪"
"てんねんりん 天然林"
"てんのう 天王 天皇"
"てんのうきかんせつ 天皇機関説"
"てんのうざん 天王山"
"てんのうしょうあき 天皇賞秋"
"てんのうしょうはる 天皇賞春"
"てんのうしょうば 天皇賞馬"
"てんのうじ 天王寺"
"てんのうじすいぞっかん 天王寺水族館"
"てんのうず 天王州"
"てんのうせい 天王星"
"てんはいれつ 点配列"
"てんはく 天白"
"てんばい 転売"
"てんばつ 天罰"
"てんばん 天板"
"てんばんごう 店番号"
"てんぱい 顛沛 聴牌"
"てんぱく 天伯 天白"
"てんぱん 天板 典範"
"てんびき 天引き"
"てんびょう 点描"
"てんびん 天秤"
"てんびんざ 天瓶座 天秤座"
"てんぴ 天日 天火"
"てんぴじお 天日塩"
"てんぴょう 天平"
"てんぴん 天稟"
"てんぶん 天分"
"てんぷ 貼付 天賦 添付"
"てんぷく 転覆"
"てんぷら 天麩羅 天ぷら"
"てんべつ 点別"
"てんぺん 天変 転変"
"てんほう 天和"
"てんほくせん 天北線"
"てんぼう 点棒 展望"
"てんぼうしゃ 展望車"
"てんぼうせき 展望席"
"てんぼうとう 展望塔"
"てんぽ テンポ 店舗"
"てんぽう 天方 天保"
"てんぽうさん 天保山"
"てんぽうざん 天保山"
"てんぽらり テンポラリ"
"てんま 天魔 天馬 天満"
"てんまく 天幕"
"てんません 伝馬船"
"てんまちょう 伝馬町"
"てんまつ 天松 顛末"
"てんまつき 顛末記"
"てんまど 天窓"
"てんまばやし 天間林"
"てんまん 天満"
"てんまんぐう 天満宮"
"てんむす 天むす"
"てんめ 点目"
"てんめい 天明 店名 天命"
"てんめつ 点滅"
"てんめん 纏綿"
"てんもう 天網"
"てんもん 天文"
"てんもんか 天文家"
"てんや 店屋"
"てんやく 点訳"
"てんやもの 店屋物"
"てんゆう 天佑"
"てんよう 転用"
"てんらい 天来"
"てんらく 転落"
"てんらん 天覧 展覧"
"てんり 天理"
"てんりひがし 天理東"
"てんりゅう 点流 天龍 天竜"
"てんりょう 転寮"
"てんれつ 点列"
"てんれんけつ 点連結"
"てんろうせい 天狼星"
"で 出"
"でーた データ"
"でーと デート"
"であい 出合い 出会い"
"であし 出足"
"でぃーりんぐ ディーリング"
"でぃくす ディクス"
"でぃじたる ディジタル"
"でぃすかっしょん ディスカッション"
"でぃすく ディスク"
"でぃすこ ディスコ"
"でぃっしゅ ディッシュ"
"でぃなー ディナー"
"でぃれくた ディレクタ"
"でい 禰 泥"
"でいすい 泥水 泥酔"
"でいたん 泥炭"
"でいど 泥土"
"でいねい 泥濘"
"でいり 出入り"
"でいりぐち 出入り口 出入口"
"でいりゅう 泥流"
"でか 刑事"
"でかぐらむ 瓧"
"でかせぎ 出稼ぎ"
"でかた 出かた 出方"
"でかめーとる 籵"
"でかりっとる 竍"
"でがわ 出川"
"でき 溺 出来"
"できあい 溺愛"
"できあがり 出来上がり"
"できごころ 出来心"
"できごと 出来事"
"できし 溺死"
"できだか 出来高"
"できね 出来値"
"できばえ 出来栄え"
"できぼし 出来星"
"でく 木偶"
"でくのぼう 木偶の坊"
"でぐあい 出具合"
"でぐち 出口"
"でげねりあか デゲネリア科"
"でこーど デコード"
"でこぼこ 凸凹"
"でこぼこみち 凸凹道"
"でさき 出先"
"でざいな デザイナ"
"でざいなーず デザイナーズ"
"でざいん デザイン"
"でざき 出崎"
"でざわ 出沢"
"でし 弟子"
"でしいり 弟子入り"
"でしお 出汐"
"でしぐらむ 瓰"
"でしりっとる 竕"
"でじたる デジタル"
"でじま 出島"
"でじる 出汁"
"ですく デスク"
"でぞめしき 出初式"
"でた 出た"
"でたに 出谷"
"でたらめ 出鱈目"
"でだし 出出し"
"でだま 出玉"
"でっき デッキ"
"でっち 丁稚"
"でっちり 出っ尻"
"でっぱ 出っ歯"
"でづっぱり 出突っ張り"
"でづら 出面"
"でどころ 出処 出所"
"ではいり 出入り"
"ではじめ 出始め"
"でば 出刃"
"でばっく デバック"
"でばな 出鼻"
"でばぼうちょう 出歯包丁 出刃庖丁 出刃包丁"
"でばん 出番"
"でぱーと デパート"
"でびゅー デビュー"
"でふぉると デフォルト"
"でふね 出船"
"でふれ デフレ"
"でぶ デブ"
"でぶしょう 出不精"
"でぶち 出淵"
"でま 手間 デマ"
"でまえ 出前"
"でまち 出町 出待ち"
"でまちやなぎ 出町柳"
"でまど 出窓"
"でみず 出水"
"でみせ 出店"
"でむかえ 出迎え"
"でむら 出村"
"でめ 出目"
"でめとく 出目徳"
"でも デモ"
"でもと 出本"
"でもの 出物"
"でもん 出門"
"でもんすとれーしょん デモンストレーション"
"でやしき 出屋敷"
"でら 寺"
"でらっくす デラックス"
"でる 出る"
"でるた δ Δ デルタ"
"でわ 出葉 出羽"
"でわざくら 出羽桜"
"でわにしき 出羽錦"
"でわのうみ 出羽海"
"でん 黏 沺 棯 畋 甸 傳 臀 鈿 澱 殿 伝 田 電"
"でんあつ 電圧"
"でんあつけい 電圧計"
"でんあつげん 電圧源"
"でんい 電位"
"でんえもん 伝衛門"
"でんえん 田園"
"でんおん 伝音"
"でんか 電荷 伝家 電化 殿下"
"でんかい 電界 電解"
"でんかいしつ 電解質"
"でんかん 電環 電管"
"でんがく 田楽 電楽"
"でんき 傳綺 伝奇 電器 伝記 電機 電気"
"でんきおよびつうしんこうがくせんこう 電気及通信工学専攻"
"でんきがま 電気釜 電器釜"
"でんきけんそくしゃ 電気検測車"
"でんきこうじし 電気工事士"
"でんきしゃ 電気車"
"でんきじかけ 電気仕掛"
"でんきとう 電気棟"
"でんきなべ 電気鍋"
"でんきひつじ 電気羊"
"でんきもの 電気物 伝奇物"
"でんきゅう 電球"
"でんきょうしゃ 電響社"
"でんきょく 電極"
"でんきろ 電気炉"
"でんぎ 電技"
"でんぎょう 電業"
"でんけい 電計"
"でんけん 電検 電顕"
"でんけんさんしゅ 電験三種"
"でんげき 電撃"
"でんげきおう 電撃王"
"でんげん 電源"
"でんげんいり 電源入"
"でんげんしゃ 電源車"
"でんげんつき 電源付"
"でんげんようりょう 電原容量"
"でんこう 電光 電工"
"でんこうばん 電光板"
"でんごん 伝言"
"でんごんばん 伝言板"
"でんさん 電算"
"でんざい 電材"
"でんし 電子"
"でんしきょう 電子工業振興協会 電子協"
"でんしこう 電子工"
"でんしじゅう 電子銃"
"でんしだい 電視台"
"でんしは 電子波"
"でんしゃ 伝者 電車"
"でんしゃちん 電車賃"
"でんしゃみち 電車道"
"でんしょ 伝書"
"でんしょう 伝承"
"でんしょく 電飾"
"でんしょくこう 電色光"
"でんしょばと 伝書鳩"
"でんしりれい 電子リレー"
"でんしん 電信"
"でんしんばしら 電信柱"
"でんじ 電磁"
"でんじき 電磁気"
"でんじしゃく 電磁石"
"でんじは 電磁波"
"でんじば 電磁場"
"でんじゅ 伝授"
"でんじょう 電情"
"でんじょうはいこう 電場配向"
"でんじん 電人"
"でんすけ 電助"
"でんせいかん 伝声管"
"でんせつ 電設 伝説"
"でんせん 伝線 電専 伝染 電線"
"でんせんひき 電線引"
"でんせんびょう 伝染病"
"でんそう 電送 電装 伝送"
"でんそうかいじょしゃ 電装解除車"
"でんそうけん 電子技術総合研究所 電総研"
"でんそうだい 電総大"
"でんそうろ 伝送路"
"でんたく 電卓"
"でんたつ 伝達"
"でんたつろ 伝達路"
"でんたん 電探"
"でんだ 伝田"
"でんだい 電大"
"でんち 電池"
"でんちく 電蓄"
"でんちざんりょうけい 電池残量計"
"でんちゅう 電柱"
"でんちゅうけん 電中研"
"でんつう 電通"
"でんつうだい 電気通信大学"
"でんつうだいいん 電通大院"
"でんてい 電停"
"でんてつ 電鉄"
"でんでん 電々 電電"
"でんでんりつ 導電率"
"でんとう 電燈 電灯 伝統"
"でんどう 伝動 電導 殿堂 電動 伝導 伝道"
"でんどうしゃ 電動車"
"でんどうたい 伝導体"
"でんどうば 殿堂馬"
"でんねつ 電熱"
"でんねつかんけい 伝熱関係"
"でんのう 電脳"
"でんのうづくえ 電脳机"
"でんば 電場"
"でんばた 田畑"
"でんばほうれいしゅう 電波法令集"
"でんぱ 伝播 電波"
"でんぱきゅうしゅうざい 電波吸収材"
"でんぱきゅうしゅうたい 電波吸収体"
"でんぱぜい 電波税"
"でんぱた 田畑"
"でんぱち 伝八"
"でんぱてきあくじょうけん 電波的悪条件"
"でんぱとう 電波塔"
"でんぱりようぜい 電波利用税"
"でんぱん 伝搬 伝播"
"でんぱんは 伝搬波"
"でんぱんろ 伝搬路"
"でんぴょう 伝票"
"でんぶ 臀部"
"でんぶん 電文 伝文 伝聞"
"でんぷん 澱粉"
"でんぽ 田圃"
"でんぽう 伝法 電報"
"でんまーく 丁抹"
"でんまちょう 伝馬町"
"でんらい 伝来"
"でんらん 電纜"
"でんり 電離"
"でんりく 電リク"
"でんりばこ 電離箱"
"でんりゅう 電流"
"でんりゅうけい 電流計"
"でんりゅうげん 電流源"
"でんりゅうせん 電留線"
"でんりょく 電力"
"でんりょくもう 電力網"
"でんれい 電鈴 伝令"
"でんわ 電話"
"でんわぎょう 電話業"
"でんわぐち 電話口"
"でんわちょう 電話帳"
"でんわもう 電話網"
"と 砿 跿 覩 蠧 蠹 蚪 莵 荼 肚 礪 睹 汢 圖 兔 闘 度 堵 屠 菟 図 兎 塗 人 妬 斗 富 鍍 砥 砺 冨 十 杜 徒 渡 賭 戸 土 吐 途 登 都"
"とーたる トータル"
"とーれ 東レ"
"とあみ 投網"
"とい 樋 土肥 戸井 問"
"といあわせ 問合せ 問合 問い合わせ"
"といき 吐息"
"といし 礪 砥石"
"といた 戸板"
"といつ 対子"
"といとい 対々"
"といみさき 都井岬"
"といめん 対面"
"といれ トイレ"
"といれっと トイレット"
"とう 訪 樋 萄 逗 訊 諮 沓 桐 兜 稲 桶 撞 稻 疾う 鼕 黨 鬪 鬥 骰 饕 鞳 鞜 陦 閙 釖 酘 迯 蹈 讀 蟷 螳 荅 罩 纛 縢 綯 籘 竇 礑 磴 蘯 潼 溏 滕 滔 淌 濤 盜 櫂 橦 榻 棠 棹 檮 档 朸 擣 搨 搗 掉 掏 抖 幢 帑 嶝 嶌 夲 叨 剳 儻 偸 亠 撓 籐 盪 疼 橈 任 十 読 篤 登 通 當 韜 塘 宕 悼 嶋 桃 梼 涛 搭 套 淘 刀 倒 凍 父 湯 唐 豆 踏 塔 蕩 党 痘 祷 鐙 燈 騰 謄 島 筒 糖 灯 棟 到 統 陶 董 答 藤 討 冬 盗 闘 透 逃 投 東 頭 当 等"
"とうあ 東亜"
"とうあつ 等圧"
"とうあぺいんと 東亜ペイント"
"とうあん 答案"
"とうい 陶猗 当為 糖衣 東夷 等位"
"とういく 陶育"
"とういじょう 糖衣錠"
"とういす 籐椅子"
"とういち 東一"
"とういつ 統一"
"とういつせん 統一戦"
"とういつたい 統一体"
"とういつば 統一場"
"とういん 東員 頭韻 当院 登院 桐蔭 党員"
"とううつ 陶鬱"
"とうえい 東栄 東永 東映 投影"
"とうえん 登園 遠縁"
"とうえんめい 陶淵明"
"とうおう 陶泓 東欧"
"とうおん 等温 唐音"
"とうか 橙 陶家 陶化 橙火 豆果 糖化 燈下 桃花 等化 灯火 １０日 投下 燈火 当課 十日 透過 等価"
"とうかい 倒潰 当会 倒壊 韜晦 東海"
"とうかいおき 東海沖"
"とうかいかーぼん 東海カーボン"
"とうかいだいかいはつこう 東海大開発工"
"とうかいだいよん 東海大四"
"とうかいどういち 東海道一"
"とうかいどうぐち 東海道口"
"とうかかく 等価格"
"とうかく 等覚 倒閣 等角 頭角 当確"
"とうかくりつ 等確率"
"とうかこう 透過光"
"とうかそくどうんどう 等加速度運動"
"とうかつ 統括 統轄"
"とうかつはん 統括班"
"とうかん 当館 等閑 投函"
"とうかんかく 等間隔"
"とうかんけいゆ 東関経由"
"とうかんし 等閑視"
"とうが 冬芽 陶瓦"
"とうがい 頭骸 頭蓋 等外 頭外 当該"
"とうがいえん 等外延"
"とうがいこつ 頭蓋骨"
"とうがった 遠刈田"
"とうがね 東金"
"とうがらし 唐辛子"
"とうがん 東岸 冬瓜"
"とうき 党旗 闘鬼 投機 騰貴 陶器 当機 当期 登記 投棄 頭記 冬期 冬季"
"とうきかいいんけん 冬季会員券"
"とうきすじ 投機筋"
"とうきずみしょ 登記済書"
"とうきち 藤吉"
"とうきちろう 藤吉郎"
"とうきび 唐黍"
"とうきぼ 登記簿"
"とうきゅう 等級 投球 東急"
"とうきゅうはんず 東急ハンズ"
"とうきょう 東教 東京"
"とうきょういち 東京一"
"とうきょうきゅうこうてつどう 東京急行電鉄"
"とうきょうきんこうまで 東京近郊迄"
"とうきょうぐち 東京口"
"とうきょうこう 東京港"
"とうきょうしば 東京芝"
"とうきょうすがお 東京菅生"
"とうきょうせん 東京戦"
"とうきょうてあとる 東京テアトル"
"とうきょうとくぶ 東京都区部"
"とうきょうとしょうとうし 東京都昭島市"
"とうきょうとみなとくしば 東京都港区芝"
"とうきょうどう 東京堂"
"とうきょうにちにちしんぶん 東京日日新聞"
"とうきょうへん 東京篇"
"とうきょうべいえぬけーほーる 東京ベイＮＫホール"
"とうきょうほか 東京他"
"とうきょうりゅう 東京流"
"とうきょうわん 東京湾"
"とうきょうわんぐち 東京湾口"
"とうきょく 当局"
"とうきょり 等距離"
"とうきん 陶鈞"
"とうきんせん 東金線"
"とうぎ 東儀 討議"
"とうぎじょう 闘技場"
"とうぎゅう 闘牛"
"とうぎゅうし 闘牛士"
"とうぎょ 統御"
"とうぎょう 陶業"
"とうぎり 当限"
"とうくつ 盗掘"
"とうぐう 東宮"
"とうけい 闘鶏 東経 統計"
"とうけいてきぱたあん 統計的パターン"
"とうけいぶ 頭頸部"
"とうけいぶんぷてきかてい 統計分布的仮定"
"とうけつ 盗血 凍結"
"とうけつろ 凍結路"
"とうけん 陶甄 東建 刀剣 闘犬 当権"
"とうげ 峠"
"とうげい 陶芸"
"とうげいか 陶芸家"
"とうげえき 峠駅"
"とうげこう 登下校"
"とうげごえ 峠越"
"とうげぞく 峠族"
"とうげつ 当月"
"とうげつざん 当月残"
"とうげみち 峠道"
"とうげん 桃源"
"とうげんきょう 桃源郷"
"とうこ 東子"
"とうこう 東耕 東工 東光 陶工 投降 登校 等高 投稿"
"とうこうけんき 東航研機"
"とうこうずみ 投稿済"
"とうこうだい 東京工業大学"
"とうこうだいこう 東工大高"
"とうこうなみ 投稿並"
"とうこうにん 党公認"
"とうこうへい 投降兵"
"とうこつ 頭骨 橈骨"
"とうこん 当今 闘魂"
"とうご 東児 頭語 統語"
"とうごう 投合 ＝ 東郷 等号 統合"
"とうごうあん 統合案"
"とうごういちがたしき 統合一型式"
"とうごく 投獄"
"とうさ 等差 踏査"
"とうさい 登載 搭載 塔載"
"とうさいうお 当歳魚"
"とうさいぎょ 当歳魚"
"とうさいしゃ 搭載車 塔載車"
"とうさいと 当サイト"
"とうさいば 当歳馬"
"とうさく 東作 盗作 倒錯"
"とうさつ 盗撮"
"とうさま 父様"
"とうさん 東讃 倒産 父さん"
"とうさんさい 唐三彩"
"とうざ 当座"
"とうざい 東西"
"とうざいりょうよこづな 東西両横綱"
"とうざん 頭山"
"とうし 祷祠 祷祀 骰子 闘志 闘士 凍死 透視 投資"
"とうしか 投資家"
"とうしがく 投資額"
"とうしき 等式"
"とうしつ 糖質 等質"
"とうしつせい 透湿性"
"とうしば 東芝"
"とうしばぐち 東芝口"
"とうしゃ 謄寫 透写 謄写 投射 当社"
"とうしゅ 陶鋳 頭首 当主 党首 投手"
"とうしゅう 東周 踏襲"
"とうしゅせん 投手戦"
"とうしょ 頭書 当処 島嶼 当所 投書 当初"
"とうしょう 凍傷 闘翔 東証 闘将"
"とうしょうぐう 東照宮"
"とうしょく 東食"
"とうしょばこ 投書箱"
"とうしれいしつ 塔指令室"
"とうしん 東伸 投信 刀身 東進 投身 等身 頭身 答申 等親"
"とうしんてつどう 東清鉄道"
"とうじ 田牛 蕩児 統治 悼辞 当事 当寺 刀自 藤治 東寺 杜氏 田路 冬至 湯治 統辞 答辞 当時"
"とうじいん 等持院"
"とうじき 陶磁器"
"とうじさい 冬至祭"
"とうじしゃいしき 当時者意識"
"とうじしゃかん 当時者間"
"とうじつ 当日"
"とうじつあさ 当日朝"
"とうじつけん 当日券"
"とうじば 湯治場"
"とうじゅ 東樹"
"とうじゅうろう 藤十郎"
"とうじょ 唐書"
"とうじょう 筒状 東城 頭状 塔乗 東上 棟上 東条 東條 搭乗 登場"
"とうじょうか 頭状花"
"とうじょうきゃく 搭乗客"
"とうじょうぐち 搭乗口"
"とうじょうけん 搭乗券"
"とうじょたいだい 東女体大"
"とうじりつ 透磁率"
"とうじろう 藤治郎"
"とうじん 唐人 陶人 蕩尽"
"とうじんぼう 東尋坊"
"とうすい 統帥 陶酔"
"とうすいだい 東水大"
"とうすう 頭数"
"とうすうけん 統数研 統計数理研究所"
"とうすけ 藤輔"
"とうすぽ 東スポ"
"とうせい 倒生 籐製 東征 陶製 統制 当世"
"とうせいがくえん 東星学園"
"とうせいれんしょうたんしき 頭制連勝単式"
"とうせき 等積 透析 投石"
"とうせん 東線 陶染 盗泉 頭線 当選"
"とうぜん 当前 當然 陶然 当然"
"とうそう 鬪爭 逃走 党争 闘争"
"とうそうおん 唐宋音"
"とうそうしん 闘争心"
"とうそうせん 東早戦"
"とうそく 頭側 等速"
"とうそつ 統率"
"とうそん 藤村"
"とうぞく 盗賊"
"とうた 淘汰"
"とうたく 董卓"
"とうたつ 到達"
"とうたつは 到達波"
"とうたん 東端"
"とうだ 頭打"
"とうだい 灯台 当代 東京大学 燈台 東大"
"とうだいいん 東大院"
"とうだいうら 東大裏"
"とうだいぐさもく トウダイグサ目"
"とうだいこう 東大工"
"とうだいじ 東大寺"
"とうだいじょうか 東大情科"
"とうだいそけん 東大素研"
"とうだいだいけい 東大大型"
"とうだいのう 東大農"
"とうだいやく 東大薬"
"とうだいり 東大理"
"とうだん 当団 登壇"
"とうち 投地 等値 統治 倒置 当地"
"とうちく 東筑"
"とうちゃく 到着"
"とうちゃくきゃく 到着客"
"とうちゃくじこくじゅん 到着時刻順"
"とうちゃくじゅん 到着順"
"とうちゃくぶんまで 到着分迄"
"とうちゃん 父ちゃん"
"とうちゅう 陶鋳 頭注"
"とうちゅうかそう 冬虫夏草"
"とうちょう 頭頂 唐朝 登庁 登頂 盗聴"
"とうちょく 当直"
"とうつう 東通 疼痛"
"とうつき 当月"
"とうてい 到底"
"とうてき 投擲"
"とうてつ 饕餮 透徹"
"とうてつこうぎょう 東鉄工業"
"とうてん 東天 当店 読点"
"とうてんこう 東天紅"
"とうで 遠出"
"とうでん 東電"
"とうとう 滔滔 滔々 等等 トウ鞳 鼕鼕 トウトウ 蕩蕩 滔 登登 偸盗 東塔 丁丁 陶陶 到頭 東陶 等々"
"とうとうみ 遠江"
"とうとすいさん 東都水産"
"とうとつ 頭突 唐突"
"とうど 凍土 糖度"
"とうどう 藤堂"
"とうどく 東独"
"とうどり 頭取"
"とうない 党内 頭内"
"とうなん 盗難 東南"
"とうなんあじあ 東南アジア"
"とうなんげき 盗難劇"
"とうなんこうい 避難行為"
"とうなんしゃ 盗難車"
"とうなんとう 東南東"
"とうにち 東日"
"とうにゅう 刀入 豆乳 投入"
"とうにゅうぐち 投入口"
"とうにょう 糖尿"
"とうにょうびょう 糖尿病"
"とうにん 当人"
"とうねん 当年"
"とうの 東野 遠野 統乃"
"とうのうだい 東農大"
"とうのしょう 東庄"
"とうは 踏破 党派"
"とうはいごう 統廃合"
"とうはく 東伯"
"とうはつ 頭髪"
"とうはてきにんげん 党派的人間"
"とうはと 東鳩"
"とうはば 等幅"
"とうはん 登坂 登攀 東版 東販"
"とうばい 等倍 当倍"
"とうばく 掏摸"
"とうばつ 討伐 倒伐"
"とうばん 登板 当番"
"とうばんじゃん 豆板醤"
"とうひ 討匪 頭皮 等比 当否 逃避"
"とうひこう 逃飛行 逃避行 討匪行"
"とうひょう 投票"
"とうひょうがく 投票額"
"とうひょうけん 投票券"
"とうひょうしゃあて 投票者宛"
"とうひょうじょ 投票所"
"とうひょうばこ 投票箱"
"とうひん 盗品"
"とうびょう 投錨 闘病"
"とうふ 豆腐"
"とうふく 東福"
"とうふくじ 東福寺"
"とうふなべ 豆腐鍋"
"とうぶ 当部 頭部 東部 東武"
"とうぶせんけいゆ 東武線経由"
"とうぶせんけいゆう 東武線経由"
"とうぶん 糖分 等分 当分"
"とうぶんかつ 等分割"
"とうぶんぷ 等分布"
"とうへい 東平"
"とうへき 東壁 盗癖"
"とうへん 陶片 等辺"
"とうへんぼく 唐変木"
"とうべつ 当別"
"とうべん 答弁"
"とうほう 投法 等方 桐朋 東方 東宝 東邦 当方"
"とうほうおき 東方沖"
"とうほうこう 等方向"
"とうほうせいざい 等方性材"
"とうほうほうしき 投票方式"
"とうほうれーよん 東邦レーヨン"
"とうほく 東北"
"とうほくさわ 東北沢"
"とうほくせん 東北戦"
"とうほくだい 東北大学"
"とうほくだいこう 東北大工"
"とうほくとう 東北東"
"とうほん 謄本"
"とうほんせいそう 東奔西走"
"とうぼう 逃亡"
"とうぼうはん 逃亡犯"
"とうぼく 透木 冬木 倒木"
"とうま 冬馬 討魔 当麻 当間 當麻 藤間"
"とうみつ 糖蜜"
"とうみつど 等密度"
"とうみょう 燈明 灯明"
"とうみん 冬眠"
"とうむら 東村"
"とうめい 透明 東名"
"とうめいごたんば 東名御殿場"
"とうめいたい 透明体"
"とうめいはん 東名阪"
"とうめん 等面 当面"
"とうめんよう 等面葉"
"とうもう 投網"
"とうもろこし 玉蜀黍"
"とうや 洞爺 陶冶 当夜"
"とうやく 投薬"
"とうやこ 洞爺湖"
"とうやま 當山 遠山 当山"
"とうやまはい 遠山灰"
"とうゆ 灯油"
"とうゆうし 投融資"
"とうよ 投与"
"とうよう 陶遥 陶俑 投用 頭葉 当用 登用 東陽 盗用 東洋"
"とうようこうそく 東葉高速"
"とうようこうはん 東洋鋼板"
"とうようし 東洋史"
"とうようだいひめじ 東洋大姫路"
"とうよく 東翼"
"とうよこ 東横"
"とうらい 到来"
"とうらうどねす 等ラウドネス"
"とうらく 騰落 当落"
"とうり 通 党利 桃李"
"とうりだい 東理大"
"とうりつ 頭立 倒立"
"とうりつぞう 倒立像"
"とうりつりょく 統率力"
"とうりとく 等利得"
"とうりゅう 闘竜 逗留 刀流"
"とうりゅうもん 登竜門"
"とうりょう 頭領 当量 投了 棟梁 等量 統領"
"とうる 徹 透"
"とうるい 糖類 盗塁"
"とうるいおう 盗塁王"
"とうれ 東レ"
"とうれい 答礼"
"とうろう 燈籠 蟷螂 螳螂 蟐螂 燈篭 灯籠"
"とうろく 登録"
"とうろくかんりょうば 登録完了馬"
"とうろくずみ 登録済"
"とうろくてづづき 登録手続"
"とうろくば 登録馬"
"とうろくひ 登録費"
"とうろくぼ 登録簿"
"とうろん 闘論 討論"
"とうわ 東和 東倭 十和"
"とうわく 当惑"
"とえ 十重"
"とえい 渡英 都営"
"とえいしゃ 都営車"
"とお 通 遠 十"
"とおあさ 遠浅"
"とおい 遠井"
"とおう 渡欧"
"とおか 十日"
"とおかった 遠刈田"
"とおがった 遠刈田"
"とおしばんごう 通し番号"
"とおだ 遠田"
"とおちか 遠近"
"とおで 遠出"
"とおとうみ 遠江"
"とおの 遠野"
"とおのり 遠乗り"
"とおぼえ 遠吠"
"とおま 遠間"
"とおまき 遠巻き"
"とおまわし 遠回し"
"とおまわり 遠回り"
"とおみ 遠見"
"とおみづか 遠見塚"
"とおめ 遠目"
"とおやま 遠山"
"とおやまざくら 遠山桜"
"とおり 通 通り"
"とおりみち 通り道"
"とおる 享 理 逹 融 達 亨 透 徹"
"とおわ 十和"
"とか 渡河 都下"
"とかい 渡海 都会"
"とかげ 石竜子 蜥蜴"
"とかしき 渡嘉敷"
"とかち 十勝"
"とが 利賀 科 咎"
"とがうち 戸河内"
"とがき 卜書"
"とがくし 戸隠"
"とがし 冨樫 富樫"
"とがのお 栂尾"
"とがみ 戸上"
"とがめ 咎め"
"とがり 戸苅 戸狩"
"とがわ 外川 戸川"
"とき 鬨 秋 時間 鴾 常 朱鷺 刻 土岐 鴇 時"
"ときいらい 時以来"
"ときえだ 時枝"
"ときお 時生 時郎 登紀夫 時雄 時夫 時男"
"ときおか 時岡"
"ときおり 時おり 時折"
"ときがわ 都幾川"
"ときこ 時子 登紀子 時空子"
"ときさだ 時貞"
"ときじろう 時次郎"
"ときた 時田"
"ときだ 時田"
"ときち 十吉"
"ときつ 時津"
"ときつかぜ 時津風"
"ときとう 時任"
"ときどき 時時 時々"
"ときね 十樹根"
"ときひろ 時広"
"ときぶんかつ 時分割"
"ときまさ 常正"
"ときめく 時めく"
"ときょう 都響"
"ときょうそう 徒競走"
"ときわ 常磐 常葉 常盤"
"ときわざ 常盤座"
"ときわじゅ 常盤樹"
"ときわまつ トキワ松"
"とぎ 富来 伽 砥 都議"
"とぎし 砥師"
"とぎせん 都議選"
"とぎつ 時津"
"とぎばなし 伽噺 伽話"
"とぎれる 途切れ"
"とぎん 都銀"
"とく 疾く 黷 讀 犢 牘 慝 悳 読 匿 涜 禿 篤 督 徳 得 特"
"とくい 特異 得意"
"とくいきゃく 得意客"
"とくいく 徳育"
"とくいげ 得意気"
"とくいち 徳一"
"とくいわざ 得意技"
"とくえ 徳衛"
"とくえい 徳衛"
"とくお 徳男 十九夫 徳雄"
"とくおか 徳岡"
"とくか 特化"
"とくがき 徳垣"
"とくがわ 徳川"
"とくがわけいき 徳川慶喜"
"とくき 特記"
"とくぎ 特技"
"とくこ 徳子"
"とくこう 特高"
"とくさく 得策"
"とくさつ 特撮"
"とくさつもの 特撮物"
"とくさぶろう 徳三郎"
"とくさわ 徳沢"
"とくさん 特産"
"とくし 特使 得之"
"とくしか 篤志家"
"とくしってんさ 得失点差"
"とくしつ 得失 特質"
"とくしま 徳島"
"とくしゃ 特赦 特車"
"とくしゅ 特種 特殊"
"とくしゅう 特集"
"とくしゅかい 特殊解"
"とくしゅけい 特殊形"
"とくしゅこう 特殊鋼"
"とくしょう 特称 ∃ 特賞"
"とくしょく 特色"
"とくしん 得真 涜神 特進 得心"
"とくじ 徳地 徳次 徳治"
"とくじゅ 特需"
"とくじょう 特上"
"とくじろう 徳次郎"
"とくせい 特製 特性"
"とくせいびょう 特性病"
"とくせつ 特設"
"とくせん 特撰 特専 特選"
"とくせんたい 特戦隊"
"とくせんひょうじゅんまい 特選標準米"
"とくそう 特装 特捜"
"とくそく 督促"
"とくぞう 徳蔵"
"とくたろう 徳太郎"
"とくだ 得田 徳田"
"とくだい 特大"
"とくだいじ 徳大寺"
"とくだね 特種"
"とくだん 特段"
"とくちゅう 特注"
"とくちょう 特長 特徴"
"とくてい 特定"
"とくていとくしない 特定都区市内"
"とくてん 特点 特典 得点"
"とくてんおう 得点王"
"とくてんけんだりつ 得点圏打率"
"とくてんつき 得点付"
"とくでん 特電"
"とくとう 禿頭 特等"
"とくとうせき 特等席"
"とくとみ 徳冨 徳富"
"とくない 都区内"
"とくなが 徳永"
"とくに 特に"
"とくのう 篤農"
"とくのうか 篤農家"
"とくのしま 徳之島"
"とくは 特派"
"とくはい 特配"
"とくはし 徳橋"
"とくはつ 特発"
"とくはら 徳原"
"とくばい 特売"
"とくばん 特番"
"とくひさ 徳久"
"とくひつ 特筆"
"とくひょう 得票"
"とくひら 徳平"
"とくひろ 徳弘"
"とくへい 徳平"
"とくべつ 特別"
"とくべつし 特別視"
"とくべつしょく 特別食 特別職"
"とくべつじあい 特別試合"
"とくべつせき 特別席"
"とくべつせん 特別戦"
"とくべつてん 特別展"
"とくべつほじゅうけん 特別補充券"
"とくべつわく 特別枠"
"とくほう 特報"
"とくほん 読本"
"とくま 徳間"
"とくまる 得丸 徳丸"
"とくみ 徳美 徳見"
"とくみち 篤道"
"とくみつ 徳光"
"とくむ 特務"
"とくめい 特命 匿名"
"とくもく 徳目"
"とくもと 徳本 徳元"
"とくもり 特盛"
"とくやく 特約"
"とくやす 徳康"
"とくやま 徳山"
"とくゆう 特有"
"とくゆき 徳行 得之"
"とくよう 特用 徳用"
"とくようぶくろ 徳用袋"
"とくら 十倉 都倉 戸倉"
"とくりつ 特立"
"とくれい 督励 特例"
"とくろん 特論"
"とぐち 戸口"
"とぐら 戸倉"
"とけ 土気"
"とけい 時計"
"とけいじかけ 時計仕掛"
"とけいつき 時計付"
"とけいとう 時計塔"
"とけつ 吐血"
"とけん 覩見 都県"
"とげ 朿 棘 刺"
"とげつきょうふきん 渡月橋付近"
"とげとげしい 刺々しい"
"とこ 床 常"
"とこう 都甲 渡航"
"とこうひ 渡航費"
"とこし 戸越"
"とこなつ 常夏"
"とこなめ 常滑"
"とこのま 床ノ間 床の間"
"とこばしら 床柱"
"とこや 床屋"
"とこやま 床山"
"とこよ 常世"
"ところ 處 処 所"
"ところが 処が"
"ところざわ 所沢"
"ところどころ 所々"
"とごう 戸郷"
"とさ 土佐"
"とさけん 土佐犬"
"とさず 土佐酢"
"とさっこ 土佐っ子"
"とさつ 屠殺"
"とさんせん 土讃線"
"とざき 戸崎"
"とざと 外里"
"とざま 外様"
"とざわ 戸沢"
"とざん 登山"
"とざんき 登山記"
"とざんきゃく 登山客"
"とざんぐち 登山口"
"とざんぐつ 登山靴"
"とし 肇 駿 夙 祀 壽 繁 世 暁 稔 敏 捷 寿 俊 利 都市 歳 年"
"としあき 年昭 俊章 聡明 敏朗 繁明 敏彰 俊朗 利昭 敏昭 俊昭 俊彰 俊明 敏明 寿明 利明"
"としあけ 年明け"
"としうえ 年上"
"としえ 敏枝 敏江 季衣 利絵 俊恵 とし恵"
"としお 淑夫 利朗 寿雄 稔雄 俊朗 利生 登志夫 寿夫 利雄 利男 敏雄 俊雄 俊夫 俊男 寿男 敏男 敏夫 利夫"
"としおとこ 年男"
"としおんな 年女"
"としかさ 年嵩"
"としかず 敏和 利和 俊和 敏一 利一 俊一 寿和 寿一"
"としかつ 敏克 利勝"
"としき 年紀 戸敷 稔貴 年樹 敏樹 歳樹 敏生 俊樹"
"としくに 年邦"
"としこ 登志子 淑子 寿子 トシ子 年子 とし子 利子 敏子 俊子"
"としこし 年越し"
"としご 年子"
"としごいのまつり 祈年祭"
"としごろ 年頃"
"とししげ 利重"
"としした 年下"
"としじ 俊治"
"としそうおう 年相応"
"としぞう 俊三"
"としたか 俊孝 利孝 敏隆"
"としただ 俊匡 利忠"
"としたに 利谷"
"としつき 年月"
"としつぐ 敏嗣 俊嗣 壽二"
"としてる 敏輝"
"としなお 俊直 利直"
"としなみ 年波"
"としのこう 年の功"
"としのころ 年の頃"
"としのせ 年の瀬 歳の瀬"
"としのぶ 利信 敏伸 利伸"
"としのり 俊範 敏則 敏規 俊則 利典 寿則 利則 年紀 敏憲"
"としはる 寿晴 敏治 俊治 利治 季栄"
"としひこ 壽彦 稔彦 寿彦 年彦 利彦 捷彦 俊彦 敏彦"
"としひさ 利久 敏寿 俊久"
"としひで 俊英 俊秀"
"としひと 敏仁"
"としひろ 俊浩 利宏 歳弘 敏啓 俊博 俊弘 利浩 利弘 敏裕 俊裕 利広 敏弘 敏宏 俊宏 利博"
"としふさ 俊房"
"としふみ 俊文 俊史 年史 敏文"
"としほど 年程"
"としま 戸嶋 十島 戸島 利島 年増 豊島"
"としまおか 豊島岡"
"としまさ 敏正"
"としみ 利美 敏巳 寿実 都志見 年美"
"としみち 俊道 利道 利通 季道"
"としみつ 俊光 敏光 利光"
"としゃ 吐瀉"
"としや 敏哉 利也 敏也 俊也 俊弥 俊哉"
"としやす 敏靖 敏康 利泰"
"としゅ 徒手"
"としゅくうけん 徒手空拳"
"としゅつ 吐出"
"としゆき 歳之 利幸 敏之 敏幸 俊行 利行 俊之 敏行 俊幸 利之"
"としょ 図書"
"としょく 塗色"
"としょけん 図書券"
"としょひ 図書費"
"としよ 敏代"
"としより 年寄り 年寄"
"としよりかぶ 年寄株"
"としろう 敏郎 俊郎 利郎 俊朗"
"としん 都心"
"とじ 刀自"
"とじかっこ 閉括弧"
"とじき 戸敷"
"とじこみ 綴じ込み"
"とじま 戸島"
"とじまり 戸締り"
"とじょう 図情 登城 途上"
"とす 鳥栖"
"とせ 歳"
"とせい 渡世"
"とぜい 都税"
"とぜつ 杜絶 途絶"
"とぜんいき 都全域"
"とそ 屠蘇"
"とそう 塗装"
"とそうずみ 塗装済"
"とたん 塗炭 途端"
"とだ 戸田"
"とだい 東京都立大学"
"とだか 戸高"
"とだな 戸棚"
"とち 柮 杤 橡 栃 土地"
"とちお 栃尾"
"とちかがみもく トチカガミ目"
"とちかん 土地勘"
"とちがら 土地柄"
"とちぎ 朽木 栃木"
"とちじ 都知事"
"とちじせん 都知事選"
"とちない 栃内"
"とちのわか 栃乃和歌"
"とちもと 栃本"
"とちゅう 途中"
"とちゅうこうき 途中降機"
"とちゅうちゃ 杜仲茶"
"とちゅうりゃく 途中略"
"とちょう 都庁"
"とちわかじだい 栃若時代"
"とっか 特価 特化"
"とっかい 特解 特快"
"とっかん 吶喊 突貫"
"とっき 特機 特器 突起 特記"
"とっきたい 突起体"
"とっきゅう 特級 特急"
"とっきゅうけん 特急券"
"とっきゅうしゃ 特急車"
"とっきゅうしゅ 特級酒"
"とっきょ 特許"
"とっきょちょう 特許庁"
"とっく 疾く 疾っく"
"とっくり 徳利"
"とっくん 特訓"
"とっけつ 突厥"
"とっけん 特研 特権"
"とっこう 特高 特効 特攻"
"とっこうやく 特効薬"
"とっさ 咄嗟"
"とっしゅつ 突出"
"とっしん 突進"
"とっしんわざ 突進技"
"とったん 突端"
"とって 把っ手 取っ手 把手 取手"
"とってい 突堤"
"とっとり 鳥取"
"とっぱ 突破"
"とっぱこう 突破口"
"とっぱつ 突発"
"とっぱつしん 突発疹"
"とっぱつせいはっしん 突発性発疹"
"とっぱん トッパン 凸版"
"とっぴ 突飛"
"とっぴょうし 突拍子"
"とっぷ トップ"
"とっぷう 突風"
"とつ 訥 柮 咄 吶 凸 突"
"とつか 戸塚"
"とつかわ 十津川"
"とつがた 凸型"
"とつがわ 十津川"
"とつきとうか 十月十日"
"とつぎさき 嫁ぎ先"
"とつけつごう 凸結合"
"とつげき 突激 突撃"
"とつじょ 突如"
"とつぜん 突然"
"とつぜんし 突然死"
"とつでん 凸電"
"とつにゅう 突入"
"とつにゅうぐち 突入口"
"とつへいほう 凸閉包"
"とつべん 訥弁"
"とつほう 凸包"
"とつめん 凸面"
"とづか 戸塚"
"とてい 徒弟"
"とても 迚も 迚"
"とでん 都電"
"ととう 渡頭 徒党"
"ととき 十時"
"とど 椴"
"とどう 都道"
"とどうけいけん 渡道経験"
"とどうふけんごと 都道府県毎"
"とどうふけんざかい 都道府県境"
"とどけ 屆 届"
"とどけがき 届書"
"とどけで 届け出 届出"
"とどけでずみしょう 届出済証"
"とどほっけむら 椴法華村"
"とどまつ 椴"
"とどむ 閼"
"とどめ 止め"
"とどめる 閼"
"とどろき 轟き 軣 等々力 轟"
"とどろきおん 轟音"
"とない 都内"
"となかい 馴鹿"
"となき 渡名喜"
"となみ 外波 渡並 礪波 砺波"
"となり 鄰 隣り 隣"
"となりあわせ 隣合わせ"
"となりきんじょ 隣近所"
"となりぐみ 隣組"
"となりどうし 隣同士"
"となりまち 隣町"
"となりむら 隣村"
"となん 都南"
"とにかく 兎に角"
"とね 利根 刀根"
"との 殿"
"とのうち 登内"
"とのおか 外岡"
"とのがた 殿方"
"とのさま 殿様"
"とのしょう 土庄"
"とのみ 富海"
"とのやまちょう 殿山町"
"とはん 登攀 登坂"
"とば 賭場 鳥羽"
"とばく 賭博"
"とばくざい 賭博罪"
"とばす 都バス"
"とばた 戸畑"
"とばり 幃 幄 帷 帳 戸張"
"とび 鵄 鴟 飛び 鳶"
"とびいり 飛び入り"
"とびおか 飛岡"
"とびおり 飛び降り"
"とびさき 飛先"
"とびしま 飛島"
"とびしょく 鳶職"
"とびた 飛田"
"とびどうぐ 飛道具"
"とびばこ 飛び箱"
"とびひ 飛び火"
"とびら 扉"
"とびらいち 扉位置"
"とびらえ 扉絵"
"とびらせん 扉線"
"とびらふきん 扉付近"
"とびわし 飛鷲"
"とぴっくす トピックス"
"とふ 塗布"
"とふけん 都府県"
"とふご 塗付後"
"とふつ 渡仏"
"とぶくろ 戸袋"
"とぶくろまど 戸袋窓"
"とべ 砥部 戸部"
"とべい 渡米"
"とほ 徒歩"
"とほう 途方"
"とぽろじー トポロジー"
"とま 篷 笘 苫"
"とまく 塗膜"
"とまこまい 苫小牧"
"とましの 苫篠"
"とまた 苫田"
"とまつ 塗抹 塗沫 戸松"
"とまと トマト"
"とまべち 苫米地"
"とままえ 苫前"
"とまり 泊り 渡真利 泊 泊まり"
"とみ 登美 トミ 冨 富"
"とみあい 富合"
"とみうら 富浦 冨浦"
"とみえ 富江"
"とみお 富雄 富夫 富男 富美男"
"とみおか 冨岡 富岡"
"とみか 富加"
"とみかわ 富川"
"とみくじ 富籤"
"とみぐすく 豊見城"
"とみこ 富美子 登美子 富子"
"とみさと 富里"
"とみさわ 冨沢 富沢"
"とみざわ 富澤 富沢"
"とみしま 富島"
"とみしろ 都城"
"とみしろこうこう 豊見城高校"
"とみじ 富治"
"とみじゅうろう 富十郎"
"とみた 冨田 富田"
"とみたろう 富太郎"
"とみつかちょう 富塚町"
"とみて 冨手"
"とみとく 富徳"
"とみなが 冨永 富永"
"とみなり 冨成"
"とみに 頓に"
"とみの 富野"
"とみはま 富浜"
"とみはり 富張"
"とみひこ 富彦"
"とみひさ 富久"
"とみまつ 富松"
"とみや 富谷"
"とみやす 富安"
"とみやま 富山"
"とみん 都民"
"とむ 吐夢"
"とむら 外村 戸村"
"とめ 留 登米"
"とめおき 留置"
"とめがね 止め金"
"とめきち 留吉"
"とめこ 留子"
"とめしょ 留所"
"とめじ 留治"
"とめそで 留袖"
"とめど 留処 止処"
"とめべん 止め弁"
"とめん 塗面"
"とも 侶 鞆 靹 舮 艫 具 恭 伴 朋 供 朝 知 智 友 共"
"ともあき 倫明 公明 恭章 智彰 智明 智朗"
"ともい 友井"
"ともいし 友石"
"ともいち 友一"
"ともえ 友衛 巴 知重"
"ともえがわ 巴川"
"ともえぐみ 巴組"
"ともえだ 友枝"
"ともえなげ 巴投げ"
"ともえふじ 巴富士"
"ともお 智雄 知夫 友朗 朋夫 智夫 智央 友雄"
"ともおか 友岡"
"ともか 友香"
"ともかず 智和 智一 友和 共和"
"ともがおか 友ヶ丘"
"ともがら 讐 讎"
"ともき 友喜 朋喜 知樹"
"ともきち 友吉"
"ともきよ 友清"
"ともこ とも子 朝子 倫子 友子 朋子 智子 知子"
"ともざる 友猿"
"ともし 知士"
"ともしび 燈 灯し火 燭 灯"
"ともじ 知司 友治"
"ともぞう 友蔵"
"ともたか 智孝"
"ともたけ 智武"
"ともたろう 智太郎"
"ともだ 友田"
"ともだおれ 共倒れ"
"ともだち 友達"
"ともち 砥用"
"ともちか 友近 知親 朋哉"
"ともづな 纜 繿"
"ともとし 智年"
"ともども 共々"
"ともなか 邑中"
"ともなが 友永 朝永"
"ともながしんいちろう 朝永振一郎"
"ともに 共に"
"ともの 伴野"
"とものうら 鞆の浦"
"とものかい 友の会"
"とものり 知典 友則 智則 友紀 智徳 智紀 知徳 知紀"
"ともはな 友花"
"ともはる 知治 智春"
"ともばたらき 共働き"
"ともひこ 知彦 友彦 智彦"
"ともひさ 友久 智久 朋久 知久"
"ともひで 智秀 知英"
"ともひと 智斉 智仁"
"ともひろ 友洋 智博 友広 朋宏 共洋 智浩 智広 知浩 恭祐 智弘 知宏 智洋"
"ともびき 友引"
"ともべ 友部"
"ともまさ 智真"
"ともまつ 友松"
"ともみ とも美 友視 友海 智己 具美 具実 具視 智巳 知視 朋美 智美 知実 知美"
"ともみち 友道 智道"
"ともみつ 伴光"
"ともみはら 倶美原"
"とももり 知盛"
"ともや 智也"
"ともやす 朋康 友康"
"ともゆき 友幸 朋之 智幸 朋幸 知之 共之 智行 知行 智之"
"ともゆみ 智之"
"ともよ 知代 智世 知世"
"ともよし 知節 友良 知義 智由 智義"
"とや 外谷 戸谷"
"とやかく 兎や角"
"とやま 戸山 外山 富山"
"とやまさん 富山産"
"とやましんこう 富山新港"
"とやまわん 富山湾"
"とゆう 都有"
"とよ トヨ 豐 豊"
"とよあき 豊明"
"とよあけ 豊明"
"とようち 豊内"
"とようら 豊浦"
"とよおか 豊丘 豊岡"
"とよかず 豊和"
"とよかわ 豊川"
"とよき 豊樹"
"とよきち 豊吉"
"とよぎだい 豊技大"
"とよくに 豊国"
"とよくら 豊倉"
"とよこ 豊子"
"とよこう 豊高"
"とよころ 豊頃"
"とよさか 豊栄"
"とよさく 豊作"
"とよさと 豊郷 豊里"
"とよさわ 豊沢"
"とよしき 豊四季"
"とよしな 豊科"
"とよしま 豊嶋 豊島"
"とよじ 豊治"
"とよす 豊洲"
"とよた トヨタ 豊田"
"とよたま 豊玉"
"とよだ 豊田"
"とよつ 豊津"
"とよてつ 豊鉄"
"とよとみ 豊富 豊臣"
"とよとみがた 豊臣方"
"とよなか 豊中"
"とよね 豊根"
"とよの 豊野 豊能"
"とよのぶ 豊伸 豊信"
"とよのぼり 豊登"
"とよはし 豊橋"
"とよはしきた 豊橋北"
"とよはま 豊浜"
"とよはら 豊原"
"とよひこ 豊彦"
"とよひさ 豊久"
"とよひせん 豊肥線"
"とよひと 十余一"
"とよひほんせん 豊肥本線"
"とよひら 豊平"
"とよひろ 豊弘 豊広"
"とよふく 豊福"
"とよふみ 豊文 東洋史"
"とよま 登米"
"とよまえかわさき 豊前川崎"
"とよまつ 豊松"
"とよまる 豊丸"
"とよやま 豊山"
"とら 乕 寅 虎"
"とらい トライ 渡来"
"とらいあんぐる トライアングル"
"とらいち 寅市"
"とらえかた 捉え方"
"とらお 虎男 寅雄 寅男 虎雄"
"とらがしら 虔"
"とらきち 虎吉 寅吉"
"とらぎ トラ技"
"とらくす 寅楠"
"とらくた トラクタ"
"とらくたー トラクター"
"とらさん 寅さん"
"とらぞう 虎造 虎三"
"とらっきんぐ トラッキング"
"とらっく トラック"
"とらとう 虎党"
"とらのもん 虎ノ門 虎の門"
"とらばーゆ トラバーユ"
"とらひこ 寅彦"
"とらひめ 虎姫"
"とらぶる トラブル"
"とらんく トランク"
"とらんじすた トランジスタ"
"とらんぷ トランプ"
"とり 禽 鶏 取 取り 酉 鳥 鷄"
"とりあえず 取り敢えず 取りあえず"
"とりあげ 取り上げ"
"とりあつかい 取扱い 取あつかい 取扱"
"とりあつかいしゃ 取扱車"
"とりい 鳥井 鳥居"
"とりいそぎ 取り急ぎ"
"とりいれ 取入れ"
"とりう 鳥生"
"とりうちぼう 鳥撃帽"
"とりうみ 鳥海"
"とりえ 取柄 取り柄"
"とりお トリオ"
"とりかご 鳥籠"
"とりかじ 取舵"
"とりがー トリガー"
"とりがい 鳥飼"
"とりきめ 取り決め"
"とりくみ 取組"
"とりくんだ 取り組んだ"
"とりけし 取消し 取消"
"とりこ 俘 虜擒 虜"
"とりこしぐろう 取り越し苦労"
"とりこみ 取込"
"とりごえ 鳥越"
"とりごや 鳥小屋"
"とりさか 鳥坂"
"とりさわ 鳥沢 鳥澤"
"とりざた 取沙汰 取りざた"
"とりざら 取り皿"
"とりしましやく 取締役"
"とりしまり 取り締り 取締 取締り"
"とりしまりやく 取締役"
"とりしらべ 取調べ 取調"
"とりす 鳥巣"
"とりすこうつう 鳥栖交通"
"とりせつ 取説"
"とりたち 鳥達"
"とりたて 取立"
"とりたに 鳥谷"
"とりだい 鳥大"
"とりだか 取り高"
"とりだし 取出 取り出し"
"とりちがえかた 取り違え方"
"とりつ 都立"
"とりつぎ 取次"
"とりつけ 取り付け 取付"
"とりつこう 都立高"
"とりつだい 東京都立大学"
"とりてき 取的"
"とりてん 鳥天"
"とりで 塞 取手 砦"
"とりにく 鳥肉 鶏肉"
"とりにんげん 鳥人間"
"とりのいち 酉の市"
"とりのこ 鳥の子"
"とりはだ 鳥肌"
"とりひき 取引"
"とりひきじょ 取引所"
"とりぷる トリプル"
"とりまき 取り巻き"
"とりめにあか トリメニア科"
"とりもの 捕物"
"とりものちょう 捕物帳 捕物帖"
"とりや 鳥谷 鳥屋"
"とりやま 鳥山"
"とりやめ 取り止め"
"とりょう 塗料"
"とりろう 鶏郎"
"とりわき 鳥脇"
"とるこ 土耳其 土耳古"
"とれーしんぐ トレーシング"
"とれーどおふ トレードオフ"
"とれーなー トレーナー"
"とれーにんぐ トレーニング"
"とれい トレイ"
"とれだか 取れ高"
"とれつ 堵列"
"とれん 都連"
"とれんでぃ トレンディ"
"とれんど トレンド"
"とろ 吐露 瀞"
"とろいせき 登呂遺跡"
"とろう 徒労"
"とろふぃー トロフィー"
"とろり トロリ"
"とわ 永遠 登和"
"とわだ 十和田"
"とわだこ 十和田湖"
"とん 飩 遯 瓲 燉 暾 問 東 惇 噸 屯 遁 沌 頓 敦 豚"
"とんいっきょく 東一局"
"とんかつや とんかつ屋"
"とんきょう 頓狂"
"とんこう 敦煌 燉煌 遁甲"
"とんこつ 豚骨"
"とんこつあじ 豚骨味"
"とんさんきょく 東三局"
"とんざ 頓挫"
"とんし 頓死"
"とんしょく 褪色"
"とんじ 遁辞"
"とんじゃく 頓着"
"とんじる 豚汁"
"とんせい 遯世 煌星 遁世"
"とんそう 遁走"
"とんぞく 遁俗"
"とんだばやし 富田林"
"とんち 頓智 頓知"
"とんちゃく 頓着"
"とんでん 屯田"
"とんなんしゃぺい 東南西北"
"とんにきょく 東二局"
"とんねる トンネル"
"とんば 東場"
"とんばら 頓原"
"とんび 鳶"
"とんぼ 蜻蛉"
"とんま 頓馬"
"とんや 問屋"
"ど 堵 駑 弩 孥 呶 戸 ° 努 ℃ 怒 奴 土 度"
"どーなつ ドーナツ"
"どーむ ドーム"
"どあ ドア"
"どあい 度合い 度合"
"どあつ 土圧"
"どあつけい 土圧計"
"どあほ ど阿呆"
"どい 土肥 土井 土居"
"どいがき 土井垣"
"どいつ 独 何奴 獨乙 獨逸 独乙 ドイツ 独逸"
"どう ゞ 桐 陶 如何 鬧 艟 耨 瞠 獰 橈 撓 慟 恫 嫐 儂 僮 々 〃 働 藤 憧 萄 撞 洞 童 銅 胴 瞳 導 動 堂 道 同"
"どうあい 同愛"
"どうあく 道悪"
"どうあげ 胴上げ"
"どうあん 同案"
"どうあんたすう 同案他数"
"どうい 同位 同意"
"どういたい 同位体"
"どういつ 同一"
"どういつし 同一視"
"どういつわ 同一話"
"どういつわく 同一枠"
"どういん 動員"
"どうえき 同駅"
"どうえん 導演"
"どうおう 道央"
"どうおん 同音"
"どうか 道歌 導火 道家 同課 銅貨 同化"
"どうかく 同角 同格"
"どうかこん 同化根"
"どうかつ 恫喝"
"どうかひか 同花被花"
"どうかん 道灌 道管 導管 同感"
"どうかんすう 導関数"
"どうが 童画 動画"
"どうがい 道外"
"どうがく 同額"
"どうがしま 堂ヶ島"
"どうがぞう 動画像"
"どうがた 同型"
"どうがたしゃ 同型車"
"どうがん 動眼 童顔"
"どうき 動気 同機 銅器 動悸 動機 同期"
"どうきちょうそうき 同期調相機"
"どうきゅう 撞球 慟泣 同級"
"どうきょ 同居"
"どうきょう 道教 同郷"
"どうきょく 同曲 同局"
"どうきん 同衾 同金 同斤"
"どうぎ 道着 胴着 動議 道義 同義"
"どうぎしん 道義心"
"どうぎょう 同業"
"どうぎょく 同玉"
"どうぎん 同銀"
"どうく 同区"
"どうくそうきょくぜんしゅう 独奏曲全集"
"どうくつ 洞窟"
"どうくん 同訓 同君"
"どうぐ 道具"
"どうぐだて 道具立て"
"どうぐち 洞口"
"どうぐばこ 道具箱"
"どうけ 道家 道化"
"どうけい 憧憬 憧景 同慶 同系 同桂 同形 同型"
"どうけつ 洞穴"
"どうけん 同県 同権"
"どうげつ 同月"
"どうげん 同源 道玄"
"どうげんざか 道玄坂"
"どうこ 銅壺"
"どうこう 同工 同興 同好 同校 同行 瞳孔 動向"
"どうこうのし 同好の士"
"どうこうほう 道交法"
"どうこく 慟哭 同刻 同国"
"どうこん 同根 同梱"
"どうご 道後"
"どうごうきん 銅合金"
"どうごはんぷく 同語反復"
"どうさ 同左 動作"
"どうさい 道斎"
"どうさぎれ 動作切"
"どうさしゅ 動作主"
"どうさつ 洞察"
"どうさてきもんだい 動作的問題"
"どうさん 道三 動産"
"どうざい 同罪"
"どうざん 銅山"
"どうし 道志 導師 同誌 同市 同氏 同志 動詞 同士"
"どうしうち 同士撃ち 同士打ち"
"どうしかく 動詞格"
"どうしけい 動詞形"
"どうした 堂下"
"どうしつ 同質 同室"
"どうして 如何して"
"どうしゃ 同車 動車 同社"
"どうしゅ 同株 同種"
"どうしゅく 同宿"
"どうしゅぞくかん 同種属間"
"どうしゅつ 導出"
"どうしゅつぎ 導出木"
"どうしょ 同書 同所"
"どうしょう 道床 同床 銅賞"
"どうしょく 同色"
"どうしょくぶつ 動植物"
"どうしょくぶつけんえきぜい 動植物検疫税"
"どうしん 同心 童心"
"どうじ 同字 動時 同次 童子 同時"
"どうじく 同軸"
"どうじし 同時枝"
"どうじつ 同日"
"どうじま 堂島"
"どうじゅん 同順"
"どうじょう 堂上 道上 同乗 道場 同情 同上"
"どうじょうがた 土壌型"
"どうじょうしん 同情心"
"どうじょうじ 道成寺"
"どうじょうだいにこう 同条第二項"
"どうじょうみゃく 動静脈"
"どうじょうやぶり 道場破り"
"どうじん 道仁 同人"
"どうすう 同数"
"どうず 同図"
"どうせい 動静 銅製 同姓 同棲 同性"
"どうせき 道関 同席"
"どうせん 動線 銅線 同船 導線"
"どうぜい 同勢"
"どうぜん 同然"
"どうそう 同相 同窓"
"どうそく 同側"
"どうそじん 道祖神"
"どうそん 同村 道村"
"どうぞう 銅像"
"どうぞく 道俗 同族"
"どうたい 胴体 同体 動態 導体"
"どうたいけい 胴体径"
"どうたいほぞん 動体保存"
"どうたく 銅鐸"
"どうだい 同題 同大"
"どうだいら 堂平"
"どうだん 道斷 満天星 同段 同断 道断"
"どうち ⇔ ≡ 同地 同値"
"どうちゃく 同着 撞着"
"どうちゅう 道中"
"どうちゅうき 道中記"
"どうちょう 道庁 同調"
"どうつう 導通"
"どうてい 道程 同底 童貞 同定"
"どうてき 動的"
"どうてきせぎょ 動的制御"
"どうてん 鬧天 動点 動顛 動転 同点"
"どうてんだん 同点弾"
"どうでん 道傳 道伝 北海道電力 導電"
"どうでんたい 導電体"
"どうとう 同党 道東 同等"
"どうとうひん 同当品"
"どうとく 道徳"
"どうとくしん 道徳心"
"どうとくせい 動特性"
"どうとんぼり 道頓堀"
"どうどう 道々 同道 堂々"
"どうどうめぐり 堂々巡り"
"どうない 道内"
"どうないばんじこくひょう 道内版時刻表"
"どうなん 道南"
"どうにゅう 導入"
"どうにゅうぐち 導入口"
"どうにん 同人"
"どうねん 動燃 同年"
"どうねんど 動粘度"
"どうのじ 々"
"どうは 導波"
"どうはい 同輩"
"どうはく 銅箔"
"どうはろ 導波路"
"どうはん 同伴"
"どうば 同馬"
"どうばん 銅板"
"どうばんがてん 銅版画展"
"どうひ 同飛 胴皮"
"どうひせい 同飛成"
"どうひょう 道標 同表"
"どうびょう 同病"
"どうふ 豆腐 同歩"
"どうふう 同封"
"どうふく 同腹"
"どうふけん 道府県"
"どうぶつ 動物"
"どうぶつほごだんたい 動物愛護団体"
"どうぶつゆ 動物油"
"どうぶん 同文"
"どうべんきこう 動弁機構"
"どうほう 同法 同朋 同胞 同報"
"どうほく 道北"
"どうま 胴間"
"どうまごえ 胴間声"
"どうまさつ 動摩擦"
"どうまさつけいすう 動摩擦系数"
"どうみゃく 動脈"
"どうみゃくけつ 動脈血"
"どうみゃくりゅう 動脈瘤"
"どうみん 道民"
"どうめい 同名 同盟"
"どうめいいし 同名異市"
"どうめいぐん 同盟軍"
"どうめいし 動名詞"
"どうめん 道面 道免"
"どうもう 艟艨 童蒙 獰猛"
"どうもく 瞠目"
"どうもと 胴元"
"どうもん 同門 洞門"
"どうや 同夜 銅谷"
"どうやく 同役"
"どうゆう 道有 同友"
"どうよう 童謡 動揺 同様"
"どうら 銅鑼"
"どうらく 道楽"
"どうらくむすめ 道楽娘"
"どうらくもの 道楽者"
"どうらん 動乱"
"どうり 道理"
"どうりきがく 動力学"
"どうりつ 道立 同率"
"どうりょう 同量 同僚"
"どうりょうやく 同僚役"
"どうりょく 動力"
"どうりょくげん 動力源"
"どうりょくしゃ 動力車"
"どうりょくせん 動力船"
"どうりょくろ 動力炉"
"どうりん 動輪"
"どうりんけい 動輪径"
"どうるい 同類"
"どうれつ 同列"
"どうれつし 同列視"
"どうれん 道連"
"どうろ 道路"
"どうろぜい 道路税"
"どうろぞい 道路沿"
"どうろひょうじ 道路標示"
"どうろもう 道路網"
"どうろよこ 道路横"
"どうわ 童話 同和"
"どうわく 同枠"
"どうわくば 同枠馬"
"どおり 通 通り"
"どかた 土方"
"どかん 土管"
"どがいし 度外視"
"どき 怒気 時 土器"
"どきどき ドキドキ"
"どきゅう 弩級 土休"
"どきゅめんてーしょん ドキュメンテーション"
"どきゅめんと ドキュメント"
"どきょう 読経 度胸"
"どきん 土禁"
"どぎも 度肝"
"どく 髑 讀 獨 徳 独 読 毒"
"どくいり 毒入"
"どくえき 毒液"
"どくえさ 毒餌"
"どくえん 独演"
"どくかい 読解"
"どくが 毒牙"
"どくがく 独学"
"どくがし 毒菓子"
"どくがん 独眼"
"どくがんりゅう 独眼竜"
"どくきんほう 独禁法"
"どくぐん 独軍"
"どくけ 毒気"
"どくけし 毒消し"
"どくご 独語 読後"
"どくさい 独裁"
"どくさつ 毒殺"
"どくしゃ 読者"
"どくしゅう 独習"
"どくしょ 読書"
"どくしょう 独唱"
"どくしょか 読書家"
"どくしょこんなんじ 読書困難児"
"どくしょとう 読書灯"
"どくしん 読唇 独身"
"どくしんおとこ 独身男"
"どくしんもの 独身者"
"どくしんりょう 独身寮"
"どくじ 独自"
"どくじゃ 毒蛇"
"どくせい 毒性"
"どくせいぶん 毒成分"
"どくせき 毒螫"
"どくせん 独擅 独占"
"どくせんよく 独占欲"
"どくぜつ 毒舌"
"どくぜつか 毒舌家"
"どくぜつせん 毒舌戦"
"どくぜん 独善"
"どくそ 毒素"
"どくそう 毒草 独走 独奏 独創"
"どくそん 獨尊 独尊"
"どくたー ドクター"
"どくだけ 毒茸"
"どくだみか ドクダミ科"
"どくだん 独断"
"どくだんじょう 独壇場"
"どくだんせんこう 独断専行"
"どくとく 独特"
"どくぬき 毒抜き"
"どくは 読破"
"どくはい 毒杯"
"どくはく 独白"
"どくばり 毒針"
"どくぶつ 毒物"
"どくほん 読本"
"どくぼう 独房"
"どくみ 毒見"
"どくみょう 独明"
"どくむし 毒虫"
"どくやく 毒薬"
"どくりつ 独立"
"どくりつあん 独立案"
"どくりつぎゆうぐん 独立義勇軍"
"どくりつじゅ 独立樹"
"どくりつたんてん 独立単点"
"どくりょう 読了"
"どくりょく 独力"
"どくろ 髑髏"
"どぐう 土偶"
"どけい 時計"
"どけん 土建"
"どけんぎょう 土建業"
"どげざ 土下座"
"どこ 何処"
"どこう 土光 土侯"
"どこか 何処"
"どこらへん どこら辺"
"どごう 怒号"
"どさけん ドサ健"
"どさん 土讃"
"どさんこ 道産子"
"どしつ 怒叱 土質"
"どしゃ 土砂"
"どしゃぶり 土砂降り"
"どじょう 土壤 鰌 鯲 泥鰌 鰍 土壌"
"どじん 土人"
"どすう 度数"
"どすてば 土捨場"
"どせい 土星"
"どせきりゅう 土石流"
"どそう 土葬"
"どそく 土足"
"どぞう 土蔵"
"どぞく 土俗"
"どたんば 土壇場"
"どだい 土台"
"どだん 土壇"
"どちゃく 土着"
"どちゅう 土中"
"どちょう 怒張"
"どちら 何方"
"どっかい 読解"
"どっきょう 読経"
"どっきょうだいがく 独協大学"
"どっきんぐ ドッキング"
"どっきんほう 独禁法"
"どっく ドック"
"どっち 何方"
"どっと ドット"
"どっぽ 独歩"
"どつ 肭"
"どつぼ ドツボ"
"どて 土堤 塢 土手"
"どてぐち 土手口"
"どてみち 土手道"
"どてら 褞袍"
"どとう 怒濤 怒涛"
"どどいつ 都々逸"
"どなべ 土鍋"
"どなり 鄰 隣"
"どにち 土日"
"どにちげつ 土日月"
"どの 殿"
"どのう 土嚢"
"どはつ 怒髪"
"どば 土場"
"どばし 土橋"
"どひ 奴婢 土肥"
"どひょう 土俵"
"どひょういり 土俵入り 土俵入"
"どひょうぎわ 土俵際"
"どぶがい 蚌"
"どぶろ 土風炉"
"どへき 土壁"
"どべい 土塀"
"どぼく 土木"
"どま 土間"
"どまり 止まり"
"どまんなか ド真中"
"どみん 土民"
"どめ 度目"
"ども 供 共"
"どもん 土門"
"どよう 土用 土曜"
"どら 鑼 鐃 錚 銅鑼"
"どらいばー ドライバー"
"どらいぶ ドライブ"
"どらえもん ドラえもん"
"どらっぐ ドラッグ"
"どらふと ドラフト"
"どらま ドラマ"
"どらむ ドラム"
"どらむす ドラムス"
"どらわん 銅羅湾"
"どり 取り"
"どりーむらんど ドリームランド"
"どりあ ドリア"
"どりょう 度量"
"どりょうこう 度量衡"
"どりょく 努力"
"どりょくか 努力家"
"どる ドル ＄"
"どるい 土類 土塁"
"どれい 奴隷"
"どれいしゅ 奴隷主"
"どれいせん 奴隷船"
"どれっしんぐ ドレッシング"
"どろ 土呂 泥"
"どろじあい 泥試合 泥仕合"
"どろっぷ ドロップ"
"どろつち 泥土"
"どろどろ 泥々"
"どろなわ 泥縄"
"どろぬま 泥沼"
"どろぬまりゅう 泥沼流"
"どろぼう 泥棒"
"どろぼうねこ 泥棒猫"
"どろみず 泥水"
"どろみち 泥道"
"どろよけ 泥除け"
"どん 緞 嫩 貪 曇 呑 鈍 丼"
"どんか 鈍化"
"どんかく 鈍角"
"どんかん 鈍感"
"どんき 鈍器"
"どんぐり 團栗 団栗 ドングリ"
"どんこう 鈍行"
"どんしょく 貪食"
"どんじゅう 鈍重"
"どんす 緞子"
"どんそく 鈍足"
"どんぞこ どん底"
"どんちょう 鈍重 緞帳"
"どんつう 鈍痛"
"どんてん 曇天"
"どんぶり 丼"
"どんま 鈍麻 鈍磨"
"どんもの 丼物"
"どんよく 貪欲"
"どんよくさ 貪欲さ"
"どんらん 曇鸞 貪婪"
"どんるい 丼類"
"な 娜 儺 納 茄 菜 奈 那 名"
"なあて 名宛"
"ない 無 内"
"ないあつ 内圧"
"ないい 内意"
"ないいんせい 内因性"
"ないうちゅう 内宇宙"
"ないえ 奈井江"
"ないえん 内縁"
"ないか 内火 内化 内科"
"ないかい 内海 内科医 内回 内界"
"ないかく 内角 内閣"
"ないかひ 内果皮"
"ないがい 内外"
"ないがいそう 内外装"
"ないがしろ 蔑ろ"
"ないがめん 内画面"
"ないき 内規 内記"
"ないきじゅんかん 内気循環"
"ないきょく 内局"
"ないきん 内勤"
"ないきんこん 内菌根"
"ないくう 内腔"
"ないぐう 内宮"
"ないけい 内径"
"ないげんけい 内原型"
"ないこう 内訌 内攻 内向"
"ないこく 内国"
"ないこくさん 内国産"
"ないこくさんば 内国産馬"
"ないさいぼうかい 内細胞塊"
"ないざい 内在"
"ないざいてきせいしつ 内在的性質"
"ないし 内侍 〜 乃至"
"ないしき 内式"
"ないしきょう 内視鏡"
"ないしゃこう 内斜行"
"ないしゅう 内周"
"ないしゅっけつ 内出血"
"ないしょ 内緒"
"ないしょう 内鞘 内証 内省"
"ないしょく 内職"
"ないしょばなし 内緒話"
"ないしん 内診 内申 内心"
"ないしんおう 内親王"
"ないじ 内耳 内示"
"ないじつ 内実"
"ないじゅ 内需"
"ないじょ 内助"
"ないじょう 内情"
"ないじん 内陣"
"ないすん 内寸"
"ないせい 内生 内製 内政 内省"
"ないせいじょう 内清浄"
"ないせき 内積"
"ないせつ 内接"
"ないせん 内戦 内線"
"ないせんもう 内線網"
"ないそう 内層 内挿 内装"
"ないそく 内側 内足"
"ないぞう 内臓 内蔵"
"ないたい 内体 内帯"
"ないたいせつ 内体説"
"ないたつ 内達"
"ないだいじん 内大臣"
"ないだく 内諾"
"ないだん 内談"
"ないち 内地"
"ないつう 内通"
"ないてい 内偵 内定"
"ないてき 内的"
"ないてん 内点"
"ないと ナイト"
"ないとう 内藤"
"ないない 内々"
"ないないてい 内々定"
"ないにゅう 内乳"
"ないねん 内燃"
"ないねんきかん 内撚機関"
"ないひ 内皮"
"ないふ ナイフ"
"ないふく 内服"
"ないふくえき 内服液"
"ないふくやく 内服薬"
"ないふん 内紛"
"ないぶ 内部"
"ないぶは 内部波"
"ないぶひずみ 内部歪"
"ないぶん 内分 内聞"
"ないぶんぴつ 内分泌"
"ないへき 内壁"
"ないほう 内包"
"ないみつ 内密"
"ないむ 内務"
"ないむしょう 内務省"
"ないめん 内面"
"ないもう 内毛"
"ないや 内野"
"ないやく 内約"
"ないやしゅ 内野手"
"ないやせき 内野席"
"ないゆう 内憂"
"ないゆうがいかん 内憂外患"
"ないよう 内容"
"ないようせき 内容積"
"ないらん 内覧 内乱"
"ないりく 内陸"
"ないりょく 内力"
"ないりん 内輪"
"ないろん ナイロン"
"ないわくせい 内惑星"
"なうて 名うて"
"なえ 奈江 苗"
"なえぎ 苗木"
"なえどこ 苗床"
"なえば 苗場"
"なえぼ 苗穂"
"なえむら 苗村"
"なお 猶 奈緒 菜穂 奈央 尚 直"
"なおあき 直明 尚明"
"なおい 直井"
"なおいち 直一"
"なおいり 直入"
"なおえ 尚江 直江"
"なおえつ 直江津"
"なおかず 直和 直一"
"なおかつ 猶且 直勝"
"なおかわ 直川"
"なおき 尚紀 直毅 直喜 直紀 直樹"
"なおきしょう 直木賞"
"なおきち 直吉"
"なおこ 奈緒子 菜桜子 奈央子 菜生子 尚子 奈保子 直子"
"なおさら 尚更"
"なおざり 等閑"
"なおし 直志 直 直史 尚史 直し"
"なおしま 直島"
"なおじ 直治"
"なおずみ 尚純 直純"
"なおた 直田"
"なおたか 直孝"
"なおたけ 尚武"
"なおと 尚人 直人"
"なおとし 直敏 直利"
"なおのぶ 直宣"
"なおのり 直徳 尚憲"
"なおはら 猶原"
"なおはる 直治"
"なおひこ 尚彦 直彦"
"なおひさ 尚久 直久"
"なおひで 直秀"
"なおひと 直人 直仁"
"なおひろ 直弘 尚宏 尚弘 直廣 直広"
"なおふみ 尚文 直史"
"なおまさ 直昌"
"なおみ 直実 奈穂美 尚美 名保美 なお美 直美 奈緒美"
"なおみち 直道"
"なおや 尚哉 直弥 尚也 直也"
"なおゆき 尚幸 直之 直行 尚之 直幸"
"なおよし 直良 直義"
"なか 那珂 仲 中"
"なかあし 中足"
"なかあだち 中阿達"
"なかい 仲居 仲井 中居 中井"
"なかいけ 仲池"
"なかいず 中伊豆"
"なかいち 中市"
"なかいま 仲井真"
"なかいり 中入"
"なかいわ 中岩"
"なかう なか卯"
"なかうち 中内"
"なかうま 中馬"
"なかうみ 中海"
"なかえ 中江"
"なかえちょうみん 中江兆民"
"なかお 中尾"
"なかおか 中岡"
"なかおかちまち 仲御徒町"
"なかおがわてっきょう 中尾川鉄橋"
"なかかるいざわ 中軽井沢"
"なかかわね 中川根"
"なかがい 仲買"
"なかがいうち 中谷内"
"なかがき 中垣"
"なかがた 中潟"
"なかがみ 中上"
"なかがわ 那賀川 仲川 中川"
"なかがわら 中河原"
"なかき 中木"
"なかきた 中来田 中北"
"なかぎし 中岸"
"なかぎり 中限 中桐"
"なかく 中区"
"なかくら 仲倉 中倉"
"なかくろ ・"
"なかぐすく 中城"
"なかぐろ ・"
"なかけちょう 名掛丁"
"なかこうじ 仲小路"
"なかこま 中巨摩"
"なかごう 中郷"
"なかごし 中越"
"なかごみ 中込"
"なかごめ 中込"
"なかごろ 中ごろ 中頃"
"なかさき 中崎"
"なかさく 中作"
"なかさつない 中札内"
"なかさと 中里"
"なかざいけ 中在家"
"なかざき 中崎 仲崎"
"なかざと 仲里 中里"
"なかざわ 仲沢 中澤 中沢"
"なかしこく 中四国"
"なかした 中下"
"なかしべつ 中標津"
"なかしほろ 中士幌"
"なかしま 中嶋 中島"
"なかしょう 中庄"
"なかじま 中嶋 中島"
"なかじゅく 中宿"
"なかじょう 中条 中條"
"なかす 中州 中須 中洲"
"なかすぎ 中杉"
"なかすじ 中筋"
"なかすみ 中済"
"なかず 中頭"
"なかせ 中瀬"
"なかせん 中仙"
"なかせんどう 中山道"
"なかそ 中曽"
"なかそね 仲宗根 中曽根"
"なかぞの 中薗 中園"
"なかた 仲田 中田"
"なかたがい 仲違い 仲たがい"
"なかたじま 中田島"
"なかたど 仲多度"
"なかたに 仲谷 中谷"
"なかたね 中種子"
"なかだ 仲田 中田"
"なかだいら 中平"
"なかだち 中立 仲立ち"
"なかだて 中舘"
"なかだるみ 中だるみ"
"なかち 中地 仲地"
"なかちょう 中長"
"なかぢ 中地"
"なかつ 中津"
"なかつえ 中枝 中津江"
"なかつか 中塚"
"なかつかさ 中務"
"なかつがる 中津軽"
"なかつぎ 中継ぎ"
"なかづり 中吊り"
"なかてん ナカテン 中点 ・"
"なかで 中出"
"なかとう 中藤"
"なかとがわ 中戸川"
"なかとき 中時"
"なかとさ 中土佐"
"なかとみ 中富"
"なかとんべつ 中頓別"
"なかなお 仲直"
"なかなおり 仲直り"
"なかなか 難々 中々 仲々"
"なかにいかわ 中新川"
"なかにいだ 中新田"
"なかにし 中西"
"なかにほん 中日本"
"なかにわ 中庭"
"なかね 仲値 中値 中根"
"なかの 仲野 中野"
"なかのくち 中之口"
"なかのしま 中野島 中之島"
"なかのしょう 中ノ庄 中之庄"
"なかのじょう 中之条"
"なかのぶがくえん 中延学園"
"なかのべ 中延"
"なかはた 中畑"
"なかはら 中原"
"なかば 半ば"
"なかばやし 中林"
"なかばる 中原"
"なかひら 中平"
"なかび 中日"
"なかびしゃ 中飛車"
"なかびょうし 中表紙"
"なかぶと 中太"
"なかへじ 中辺路"
"なかほど 中程"
"なかほり 中堀"
"なかま 仲魔 中間 仲間"
"なかまいり 仲間入り 仲間入"
"なかまうち 仲間内"
"なかまき 中牧"
"なかまち 中町"
"なかまつ 中松"
"なかまる 中束 ・"
"なかみ 中味 中身"
"なかみかわ 中見川"
"なかみせ 仲見世"
"なかみぞ 中溝"
"なかみち 中道 仲道"
"なかみなと 那珂湊"
"なかむら 仲村 中村"
"なかめぐろ 中目黒"
"なかもず 中百舌鳥"
"なかもと 中本"
"なかもり 中森"
"なかもん 中門"
"なかや 仲谷 中矢 中屋 中谷"
"なかやま 仲山 中山"
"なかやましば 中山芝"
"なかやまりょう 中山陵"
"なかゆび 中指"
"なかよく 仲良く"
"なかよし 仲良し"
"なかりゃく 中略"
"なかれ 毓 毋 毋れ 勿れ 莫れ 勿"
"なかわきべつえき 中湧別駅"
"なかわり 中割り"
"なかんずく 就中"
"なが 永 長"
"ながあめ 長雨"
"ながい 永射 長居 長井 永井"
"ながいかふう 永井荷風"
"ながいき 長生 長生き"
"ながいけ 長池"
"ながいす 長椅子"
"ながいずみ 長泉"
"ながいた 長板"
"ながうた 長唄"
"ながえ 永江"
"ながえさんきょう 長江三峡"
"ながお 長緒 永尾 長尾"
"ながおか 永岡 長岡"
"ながおかきょう 長岡京"
"ながき 長岐"
"ながぎし 永岸"
"ながくて 長久手"
"ながくら 長倉"
"ながくらしんでんふきん 長蔵新田付近"
"ながぐつ 長靴"
"ながけちょう 名掛丁"
"ながさ 長さ"
"ながさか 長坂"
"ながさき 永崎 長崎"
"ながさきこう 長崎港"
"ながさきでんき 長崎電軌"
"ながさきわん 長崎湾"
"ながさく 永作"
"ながさわ 長澤 長沢 永沢"
"ながしだい 流し台"
"ながしま 永島 永嶋 長嶋 長島"
"ながす 長洲"
"ながすぎ 長過ぎ"
"ながずぼん 長ズボン"
"ながせ 長瀬 永瀬"
"ながそで 長袖"
"ながた 長多 長田 永田"
"ながたに 長谷 永谷"
"ながたび 長旅"
"ながちょうば 長丁場"
"ながっちり 長っ尻"
"ながつ 永津 長津"
"ながつか 長束 長塚"
"ながつき 長月"
"ながつだ 長津田"
"ながつづき 永続き 長続き"
"ながつま 長妻"
"ながてぶくろ 長手袋"
"ながてほうこう 長手方向"
"ながでんわ 長電話"
"ながと 長戸 長門"
"ながとし 長年"
"ながとみ 長冨 長富"
"ながとも 永友 長友"
"ながとろ 長瀞"
"ながなが 長々"
"ながぬま 長沼"
"ながねぎ 長葱"
"ながねん 永年 長年"
"ながの 永埜 長能 永野 長野"
"ながのこう 長野高"
"ながのはら 長野原"
"ながのはらくさつぐち 長野原草津口"
"ながはし 長橋"
"ながはた 永幡"
"ながはま 長濱 長浜"
"ながはら 永原 長原"
"ながばなし 長話"
"ながふさ 長房"
"ながぶせ 長伏"
"ながぶち 長淵 長渕"
"ながぶちつよし 長淵剛"
"ながほ 長保"
"ながまさ 長政"
"ながまち 長町"
"ながまつ 長松 永松"
"ながみ 永見"
"ながみつ 永光 長光"
"ながみね 長嶺 長峯"
"ながむね 長宗"
"ながめ 眺め 長目"
"ながもち 長持ち 長もち"
"ながもちうた 長持唄"
"ながもり 永森"
"ながや 長谷 長屋 長家"
"ながやす 永安"
"ながやま 永山 長山"
"ながゆ 長湯"
"ながゆき 長幸"
"ながよ 長与"
"ながよし 永吉"
"ながら 長良 長柄 乍ら 乍"
"ながらく 長らく"
"ながれ 流れ"
"ながれさぎょう 流作業"
"ながれぼし 流れ星"
"ながれもの 流れ者"
"ながれやま 流山"
"ながわ 奈川 名川"
"ながわずらい 痼 長患い"
"なき 鳴 泣き"
"なきがお 泣き顔"
"なきがら 亡骸"
"なきごえ 鳴声 鳴き声"
"なきむし 泣き虫"
"なきり 奈切"
"なぎ 南木 奈義 椥 梛 薙 凪"
"なぎさ 渚"
"なぎそ 南木曾"
"なぎなた 薙刀 長刀"
"なぎなたがた 長刀形"
"なぎなたほこ 長刀鉾"
"なぎなたぼこ 長刀鉾"
"なぎょう ナ行"
"なくなく 泣く泣く"
"なくら 名倉"
"なぐ 薙"
"なぐさめ 慰め"
"なぐも 南雲"
"なぐら 殴羅 名倉"
"なぐり 名栗"
"なぐりがき 殴り書き"
"なげうり 投げ売り"
"なげざお 投げ竿"
"なげし 長押"
"なげづり 投げ釣"
"なげやり 投げ遣り"
"なこ 名古"
"なこうど 仲人"
"なこそ 勿来"
"なご 名護"
"なごや 那古屋 名越 名古屋"
"なごやきんこぐん 名古屋金鯱軍"
"なごやぐち 名古屋口"
"なごやだいいん 名古屋大院"
"なごやだいり 名古屋大理"
"なごやにし 名古屋西"
"なごやまつり 名古屋祭"
"なごり 名残り 名残"
"なごん 納言"
"なさけ 情け 情"
"なさぬなか 生さぬ仲"
"なざし 名指し"
"なし 無 梨"
"なしじ 梨子地"
"なしだ 梨田"
"なしだい 梨大"
"なしのつぶて 梨の礫"
"なしょなる ナショナル"
"なじみ 馴染"
"なす ナス 那州 茄子 那須"
"なすすべ 為す術 為す業"
"なずな 薺"
"なぜ 名瀬 何故"
"なぜか 何故か"
"なぜなら ∵"
"なぞ 謎"
"なぞがく 謎学"
"なぞとき 謎解き"
"なぞわざ 謎技"
"なた 鉈 釶 屶"
"なたしょう 名田庄"
"なたに 名谷"
"なだ 灘"
"なだい 灘井 名題 名代"
"なだきたどおり 灘北通"
"なだく 灘区"
"なだこう 灘校 灘高"
"なだこうとうがっこう 灘高等学校"
"なださき 灘崎"
"なだたる 名立たる"
"なだち 名立"
"なだちゅう 灘中"
"なだれ 雪崩"
"なち 那智"
"なっせん 捺染"
"なっと ナット"
"なっとう 納豆"
"なっとうきん 納豆菌"
"なっとうしゅう 納豆臭"
"なっとうまき 納豆巻"
"なっとく 納得"
"なっぱ 菜っ葉 菜葉"
"なつ 奈津 捺 夏"
"なつあき 夏秋"
"なついがい 夏以外"
"なついろ 夏色"
"なついん 捺印"
"なつえ 夏江"
"なつお 夏生"
"なつおんな 夏女"
"なつかし 懐かし"
"なつかぜ 夏風邪"
"なつかわ 夏川"
"なつがき 夏牡蛎"
"なつがた 夏型"
"なつがっこう 夏学校"
"なつがっしゅく 夏合宿"
"なつき 奈月 無月 夏木 夏樹 夏生"
"なつぎ 夏着"
"なつくさ 夏草"
"なつこ 夏子 那津子 奈津子 なつ子"
"なつごう 夏号"
"なつごろ 夏頃"
"なつしんぽ 夏シンポ"
"なつじかん 夏時間"
"なつじゅう 夏中"
"なつぜんご 夏前後"
"なつぞら 夏空"
"なつの 夏野"
"なつば 夏場"
"なつばて 夏バテ"
"なつばん 夏版"
"なつひこ 夏彦"
"なつふく 夏服"
"なつまつり 夏祭"
"なつみ 夏実 奈津美 菜摘 夏巳 夏美"
"なつむき 夏向き"
"なつめ 棘 棗 夏目"
"なつもの 夏物"
"なつやさい 夏野菜"
"なつやすみ 夏休み"
"なつやま 夏山"
"なつよ 夏代"
"なつよう 夏用"
"なづけおや 名付親"
"なでしこ 撫子"
"なでしこもく ナデシコ目"
"なではら 撫原"
"なでら 斜平"
"なとり 名取"
"なとりうむ ナトリウム"
"など 等"
"などなど 等々"
"なな 奈奈 ナナ 奈々 ７ 七"
"なない 七位"
"なないろ 七色"
"ななえ 七栄 奈々江 奈々絵 七重"
"ななお 七尾"
"ななかい 七会"
"ななかく 七角"
"ななきた 七北田"
"ななくさ 七草"
"ななくま 七隈"
"ななこ 七個 奈々子"
"ななころび 七転び"
"ななさわ 奈々沢"
"ななさん 七三"
"ななし 名無"
"ななしょく 七色"
"ななじゅうねんだい 七十年代"
"ななじょう 七条"
"ななせ 七瀬"
"ななそ 七十"
"ななたび 七度"
"ななたま 七玉"
"ななだいせん 七大戦"
"ななだる 七滝"
"ななつ 七ツ 七つ"
"ななつか 七塚"
"ななつたき 七ッ滝"
"ななつもり 七ッ森"
"ななねん 七年"
"ななひき 七匹"
"ななふしぎ 七不思議"
"ななぶ 七部"
"ななみ 七海 七生"
"ななめ 斜め"
"ななめこうほう 斜後方"
"ななめぜんぽう 斜前方"
"ななやしろ 七社"
"ななやま 七山"
"ななれんしょう 七連勝"
"なに 何"
"なにいろ 何色"
"なにうりば 何売場"
"なにか 何か 何科"
"なにかと 何彼と"
"なにがし 何某 某"
"なにがた 何型"
"なにけい 何系"
"なにけん 何県"
"なにげ 何気"
"なにご 何語"
"なにごと 何言 何事"
"なにさま 何様"
"なにしろ 何しろ"
"なにじん 何人"
"なにせん 何線"
"なにせんせい 何先生"
"なにとぞ 何卒"
"なになに 何何 何々"
"なにはさておき 何は扨措き"
"なにばしょ 何場所"
"なにぶん 何分"
"なにもの 何物 何者"
"なにもよう 何模様"
"なにや 何屋"
"なにゆえ 何故"
"なによう 何用"
"なにわ 難波 灘 浪速 浪花"
"なにわぶし 浪花節"
"なぬし 名主"
"なのか 七日 ７日"
"なのかしゅうき 七日週期"
"なのこ 菜子"
"なのはな 菜の花"
"なのり 名乗り"
"なは 那覇"
"なはさば 鯆"
"なはり 名張 奈半利"
"なばり 名張"
"なふだ 名札"
"なぶら ∇ ▽"
"なへん 那辺 奈辺"
"なべ 邊 辺 邉 鍋"
"なべかい 鍋会"
"なべき 鍋気"
"なべた 鍋田"
"なべたに 鍋谷"
"なべて 並べて"
"なべの 鍋野"
"なべはり 鍋貼"
"なべもの 鍋物 鍋もの"
"なほ 猶 尚 菜穂"
"なほこ 菜穂子"
"なほざり 等閑"
"なほし 直衣"
"なほみ 奈保美"
"なほもって 尚以て"
"なま 生"
"なまいき 生意気"
"なまえ 名前"
"なまえいり 名前入"
"なまえつきぱいぷ 名前付きパイプ"
"なまえんそう 生演奏"
"なまえんそうか 生演奏家"
"なまおと 生音"
"なまおん 生音"
"なまかいとうきのう 生解凍機能"
"なまかわ 生皮"
"なまかんせん 生観戦"
"なまがき 生牡蛎 生蛎"
"なまがし 生菓子"
"なまがっき 生楽器"
"なまがわ 生皮"
"なまき 生木"
"なまくび 生首"
"なまぐさ 腥 生臭"
"なまけぐせ 怠け癖"
"なまけもの 怠け者"
"なまげんこう 生原稿"
"なまこ 海鼠 ナマコ"
"なまごろし 生殺し"
"なまざかな 生魚"
"なましいたけ 生椎茸"
"なましゅつえん 生出演"
"なましょく 生食"
"なまじ 憖"
"なまじっか 憖っか"
"なまじゃけ 生鮭"
"なまじゃしん 生写真"
"なます 韲 鱠 膾"
"なますじこ 生筋子"
"なまず 鮠 癜 鯰"
"なませっこう 生石膏"
"なまたまご 生卵"
"なまため 生田目 生天目"
"なまだら 生ダラ"
"なまちゅうけい 生中継"
"なまつば 生唾"
"なまづめ 生詰"
"なまなしけん 山梨県"
"なまなま 生々 生生"
"なまにく 生肉"
"なまはけい 生波形"
"なまはんか 生半可"
"なまばな 生花"
"なまばんぐみ 生番組"
"なまびょうほう 生兵法"
"なまぴ 生ピ"
"なまふ 生麩"
"なまへんじ 生返事"
"なまほうそう 生放送"
"なまぼし 生乾し"
"なままめ 生豆"
"なまみ 生身"
"なまみず 生水"
"なまみそ 生味噌"
"なまむぎ 生麦"
"なまめん 生麺"
"なまもの 生物"
"なまやさい 生野菜"
"なまり 訛 鉛"
"なまりいた 鉛板"
"なまりいり 鉛入"
"なまりだん 鉛弾"
"なまりばん 鉛版"
"なまりぶくろ 鉛袋"
"なまろく 生録"
"なみ 名美 竝 奈未 奈巳 浪 奈美 〜 波 並"
"なみあい 浪合"
"なみあし 並足"
"なみいか 並以下"
"なみうち 波打"
"なみうちぎわ 波打際 波打ち際 波内際"
"なみえ 浪江"
"なみお 波雄"
"なみおか 浪岡"
"なみおと 波音"
"なみかぜ 波風"
"なみかた 波方"
"なみかわ 並河 浪川"
"なみがい 浪貝"
"なみがけ 並罫"
"なみき 行木 並木"
"なみきざ 並木座"
"なみきみち 並木道"
"なみこし 浪越"
"なみしょう 浪商"
"なみせい 並製"
"なみせん 波線"
"なみたいてい 並大抵"
"なみだ 泪 涙"
"なみだがお 涙顔"
"なみだがた 涙型"
"なみだきん 涙金"
"なみだごえ 涙声"
"なみだめ 涙目"
"なみなみ 並々"
"なみの 波野"
"なみのり 波乗"
"なみへい 波平"
"なみま 波間"
"なむ 南無"
"なむさん 南無三"
"なめ 嘗 滑"
"なめいし 大理石"
"なめかた 行方"
"なめかわ 滑川"
"なめがた 行方"
"なめくじ 蛞蝓"
"なめらか 滑らか"
"なめりかわ 滑川"
"なや 納谷 納屋"
"なやみ 悩み"
"なゆ 那由"
"なゆた 奈由太 那由他 那由多"
"なよろ 名寄"
"なら 枹 柞 平城 楢 奈良"
"ならい 奈良井"
"ならいごと 習い事"
"ならお 奈良尾"
"ならおか 奈良岡"
"ならかわ 楢川"
"ならき 奈良木"
"ならく 奈落"
"ならさき 楢崎"
"ならざき 楢崎"
"ならしの 習志野"
"ならず 不成"
"ならでん 奈良電"
"ならは 楢葉"
"ならはら 奈良原"
"ならば ⊃ →"
"ならび 並び"
"ならびかえ 並び換え"
"ならへいあんじだい 奈良・平安時代"
"ならべかえ 並べ変え 並べ替え"
"ならやまぶしこう 楢山節考"
"ならわし 習わし"
"なり 形 鳴り 斉 就 成 也"
"なりあがり 成り上がり"
"なりあき 成昭"
"なりあきら 斉彬"
"なりお 成雄"
"なりかわ 成川"
"なりきん 成金"
"なりぎん 成銀"
"なりこ 成子"
"なりこま 成駒"
"なりさと 成里"
"なりさわ 成澤 成沢"
"なりさわりんどう 鳴沢林道"
"なりしげ 成茂"
"なりしま 成嶋"
"なりた 成田"
"なりたち 成立ち"
"なりたつ 成り立つ"
"なりたにし 成田西"
"なりち 成知"
"なりて 為り手"
"なりと 成人"
"なりとみ 成富"
"なりとも 成伴 成知"
"なりはら 成原"
"なりひと 成人"
"なりひらばし 業平橋"
"なりひろ 成洋"
"なります 成増"
"なりまつ 成松"
"なりみ 也美 也実"
"なりみつ 成允"
"なりもと 成本"
"なりやす 成康"
"なりゆき 成行 成行き"
"なりよし 成良"
"なりわ 成羽"
"なりわい 業 生業"
"なる 奈留 鳴 徳 成"
"なるお 成雄 鳴尾"
"なるかみ 鳴神"
"なるき 成紀"
"なるきよ 成清"
"なるけ 成毛"
"なるこ 鳴子"
"なるご 鳴子"
"なるさわ 成沢 鳴沢 成澤 鳴澤"
"なるしま 成嶋"
"なるせ 鳴瀬 成瀬"
"なるたき 鳴滝"
"なるち 成知"
"なると 鳴門"
"なるとう 成東"
"なるとだい 鳴門鯛"
"なるひこ 徳彦"
"なるひさ 徳寿"
"なるべく 可成 成る可く"
"なるほど 成る程 成程"
"なるみ 成己 鳴海 成美"
"なるみつ 成光"
"なるよし 成良"
"なれ 馴 慣れ"
"なわ 繩 名和 縄"
"なわしろ 苗代"
"なわた 縄田"
"なわて 縄手 畷"
"なわとび 縄跳び"
"なわない 縄綯い"
"なわばしご 縄梯子"
"なわばり 縄張り 縄張"
"なをれ 名折れ"
"なん 娚 喃 男 楠 軟 南 難 何"
"なんあり 難有り"
"なんい 何位 南緯 難易"
"なんえん 何円"
"なんおう 南欧"
"なんおく 何億"
"なんおん 軟音"
"なんか 軟化 南下"
"なんかい 何階 難解 南海 何回"
"なんかいせん 南海戦"
"なんかいりゅう 南海龍"
"なんかげつ 何か月"
"なんかこくご 何か国語"
"なんかしょ 何ヵ所 何か所"
"なんかん 南関 何巻 難関"
"なんが 軟臥"
"なんがい 南外"
"なんがつ 何月"
"なんがつごろ 何月頃"
"なんき 何機"
"なんきごう 南紀号"
"なんきしらはま 南紀白浜"
"なんきつ 難詰"
"なんきゅう 軟球"
"なんきょく 何局 難曲 難局 何曲 南極"
"なんきん 軟禁 南京"
"なんぎ 難儀"
"なんぎょう 難業 難行 何行"
"なんく 何区"
"なんくせ 何癖 難癖"
"なんくち 何口"
"なんくみ 何組"
"なんぐう 南宮"
"なんけた 何桁"
"なんけん 軟件 何軒 何件"
"なんげん 南限 何軒"
"なんこ 何個"
"なんこう 南光 軟攻 南高 楠公 軟膏 南港 難航"
"なんこうがい 軟口蓋"
"なんこうどう 南江堂"
"なんこうふらく 難攻不落"
"なんこつ 軟骨"
"なんこつぎょ 軟骨魚"
"なんご 喃語 南後"
"なんごう 南郷 何号"
"なんごく 南国"
"なんさい 何才 何歳"
"なんさく 何作"
"なんさつ 何冊"
"なんざ 軟座"
"なんざん 難産 南山"
"なんし 難思"
"なんしき 軟式"
"なんしつ 軟質"
"なんしつまい 軟質米"
"なんしゅ 何種"
"なんしゅう 何週 何周"
"なんしょ 難所"
"なんしょう 何勝"
"なんしょうなんぱい 何勝何敗"
"なんしょく 男色 何色 難色"
"なんしん 南進"
"なんじ 尓 難事 爾 何次 汝 何時"
"なんじっかい 何十回"
"なんじっけん 何十件"
"なんじってん 何十点"
"なんじゃく 軟弱"
"なんじゃくもの 軟弱者"
"なんじゅう 難渋 何重 何十"
"なんじゅうもん 何十問"
"なんじゅっかい 何十回"
"なんじゅっけん 何十軒 何十件"
"なんじゅっしゅるい 何十種類"
"なんじゅってん 何十点"
"なんじゅっぽん 何十本"
"なんじょう 何乗 何条 南條 南常 南条 南城"
"なんすい 軟水"
"なんせ 何せ"
"なんせい 南勢 何世 軟性 南西"
"なんせき 何隻"
"なんせん 南線"
"なんせんめ 何戦目"
"なんぜん 何千"
"なんぜんじ 南禅寺"
"なんぜんびき 何千匹"
"なんそう 何層"
"なんそく 何足"
"なんそしき 軟組織"
"なんたい 男体 何体 軟体"
"なんたいさん 男体山"
"なんたん 南端"
"なんだい 何代 難題 何台"
"なんだばつ 何打罰"
"なんだん 南淡 何段"
"なんちしっかん 難治疾患"
"なんちゃく 何着"
"なんちゃくりく 軟着陸"
"なんちゅう 南中"
"なんちょう 南朝 軟調 何丁 難聴"
"なんつう 何通"
"なんて 何て"
"なんてい 軟庭"
"なんてき 何滴"
"なんてつ 軟鉄"
"なんてん 何店 何点 難点"
"なんてんか ナンテン科"
"なんでも 何でも"
"なんと 南都 南斗 何と"
"なんとう 何等 南島 軟投 何頭 南東"
"なんとうがたとうしゅ 軟投型投手"
"なんとか 何とか"
"なんとなく 何となく"
"なんとなれば ∵"
"なんど 納戸 難度 何度"
"なんどう 南洞"
"なんどうせん 軟銅線"
"なんどき 何時"
"なんどく 難読"
"なんなく 難無く 難なく"
"なんなんせい 南南西"
"なんなんとう 南南東"
"なんにち 何日"
"なんにちごろ 何日頃"
"なんにん 何人"
"なんねん 何年"
"なんねんうえ 何年上"
"なんねんくらいまえ 何年位前"
"なんねんせい 難燃性"
"なんの 何の 南野"
"なんのう 南濃"
"なんはく 何拍"
"なんはこ 何箱"
"なんば 難波"
"なんばー ナンバー"
"なんばい 何倍 何杯"
"なんばら 南原"
"なんばん 軟盤 南蛮 何番"
"なんぱ 難破 軟派"
"なんぱく 何拍 何泊"
"なんぱこ 何箱"
"なんぱせん 難破船"
"なんぱつ 何発"
"なんひき 何匹"
"なんひょう 何票"
"なんびき 何匹"
"なんびと 何人"
"なんびゃく 何百"
"なんびゃっこ 何百個"
"なんびょう 難病 何秒"
"なんぴと 何人"
"なんぴょう 何票"
"なんぴょうよう 南氷洋"
"なんぴん 何品"
"なんふつ 南仏"
"なんふん 何分"
"なんぶ 軟部 南武 南部 何部"
"なんぶつ 難物"
"なんぶん 何分"
"なんぷう 南風"
"なんぷくじ 南福寺"
"なんぷん 何分"
"なんべい 南米"
"なんべいさん 南米産"
"なんべいびょう 南米病"
"なんぺん 何編"
"なんぼいん 軟母音"
"なんぼく 南北"
"なんぼくちょう 南北朝"
"なんぼん 何本"
"なんぼんばしら 何本柱"
"なんぽ 何歩"
"なんぽう 南方"
"なんぽうかぜ 南方風"
"なんぽうぐんしゅうだん 南方軍集団"
"なんぽく 南北"
"なんぽろ 南幌"
"なんぽん 何本"
"なんまい 何枚"
"なんまん 何万"
"なんみょうほうれんげきょう 南妙法蓮華経"
"なんみん 難民"
"なんみんきゅうさいじょ 難民救済所"
"なんみんはん 難民班"
"なんめい 何名"
"なんめん 南面 何面"
"なんもう 軟毛"
"なんもく 南牧"
"なんもん 何問 難問"
"なんや 南谷"
"なんよう 何曜 南洋 南陽"
"なんら 何ら 何等"
"なんらか 何らか"
"なんり 南里"
"なんりゅうせき 南流石"
"なんりょう 何両"
"なんりん 何輪"
"なんれつ 何列"
"なんろ 難路"
"なんわ 何話"
"なんわり 何割"
"に 爾 貮 貳 岻 邇 児 2 丹 弍 ２ 似 尼 煮 弐 迩 荷 二"
"にーず ニーズ"
"にーたん ニータン"
"にあう 似合う"
"にあげ 荷揚げ"
"にあつかい 荷扱い"
"にあみす ニアミス"
"にい 新居 二位 新 兄"
"にいい 新居"
"にいかっぷ 新冠"
"にいかわ 新川"
"にいがき 新垣"
"にいがた 新潟"
"にいがたぐち 新潟口"
"にいがたさん 新潟産"
"にいがためいくんこう 新潟明訓高"
"にいくら 新倉"
"にいさと 新里"
"にいさん 兄さん"
"にいざ 新座"
"にいざか 新坂"
"にいざき 新居崎"
"にいざと 新里"
"にいじま 新島"
"にいじょう 二以上"
"にいだ 新田"
"にいちゃん 兄ちゃん"
"にいつ 新津"
"にいつま 新妻"
"にいつる 新鶴"
"にいづま 新妻"
"にいで 新出"
"にいな 二名"
"にいぬま 新沼"
"にいはま 新居浜"
"にいはら 新原"
"にいはり 新治"
"にいはる 新治"
"にいばる 新治"
"にいべ 新部"
"にいほ 新穂 仁保"
"にいみ 新實 新実 新見 新美"
"にいむら 新村"
"にいるぴと 二色人"
"にいんせい 二院制"
"にうけ 荷受 荷受け"
"にえ 錵 贄"
"にえゆ 煮湯"
"にお 仁尾 鳰 匂"
"におい 匂 匂い"
"におう 仁王"
"におうふく 二往復"
"におくりにん 荷送人"
"におし 二推し"
"におろし 荷下ろし 荷卸し"
"にか 二価 二課"
"にかい ２階 ２回 二回 二階"
"にかいせき 二階席"
"にかいせん 二回戦"
"にかいだて 二階建"
"にかいどう 二階堂"
"にかく 仁鶴"
"にかげつ 二カ月 二ヶ月 二箇月"
"にかしょ 二カ所 二箇所"
"にかほ 仁賀保"
"にかわ 仁川 膠"
"にかわせ 荷為替"
"にかん 二冠"
"にかんちゅうしんちゅう 二環中心柱"
"にが 苦"
"にがお 似顔"
"にがおえ 似顔絵"
"にがさ 苦さ"
"にがたけ 苦竹"
"にがつ 如月 二月 ２月"
"にがて 苦手"
"にがみ 苦味"
"にがむし 苦虫"
"にがゆ 煮粥"
"にがわ 仁川"
"にがわせ 荷為替"
"にがわらい 苦笑い"
"にがん 二眼"
"にき 仁木 二木 二基"
"にきかい 二期会"
"にきしゅ 二機種"
"にきび 靤"
"にきゅう 二級"
"にきゅうしゅ 二級酒"
"にきょく 二極 二曲"
"にぎてき 二義的"
"にぎにぎしい 賑々しい"
"にぎやか 賑やか"
"にぎょう 二行"
"にぎょうめいか 二行目以下"
"にぎりずし 握り鮨"
"にぎわい 賑"
"にく 肉"
"にくあつ 肉厚"
"にくか 肉果"
"にくかい 肉塊"
"にくが 肉芽"
"にくがかり 肉係"
"にくがん 肉眼"
"にくきゅう 肉球"
"にくぎゅう 肉牛"
"にくけい 肉桂"
"にくげ 肉芽"
"にくしつ 肉質"
"にくしみ 憎しみ"
"にくしゅ 肉腫"
"にくしょく 肉食"
"にくしょくぎょ 肉食魚"
"にくしん 肉親"
"にくじき 肉食"
"にくじゅう 肉汁"
"にくすい 肉垂 肉穂"
"にくずくか ニクズク科"
"にくせい 肉声"
"にくたい 肉体"
"にくたいてきちから 肉体的力"
"にくだい 肉代"
"にくだま 肉玉"
"にくだん 肉彈 肉弾"
"にくだんせん 肉彈戰 肉弾戦"
"にくづき 肉付き"
"にくづけ 肉付け"
"にくはく 肉薄 肉迫"
"にくひつ 肉筆"
"にくへん 肉片"
"にくぼう 肉棒"
"にくや 肉屋"
"にくよく 肉欲"
"にくりょうり 肉料理"
"にくるい 肉類"
"にぐるま 荷車"
"にぐん 二群 二軍"
"にけん 二軒 ２研 二間 二件 二研"
"にげ 逃げ"
"にげあし 逃げ足"
"にげきり 逃げ切り"
"にげごし 逃げ腰"
"にげば 逃げ場"
"にげみず 逃げ水"
"にげみち 逃げ道"
"にげん 二元"
"にげんしゃ 二玄社"
"にこ 二個"
"にこう 二高 二項"
"にこく 二国"
"にこちん ニコチン"
"にこにこ ニコニコ"
"にこみ 煮込み 煮込"
"にご 二語"
"にごう 二合 二号"
"にごりえ 濁江"
"にごん 二言"
"にさ 二叉"
"にさくひん 二作品"
"にさつ 二冊"
"にさん 二、三 二三"
"にさんか 二酸化"
"にざえもん 仁左衛門"
"にざかな 煮魚"
"にし 二死 螺 爾志 西"
"にしあい 二試合"
"にしあいづ 西会津"
"にしあおやま 西青山"
"にしあかし 西明石"
"にしあざい 西浅井"
"にしあざぶ 西麻布"
"にしあち 西阿知"
"にしあまね 西周"
"にしあらい 西新井"
"にしありえ 西有家"
"にしありた 西有田"
"にしあわくら 西粟倉"
"にしい 西井"
"にしいえ 西家"
"にしいけ 西池"
"にしいず 西伊豆"
"にしいちさんるい 二死一三塁"
"にしいばらき 西茨城"
"にしいる 西入ル"
"にしいわい 西磐井"
"にしいんたあ 西インター"
"にしうすき 西臼杵"
"にしうみ 西海"
"にしうみばしけいゆ 西海橋経由"
"にしうめだ 西梅田"
"にしうら 西裏 西浦"
"にしうわ 西宇和"
"にしお 西尾"
"にしおおい 西大井"
"にしおおさかせん 西大阪線"
"にしおおじ 西大路"
"にしおおじしちじょう 西大路七条"
"にしおおつ 西大津"
"にしおか 西岡"
"にしおかざきかん 西岡崎間"
"にしおぎ 西荻"
"にしおぎくぼ 西荻窪"
"にしおせんけいとう 西尾線系統"
"にしおちあい 西落合"
"にしかいがん 西海岸"
"にしかごしま 西鹿児島"
"にしかさい 西葛西"
"にしかしま 西鹿島"
"にしかすがい 西春日井"
"にしかぜ 西風"
"にしかた 西形 西方 西片"
"にしかつやま 西勝山"
"にしかつら 西桂"
"にしかど 西角 西門"
"にしかながわじゅうみん 西神奈川住民"
"にしかなざわ 西金沢"
"にしかも 西加茂"
"にしかるいざわ 西軽井沢"
"にしかわ 西川"
"にしかわきよし 西川きよし"
"にしかん 西館"
"にしかんだ 西神田"
"にしかんばら 西蒲原"
"にしがいち 西垣内"
"にしがき 西垣"
"にしがわ 西側"
"にしき 西木 西紀 二式 錦"
"にしきえ 錦絵"
"にしきがおか 錦ヶ丘"
"にしきがわてつどう 錦川鉄道"
"にしきぎか ニシキギ科"
"にしきぎもく ニシキギ目"
"にしきた 西北"
"にしきちょう 錦町"
"にしきど 錦戸"
"にしきどう 錦堂"
"にしきね 和稲"
"にしきみ 錦見"
"にしきょうごく 西京極"
"にしきょうとえき 西京都駅"
"にしきりゅう 西桐生"
"にしぎょうく 西京区"
"にしぎんざ 西銀座"
"にしく 西区"
"にしくじょう 西九条"
"にしくにさき 西国東"
"にしくびき 西頚城"
"にしくわな 西桑名"
"にしぐち 西口"
"にしこう 西高"
"にしこうえん 西公園"
"にしこうべ 西神戸"
"にしこく 西国"
"にしこくぶんじ 西国分寺"
"にしこくら 西小倉"
"にしこまごめ 西駒込"
"にしこむすび 西小結"
"にしご 西語"
"にしごう 西郷"
"にしごうし 西合志"
"にしごたんだ 西五反田"
"にしさんそう 西三荘"
"にしさんどう 西参道"
"にしざおう 西蔵王"
"にしざき 西崎"
"にしざわ 西沢 西澤"
"にししおがま 西塩釜"
"にしした 西下"
"にししば 西柴"
"にししらい 西白井"
"にししらかわ 西白河"
"にししん 西新"
"にししんじゅく 西新宿"
"にしじま 西島 西嶋"
"にしじん 西新 西陣"
"にしすぎ 西杉"
"にしすずらんだい 西鈴蘭台"
"にしせきわけ 西関脇"
"にしせんだい 西仙台"
"にしせんぼく 西仙北"
"にしぜき 西関"
"にしぞの 西園"
"にしたかしまだい 西高島台"
"にしたが 西多賀"
"にしたてやま 西舘山 西館山"
"にしたに 西谷"
"にしたま 西多摩"
"にしたんざわ 西丹沢"
"にしだ 西田"
"にしだいら 西平"
"にしだけ 西岳"
"にしだて 西館"
"にしちく 西地区"
"にしつがる 西津軽"
"にしてつ 西鉄"
"にしとう 西棟"
"にしとうきょう 西東京"
"にしとさ 西土佐"
"にしとじょうかん 西都城間"
"にしとなみ 西礪波 西砺波"
"にしどいつ 西独 西ドイツ"
"にしどうろ 西道路"
"にしどみ 西富"
"にしな 西名 仁科"
"にしなが 西永"
"にしなす 西那須"
"にしなだ 西灘"
"にしなり 西成"
"にしにっぽり 西日暮里"
"にしにっぽん 西日本"
"にしにほん 西日本"
"にしにほんいち 西日本一"
"にしにほんたんだいふ 西日本短大附 西日本短大付"
"にしね 西根"
"にしの 西野"
"にしのおもて 西之表"
"にしのしま 西ノ島"
"にしのだいら 西の平"
"にしのはら 西之原"
"にしのみや 西宮"
"にしはくしまちょう 西白島町"
"にしはし 西橋"
"にしはた 西畑"
"にしはちおうじえき 西八王子駅"
"にしはま 西浜"
"にしはら 西原"
"にしはりだしこむすび 西張出小結"
"にしはりだしせきわけ 西張出関脇"
"にしはる 西春"
"にしはんきゅう 西半球"
"にしはんぶん 西半分"
"にしばん 西版"
"にしひら 西平"
"にしひろしまし 西広島市"
"にしび 西陽 西日"
"にしびわじま 西枇杷島"
"にしふじ 西富士"
"にしふじのみや 西富士宮"
"にしふな 西船"
"にしべ 西部"
"にしほ 西穂"
"にしほうめん 西方面"
"にしほだか 西穂高"
"にしほんまち 西本町"
"にしまいづる 西舞鶴"
"にしまき 西牧"
"にしまごめ 西馬込"
"にしまつうら 西松浦"
"にしまど 西窓"
"にしみや 西宮"
"にしむら 西村"
"にしむろ 西牟婁"
"にしめ 西目"
"にしめいはん 西名阪"
"にしめら 西米良"
"にしもと 西本"
"にしもり 西森"
"にしもろかた 西諸県"
"にしゃ 二社 二者"
"にしやいづ 西焼津"
"にしやつしろ 西八代"
"にしやま 西山"
"にしゅ 二種"
"にしゅうかん 二週間"
"にしゅうめいこう 二周目以降"
"にしゅうれんぞく 二週連続"
"にしゅつ 二出"
"にしょう 二章"
"にしょうがくしゃ 二松学舎"
"にしょうてん 二焦点"
"にしょうめ 二勝目"
"にしょく 二色 二食"
"にしよこづな 西横綱"
"にしよこはま 西横浜"
"にしよどがわ 西淀川"
"にしわかまつ 西若松"
"にしわき 西脇"
"にしわせだ 西早稲田"
"にしわだ 西和田"
"にしん 鯡 二進 二審 鰊"
"にしんき 二進木"
"にしんぎ 二進木"
"にしんほう ２進法"
"にじ 二字 二時 二児 ２次 虹 二次"
"にじいろ 虹色"
"にじかんせん 二次巻線"
"にじく 二軸"
"にじけん 二次元"
"にじげん ２次元 二次元"
"にじこ 虹子"
"にじすいしょう 虹水晶"
"にじせい 二字姓"
"にじっさい 二十歳"
"にじっせいき 二十世紀"
"にじっぴき 二十匹"
"にじでんせつ 虹伝説"
"にじの 虹野"
"にじばいあす 二次バイアス"
"にじへき 二次壁"
"にじみゃく 二次脈"
"にじゅう 廿 二十 二重"
"にじゅうあご 二重顎"
"にじゅういちじょう 二一条"
"にじゅういっせいき 二十一世紀"
"にじゅううつし 二重映し"
"にじゅうおくこうねん 二十億光年"
"にじゅうかべ 二重壁"
"にじゅうかん 二重管"
"にじゅうし 二十四"
"にじゅうしょう 二重唱"
"にじゅうすうせき 二十数隻"
"にじゅうそう 二重奏"
"にじゅうとうとく 二重登録"
"にじゅうまど 二重窓"
"にじゅうまる ◎ 二重丸"
"にじゅうわく 二重枠"
"にじゅっさい 二十歳"
"にじゅっせいき 二十世紀"
"にじゅっぴき 二十匹"
"にじょ 二女"
"にじょう 二丈 二条 二乗"
"にじょうてきしゅうかんせい 日常的習慣性"
"にじょうわ ２乗和"
"にじる 煮汁"
"にじるし 荷印"
"にじんえい 二陣営"
"にすうか 二数花"
"にすがた 荷姿"
"にせ 僞 偐 贋 偽"
"にせい ２声 二世"
"にせき 二関"
"にせけいかん 偽警官"
"にせこ ニセコ"
"にせさつ 偽札"
"にせたんてい 偽探偵"
"にせほんちょう 二瀬本町"
"にせもの 偽者 贋物 偽物"
"にせん 二錢 二線 二千"
"にせんにんいじょう 二千人以上"
"にそう 二曹 二相 尼僧 二層"
"にそうしきせんたくき 二槽式洗濯機"
"にそく 二足"
"にそくさんもん 二束三文"
"にた 仁多"
"にたい 二体"
"にただ 仁多田"
"にたどり 似鳥"
"にたに 二谷"
"にたにた ニタニタ"
"にたみ 仁多見"
"にたやま 仁田山"
"にたろう 二太郎"
"にだいかいちょう 二代会長"
"にだいしょうぐん 二代将軍"
"にだいめ 二台目 二代目"
"にだし 荷出し"
"にだな 荷棚"
"にだん 二段"
"にだんがさね 二段重ね"
"にち 二値 日"
"にちいき 日域"
"にちいだい 日医大"
"にちいん 日陰"
"にちえい 日栄 日影 日英"
"にちおう 日欧"
"にちおん 日音"
"にちか 二千翔"
"にちかもくきんど 日火木金土"
"にちかん 日間"
"にちが 日我"
"にちがく 日額"
"にちぎん 日銀"
"にちげつ 日月"
"にちげん 日限"
"にちご 日後"
"にちじ 日次 日時"
"にちじび 日耳鼻"
"にちじゅう 日中"
"にちじょう 日常"
"にちじょうしゅ 日常酒"
"にちじょたいだい 日女体大"
"にちずい 日瑞"
"にちだい 日本大学 日大"
"にちだいせいさんこう 日大生産工"
"にちだいつるがおか 日大鶴ヶ丘"
"にちだいぶざん 日大豊山"
"にちづけ 日付"
"にちでん 日電"
"にちでんきょう 日電協"
"にちどう 日動"
"にちどく 日独"
"にちなん 日南"
"にちにち 日々"
"にちはむ 日本ハム"
"にちはら 日原"
"にちはん 日販 日半"
"にちふつ 日仏"
"にちぶ 日舞"
"にちぶん 日文 日分"
"にちべい 日米"
"にちべんれん 日弁連"
"にちほうほんせん 日豊本線"
"にちぼうしん 日貿信"
"にちぼつ 日没"
"にちまえ 日前"
"にちめ 日目"
"にちめんじつぎょう 日綿実業"
"にちや 日夜"
"にちゅう 二中"
"にちょう 二鳥"
"にちょうなげ 二丁投げ"
"にちょうめ 二丁目"
"にちよう 日用 日曜"
"にちようあさ 日曜朝"
"にちようびあさ 日曜日朝"
"にちようよる 日曜夜"
"にちりょう 日糧"
"にちりん 日林 日輪"
"にちれき 日瀝"
"にちれん 日蓮"
"にちろ 日露"
"にちろぎょぎょう 日魯漁業"
"にちわ 日和"
"にっか 日課"
"にっかぎれん 日科技連"
"にっかつ 日活"
"にっかゆし 日華油脂"
"にっかわ 新川"
"にっかん 日韓 日刊"
"にっかんこう 日刊工"
"にっかんし 日刊紙"
"にっき 日揮 日記"
"にっきそう 日機装"
"にっきちょう 日記帳"
"にっきゅう 日給"
"にっきょう 日共"
"にっきょうさい 日教済"
"にっきょうそ 日教組"
"にっきん 日勤"
"にっくう 日空"
"にっくに 新国"
"にっけい 肉桂 日計 日系 日経"
"にっけんかがく 日研化学"
"にっこう 日工 日航 日興 日光"
"にっこうきょうせき 日鉱共石"
"にっこうよく 日光浴"
"にっこり 莞爾"
"にっさん 日参 日産"
"にっさんしゃ 日産車"
"にっし 日誌"
"にっしゃ 日射"
"にっしゃびょう 日射病"
"にっしゅう 日周 日収"
"にっしょう 日章 日照 日商"
"にっしょうどう 日章堂"
"にっしょく 日蝕 日食"
"にっしん 日心 日新 日神 日進 日清"
"にっすう 日数"
"にっせい 日生 日精"
"にっせいさんぎょう 日製産業"
"にっせき 日石 日赤"
"にっそ 日ソ"
"にった 仁田 新田"
"にったいおうか 日体桜華"
"にったいだい 日体大"
"にったく 日拓"
"にったん 日鍛"
"にっちつ 日窒"
"にっちも 二進も"
"にっちゅう 日中"
"にっちゅうかん 日中韓"
"にっちょく 日直"
"にっつう 日通"
"にってい 日帝 日程"
"にってつ 日鉄"
"にってれ 日テレ"
"にってん 日展"
"にっとー ニットー"
"にっとう 入唐 日塔 日東 日当"
"にっとうぼう 日東紡"
"にっぴょう 日評"
"にっぽう 日豊 日報"
"にっぽじしょ 日葡辞書"
"にっぽり 日暮里"
"にっぽん 日本"
"にっぽんあすべすと 日本アスベスト"
"にっぽんいち 日本一"
"にっぽんかーぼん 日本カーボン"
"にっぽんかい 日本海"
"にっぽんがいし 日本ガイシ"
"にっぽんぐんへいし 日本軍兵士"
"にっぽんけおり 日本毛織"
"にっぽんけみこん 日本ケミコン"
"にっぽんけみふぁ 日本ケミファ"
"にっぽんころむびあ 日本コロムビア"
"にっぽんしん 日本新"
"にっぽんぜおん 日本ゼオン"
"にっぽんとむそん 日本トムソン"
"にっぽんはむ 日本ハム"
"にっぽんひゃくめいとうげ 日本百名峠"
"にっぽんびくたー 日本ビクター"
"にっぽんぺいんと 日本ペイント"
"にっぽんゆにばっく 日本ユニバック"
"につう 二通"
"にづくり 荷造り 荷作り"
"にづくりひ 荷造費"
"にて 二手"
"にてん 二点"
"にてんさんてん 二転三転"
"にとう 二頭 二等 仁藤"
"にとうきん 二頭筋"
"にとうしゃ 二等車"
"にとうしん 二頭身"
"にとうぶんせん 二等分線"
"にとうへい 二等兵"
"にとうへいそう 二等兵曹"
"にとうへんさんかっけい 二等辺三角形"
"にとうりゅう 二刀流"
"にとべ 二藤部"
"にとものがたり 二都物語"
"にとろ ニトロ"
"にど 二度"
"にどうち 二度打ち"
"にどぬり 二度塗"
"にな 蜷"
"にないて 担い手"
"にながわ 蜷川"
"になんせん 日南線"
"ににん 二人"
"ににんしょう 二人称"
"にぬけ ２抜け"
"にぬし 荷主"
"にねん ２年 二年"
"にのあし 二の足"
"にのかまえ 二構え 二構"
"にのつぎ 二の次"
"にのへ 二戸"
"にのまい 二の舞い 二の舞"
"にのまる 二の丸"
"にのみや 二宮"
"には 二派 二波"
"にはい 二敗 二杯"
"にはか 俄"
"にはく 二拍 二泊"
"にはつ 二発"
"にはん 二版 二犯"
"にばい 二倍"
"にばいす 二杯酢"
"にばしゃ 荷馬車"
"にばん 二番"
"にばんせき 二番席"
"にばんせん 二番煎"
"にばんせんじ 二番煎じ"
"にばんて 二番手"
"にひき 二匹"
"にひゃく 二百"
"にひょうめいこう 二票目以降"
"にびいろ 鈍色"
"にふ 二夫 ２符"
"にふだ 荷札"
"にぶ 二部"
"にぶつ 二物"
"にぶん 二分"
"にぶんき 二分木"
"にぶんぎ 二分木"
"にへい 二瓶"
"にべ 仁部"
"にほ 二歩"
"にほう 二方"
"にほうじゅう 日本中"
"にほうせい 二峰性"
"にほん 二本 日本"
"にほんあし 二本足"
"にほんいち 日本一"
"にほんいりゅうみん 日本居留民"
"にほんえんかきょうかい 日本煙火協会"
"にほんえんげきし 日本演劇史"
"にほんかい 日本海"
"にほんかいがたきこう 日本海型気候"
"にほんかがっかい 日本化学会"
"にほんかぶ 日本株"
"にほんがいし 日本ガイシ"
"にほんきいん 日本棋院"
"にほんぎんこうけん 日本銀行券"
"にほんぐん 日本軍"
"にほんこく 日本國"
"にほんごてきかんかく 日本語的感覚"
"にほんさいじょうりく 日本再上陸"
"にほんさん 日本産 日本サン"
"にほんさんば 日本産馬"
"にほんざる 日本猿"
"にほんし 日本史"
"にほんしゃ 日本車"
"にほんしゅ 日本酒"
"にほんしょく 日本食"
"にほんしん 日本新"
"にほんじんはつ 日本人初"
"にほんじんばぬし 日本人馬主"
"にほんせん ‖"
"にほんぜい 日本勢"
"にほんたたき 日本叩き"
"にほんだいら 日本平"
"にほんだて 二本建"
"にほんちゃ 日本茶"
"にほんでんねつがっかい 日本伝熱学会"
"にほんとう 日本刀"
"にほんなみ 日本並"
"にほんねこ 日本猫"
"にほんはつ 日本初"
"にほんはむ 日本ハム"
"にほんば 日本馬"
"にほんばんだい 日本版第"
"にほんひかりがっかい 日本光学会"
"にほんまい 日本米"
"にほんまつ 二本松"
"にほんまる 日本丸"
"にほんみこうかいさく 日本未公開作"
"にほんむかし 日本昔"
"にほんむけ 日本向"
"にほんもの 日本物"
"にほんやっきょくほう 日本薬局方"
"にほんりゅう 日本流"
"にほんりょう 日本領"
"にぼし 煮干"
"にまい ２枚 二枚"
"にまいがい 二枚貝"
"にまいげり 二枚蹴り"
"にまいごし 二枚腰"
"にまいめやく 二枚目役"
"にまめ 煮豆"
"にまんえん 二万円"
"にみや 二宮"
"にみょう 二名"
"にむら 二村"
"にめい 二名"
"にめん 二面"
"にめんたいぐん 二面体群"
"にもうさく 二毛作"
"にもじ 二文字"
"にもつ 荷物"
"にもつとびら 荷物扉"
"にもの 煮物"
"にゃく 蒻 若"
"にやく 二役"
"にゅーじーらんど 新西蘭"
"にゅーす ニュース"
"にゅーず ニューズ"
"にゅーよーく 紐育"
"にゅあんす ニュアンス"
"にゅいんちゅう 入院中"
"にゅう ν 柔 乳 入"
"にゅういん 入院"
"にゅういんひ 入院費"
"にゅううん 乳暈"
"にゅうえい 入営"
"にゅうえき 乳液"
"にゅうえん 入園"
"にゅうえんけん 入園券"
"にゅうか 乳化 入荷"
"にゅうかい 入会"
"にゅうかいひ 入会費"
"にゅうかく 入閣"
"にゅうかわ 丹生川"
"にゅうかん 乳管 入感 入館"
"にゅうかんけん 入館券"
"にゅうがく 入学"
"にゅうがん 乳癌"
"にゅうきゅう 入厩"
"にゅうきょ 入居"
"にゅうきょう 入京 入鋏"
"にゅうきん 入金"
"にゅうきんがく 入金額"
"にゅうぎゅう 乳牛"
"にゅうぎょ 入漁"
"にゅうぎょう 乳業"
"にゅうぎょく 入玉"
"にゅうこ 入呼 入庫"
"にゅうこう 入校 入港 入構 入稿"
"にゅうこく 入国"
"にゅうこくぜい 入国税"
"にゅうこん 入魂"
"にゅうごく 入獄"
"にゅうさつ 入札"
"にゅうさつほうほう 入札方式"
"にゅうさん 乳酸"
"にゅうさんきんいんりょう 乳酸菌飲料"
"にゅうざい 乳剤"
"にゅうざん 入山"
"にゅうし 乳脂 乳歯 入試"
"にゅうしち 入質"
"にゅうしつ 入室"
"にゅうしゃ 入射 入社"
"にゅうしゃかく 入射角"
"にゅうしゃこう 入射光"
"にゅうしゃしきろしゅつけい 入射式露出計"
"にゅうしゃそく 入射束"
"にゅうしゃは 入射波"
"にゅうしゅ 入手"
"にゅうしゅじゅん 入手順"
"にゅうしゅずみ 入手済"
"にゅうしゅっこ 入出庫"
"にゅうしゅっこくじ 入出国時"
"にゅうしゅつ 入出"
"にゅうしゅつりょくぱ 入出力パターン"
"にゅうしゅなん 入手難"
"にゅうしょ 入所"
"にゅうしょう 入省 入賞"
"にゅうしょうじ 乳小児"
"にゅうしょく 入植"
"にゅうしょつりょく 入出力"
"にゅうしん 入心 入信"
"にゅうじ 乳児"
"にゅうじゅく 入塾"
"にゅうじょう 入城 乳状 入場"
"にゅうじょうきゃくぞうか 入場客増加"
"にゅうじょうぐち 入場口"
"にゅうじょうけん 入場券"
"にゅうじょうけんきゃく 入場券客"
"にゅうすい 入水"
"にゅうせいひん 乳製品"
"にゅうせき 入籍"
"にゅうせん 乳腺 入船 入線 入選"
"にゅうせんけん 入船券"
"にゅうぜん 入善"
"にゅうそう 入槽"
"にゅうたい 入退 入体 入隊"
"にゅうたいしゅつ 入退出"
"にゅうだん 入団"
"にゅうちゃく 入着"
"にゅうちょう 入超"
"にゅうてい 入廷"
"にゅうてん 入店"
"にゅうでん 入電"
"にゅうとう 乳糖 入党 入刀 乳頭"
"にゅうとうきん 乳頭筋"
"にゅうどう 入道"
"にゅうどうぐも 入道雲"
"にゅうどうざき 入道崎"
"にゅうねん 入念"
"にゅうの 入野"
"にゅうはくしょく 乳白色"
"にゅうばい 入梅"
"にゅうばち 乳鉢"
"にゅうぶ 入部"
"にゅうほうほう 入方法"
"にゅうぼう 乳房 乳棒"
"にゅうまく 入幕"
"にゅうめん 入麺"
"にゅうもん 入門"
"にゅうもんてい 入門艇"
"にゅうよう 入用"
"にゅうようじ 乳幼児"
"にゅうよく 入欲 入浴"
"にゅうよくけん 入浴券"
"にゅうらい 入来"
"にゅうりょう 入寮"
"にゅうりょうひ 入寮費"
"にゅうりょく 入力"
"にゅうりょくぱたあん 入力パターン"
"にゅうりょくぱらめーた 入力パラメータ"
"にゅうりょくりきりつ 入力力率"
"にゅうりょくわく 入力枠"
"にゅうりん 乳輪"
"にゅうわ 柔和"
"にゅりょくしんごう 入力信号"
"にょ 汝 如 女"
"にょい 如意"
"にょう 獰 繞 尿"
"にょうい 尿意"
"にょうけっせき 尿結石"
"にょうけんさ 尿検査"
"にょうさいかん 尿細管"
"にょうそ 尿素"
"にょうどう 尿道"
"にょうどうえん 尿道炎"
"にょうぼう 女房"
"にょうぼうやく 女房役"
"にょうまく 尿膜"
"にょうろ 尿路"
"にょかん 女官"
"にょじつ 如実"
"にょたい 女体"
"にょにん 女人"
"にょほう 如法"
"にょらい 如来"
"にょろ 〜"
"によう 二様 二葉"
"によど 仁淀"
"にら 韭 薤 韮"
"にらさき 韮崎"
"にらさわ 韮沢"
"にらづか 韮塚"
"にらみ 睨み"
"にらみあい 睨み合い"
"にらめっこ 睨めっこ"
"にらやま 韮山"
"にらんせいそうせいじ 二卵性双生児"
"にりつ 二律"
"にりゅう 二流"
"にりゅうか 二硫化"
"にりん ２輪 二輪"
"にりんか 二輪花"
"にりんしゃ 二輪車"
"にるい 二類 二塁"
"にるいしゅ 二塁手"
"にるいだ 二塁打"
"にれ 楡"
"にれい 楡井"
"にれつ 二列"
"にれんぱつ 二連発"
"にろう 二浪"
"にわ 二話 二羽 丹羽 庭"
"にわか 仁輪加 俄か 俄"
"にわかあめ 瀑 にわか雨"
"にわき 庭木"
"にわきょういく 庭教育"
"にわさか 庭坂"
"にわさき 庭先"
"にわし 庭師"
"にわせ 庭瀬"
"にわた 庭田"
"にわたし 荷渡"
"にわとり 鷄 ニワトリ 鶏"
"にわの 庭野"
"にわり 二割"
"にん 姙 刄 儿 仁 刃 忍 妊 認 任 人"
"にんい ∀ 任意"
"にんか 認可"
"にんかん 任官"
"にんき 任期 人気"
"にんきうすどうし 人気薄同士"
"にんきうま 人気馬"
"にんきじゅん 人気順"
"にんきもの 人気者"
"にんきょう 任侠 仁侠"
"にんぎょ 人魚"
"にんぎょう 人形"
"にんぎょうげき 人形劇"
"にんぎょでん 人魚伝"
"にんぎょひめ 人魚姫"
"にんく 忍苦"
"にんぐみ 人組"
"にんげつ 人月"
"にんげん 人間"
"にんげんぎらい 人間嫌い"
"にんげんぞう 人間像"
"にんげんなみ 人間並"
"にんげんみ 人間味"
"にんげんわざ 人間技"
"にんさんばけしち 人三化七"
"にんしき 認識"
"にんしゅう 人衆"
"にんしょう 認照 人称 認証"
"にんしん 妊娠"
"にんじゃ 忍者"
"にんじゃでら 忍者寺"
"にんじゃもの 忍者物"
"にんじゃやく 忍者役"
"にんじゅう 忍従"
"にんじゅつ 忍術"
"にんじょう 刃傷 人情"
"にんじょうばなし 人情噺 人情話"
"にんじょうみ 人情味"
"にんじん 忍人 人蔘 人参"
"にんずう 人数"
"にんそう 人相"
"にんそく 人足"
"にんたい 忍耐"
"にんち 任地 認知"
"にんちかがくせみなあ 認知科学セミナー"
"にんてい 認定"
"にんていい 認定医"
"にんてん 人天"
"にんてんどう 仁天堂 任天堂"
"にんでん 人天"
"にんとく 仁徳"
"にんどう 忍道"
"にんなじ 仁和寺"
"にんにく 葫 大蒜"
"にんにち 人日"
"にんねん 人年"
"にんぴ 認否"
"にんぴにん 人非人"
"にんぴょう 任憑"
"にんぴん 人品"
"にんぶん 人分"
"にんぷ 人夫 妊婦"
"にんぽう 忍法"
"にんぽうちょう 忍法帳 忍法帖"
"にんまえ 人前"
"にんむ 任務"
"にんめ 人目"
"にんめい 任命"
"にんめん 任免"
"にんよう 認容 任用"
"ぬ 濡 怒 奴"
"ぬいめ 縫目"
"ぬいもの 縫物"
"ぬえ 鵺"
"ぬか 糠"
"ぬかた 額田"
"ぬかばたらき 糠働き"
"ぬかびら 糠平"
"ぬかびらこ 糠平湖"
"ぬき 抜き 貫"
"ぬきい 貫井"
"ぬきさし 抜き差し"
"ぬきだし 抜き出し"
"ぬきに 抜き荷"
"ぬきみ 抜き身"
"ぬきやま 抜山"
"ぬぎき 脱着"
"ぬくい 貫井"
"ぬくしな 温品"
"ぬけ 抜け 抜 脱"
"ぬけあな 抜穴 抜け穴"
"ぬけがけ 抜駆 抜け駆け"
"ぬけがら 蛻 抜殻 脱殻"
"ぬけに 抜荷 抜け荷"
"ぬけにん 抜忍"
"ぬけみち 抜道 抜け道"
"ぬけめ 抜目"
"ぬさ 帛"
"ぬし 主"
"ぬすっと 盗人"
"ぬすびと 盗人"
"ぬすみ 窃 盗み"
"ぬすみぎき 盗み聞き"
"ぬすみぐい 盗み食い"
"ぬすみみ 盗み見"
"ぬすむ 窃"
"ぬた 垈"
"ぬの 布"
"ぬのいち 布市"
"ぬのかわ 布川"
"ぬのじ 布地"
"ぬのせい 布製"
"ぬのはし 布橋"
"ぬのはらえき 布原駅"
"ぬのびき 布引"
"ぬのむら 布村"
"ぬのめ 布目"
"ぬま 沼"
"ぬまうえ 沼上"
"ぬまお 沼尾"
"ぬまおか 沼岡"
"ぬまかみ 沼上"
"ぬまがみ 沼上"
"ぬまくない 沼宮内"
"ぬまくま 沼隈"
"ぬまくら 沼倉"
"ぬまぐち 沼口"
"ぬまざき 沼崎"
"ぬまず 沼津"
"ぬまずこう 沼津港"
"ぬまずひがし 沼津東"
"ぬまた 沼田"
"ぬまち 沼地"
"ぬまづ 沼津"
"ぬまづこう 沼津港"
"ぬまべ 沼部"
"ぬまやま 沼山"
"ぬめ 絖"
"ぬり 塗"
"ぬりえ 塗り絵"
"ぬりかべ 塗り壁 塗壁"
"ぬりぐすり 塗薬"
"ぬりつけ 塗付"
"ぬるま 微温"
"ぬるまゆ ぬるま湯"
"ぬれぎぬ 濡衣 濡れ衣"
"ぬれごと 濡事 濡れ事"
"ぬれば 濡場 濡れ場"
"ぬればいろ 濡羽色"
"ね 袮 涅 寢 嶺 祢 禰 子 音 寝 値 根"
"ねーちゃん ネーちゃん"
"ねーみんぐ ネーミング"
"ねーむ ネーム"
"ねあがり 根上 値上がり"
"ねあがりまつ 根上り松"
"ねあげ 値上 値上げ"
"ねあせ 寝汗"
"ねい 聹 濘 檸 侫 佞 嚀 祢 寧 禰"
"ねいき 寝息"
"ねいじつ 寧日"
"ねいす 寝椅子"
"ねいひつ 寧謐"
"ねいろ 音色"
"ねうち 値打ち 値打"
"ねえ 姉"
"ねえさま 姉様"
"ねえさん 姉さん"
"ねえちゃん 姉ちゃん"
"ねえよ 寧代"
"ねお 根尾"
"ねおき 寝起 寝起き"
"ねおん ネオン"
"ねが 願"
"ねがい 願 願い"
"ねがいごと 願い事"
"ねがいで 願い出"
"ねがえり 寝返り"
"ねがお 寝顔"
"ねがさ 値がさ"
"ねがみ 根上"
"ねぎ 葱"
"ねぎあか ネギ亜科"
"ねぎか 葱科"
"ねぎし 根岸"
"ねぎしけいばじょうあと 根岸競馬場跡"
"ねぎとろどん ねぎとろ丼"
"ねぎり 値切り 値切"
"ねくたい ネクタイ"
"ねくび 寝首"
"ねくら 根暗"
"ねぐら 塒"
"ねぐりじぇ ネグリジェ"
"ねこ 猫"
"ねこあし 猫脚"
"ねこか 猫科"
"ねこかん 猫缶"
"ねこかんけい 猫関係"
"ねこがた 猫型"
"ねこぐるま 猫車"
"ねこじまん 猫自慢"
"ねこぜ 猫背"
"ねこた 猫田"
"ねこて 猫手"
"ねこは 猫派"
"ねこべ 猫部"
"ねこま 猫間 猫魔"
"ねこむすめ 猫娘"
"ねこめいし 猫目石"
"ねごこち 寝心地"
"ねごと 寝言"
"ねごろ 根来"
"ねさがり 値下がり"
"ねさげ 値下げ 値下"
"ねざかな 根魚"
"ねざき 根崎"
"ねざし 根差し"
"ねざめ 寝醒め"
"ねしょうがつ 寝正月"
"ねしょんべん 寝小便"
"ねじ 捩子 螺子 捻子 螺"
"ねじこみ 捩じ込み"
"ねじめ 根占"
"ねじりはちまき 捩り鉢巻き 捩じり鉢巻き"
"ねじろ 根城"
"ねず 禰津 根津"
"ねずみ 鼡 鼠"
"ねずみいろ 鼠色"
"ねずみおとこ 鼠男"
"ねずみたち 鼠達"
"ねぞう 寝相 寝惚"
"ねた ネタ"
"ねだめ 寝溜め"
"ねだやし 根絶やし"
"ねだん 値段"
"ねっから 根っから"
"ねっき 熱気"
"ねっききゅう 熱気球"
"ねっきゅう 熱球"
"ねっきょう 熱狂"
"ねっく ネック"
"ねっけつ 熱血"
"ねっけつかん 熱血漢"
"ねっけん 熱圏"
"ねっこ 根っこ"
"ねっしゃ 熱写"
"ねっしゃびょう 熱射病"
"ねっしゅ 熱酒"
"ねっしょう 熱唱"
"ねっしん 熱心"
"ねっすい 熱水"
"ねっせん 熱線 熱戦"
"ねったい 熱帯"
"ねったいぎょ 熱帯魚"
"ねったいさん 熱帯産"
"ねったいや 熱帯夜"
"ねったいやむけ 熱帯夜向"
"ねったいりん 熱帯林"
"ねっちゅう 熱中"
"ねっと ネット"
"ねっとう 熱闘 熱湯"
"ねっぱつ 熱発"
"ねっぷう 熱風"
"ねつ 捏 熱"
"ねつあい 熱愛"
"ねつい 熱意"
"ねつうんどう 熱運動"
"ねつえん 熱演"
"ねつえんじゅんかん 熱塩循環"
"ねつか 熱価"
"ねつかくはんのうだん 熱核反応弾"
"ねつかんわ 熱緩和"
"ねつき 寝付き"
"ねつきょうきゅう 熱供給"
"ねつけいれん 熱痙攣"
"ねつけん 熱研"
"ねつげん 熱源"
"ねつこうかん 熱交換"
"ねつこうりつ 熱効率"
"ねつしょり 熱処理"
"ねつしょりずみ 熱処理済"
"ねつじょう 熱情"
"ねつせっしょく 熱接触"
"ねつそくど 熱速度"
"ねつそんしつ 熱損失"
"ねつぞう 捏造"
"ねつたいさく 熱対策"
"ねつちゅうせいし 熱中性子"
"ねつちゅうせいしそく 熱中性子束"
"ねつていこう 熱抵抗"
"ねつてき 熱的"
"ねつてんしゃ 熱転写"
"ねつでんたつりつ 熱伝達率"
"ねつでんつい 熱電対"
"ねつでんどう 熱伝導"
"ねつはっさん 熱発散"
"ねつはっせい 熱発生"
"ねつびょう 熱病"
"ねつふか 熱負荷"
"ねつふくしゃ 熱輻射"
"ねつぶつりがく 熱物理学"
"ねつへいこう 熱平衡"
"ねつへんか 熱変化"
"ねつへんせい 熱変性"
"ねつべん 熱弁"
"ねつぼう 熱望"
"ねつぼうそう 熱暴走"
"ねつゆそう 熱輸送"
"ねつようりょう 熱容量"
"ねつよく 熱浴"
"ねつりき 熱力"
"ねつりゅう 熱流"
"ねつりょう 熱量"
"ねつるい 熱涙"
"ねつれつ 熱烈"
"ねづ 禰津 根津"
"ねづか 根塚"
"ねづけ 値付け"
"ねとまり 寝泊まり"
"ねどこ 寝床"
"ねなしぐさ 根無草"
"ねなりがき 根成柿"
"ねはば 値幅"
"ねはん 涅槃"
"ねば 根羽"
"ねびえ 寝冷え"
"ねびき 値引き"
"ねびきか 値引可"
"ねびきすう 値引数"
"ねびきりつ 値引率"
"ねふだ 値札"
"ねぶかわ 根府川"
"ねぶくろ 寝袋"
"ねぶそく 寝不足"
"ねぼう 寝坊"
"ねまき 寝間着"
"ねまわし 根回し"
"ねみだれ 寝乱れ"
"ねみみ 寝耳"
"ねむけ 眠気"
"ねむのき 棔"
"ねむりきょうしろう 眠狂四郎"
"ねむりひめ 眠り姫"
"ねむろ 根室"
"ねもと 根元 根本"
"ねものがたり 寝物語"
"ねや 閨"
"ねやがわ 寝屋川"
"ねらい 狙い"
"ねらいうち 狙い打ち 狙い撃ち"
"ねり 練り 練"
"ねりこう 練香"
"ねりべい 練塀"
"ねりま 練馬"
"ねるちんすく 尼布楚"
"ねわざ 寝技"
"ねん 然 棯 拈 稔 捻 撚 燃 粘 念 年"
"ねんあけ 年明"
"ねんいじょう 年以上"
"ねんいちど 年一度"
"ねんいっかい 年一回"
"ねんいり 念入 念入り"
"ねんえき 粘液"
"ねんかい 年会"
"ねんかいひ 年会費"
"ねんかん 年鑑 年刊 年間"
"ねんかんそうこうにゅうがく 年間総購入額"
"ねんが 年賀"
"ねんがく 年額"
"ねんがっぴ 年月日"
"ねんがらねんじゅう 年がら年中"
"ねんがん 念願"
"ねんき 年季 年忌 年期"
"ねんきぼうこう 年期奉公"
"ねんきゅう 年休"
"ねんきゅうぼ 年休簿"
"ねんきん 粘菌 年金"
"ねんくれ 年暮"
"ねんぐ 年貢"
"ねんけいかく 年計画"
"ねんげつ 年月"
"ねんげん 年限"
"ねんこう 年功"
"ねんご 年後"
"ねんごう 年号"
"ねんごろ 懇ろ 年頃"
"ねんさ 年差"
"ねんさん 年産"
"ねんざ 捻挫"
"ねんし 撚糸 年始"
"ねんしき 年式"
"ねんした 年下"
"ねんしゃ 念写"
"ねんしゅう 年収"
"ねんしゅうにゅう 年収入"
"ねんしゅつ 捻出"
"ねんしょ 念書"
"ねんしょう 年商 燃焼 年少"
"ねんしょうとう 燃焼筒"
"ねんじ 年時 年次"
"ねんじゅう 年中"
"ねんすう 年数"
"ねんせい 粘性 年制 年生"
"ねんそつ 年卒"
"ねんたんい 年単位"
"ねんだい 年代"
"ねんだいき 年代記"
"ねんだいじゅん 年代順"
"ねんだいもの 年代物"
"ねんちゃく 粘着"
"ねんちゃくざい 粘着材"
"ねんちゅう 年中"
"ねんちょう 粘稠 年長"
"ねんてん 捻転"
"ねんとう 年頭 念頭"
"ねんど 粘土 粘度 年度"
"ねんどう 念動"
"ねんどしつ 粘土質"
"ねんどまつ 年度末"
"ねんない 年内"
"ねんねん 年年 年々"
"ねんねんかん 千年間"
"ねんねんさいさい 年年歳歳"
"ねんのため 念の為 為念 念のため"
"ねんはん 年半"
"ねんばらい 年払い"
"ねんばん 年版"
"ねんぱ 念波"
"ねんぱい 年輩 年配"
"ねんぴ 然費 燃費"
"ねんぴけい 燃費計"
"ねんぴょう 年表"
"ねんぶつ 念仏"
"ねんぶつじ 念仏寺"
"ねんぶん 年分"
"ねんぷ 年賦 年譜"
"ねんべつ 年別"
"ねんぼうけいやくせい 年棒契約制"
"ねんぽう 念法 年俸 年報"
"ねんまえ 年前"
"ねんまく 粘膜"
"ねんまつ 年末"
"ねんめ 年目"
"ねんらい 年来"
"ねんり 年利"
"ねんりき 念力"
"ねんりつ 年率"
"ねんりょう 燃量 燃料"
"ねんりょうけい 燃料計"
"ねんりょうひ 燃料費"
"ねんりん 年輪"
"ねんれい 年令 年齢"
"の − 濃 廼 埜 乃 之 野"
"のーと 帳面 ノート"
"のいけ 野池"
"のいず ノイズ"
"のいち 野市"
"のいろーぜ ノイローゼ"
"のう 獰 能生 衲 腦 碯 瑙 曩 惱 嚢 皇 悩 濃 王 膿 納 農 脳 能"
"のういがい 脳以外"
"のういっけつ 脳溢血"
"のうえん 濃艶 脳炎 農園"
"のうおんか 濃音化"
"のうか 農家"
"のうかい 納会"
"のうかいだい 能開大"
"のうかがく 脳科学"
"のうかく 能格"
"のうかすいたい 脳下垂体"
"のうかん 脳幹 納竿 納棺 能管"
"のうかんき 農閑期"
"のうかんけい 脳関係"
"のうがき 能書き"
"のうがく 農学"
"のうがくどう 能楽堂"
"のうがや 能ヶ谷"
"のうき 納城 農機 納期"
"のうきぐ 農機具"
"のうきのう 脳機能"
"のうきょう 納経 農協"
"のうきん 納金"
"のうぎょう 農業"
"のうぐ 農具"
"のうけつりゅう 脳血流"
"のうけん 脳研"
"のうげいかがく 農芸化学"
"のうげか 脳外科"
"のうこう 農耕 農工 濃厚"
"のうこうそく 脳硬塞"
"のうこうみん 農耕民"
"のうこつ 納骨"
"のうこん 濃紺"
"のうさい 納采"
"のうさいぼう 脳細胞"
"のうさぎょう 農作業"
"のうさく 農作"
"のうさくもつ 農作物"
"のうさつ 納札 悩殺"
"のうさつじょ 納札所"
"のうさん 農産"
"のうざい 能材"
"のうざしょう 脳挫傷"
"のうし 直衣 脳死"
"のうしゃ 納車"
"のうしゃかい 納射会"
"のうしゅく 濃縮"
"のうしゅっけつ 脳出血"
"のうしょ 能書"
"のうしょう 脳漿 農相"
"のうしょうがい 脳障害"
"のうしょくけい 濃色系"
"のうしんけい 脳神経"
"のうしんとう 脳震盪"
"のうじ 農事"
"のうじず 脳磁図"
"のうじょう 嚢状 農場"
"のうじょうさん 農場産"
"のうじょうよう 嚢状葉"
"のうすいしょう 農水省"
"のうずい 脳髄"
"のうせい 農政 能性"
"のうぜい 納税"
"のうぜんかずら 凌霄蔓"
"のうそうぶん 放送分"
"のうそっちゅう 脳卒中"
"のうそん 農村"
"のうそんしょう 脳損傷"
"のうたん 濃淡"
"のうだ 納田"
"のうだい 農大"
"のうち 野内 農地 納地"
"のうてい 脳底"
"のうてん 脳天"
"のうてんき 腦天氣 脳天気"
"のうど 農奴 濃度"
"のうどう 農道 能動"
"のうどうたい 能動態"
"のうない 脳内"
"のうにゅう 納入"
"のうにゅうさきじゅうしょ 納入先住所"
"のうにん 納人"
"のうは 脳波"
"のうはう ノウハウ"
"のうはんき 農繁期"
"のうひょう 脳表"
"のうひん 納品"
"のうひんけつ 脳貧血"
"のうふ 農婦 農夫 納付"
"のうぶたい 能舞台"
"のうべん 能弁"
"のうほう 膿疱 農法 嚢胞"
"のうほん 納本"
"のうまく 脳膜"
"のうみ 能美"
"のうみそ 脳味噌"
"のうみつ 濃密"
"のうみん 農民"
"のうみんで 農民出"
"のうむ 濃霧"
"のうめん 能面"
"のうやく 農薬"
"のうやくくうさん 農薬空散"
"のうやくしゃ 能役者"
"のうやま 納山"
"のうよう 嚢瘍 膿瘍"
"のうらん 悩乱"
"のうり 能吏 脳裏"
"のうりつ 能率"
"のうりゅうさん 濃硫酸"
"のうりょう 脳梁 納涼"
"のうりょうさい 納涼祭"
"のうりょく 濃緑 能力"
"のうりょくきゅう 能力給"
"のうりん 農林"
"のうりんしょう 農林省"
"のうりんすいさんぎょう 農林水産業"
"のうりんすいさんしょう 農林水産省"
"のえ 野家"
"のえる Ｎｏёｌ"
"のおがた 直方"
"のかみ 野上"
"のがき 野垣"
"のがた 野方"
"のがみ 埜上 野上"
"のがわ 野河 野川"
"のき 軒"
"のきさき 軒先"
"のきした 軒下"
"のきなみ 軒並"
"のぎ 野義 芒 乃木 野木 禾"
"のぎく 野菊"
"のぎさか 乃木坂"
"のぎざか 乃木坂"
"のぎし 野岸"
"のぎわようこ 野際陽子"
"のぐち 野口"
"のげ 野毛"
"のこ 鋸"
"のこぎり 鋸"
"のこした 残した"
"のこのしま 能古島"
"のこり 残り"
"のさか 野栄 野坂"
"のさっぷ 納沙布"
"のざき 野咲 野崎"
"のざききた 野崎北"
"のざと 野里"
"のざらし 野晒し"
"のざる 野猿"
"のざわ 野澤 野沢"
"のざわな 野沢菜"
"のし 熨斗 熨"
"のした 野下"
"のしぶくろ 熨斗袋"
"のしろ 能城 野城 能代"
"のしろこう 能代工"
"のじ 野路"
"のじま 野嶋 野島"
"のじゅく 野宿"
"のじり 野尻"
"のじりこ 野尻湖"
"のじん 野人"
"のずえ 野末"
"のせ 能勢 能瀬 野瀬"
"のせがわ 野迫川"
"のせぐち 能勢口"
"のぞえ 野副 野添"
"のぞき 覗"
"のぞみ 稀 希 望"
"のぞむ 望"
"のたれじに 野垂れ死に"
"のだ 野田"
"のだせんこうじせん 野田専光寺線"
"のだはま 野田浜"
"のち 後"
"のちのち 後々"
"のちほど 後程"
"のっとり 乗っ取り"
"のっぽろ 野幌"
"のつ 野津"
"のつはる 野津原"
"のづき 野月"
"のづみ 野積み"
"のてん 野天"
"ので 野出"
"のでら 野寺"
"のと 能都 能登"
"のとかわ 能登川"
"のとじま 能登島"
"のとろ 能取"
"のど 咽 喉"
"のどか 長閑"
"のどぼとけ 喉仏"
"のどもと 喉元"
"のなか 野仲 野中"
"のなみ 野並"
"のの 野々"
"ののか 野々香"
"ののはら 野々原"
"のはら 野原"
"のばし 伸ばし"
"のばす 〜〜〜〜〜〜〜〜"
"のばなし 野放図 野放し"
"のひら 野平"
"のび 伸 野火"
"のびと 野人"
"のびのび 伸び伸び"
"のびりつ 伸率 伸び率"
"のびる 野蒜"
"のふせ 野伏"
"のぶ 允 惟 亘 展 順 修 暢 延 宣 伸 信"
"のぶあき 悦旦 延晃 宣明 伸晃 信明 信昭 伸明"
"のぶえ 延枝 伸枝 信恵"
"のぶお 暢夫 陳雄 信生 信朗 宣夫 信雄 伸夫 伸生 信男 信夫"
"のぶおき 暢興"
"のぶかつ 信雄 信勝 信克"
"のぶき 伸樹 信木 信樹"
"のぶくに 信邦"
"のぶこ 展子 延子 暢子 伸子 敦子 信子"
"のぶし 野武士"
"のぶじ 伸治 伸自"
"のぶた 信太"
"のぶたか 信隆 信高 信孝"
"のぶただ 信忠"
"のぶなが 信長"
"のぶながげんしょう 伸長現象"
"のぶはる 伸治"
"のぶひこ 宣彦 暢彦 信彦 伸彦 延彦"
"のぶひさ 暢久 順久 信久 延久"
"のぶひで 宣秀"
"のぶひと 宣仁"
"のぶひろ 伸広 信弘 伸廣 展弘 伸裕 宣弘 信博 伸啓 宣博 信宏 信洋 伸弘 信寛 伸浩"
"のぶまさ 宣政"
"のぶみつ 信光"
"のぶや 信也 暢也 誠也"
"のぶやす 宣保 信康"
"のぶゆき 伸介 宣之 伸幸 展之 暢之 伸之 信行 伸行 信幸 信之"
"のぶよし 信義"
"のぶろう 信郎 伸郎 宣郎"
"のへじ 野辺地"
"のべ 延べ 野辺"
"のべおか 延岡"
"のべな 野辺名"
"のべにんこうすう 延人工数"
"のべにんずう 延人数"
"のほう 野放 野方"
"のほり 野堀"
"のほろはつ 野幌発"
"のぼり 幟 登 上り"
"のぼりざか 上り坂 登り坂"
"のぼりと 登戸"
"のぼりべつ 登別"
"のぼる 登 昇"
"のま 々 野間"
"のまおい 野馬追"
"のまち 野町"
"のみ 鑿 乃美 能美 蚤"
"のみかい 呑み会 飲み会"
"のみくい 呑み喰い 飲み喰い"
"のみしろ 飲み代 呑み代"
"のみだい 飲み代"
"のみねーと ノミネート"
"のみほうだい 飲み放題"
"のみみず 飲み水"
"のみもの 飲物 飲み物"
"のみや 呑屋 飮み屋 野宮 飲み屋"
"のみやま 野見山"
"のむぎとうげ 野麦峠"
"のむら 乃村 野村"
"のも 野茂"
"のもざき 野母崎"
"のもと 野本"
"のやま 野山"
"のら 野良"
"のらいぬ 野良犬"
"のらねこ 野良猫"
"のり 弼 朔 規範 乗り 悳 伯 哲 就 宜 雅 糊 矩 海苔 ノリ 規 範 憲 徳 典 則 法 紀"
"のりあい 乗り合い 乗合"
"のりあき 徳晶 規昭 紀昭 紀明 範明 典昭 法明 憲明 憲章 則明 倫明 典明"
"のりいれ 乗入"
"のりえ 礼江 法枝"
"のりお 憲雄 展男 典生 昇男 憲生 憲夫 則郎 則夫 紀夫 紀男 範夫 徳雄 典夫"
"のりおり 乗り降り"
"のりかえ 乗換"
"のりかえきゃく 乗換客"
"のりかえぐち 乗換口"
"のりかず 則和 紀和"
"のりき 乗り気"
"のりくみいん 乗組員"
"のりくみいんすがた 乗組員姿"
"のりくら 乗鞍"
"のりこ 教子 賀子 規子 能理子 訓子 乃梨子 徳子 祈子 のり子 則子 倫子 法子 典子 範子 紀子"
"のりこし 乗越 乗り越し"
"のりごこち 乗心地"
"のりざね 徳実"
"のりしげ 則茂"
"のりたか 典孝 則貴"
"のりたけ 憲武 則竹"
"のりちか 乃親"
"のりつぎ 乗継 乗り継ぎ"
"のりづき 法月"
"のりづけ 糊付 糊付け"
"のりと 祝詞"
"のりのみや 紀宮"
"のりば 乗場 乗り場"
"のりひこ 規彦 憲彦 紀彦"
"のりひさ 哲久 典尚 典久 範久 則久"
"のりひと 徳仁"
"のりひろ 則浩 紀大 憲広 典大"
"のりふみ 憲文"
"のりほ 範穂"
"のりまき 則巻"
"のりまさ 紀政 典正"
"のりまつ 乗松"
"のりむね 倫宗"
"のりもと 紀元"
"のりもの 乗物 乗り物"
"のりものけん 乗物券"
"のりや 紀哉 法也"
"のりやす 典康"
"のりゆき 矩之 紀幸 敬之 徳幸 典行 哲之 宜之 徳行 規之 紀之 則之 憲行 則行 規行 範幸"
"のりよ 記代"
"のりよし 徳吉 徳芳 法良 紀吉"
"のりろう 憲郎"
"のるうぇー 諾威"
"のるむ ノルム"
"のれん 暖簾"
"のろ 野呂"
"のろい 呪い"
"のろけ 惚気"
"のろし 狼煙 燧 烽火 烽"
"のわき 野分"
"のんき 暖気 暢気 呑気"
"は 齒 陂 葩 菠 笆 碆 玻 霸 怕 垪 坡 叭 刄 跛 爬 簸 芭 張 頗 巴 播 刃 把 杷 羽 覇 端 琶 波 破 派 歯 葉"
"はーぐ 海牙"
"はーと ハート"
"はーど ハード"
"はーぶ ハーブ"
"はあく 把握"
"はあん 破闇"
"はい 稗 這 埴 睥 霈 胚 碚 癈 琲 珮 湃 沛 旆 擺 拜 憊 悖 廢 孛 坏 佩 裴 徘 灰 俳 盃 廃 拝 排 牌 肺 輩 背 敗 杯 配"
"はいあん 廃案"
"はいい 廃位"
"はいいけつごう 配位結合"
"はいいろ 灰色"
"はいいろぐま 灰色熊"
"はいいん 配員 敗因"
"はいうぇい ハイウェイ"
"はいえい 背泳"
"はいえき 廃駅 廃液"
"はいえん 排煙 肺炎"
"はいえんか 排煙家"
"はいえんど ハイエンド"
"はいおく 廃屋"
"はいか 排架 拝火 配下"
"はいかい 徘諧 誹諧 俳諧 徘徊"
"はいかつりょう 肺活量"
"はいかん 拝観 配管 廃刊"
"はいかんきゃく 拝観客"
"はいが 胚芽"
"はいがいうんどう 排外運動"
"はいがた 灰型"
"はいがん 拝顔 肺癌 肺ガン"
"はいがんし 肺癌死"
"はいき 排気 廃棄"
"はいきあつ 排気圧"
"はいきかん 排気管"
"はいききじゅん 廃機基準"
"はいきこう 排気口"
"はいきねつ 排気熱"
"はいきのう 肺機能"
"はいきゃく 廃却"
"はいきゅう 配球 廃休 排球 配給"
"はいきゅうまい 配給米"
"はいきゅうもう 配給網"
"はいきょ 廃墟 廃虚"
"はいきょう 背教 俳協"
"はいきょく 廃局"
"はいきん 背筋"
"はいきんぐ ハイキング"
"はいぎょう 廃業"
"はいく 俳句"
"はいぐうし 配偶子"
"はいぐうしゃ 配偶者"
"はいけい 拝啓 背景"
"はいけいこう 背景光"
"はいけいせい 胚形成"
"はいけっかく 肺結核"
"はいけつしょう 敗血症"
"はいけん 拝見"
"はいげき 排撃"
"はいこう 配光 廃坑 配向 廃鉱 廃校"
"はいこうじょう 廃工場"
"はいご 廃語 背後"
"はいごう 配合"
"はいごれい 背後霊"
"はいさつ 廃札 拝察"
"はいざい 配剤 廃材"
"はいざら 灰皿"
"はいざん 敗残"
"はいし 廃止"
"はいしあん 廃止案"
"はいしつ 癈疾"
"はいしゃ 敗者 配車 歯医者 廃車"
"はいしゃく 拝借"
"はいしゃたい 廃車体"
"はいしゅ 胚珠"
"はいしゅつ 輩出 排出"
"はいしょう 廃娼"
"はいしょうき 排障器"
"はいしょく 憊色 敗色 配色"
"はいしん 配信 背信"
"はいじ 拝辞"
"はいじく 胚軸"
"はいじま 拝島"
"はいじゅ 拝受"
"はいじゅくれい 廃塾令"
"はいじょ 排除"
"はいじん 癈人 俳人 廃人"
"はいすい 背水 配水 排水"
"はいすいかん 配水管 排水管"
"はいすいこう 排水溝 排水口"
"はいすいしゅ 肺水腫"
"はいすいのじん 背水乃陣"
"はいせい 廃星"
"はいせき 排斥"
"はいせつ 排泄"
"はいせん 配船 廃線 廃船 敗戦 配線"
"はいせんあと 廃線跡"
"はいせんしき 廃線敷"
"はいぜつ 廃絶"
"はいぜん 沛然 配膳"
"はいそ 敗訴"
"はいそう 敗走 配送"
"はいそく 背側 背足"
"はいそん 廃村"
"はいぞう 肺臓"
"はいぞく 配属"
"はいた 歯痛 排他"
"はいたい 胚胎 敗退"
"はいたつ 配達"
"はいだ 灰田"
"はいだん 俳壇"
"はいち 配置"
"はいちがえ 配置替え 配置換"
"はいちゃく 敗着"
"はいちゅうりつ 排中律"
"はいちょう 拝聴"
"はいつ ハイツ"
"はいていらおゆえ 海底撈月"
"はいてく ハイテク"
"はいてん 配転 配点"
"はいてんねがい 配転願"
"はいでん 拝殿 配電"
"はいとう 配当"
"はいとうれい 廃刀令"
"はいとく 背徳"
"はいどう 廃道"
"はいどく 拝読"
"はいにち 排日"
"はいにゅう 胚乳"
"はいにょうこんなん 排尿困難"
"はいにん 背任"
"はいにんざい 背任罪"
"はいねつ 廃熱 排熱"
"はいのう 胚嚢 背嚢"
"はいはん 背反 排反"
"はいはんちけん 廃藩置県"
"はいばら 生原 榛原"
"はいばん 廃番 廃版 廃盤"
"はいばんほう 胚盤胞"
"はいばんろうぜき 杯盤狼籍"
"はいぱい 配牌"
"はいひん 廢品 廃品"
"はいび 拝眉 配備"
"はいびょう 肺病"
"はいびん 配便"
"はいふ 肺腑 配付 配布"
"はいふき 灰吹"
"はいふく 拝復"
"はいふん ‐ ハイフン ―"
"はいぶ 背部"
"はいぶつ 廃物"
"はいぶん 拝聞 配分"
"はいぶんがく 配分額"
"はいべん 排便"
"はいほう 肺袋 肺胞"
"はいほん 配本"
"はいぼく 敗北"
"はいむ ハイム"
"はいめ 敗目"
"はいめい 拝命"
"はいめん 背面"
"はいもん 肺門"
"はいや 肺野"
"はいやく 配役"
"はいゆ 廃油"
"はいゆう 俳優"
"はいゆうざ 俳優座"
"はいよう 胚葉 廃用"
"はいらん 排卵"
"はいり 背理"
"はいりくち 入り口"
"はいりょ 配慮"
"はいりょう 拝領"
"はいれい 拝礼"
"はいれつ 排列 配列"
"はいれつがたへんかん 配列型変換"
"はいれつせいやく 配置制約"
"はいれべる ハイレベル"
"はいろ 廃炉"
"はいろーざ ハイローザ"
"はうす ハウス"
"はえ 南風 蠅 蝿"
"はえとり 蝿取り"
"はえぬき 生え抜き"
"はえばる 南風原"
"はおう 覇王"
"はおうでん 覇王伝"
"はおり 羽織"
"はか 破瓜 墓"
"はかい 破戒 破壊"
"はかいし 墓石"
"はかいしん 破壊神"
"はかく 破格"
"はかくね 破格値"
"はかげ 葉陰"
"はかず 葉数"
"はかせ 博士"
"はかた 伯方 博多"
"はかたみなみ 博多南"
"はかたわん 博多湾"
"はかば 墓場"
"はかま 袴"
"はかまいり 墓参り"
"はかまだ 袴田"
"はかむら 墓村"
"はかり 秤"
"はかりごと 謀"
"はが 波賀 羽賀 芳賀"
"はがいじめ 羽交い締め 羽交い絞め"
"はがき 葉書き ハガキ 葉書"
"はがた 歯形 歯型"
"はがね 鋼"
"はがわ 羽川"
"はがん 破顔"
"はき 杷木 破毀 覇気 破棄"
"はきけ 吐気 吐き気"
"はきもの 履物"
"はきゅう 波及"
"はきょく 破局"
"はぎ 脛 矧 萩"
"はぎお 萩尾"
"はぎしり 歯軋り"
"はぎた 萩田"
"はぎたに 萩谷"
"はぎの 萩野"
"はぎのつき 萩の月"
"はぎはら 萩原"
"はぎまつり 萩まつり"
"はぎもと 萩本"
"はぎもり 萩森"
"はぎや 萩谷"
"はぎょう ハ行"
"はぎれ 歯切 歯切れ"
"はぎわら 萩原"
"はく 栢 陌 膊 璞 蘗 擘 搏 愽 帛 岶 佰 亳 狛 魄 剥 珀 箔 粕 舶 柏 拍 博 薄 伯 迫 白 泊"
"はくあ 白堊 白亜"
"はくあい 博愛"
"はくあき 白堊紀"
"はくい 伯井 羽咋 白衣"
"はくう 白雨"
"はくうん 白雲"
"はくえい 搏景"
"はくえん 白煙"
"はくおう 白鳳 白鴎 白鴬"
"はくかい 擘開"
"はくがい 迫害"
"はくがく 博学"
"はくがん 白眼"
"はくがんし 白眼視"
"はくぎ 博儀"
"はくぎん 白銀"
"はくげい 白鯨"
"はくげき 搏撃 迫撃"
"はくげきほう 迫撃砲"
"はくさい 舶載 白菜"
"はくさん 白山"
"はくさんした 白山下"
"はくし 搏摯 薄志 白紙 博士"
"はくしき 博識"
"はくしま 白島"
"はくしゃ 薄謝 拍車"
"はくしゃく 伯爵"
"はくしゅ 拍手"
"はくしょ 帛書 白書"
"はくしょく 白色"
"はくしょくこう 白色光"
"はくしん 白新 迫真"
"はくじ 白磁"
"はくじつ 白日"
"はくじゃ 白蛇"
"はくじゃく 薄弱"
"はくじゃくじ 薄弱児"
"はくじょう 薄情 白状"
"はくじん 白刃 白人"
"はくすい 白水"
"はくすう 搏数 泊数 拍数"
"はくせい 剥製"
"はくせん 白線"
"はくせんきん 白鮮菌 白癬菌"
"はくせんしゃ 薄銭社 白泉社"
"はくぜん 白髯"
"はくた 伯太"
"はくだく 白濁"
"はくだつ はく奪 剥奪"
"はくだん 白檀"
"はくち 泊地 白痴"
"はくちず 白地図"
"はくちゅう 伯仲 白昼"
"はくちゅうこう 白昼光"
"はくちゅうむ 白昼夢"
"はくちょう 白鳥"
"はくちょうこ 白鳥湖"
"はくちょうざ 白鳥座"
"はくちょうのうた 白鳥の歌"
"はくつる 白鶴"
"はくてん 白点"
"はくとう 白糖"
"はくどう 拍動"
"はくないしょう 白内障"
"はくねつ 白熱"
"はくねつこう 白熱光"
"はくねつとう 白熱灯"
"はくはつ 白髪"
"はくはつちゅん 白發中"
"はくはん 白斑"
"はくば 白馬"
"はくばい 白梅"
"はくばん 薄板 白板"
"はくひょう 薄氷"
"はくひんかんげきじょう 博品館劇場"
"はくび 白眉"
"はくびせん 伯備線"
"はくふ 帛布 白布"
"はくぶつ 博物"
"はくぶつし 博物史"
"はくへい 白兵"
"はくへいせん 白兵戦"
"はくほう 白鳳"
"はくほうどう 博報堂"
"はくぼ 薄暮"
"はくぼく 白墨"
"はくま 白魔"
"はくまい 白米"
"はくまく 白膜 薄膜"
"はくめ 拍目"
"はくめい 薄命"
"はくめんか 薄面化"
"はくや 白夜"
"はくゆん 学胤"
"はくよう 伯洋"
"はくようけん 伯養軒"
"はくようしゃ 白揚社 白洋舎"
"はくらい 舶来"
"はくらく 白楽 剥落 伯楽"
"はくらん 博覧"
"はくり 白痢 薄利 剥離"
"はくりき 薄力"
"はくりきこ 薄力粉"
"はくりゅう 白龍"
"はくりょく 薄力 迫力"
"はくりょくこ 薄力粉"
"はくれんが 白煉瓦"
"はくろ 白露"
"はくろう 伯労"
"はくろん 博論"
"はぐき 歯ぐき 齦 歯茎"
"はぐるま 歯車"
"はぐれぐも 浮浪雲"
"はぐろ 歯黒 羽黒"
"はけ 捌け 刷毛"
"はけい 波形"
"はけん 覇権 派遣"
"はげ 禿 ハゲ"
"はげあたま 禿頭"
"はげたか 禿鷹"
"はげやま 禿山"
"はげん 波源"
"はこ 匣 箪 筥 凾 匡 □ 葉子 運 函 箱"
"はこいり 箱入 箱入り"
"はこう 波高 跛行 破口"
"はこえ 箱絵"
"はこがた 箱型"
"はこさきぐう 筥崎宮"
"はこざき 筥崎 箱崎"
"はこした 箱下"
"はこだて 函館"
"はこづけ 箱付"
"はこづめ 箱詰 箱詰め"
"はこにわ 箱庭"
"はこね 箱根"
"はこねじ 箱根路"
"はこねわん 箱根湾"
"はこはんぶん 箱半分"
"はこぶね 方舟 箱船 箱舟"
"はこまつ 筥松"
"はこものちゅうしん 箱物中心"
"はこもり 箱守"
"はご 羽子"
"はごいた 羽子板"
"はごろも 羽衣"
"はさい 破砕"
"はさき 刃先 波崎"
"はさこ 羽迫"
"はさつおん 破擦音"
"はさま 挟間 迫"
"はさみ 波佐見 鋏 螯"
"はさみうち 挾み打ち 挾み撃ち 挟み打ち 挟み撃ち"
"はさみつけ 挾み付け"
"はさん 破算 破産"
"はざい 端材"
"はざかい 端境"
"はざくら 葉桜"
"はざま 間 羽佐間 陌間 狭間 硲"
"はざまぐみ 間組"
"はざわ 羽沢"
"はし 梯 觜 走 箸 端 橋"
"はしうえとうけつちゅうい 橋上凍結注意"
"はしうら 橋浦"
"はしお 走尾"
"はしか 麻疹"
"はしかみ 階上"
"はしかわ 橋川"
"はしがき 端書"
"はしがみ 橋上"
"はしくら 橋倉"
"はしくれ 端くれ"
"はしぐち 橋口"
"はしけ 艀"
"はしげた 橋げた 橋桁"
"はしご 梯子"
"はしずめ 橋爪"
"はした 端"
"はしたか 鷂"
"はしたがね 端た金 端金"
"はしたに 橋谷"
"はしため 婢"
"はしだ 橋田"
"はしづめ 橋爪 橋詰"
"はしの 橋野"
"はしのすけ 橋之助"
"はしば 羽柴"
"はしばし 端々"
"はしばみ 榛"
"はしま 羽島"
"はしもと 橋本"
"はしゃ 覇者"
"はしゅ 播種 把手"
"はしゅつ 派出"
"はしゅつしょ 派出署"
"はしゅつじょ 派出所"
"はしょうふう 破傷風"
"はしら 柱"
"はしらたに 柱谷"
"はしらとりつけかなぐ 柱取付金具"
"はしらどけい 柱時計"
"はしり 走り"
"はしりがき 走り書き"
"はしわたし 橋渡し"
"はじ 土師 耻 初 把持 始 端 恥"
"はじかみ 薑"
"はじま 羽島"
"はじまり 始まり"
"はじめ 創 始め 壹 弌 初 始 哉 元 壱 馨 甫 初め 一 肇"
"はじめて 初めて"
"はじめね 始値 始め値"
"はじめまして 始めまして"
"はじゃ 覇者 破邪"
"はじょう 波状"
"はじょうろ 波状路"
"はじらい 羞じらい"
"はす 斜 蓮"
"はすい 破水"
"はすいけ 蓮池"
"はすう 歯数 波数 端数"
"はすか ハス科"
"はすこ 蓮子"
"はすだ 蓮田"
"はすっぱ 蓮っ葉 蓮葉"
"はすぬま 蓮沼"
"はすのはぎりか ハスノハギリ科"
"はすは 泰葉"
"はすみ 羽須美 羽角 蓮見 羽純"
"はすむかい 斜向い"
"はず 筈"
"はずい 筈井"
"はずかしめ 辱め"
"はずみぐるま 弾み車"
"はずれ 外"
"はせ 馳 長谷"
"はせい 長谷井 派生"
"はせくら 支倉"
"はせべ 長谷部"
"はせみ 長谷見"
"はせん 波線 破線"
"はぜ 枦 鯊 櫨"
"はそうさき 配送先"
"はそく 波束"
"はそん 破損"
"はた 圃 波田 機 傍 幟 羽田 籏 旙 旛 波多 秦 幡多 畠 端 幡 畑 旗"
"はたあげ 旗揚げ 旗揚"
"はたい 波帯"
"はたいけ 幡池"
"はたいろ 旗色"
"はたうえ 畑上"
"はたえ 波多江 二十重"
"はたおか 畑岡"
"はたおり 旗折"
"はたがしら 旗頭"
"はたがや 幡ヶ谷"
"はたきこみ 叩き込み"
"はたけ 畠 畑"
"はたけやま 畑山 畠山"
"はたご 旅籠"
"はたさ 畑佐"
"はたさく 畑作"
"はたざき 畑崎"
"はたして 果して"
"はたしょう 秦荘"
"はたじるし 旗印"
"はたたて 旗立"
"はただ 畑田 畠田"
"はたち 畑地 二十 ２０歳 二十歳"
"はたとせ 二十歳"
"はたなか 畠中 畑仲 畑中"
"はたの 畑野 幡野 秦野 羽田野 籏野 波多野"
"はたのう 畑農"
"はたのだいだんち 秦野台団地"
"はたはた 鰰"
"はたふり 旗振り"
"はたぶ 幡生"
"はたむら 畑村"
"はため はた目 傍目"
"はたもと 畑本 播本"
"はたや 畑谷"
"はたやま 畠山 畑山"
"はたら 働"
"はたらき 働き"
"はたん 破綻"
"はだ 羽田 膚 肌"
"はだあい 肌合"
"はだあれ 肌荒 肌あれ"
"はだいろ 肌色"
"はだか 裸"
"はだかけ 肌掛け"
"はだかてがた 裸手形"
"はだかび 裸火"
"はだかむぎ 裸麦"
"はだぎ 肌着"
"はだざわり 肌触り"
"はだし 跣 裸足"
"はだの 秦野"
"はだぶとん 肌布団"
"はだみ 肌身"
"はだん 破断 破談"
"はち 捌 ハチ 蜂 ８ 鉢 八"
"はちあわせ 鉢合わせ"
"はちうえ 鉢植"
"はちおうじ 八王子"
"はちかい 八開"
"はちがつ 葉月 八月"
"はちく 破竹"
"はちけん 八軒"
"はちげんすう 八元数"
"はちこう ハチ公"
"はちこうだい 八工大"
"はちごうめ 八合目"
"はちじ 八時"
"はちじゅう 八十"
"はちじゅうに 八十二"
"はちじゅうはちや 八十八夜"
"はちじょう 鉢状 八条 八丈"
"はちじょうぐち 八条口"
"はちじょうじま 八丈島"
"はちにん 八人"
"はちねん 八年"
"はちのす 蜂の巣"
"はちのへ 八戸"
"はちのへこうだいいち 八戸工大一"
"はちはちかんたい 八八艦隊"
"はちばん 八番"
"はちぶ ８分 八分"
"はちぶおんぷ ♪"
"はちぶせやま 鉢伏山"
"はちほん 八本"
"はちほんまつ 八本松"
"はちまい 八枚"
"はちまき 鉢巻"
"はちまん 八幡"
"はちまんぐう 八幡宮"
"はちまんたい 八幡平"
"はちみつ 蜂蜜"
"はちめんろっぴ 八面六臂"
"はちもの 鉢物"
"はちもり 八森"
"はちゃめちゃ 葉茶目茶"
"はちや 鉢谷 八谷 蜂屋"
"はちゅう 爬虫"
"はちゅうるい 爬蟲類"
"はちょう 波長"
"はちょうごと 波長毎"
"はちりゅう 八竜"
"はちろ 八路"
"はちろう 八郎"
"はちろうがた 八郎潟"
"はちろぐん 八路軍"
"はっ 發 法 発"
"はっか 薄荷 発火"
"はっかー ハッカー"
"はっかい 八戒 発会"
"はっかいさん 八海山"
"はっかく 発覚"
"はっかせき 発火石"
"はっかん 発汗 発刊"
"はっき 発輝 発揮"
"はっきゅう 薄給 発給"
"はっきょう 発狂"
"はっきょうし 発狂死"
"はっきり ハッキリ"
"はっきん 白金 発禁"
"はっきんせんでんきょく 白金線電極"
"はっく 八九"
"はっくつ 発掘"
"はっけ 八卦"
"はっけい 発勁 八景"
"はっけいおき 八景沖"
"はっけいじま 八景島"
"はっけっきゅう 白血球"
"はっけつびょう 白血病"
"はっけん 白鍵 発券 発見"
"はっけんでん 八犬伝"
"はっこ 発呼"
"はっこう 白光 八紘 薄幸 醗酵 発効 発光 発酵 発行"
"はっこうしゃべつ 発行社別"
"はっこうしゅう 発酵臭"
"はっこうじょ 発行所"
"はっこうせん 八高線"
"はっこうたい 発光体"
"はっこうだ 八甲田"
"はっこうださん 八甲田山"
"はっこつ 白骨"
"はっさい 八歳"
"はっさく 八朔"
"はっさむ 発寒"
"はっさん 発散"
"はっしゃ 発車 発射"
"はっしゃかん 発射管"
"はっしゃこう 発射口"
"はっしゅち ハッシュ値"
"はっしゅひょう ハッシュ表"
"はっしょう 八省 発症 発消 八章 発祥"
"はっしょく 発色"
"はっしょくげんしょう 発色現像"
"はっしん 発震 八神 発進 発振 発疹 発信"
"はっしんげん 発信源"
"はっしんにんばらい 発信人払い"
"はっしんひょうき 八進表記"
"はっすい 発水"
"はっすいざい 溌水剤"
"はっすいせい 撥水性 溌水性"
"はっせい 八世 発声 発生"
"はっせいげん 発生源"
"はっせいじゅん 発生順"
"はっせん 八千"
"はっそう 発走 発想 発送"
"はっそく 発足"
"はった 八田"
"はったつ 発達"
"はったん 八反 発端"
"はったんにしき 八反錦"
"はっちゃく 発着"
"はっちゃくしん 発着信"
"はっちゃくじょ 発着所"
"はっちゃくわく 発着枠"
"はっちゅう 八中 発注"
"はっちゅうじゅん 発注順"
"はっちゅうずみ 発注済"
"はっちゅうぬし 発注主"
"はっちょう 八丁"
"はっちょうぼり 八丁堀"
"はってん 発展"
"はってんけい 発展形"
"はってんだいかい 発展段階"
"はっと 法度"
"はっとう 八東"
"はっとうしん 八等身"
"はっとり 服部"
"はっとりせいこー 服部セイコー"
"はっぱ 発破 葉っぱ"
"はっぴ 法被"
"はっぴき 八匹"
"はっぴゃく 八百"
"はっぴょう 発表"
"はっぴょうじゅん 発表順"
"はっぴょうずみ 発表済"
"はっぴよう 発表"
"はっぷ 髪膚 発布"
"はっぷん 発憤 発奮"
"はっぺい 八平"
"はっぽう 発泡 発砲 八方"
"はっぽうえん 八芳園"
"はっぽうこうげん 白峰高原"
"はっぽうさい 八宝菜"
"はっぽうせつ 発砲説"
"はつ 髮 釟 秡 癶 發 撥 溌 醗 髪 初 発"
"はつあん 発案"
"はつい 発意"
"はついく 発育"
"はついし 初石"
"はつうま 初午"
"はつうり 初売り 初売"
"はつえ 初江 初絵"
"はつえき 発駅"
"はつえきけん 発駅券"
"はつえん 発煙"
"はつえんとう 発炎筒 発煙灯 発煙筒"
"はつお 初男"
"はつおん 撥音 発音"
"はつおんたい 発音体"
"はつか 廿日 二十日 ２０日"
"はつかいち 甘日市"
"はつかん 発艦"
"はつが 発芽"
"はつがお 初顔"
"はつがつお 初鰹"
"はつがり 初狩"
"はつがん 発がん 発ガン 発癌"
"はつぎ 発議"
"はつげん 撥弦 発現 発言"
"はつこい 初恋"
"はつご 初子 発語"
"はつさわ 初沢"
"はつしば 初芝"
"はつしも 初霜"
"はつしゅっしいちらん 初出誌一覧"
"はつしん 発進"
"はつじこく 発時刻"
"はつじも 初霜"
"はつじょう 発条 発情"
"はつすべり 初滑り"
"はつずりぶん 初刷分"
"はつだい 初台"
"はつづり 初釣"
"はつで 初出"
"はつでん 発電"
"はつでんき 発電気"
"はつとうばん 初投板"
"はつとみ 初富"
"はつどう 発動"
"はつに 初荷"
"はつねつ 發熱 発熱"
"はつねつたい 発熱体"
"はつはる 初春"
"はつばい 発売"
"はつばいがく 発売額"
"はつばいじゅん 発売順"
"はつばいじょ 発売所"
"はつばいずみ 発売済"
"はつばいづき 発売月"
"はつばいわく 発売枠"
"はつひ 初日"
"はつびょう 発病"
"はつふゆ 初冬"
"はつほん 発本"
"はつみ 初実 初見"
"はつみみ 初耳"
"はつめい 発明"
"はつめいおう 発明王"
"はつめいか 発明家"
"はつもうで 初詣"
"はつもの 初物"
"はつもん 発問"
"はつゆき 初雪"
"はつゆめ 初夢"
"はつよう 発揚"
"はつらつ 溌刺 溌剌"
"はつれい 発令"
"はつろ 発露"
"はつわ 発話"
"はつわらい 初笑"
"はづき 葉月"
"はて 果て"
"はてな ？"
"はてんこう 破天荒"
"はで 派手"
"はと 鴿 鳩"
"はとう 陂塘 坡頭 坡塘 波涛 波濤 波頭"
"はとがや 鳩谷"
"はとの 鳩野"
"はとば 波止場"
"はとむね 鳩胸"
"はともと 波戸元"
"はとやま 鳩山"
"はとり 羽鳥"
"はどう 波導 覇道 波動"
"はどうけん 波動拳"
"はどうば 波動場"
"はどうほう 波動砲"
"はどめ 歯止 歯止め"
"はどり 羽鳥"
"はな 塙 ハナ 端 洟 離 話 華 鼻 花"
"はない 花井"
"はないき 鼻息"
"はないずみ 花泉"
"はなうた 鼻歌"
"はなうり 花売り"
"はなうりむすめ 花売娘"
"はなえ 花江 英恵"
"はなお 鼻緒"
"はなおか 花岡"
"はなかご 花籠"
"はなかぜ 鼻風邪 鼻カゼ"
"はながた 鼻型 花形 花型"
"はながみ 鼻紙"
"はながら 花柄"
"はなき 花紀"
"はなきん 花金"
"はなくそ 鼻糞"
"はなくま 花隈"
"はなぐもり 花曇"
"はなげ 鼻毛"
"はなこ 華子 花子"
"はなこうぼう 花工房"
"はなことば 花言葉"
"はなさ 鼻差"
"はなさか 花阪"
"はなさかじじい 花咲爺"
"はなさき 花咲 鼻先"
"はなざかり 花盛り"
"はなざくら 花桜"
"はなざけ 花酒"
"はなざわ 花沢"
"はなざんげ 花ざんげ"
"はなし 譚 咄 噺 話"
"はなしあい 話合 話合い 話し合い"
"はなしあいて 話相手 話し相手"
"はなしあう 話し合う"
"はなしいぜん 話以前"
"はなしか 噺家"
"はなしかた 話し方"
"はなしがい 放し飼い"
"はなしことば 話言葉 話し言葉"
"はなしごえ 話し声"
"はなしじたい 話自体"
"はなしじょうず 話上手"
"はなしずき 話好き"
"はなしちゅう 話中 話し中"
"はなして 話し手"
"はなしてき 話的"
"はなしはんぶん 話半分"
"はなしべた 話下手"
"はなしま 花島"
"はなしょうぶ 花菖蒲"
"はなしんじゅ 花真珠"
"はなじ 衂 衄 鼻血"
"はなじる 洟"
"はなじるし 花印"
"はなすじ 鼻梁 鼻筋"
"はなずもう 花相撲"
"はなずら 鼻面"
"はなせ 花背"
"はなせんじょう 鼻洗浄"
"はなぞの 華園 花園"
"はなた 花田"
"はなたか 花高"
"はなたに 花谷"
"はなたば 花束"
"はなだ 花田"
"はなぢ 鼻血"
"はなつまみ 鼻摘"
"はなづら 鼻面"
"はなてん 放出"
"はなでんしゃ 花電車"
"はなどき 花時"
"はなどけい 花時計"
"はなぬすびと 花盗人"
"はなのまき 花巻"
"はなはく 花博"
"はなはた 花畑"
"はなはだ 甚だ 甚"
"はなばたけ 花畑"
"はなばな 花々"
"はなばんか 花挽歌"
"はなひゃっけい 花百景"
"はなび 花火"
"はなびえ 花冷"
"はなびだま 花火玉"
"はなびら 花弁 花びら"
"はなふさ 花房"
"はなふだ 花札"
"はなふぶき 花吹雪"
"はなぶえ 鼻笛"
"はなぶさ 蕚 萼 花房"
"はなまき 花巻"
"はなまつり 花祭り 花祭"
"はなみ 花見"
"はなみず 洟 鼻水"
"はなみずがわ 花水川"
"はなみち 花道"
"はなむけ 餞"
"はなむこ 花婿"
"はなむら 花村"
"はなめがね 鼻眼鏡"
"はなもじ 花文字"
"はなもと 花本"
"はなや 花屋"
"はなやしき 花屋敷"
"はなやま 花山"
"はなよめ 花嫁"
"はならび 歯並び"
"はなれわざ 離れ業"
"はなわ 鼻輪 花輪 塙"
"はに 埴"
"はにうだ 羽生田"
"はにしな 埴科"
"はにゅう 埴生 羽生"
"はにゅうだ 羽生田"
"はにわ 埴輪"
"はぬけ 歯抜け"
"はね 翅 羽根 羽"
"はねいし 羽石"
"はねぎ 羽根木"
"はねだ 羽田"
"はねだおき 羽田沖"
"はねばし 跳ね橋"
"はねぶとん 羽布団"
"はねまくら 羽根枕"
"はねむーん ハネムーン"
"はねむし 羽虫"
"はねもの 羽根物 羽物"
"はの 羽野"
"はのうら 羽ノ浦"
"はは 義母 母"
"ははうえ 母上"
"ははおや 母親"
"ははおやに 母親似"
"ははおややく 母親役"
"ははかた 母方"
"ははきぎ 帚木"
"ははぎみ 母君"
"ははこ 母子"
"ははのひ 母の日"
"はば 掵 巾 幅"
"はばうえ 巾上"
"はばかる 憚る"
"はばつ 派閥"
"はばとび 幅跳び"
"はばひろ 巾広 幅広"
"はばゆうせん 幅優先"
"はびきの 羽曳野"
"はぴょうしゃ 発表者"
"はふ 破風"
"はぶ 埴生 羽生"
"はぶたえ 羽二重"
"はぶらし 歯ブラシ"
"はぶり 羽振り"
"はへい 派兵"
"はへん 破片"
"はほろ 羽幌"
"はぼたんしょう 葉牡丹賞"
"はぼまい 歯舞"
"はぼろ 羽幌"
"はま 破魔 濱 浜"
"はまお 浜尾"
"はまおおつ 浜大津"
"はまおか 浜岡"
"はまかつ 浜勝"
"はまかど 濱角"
"はまかわ 濱川 浜川"
"はまかわさき 浜川崎"
"はまがくえん 浜学園"
"はまがみ 濱上 浜上"
"はまがわ 浜側"
"はまき 葉巻"
"はまきた 浜北"
"はまきょう 浜響"
"はまぐち 浜口"
"はまぐり 蛤"
"はまさか 浜坂"
"はまさき 濱崎 浜崎"
"はまざき 浜崎"
"はましま 濱島"
"はまじま 浜島"
"はまたけ 浜竹"
"はまだ 濱田 浜田"
"はまちどり 浜千鳥"
"はまちょう 浜町"
"はまっこ 浜っ子"
"はまつか 濱塚"
"はまで 濱出"
"はまとんべつ 浜頓別"
"はまな 浜名"
"はまなか 濱中 浜中"
"はまなこ 浜名湖"
"はまの 濱野 浜野"
"はまべ 浜部 浜辺"
"はまます 浜益"
"はままつ 浜松"
"はままつしょくくんたんだい 浜松職訓短大"
"はままつだこ 浜松凧"
"はままつにし 浜松西"
"はままで 浜迄"
"はまみやせん 浜宮線"
"はまめし 浜飯"
"はまもと 濱本"
"はまやき 浜焼"
"はまやす 浜靖"
"はまりきゅう 浜離宮"
"はまりやく 嵌役 嵌まり役 填役"
"はみ 葉美"
"はみがき 歯磨 歯磨き"
"はみがきこ 歯磨き粉"
"はむし 羽虫"
"はむら 羽村"
"はめ 破目 羽目"
"はめいた 羽目板"
"はめこみ 嵌め込み"
"はめつ 破滅"
"はめん 波面"
"はも 羽茂 鱧"
"はもの 釖 端物 刃物"
"はもん 破門 波紋"
"はや 鮠 頓 速 早目 早"
"はやあし 早足 速足"
"はやあるき 速歩き"
"はやい 速い"
"はやうち 速打ち"
"はやうまれ 早生まれ"
"はやお 駿 早生"
"はやおき 早起き"
"はやおくり 早送り 速送り"
"はやおし 早押し"
"はやかわ 早川"
"はやかわこう 早川港"
"はやがてん 早合点"
"はやがね 早鐘"
"はやがわり 早変わり"
"はやき 隼輝 勇樹"
"はやきた 早来"
"はやく 破約 端役 早く"
"はやくさ 早草"
"はやくち 早口"
"はやぐい 早喰い"
"はやごせんしゅけん 早碁選手権"
"はやさ 速さ"
"はやさか 早坂"
"はやざき 早咲き"
"はやざし 早指し"
"はやし 囃 囃子 林"
"はやしだ 林田"
"はやしば 林葉"
"はやしばら 林原"
"はやしま 早島"
"はやしや 林屋 林家"
"はやじに 早死"
"はやせ 早勢 早瀬"
"はやた 早田"
"はやて 疾風"
"はやで 早出"
"はやと 早戸 勇人 隼人"
"はやとき 早解き"
"はやとちり 早とちり"
"はやね 早寝"
"はやの 早野"
"はやば 早場"
"はやばまい 早場米"
"はやばや 早々"
"はやばん 早版 早番"
"はやびき 速弾き"
"はやぶさ 鶻 隼"
"はやべん 早弁"
"はやま 端山 葉山"
"はやみ 速見 速水 早見"
"はやみず 早水 速水"
"はやみち 早道"
"はやみばん 早見板"
"はやみみ 早耳"
"はやみや 頓宮"
"はやめ 早め 早目"
"はやり 流行"
"はやわざ 早技 早業"
"はら 肚 腹 原"
"はらい 払い 赦い 祓い 祓 拂 払"
"はらいかわ 祓川 秡川"
"はらいこみ 払込み 払込"
"はらいだし 払い出し"
"はらいっぱい 腹一杯"
"はらいどの 払殿"
"はらいもどし 払戻し 払戻 払い戻し"
"はらお 原尾"
"はらおか 原岡"
"はらから 同胞"
"はらがまえ 腹構え"
"はらき 原木"
"はらぐあい 腹具合"
"はらぐち 原口"
"はらげい 腹芸"
"はらこ 原子"
"はらこし 原越"
"はらごころ 腹心"
"はらごしらえ 腹拵え"
"はらさき 原崎"
"はらさわ 原澤 原沢"
"はらしま 原嶋 原島"
"はらしょぼう 原書房"
"はらじま 原島"
"はらじゅく 原宿"
"はらせつこ 原節子"
"はらたつのり 原辰徳"
"はらだ 原田"
"はらちがい 腹違い"
"はらっぱ 原っぱ"
"はらどけい 腹時計"
"はらの 原野"
"はらのまち 原ノ町 原町"
"はらのや 原野谷"
"はらひでこ 原日出子"
"はらまち 原町"
"はらまちだ 原町田"
"はらみず 原水"
"はらやま 原山"
"はらよし 原良"
"はらわた 腸"
"はらん 波瀾 波蘭 波乱"
"はらんぶくみ 波乱含み"
"はり 貼 鍼 蓁 玻璃 梁 播 針 張"
"はりあい 張り合い 張合い"
"はりあな 針穴"
"はりいち 針位置"
"はりかえ 張替"
"はりがね 針金"
"はりがみ はり紙 張紙 貼紙 張り紙 貼り紙"
"はりがや 針谷 針ヶ谷"
"はりき 針木"
"はりきゅうちりょう 鍼灸治療"
"はりくよう 針供養"
"はりぐち 播口"
"はりけん 破裏拳"
"はりこ 張子"
"はりこうかん 針交換"
"はりこみ 貼り込み 張り込み"
"はりさき 針先"
"はりしごと 針仕事"
"はりじょう 針状"
"はりだしこむすび 張出小結"
"はりだしせきわけ 張出関脇"
"はりちりょう 針治療"
"はりつけ 張り付け 磔 貼付 貼り付け"
"はりぬい 針縫"
"はりねずみ 蝟"
"はりふだ はり札"
"はりま 播摩 針間 播磨"
"はりまなげ 波離間投げ"
"はりまなだ 播磨灘"
"はりまのくに 播磨国"
"はりまびと 播磨人"
"はりまや 針間矢"
"はりもと 播本 張本"
"はりや 針谷"
"はりやま 張山"
"はる 榛 青春 請 玄 温 晴 治 春"
"はるあき 春秋"
"はるいがい 春以外"
"はるいちばん 春一番"
"はるうらら 春麗"
"はるえ 治恵 春江"
"はるお 東生 晴雄 晴夫 春雄 治雄 治夫 治男 春男 春夫"
"はるおか 春岡"
"はるおみ 晴臣"
"はるか 悠 遥か 遙 晴香 遥"
"はるかぜ 春風"
"はるかわ 春川"
"はるがっしゅく 春合宿"
"はるき 治己 春樹 春木"
"はるきち 春吉"
"はるぐち 春口"
"はるけいば 春競馬"
"はるこ 治子 春子 晴子"
"はるごころ 春心"
"はるごろ 春頃"
"はるさき 春先"
"はるさめ 春雨"
"はるし 治志"
"はるじ 春治"
"はるた 春田"
"はるだ 春田"
"はるだんじ 春団次"
"はるな 榛名 春菜"
"はるなつ 春夏"
"はるの 榛野 春野"
"はるばしょ 春場所"
"はるひ 春日 晴日"
"はるひこ 晴比古 治彦 晴彦 春彦"
"はるひさ 陽久 春久 治久 晴久"
"はるひで 治秀"
"はるひと 治人"
"はるひろ 晴弘"
"はるびん 哈爾浜"
"はるふじ 春藤"
"はるまき 春巻"
"はるまつり 春祭"
"はるみ はる美 晴見 春美 晴美 晴海"
"はるみつ 晴光"
"はるもの 春物"
"はるやす 陽保"
"はるやすみ 春休み"
"はるやま 春山"
"はるゆき 晴幸 治之 陽之 春幸"
"はるよ 春代"
"はるよし 晴芳"
"はるらんまん 春爛漫"
"はれ 晴れ 晴"
"はれぎ 晴着 晴れ着"
"はれすがた 晴れ姿"
"はれつ 破裂"
"はればれ 晴々"
"はれま 晴間 晴れ間"
"はれやま 晴山"
"はれんち 破廉恥"
"はろ 波呂"
"はろう 波浪"
"はわい ハワイ 布哇"
"はわいとう ハワイ島"
"はわたり 刃渡り"
"はん 凡 磐 幡 阪 蕃 鈑 袢 蟠 范 膰 胖 繙 絆 笵 燔 潘 泛 樊 槃 攀 拌 瘢 翻 叛 斑 搬 帆 氾 藩 釆 伴 頒 繁 板 畔 犯 汎 煩 班 般 販 範 坂 判 反 飯 版 半"
"はんい 犯意 範囲"
"はんいぶんせき 範囲解析"
"はんいん 班員"
"はんえい 半影 繁栄 反映"
"はんえん 半円"
"はんえんけい 攀縁茎"
"はんおし 半押"
"はんおん 半音"
"はんおんした 半音下"
"はんか 頒価 繁華 汎化"
"はんかい 半潰 半開 半解 半壊"
"はんかいしんけい 反回神経"
"はんかく 反核 半角"
"はんかくざいりょう 販拡材料"
"はんかた 汎型"
"はんかちょう 犯科帳"
"はんかつう 半可通"
"はんかん 半環 反感"
"はんかんすう 汎関数"
"はんが 版画"
"はんがか 版画家"
"はんがく 半額"
"はんがくけん 半額券"
"はんがた 判型 版型"
"はんがてん 版画展"
"はんがめいさくてん 版画名作展"
"はんがりー 洪牙利"
"はんがん 判官"
"はんき 搬器 叛旗 半旗 半期"
"はんきかん 半規管"
"はんきゅう 阪九 半球 阪急 半休"
"はんきょう 反共 般教 反響"
"はんきょり 汎距離"
"はんぎ 半技"
"はんぎゃく 反逆"
"はんぎょじん 半魚人"
"はんくら 半クラ"
"はんぐん 反軍 半群"
"はんけい 判型 半径"
"はんけつ 判決"
"はんけん 半研 半券 版権"
"はんげき 反撃"
"はんげつ 半月"
"はんげつばん 半月板"
"はんげん 半舷 半源 半減"
"はんこ 判子 ハンコ"
"はんこう 犯行 反抗"
"はんこつ 反骨"
"はんこん 瘢痕"
"はんご 反語"
"はんごう 半合 飯盒"
"はんごんたん 反魂丹"
"はんさ 煩瑣"
"はんさき 飯崎"
"はんざい 犯罪"
"はんざつ 煩雑 繁雑"
"はんざわ 半沢 半澤"
"はんざん 飯山"
"はんし 半紙"
"はんした 版下"
"はんしちとりものちょう 半七捕物帳"
"はんしつ 半室"
"はんしはんしょう 半死半生"
"はんしゃ 販社 反射"
"はんしゃきょう 反射鏡"
"はんしゃこう 反射光"
"はんしゃざい 反射材"
"はんしゃそく 反射束"
"はんしゃたい 反射体"
"はんしゃは 反射波"
"はんしゃばん 反射板"
"はんしゃりつ 反射律"
"はんしゃろ 反射炉"
"はんしゅう 半周"
"はんしゅつ 搬出"
"はんしょう 半鐘 半焼 反証"
"はんしょく 蕃殖 飯食 繁殖"
"はんしょくば 繁殖馬"
"はんしん 半身 阪神"
"はんしんせん 阪神戦"
"はんしんはんぎ 半信半疑"
"はんしんろん 汎神論 汎心論"
"はんじ 判事"
"はんじゅく 半熟"
"はんじゅくたまご 半熟卵"
"はんじょう 繁盛"
"はんじょうき 繁盛記"
"はんすう 半数 反芻 版数"
"はんせい 半生 反省"
"はんせいよくせつ 汎性欲説"
"はんせつ 反切"
"はんせん 反戦 帆船"
"はんぜん 判然"
"はんそ 反訴 反ソ"
"はんそう 半荘 帆走 搬送"
"はんそうは 搬送波"
"はんそく 半束 販促 反則"
"はんそくきんかりのうふ 反則金仮納付"
"はんそくわざ 反則技"
"はんそで 半袖"
"はんぞう 楾 半蔵"
"はんぞうもん 半蔵門"
"はんたい 反対"
"はんたいぎし 反対岸"
"はんたいじ 繁体字"
"はんたいせつ 反対説"
"はんたま 半玉"
"はんたんい 班単位"
"はんだ 盤陀 半田"
"はんだい 版代 飯台 大阪大学 阪大"
"はんだいきゅうきょうよう 阪大旧教養"
"はんだいこう 阪大工"
"はんだいじんか 阪大人科"
"はんだいつうしんこう 阪大通信工"
"はんだいぶつり 阪大理物"
"はんだいり 阪大理"
"はんだくてん ゜"
"はんだぐちふきん 半田口付近"
"はんだずけ 半田付け"
"はんだん 判断"
"はんち 半値"
"はんちゃん 半荘"
"はんちゅう 範衷 範中 藩中 範疇"
"はんちょう 反跳 班長"
"はんつき 半月"
"はんつきまい 半搗き米"
"はんて 半手"
"はんてい 判定"
"はんてつ 半徹"
"はんてん 反轉 半纏 飯店 斑点 反転"
"はんと 版図"
"はんとう 反騰 半島"
"はんとうまく 半透膜"
"はんとけいまき 反時計巻"
"はんとし 半年"
"はんとしごと 半年毎"
"はんど ハンド"
"はんどう 半藤 般道 反動"
"はんどく 判読"
"はんどばっぐ ハンドバッグ"
"はんどら ハンドラ"
"はんどる ハンドル"
"はんな 阪奈"
"はんなん 阪南"
"はんにち 反日 半日"
"はんにちけん 半日券"
"はんにっし 班日誌"
"はんにゃ 般若"
"はんにゃしんきょう 般若心経"
"はんにゃとう 般若湯"
"はんにゅう 搬入"
"はんにゅうこう 搬入口"
"はんにゅうとどけ 搬入届"
"はんにん 半人 犯人"
"はんにんぞう 犯人像"
"はんにんやく 犯人役"
"はんね 半値"
"はんねん 半年"
"はんのう 半能 半納 半農 飯能 反応"
"はんはん 半々"
"はんば 半場 飯場"
"はんばい 半杯 販売"
"はんばいうちきり 販売打切り"
"はんばいかい 即売会"
"はんばいじょ 販売所"
"はんばいだか 販売高"
"はんばいひ 販売費"
"はんばいもう 販売網"
"はんばく 反ばく 反駁"
"はんぱ 半波 半端"
"はんぱく 半泊"
"はんぱつ 反撥 反発"
"はんひん 販品"
"はんぴれい 反比例"
"はんふだい 阪府大"
"はんぶうすう 繁分数"
"はんぶるぐ 漢堡"
"はんぶん 半分"
"はんぶんじゃく 半分弱"
"はんぶんすう 繁分数"
"はんぷ 帆布 頒布"
"はんぷく 反復"
"はんべい 反米"
"はんべつ 判別"
"はんべつきょうぎ 班別協議"
"はんぺい 汎平"
"はんぺいた 半平太"
"はんぺん 反変"
"はんぼう 繁忙"
"はんぽ 半歩"
"はんまー ハンマー"
"はんみ 半身"
"はんみょう 斑猫"
"はんむら 半村"
"はんめい 判明"
"はんめん 版面 半面 反面"
"はんも 繁茂"
"はんもく 反目"
"はんもと 版元"
"はんもん 煩悶 斑紋 反問"
"はんもんてん 板門店"
"はんよう 汎用"
"はんらく 反落"
"はんらん 汎濫 叛乱 反乱 氾濫"
"はんらんぐん 反乱軍"
"はんらんざい 反乱罪"
"はんりょ 伴侶"
"はんりょく 反力"
"はんれい 煩禮 範例 汎例 凡例 反例 判例"
"はんれつ 半列"
"はんろ 販路"
"はんろん 汎論 反論"
"はんわ 阪和"
"ば 刄 刃 庭 葉 塲 羽 罵 婆 芭 馬 場"
"ばー バー"
"ばーじょん バージョン"
"ばーべきゅー バーベキュー"
"ばあ 婆"
"ばあい 場合"
"ばあさま 婆様"
"ばあさん 婆さん"
"ばあたりてき 場当たり的"
"ばい 黴 霾 賣 憊 焙 Ｂｙ 吠 貝 唄 楳 媒 煤 培 狽 梅 陪 買 賠 売 倍"
"ばいあすろん バイアスロン"
"ばいいじょう 倍以上"
"ばいいない 倍以内"
"ばいう 梅雨"
"ばいうころ 梅雨頃"
"ばいえん 煤煙"
"ばいお バイオ"
"ばいおん 倍音"
"ばいおんそく 倍音速"
"ばいか 買価 倍化 売価 倍加"
"ばいかい 媒介"
"ばいかく 倍角"
"ばいかたんきだいがく 梅花短期大学"
"ばいかん 売勘"
"ばいがく 倍額"
"ばいきゃく 売却"
"ばいきん 黴菌"
"ばいく バイク"
"ばいくとう バイク盗"
"ばいくらい 倍位"
"ばいけん 買券"
"ばいこく 売国"
"ばいこくど 売国奴"
"ばいしつ 媒質"
"ばいしゃく 媒妁 媒酌"
"ばいしゅう 買収"
"ばいしゅん 売春 買春"
"ばいしゅんふ 売春婦"
"ばいしゅんやど 買春宿"
"ばいしょう 売笑 賠償"
"ばいしょうがく 賠償額"
"ばいしん 陪臣 陪審"
"ばいじん 煤塵"
"ばいすう 倍数"
"ばいせい 媒精"
"ばいせいど 倍精度"
"ばいせき 陪席"
"ばいせん 煤煎 焙煎"
"ばいそく 倍速"
"ばいぞう 倍増"
"ばいぞうかん 倍増管"
"ばいた 売女"
"ばいたい 媒体"
"ばいち 培地"
"ばいちょう 倍調 倍長"
"ばいていど 倍程度"
"ばいてん 売店"
"ばいとすう バイト数"
"ばいどく 梅毒"
"ばいなりー バイナリー"
"ばいにく 梅肉"
"ばいにん 売人"
"ばいはば 倍幅"
"ばいばい 倍々 売買"
"ばいばいえき 売買益"
"ばいばいしゅん 売買春"
"ばいひん 売品"
"ばいふうかん 培風舘 培風館"
"ばいぶれーた バイブレータ"
"ばいまん 倍満"
"ばいめい 売名"
"ばいめいしん 売名心"
"ばいやく 売薬 売約"
"ばいやくまん 倍役満"
"ばいよう 培養"
"ばいようえき 培養液"
"ばいようりょう 倍容量"
"ばいりつ 倍率"
"ばいりょう 倍量"
"ばいりん 梅林"
"ばう 芒"
"ばか 莫伽 莫迦 馬鹿"
"ばかおんな 馬鹿女"
"ばかく 馬格"
"ばかじから 馬鹿力"
"ばかず 場数"
"ばかぢから 馬鹿力"
"ばかづら 馬鹿面"
"ばかとの 馬鹿殿"
"ばかね 馬鹿値"
"ばかばかしい バカバカしい 馬鹿馬鹿しい"
"ばかばなし 馬鹿話"
"ばかもの 馬鹿者"
"ばかやす 馬鹿安"
"ばかり 許 許り"
"ばきゃく 馬脚"
"ばきん 馬琴"
"ばぎょう バ行"
"ばく 博 麥 貘 藐 瀑 寞 驀 幕 暴 曝 獏 漠 莫 駁 縛 爆 麦"
"ばくえい 幕営"
"ばくえき 博奕"
"ばくえん 爆炎"
"ばくおん 爆音"
"ばくが 麦芽"
"ばくがとう 麦芽糖"
"ばくげき 爆撃"
"ばくさい 博才 爆砕"
"ばくさつ 爆殺"
"ばくし 爆死"
"ばくしゅう 麦秋"
"ばくしょう 爆笑"
"ばくしょうもの 爆笑物"
"ばくしん 驀進 爆進 爆心"
"ばくすい 爆睡"
"ばくせん 瀑泉"
"ばくぜん 漠然"
"ばくそう 爆装 麦草 爆走"
"ばくだい 莫大"
"ばくだっど バクダッド"
"ばくだん 爆彈 爆弾"
"ばくだんおとこ 爆弾男"
"ばくち 博奕 博打"
"ばくちく 爆竹"
"ばくちゃく 縛着"
"ばくちん 爆沈"
"ばくてりあ バクテリア"
"ばくと 博徒"
"ばくは 爆破"
"ばくはつ 爆発"
"ばくふ 瀑布 幕府"
"ばくふう 爆風"
"ばくふぐん 幕府軍"
"ばくまつ 幕末"
"ばくやく 爆薬"
"ばくらい 爆雷"
"ばくらいせん 爆雷戦"
"ばくりゅう 瀑流"
"ばくりょう 幕僚"
"ばくれつ 爆裂"
"ばくろ 曝露 暴露"
"ばくろう 伯労 博労 伯楽 馬喰"
"ばくろばなし 暴露話"
"ばぐ 馬具"
"ばぐん 馬群"
"ばけ 化"
"ばけがく 化学"
"ばけつ バケツ"
"ばけねこ 化猫"
"ばけもの 化け物 化物"
"ばけん 馬券"
"ばこ 箱"
"ばさし 馬刺"
"ばさんち 馬産地"
"ばし 橋"
"ばしゃ 馬車"
"ばしゃうま 馬車馬"
"ばしゃく 馬借"
"ばしゃみち 馬車道"
"ばしゅ 馬主"
"ばしょ 場所"
"ばしょう 芭蕉"
"ばしょがら 場所柄"
"ばしょく 馬謖"
"ばしょせつ 場所説"
"ばしら 柱"
"ばしん 馬身"
"ばじとうふう 馬耳東風"
"ばじゅつ 馬術"
"ばじょう 馬上 馬乗"
"ばす バス"
"ばすえ 場末"
"ばすけっと バスケット"
"ばすてい バス停"
"ばすれふ バスレフ"
"ばせい 罵声"
"ばぞく 馬賊 馬族"
"ばた 畑"
"ばたー バター"
"ばたい 馬体"
"ばたけ 畠 畑"
"ばち 罸 撥 鉢 罰"
"ばちがい 場違い"
"ばちすもく バチス目"
"ばちゅう 馬柱"
"ばっか 麦価"
"ばっかすきほう バッカス記法"
"ばっきょ 抜去"
"ばっきん 罰金"
"ばっきんがく 罰金額"
"ばっきんけい 罰金刑"
"ばっく バック"
"ばっくみらー バックミラー"
"ばっこ 跋扈"
"ばっさい 伐採 伐裁"
"ばっさつ 抜刷"
"ばっさり バッサリ"
"ばっし 抜糸 抜歯"
"ばっしゅつ 伐出"
"ばっしょう 跋渉"
"ばっじ バッジ"
"ばっすい 抜粋"
"ばっそく 罰則"
"ばった 飛蝗"
"ばったい 罰退"
"ばっち バッチ"
"ばってき 抜てき 抜擢"
"ばってん 罰点"
"ばっと バット"
"ばっとう 抜刀 伐倒"
"ばっふぁー バッファー"
"ばっぷ 罰符"
"ばっぽん 抜本"
"ばつ 魃 罸 拔 末 跋 伐 筏 閥 抜 × 罰"
"ばついっぱん 罰一般"
"ばつぐん 抜群"
"ばつぞく 閥族"
"ばつたい 罰退"
"ばつだ 罰打"
"ばつばつ ××"
"ばつぼく 伐木"
"ばてい 馬蹄 馬丁"
"ばとう 馬頭 罵倒"
"ばとうきん 馬頭琴"
"ばどみんとん バドミントン"
"ばな 鼻"
"ばなし 話"
"ばなはかん バナハ環"
"ばなはくうかん バナハ空間"
"ばなれ 離れ 場慣れ"
"ばにく 馬肉"
"ばにら バニラ"
"ばぬしめい 馬主名"
"ばね 発条 バネ"
"ばば 婆 馬場"
"ばばぐち 馬場口"
"ばばじる 婆汁"
"ばばんれんふく 馬番連複"
"ばふん 馬糞"
"ばぼう 馬房"
"ばぼうさく 馬防柵"
"ばめい 馬名"
"ばめん 場面"
"ばめんごと 場面毎"
"ばや 速 早"
"ばら バラ 原 薔薇"
"ばらき 原木"
"ばらのぷすもく バラノプス目"
"ばらんす バランス"
"ばり 罵詈 針"
"ばりえーしょん バリエーション"
"ばりき 馬力"
"ばる 原"
"ばるかん 巴爾幹"
"ばるく バルク"
"ばるぶ バルブ"
"ばれーぼーる バレーボール"
"ばれい 馬齢"
"ばれいしょ 馬鈴薯"
"ばれえ バレエ"
"ばれん 馬連"
"ばれんたいん バレンタイン"
"ばろめーた バロメータ"
"ばん 阪 鷭 鑁 輓 蠻 絆 礬 旙 旛 悗 播 萬 挽 板 坂 伴 蕃 蛮 磐 判 万 盤 晩 版 番"
"ばんあれんたい バンアレン帯"
"ばんえつ 磐越"
"ばんか 晩歌 晩夏 挽歌"
"ばんかい 挽回"
"ばんかん 万感"
"ばんがい 番街 番外"
"ばんき 晩期"
"ばんきょ 蟠踞"
"ばんきん 鈑金 板金"
"ばんぎく 晩菊"
"ばんくーばー 晩香坡"
"ばんくみ 版組"
"ばんぐみ 番組"
"ばんぐみだい 番組第"
"ばんぐみはつ 番組初"
"ばんけん 番犬"
"ばんけんもと 版権元"
"ばんこ 萬古"
"ばんこう 蛮行 磐高"
"ばんこく 盤谷 万国"
"ばんこん 晩婚"
"ばんご 番後"
"ばんごう 番号"
"ばんごうごと 番号毎"
"ばんごうじゅん 番号順"
"ばんごうぼ 番号簿"
"ばんごうわく 番号枠"
"ばんごはん 晩御飯"
"ばんさい 磐西"
"ばんさく 万策"
"ばんさん 晩餐"
"ばんざい 万歳"
"ばんしつ 盤質"
"ばんしゃく 晩酌"
"ばんしゅう 播州 晩秋"
"ばんしゅん 晩春"
"ばんしょ 番所 板書"
"ばんしょう 万象 晩鐘 番匠 万障"
"ばんしんどう 板振動"
"ばんじ 万事"
"ばんじきゅうす 万事窮す"
"ばんじゃく 盤石 磐石"
"ばんじょ 磐女"
"ばんじょう 盤上 万丈"
"ばんじん 万人"
"ばんすい 晩翠"
"ばんすいそうどう 晩翠草堂"
"ばんすう 番数"
"ばんせい 万世 晩成"
"ばんせん 番宣 番線"
"ばんせんけいゆ 播但線経由"
"ばんぜん 万全"
"ばんそう 晩霜 伴奏"
"ばんそうこう 絆創膏 ばん創膏"
"ばんたん 播但 盤端 万端"
"ばんだ 万朶"
"ばんだい 磐梯 万代 番台"
"ばんだいさん 磐梯山"
"ばんち 番値 番地"
"ばんちゃ 番茶"
"ばんちょう 番長 番丁"
"ばんづけ 番付"
"ばんて 番手"
"ばんとう 蛮刀 晩冬 番頭"
"ばんど バンド"
"ばんどう 坂東"
"ばんない 坂内 判内"
"ばんなぐろ 花畔"
"ばんなん 万難"
"ばんにん 万人 番人"
"ばんねん 晩年"
"ばんの 伴野 坂野 番野"
"ばんのう 万能"
"ばんのうかぎ 万能鍵"
"ばんのうざお 万能竿"
"ばんのうやく 万能薬"
"ばんば 輓馬"
"ばんばん バンバン"
"ばんばんざい 万万歳"
"ばんばんじー 棒棒鶏 棒々鶏"
"ばんぱく 万博"
"ばんぱん 万般"
"ばんぶつ 万物"
"ばんぷう 蛮風"
"ばんべつ 万別"
"ばんぺい 番兵"
"ばんみん 万民"
"ばんめ 番目"
"ばんめし 晩飯"
"ばんめん 盤面"
"ばんゆう 蛮勇 万有"
"ばんらい 万雷"
"ばんり 萬里 万里"
"ばんりのちょうじょう 万里の長城"
"ばんれいしか バンレイシ科"
"ぱ 羽 播 破 波"
"ぱーせんと ％ パーセント"
"ぱーそなりてぃ パーソナリティ"
"ぱーそなる パーソナル"
"ぱーてぃ パーティ"
"ぱーてぃー パーティー"
"ぱーと パート"
"ぱーとなー パートナー"
"ぱーふぇくと パーフェクト"
"ぱーみる ‰"
"ぱーる パール"
"ぱあそう 八索"
"ぱい Π 盃 π パイ 配 杯 敗 牌"
"ぱいちゅー 白酒"
"ぱいなっぷるもく パイナップル目"
"ぱいぷや ぱいぷ屋"
"ぱいろっと パイロット"
"ぱお 包"
"ぱおず 包子"
"ぱぎょう パ行"
"ぱく 駮 愽 博 泊 拍 朴"
"ぱこ 箱"
"ぱじゃま パジャマ"
"ぱす パス"
"ぱすた パスタ"
"ぱずる パズル"
"ぱそこん パソコン"
"ぱそつう パソ通"
"ぱたーん パターン"
"ぱち 八"
"ぱちんこ パチンコ"
"ぱっく パック"
"ぱっと パット"
"ぱっど パッド"
"ぱつ 發 発"
"ぱなま 巴奈馬"
"ぱなまそうもく パナマソウ目"
"ぱにっく パニック"
"ぱねりすと パネリスト"
"ぱねる パネル"
"ぱのらま パノラマ"
"ぱぱ パパ"
"ぱふぉーまんす パフォーマンス"
"ぱらぐらふ パラグラフ"
"ぱらびおん パラビオン"
"ぱらめーたー パラメーター"
"ぱららいざー パラライザー"
"ぱり 巴里"
"ぱりっこ パリっ子"
"ぱる パル"
"ぱるしぇ パルシェ"
"ぱるすはば パルス幅"
"ぱるぷ パルプ"
"ぱれす パレス"
"ぱれっと パレット"
"ぱろでぃ パロディ"
"ぱわー パワー"
"ぱん 播 幇 麺麭 板 搬 パン 版"
"ぱんく パンク"
"ぱんこ パン粉"
"ぱんだ パンダ"
"ぱんつ パンツ"
"ぱんてぃ パンティ"
"ぱんどら パンドラ"
"ぱんふれっと パンフレット"
"ぱんぷきん パンプキン"
"ぱんぷす パンプス"
"ひ 氷 毘 簸 轡 髀 鞴 鞁 霏 鄙 贔 豼 貔 譬 裨 蜚 蓖 菲 臂 紕 秕 祕 痞 狒 梭 杼 朏 暃 昜 妣 俾 丕 桧 干 腓 脾 砒 灯 檜 疲 泌 匪 庇 斐 卑 痺 披 妃 批 碑 誹 悲 否 罷 緋 皮 肥 陽 樋 扉 避 秘 被 飛 彼 火 比 費 非 日"
"ひーた ヒータ"
"ひーろー ヒーロー"
"ひあい 悲哀"
"ひあたり 日当たり"
"ひあっしゅくりゅう 非圧縮流"
"ひあぶり 火焙り"
"ひい 贔"
"ひいき 贔屓"
"ひいじじ 曽祖父"
"ひいまご 曾孫"
"ひいらぎ 柊"
"ひいれしき 火入式"
"ひいろ 緋色"
"ひう 日宇"
"ひうち 燧 火打ち"
"ひうちやま 火打山"
"ひうら 日浦 火浦 樋浦"
"ひうん 非運 悲運"
"ひえ 稗"
"ひえい 飛影 比叡 飛栄"
"ひえいざん 比叡山"
"ひえき 裨益 桧枝岐"
"ひえこみ 冷えこみ"
"ひえしょう 冷え症"
"ひえじんじゃ 日枝神社"
"ひえだ 檜枝 稗田"
"ひえづ 日吉津"
"ひえぬき 稗貫"
"ひえん 飛燕"
"ひおき 日置"
"ひおとこ 火男"
"ひか 皮下"
"ひかいいんあて 非会員宛"
"ひかえ 控え 控"
"ひかえしつ 控室"
"ひかがみ 膕"
"ひかき 火掻き"
"ひかく 飛角 皮革 比較"
"ひかくてきらく 比較的楽"
"ひかげ 日影 日蔭 日陰"
"ひかげもの 日陰者"
"ひかげん 火加減"
"ひかた 干潟"
"ひかみ 氷上"
"ひかり 芒 光"
"ひかりかんれん 光関連"
"ひかりきのうざいりょうぶ 光機能材料部"
"ひかりきゅうしゅう 光吸収"
"ひかりぎじゅつ 光技術"
"ひかりぎょうこ 光凝固"
"ひかりこうかん 光交換"
"ひかりこうがく 光工学"
"ひかりしげき 光刺激"
"ひかりしゅうせき 光集積工学"
"ひかりしゅうせきこうがく 光集積工学"
"ひかりしゅつりょく 光出力"
"ひかりしんごう 光信号"
"ひかりじき 光磁気"
"ひかりじゅようき 光受容器"
"ひかりじょうほう 光情報"
"ひかりそうさ 光走査"
"ひかりたんし 光端子"
"ひかりだい 光台"
"ひかりちゅうせいし 光中性子"
"ひかりつうしん 光通信"
"ひかりでんち 光電池"
"ひかりどけい 光時計"
"ひかりはつでん 光発電"
"ひかりはんのう 光反応"
"ひかりふぁいばあ 光ファイバー"
"ひかる 熈 光"
"ひかわ 斐川 簸川 氷川"
"ひかわじんじゃ 火川神社"
"ひかわまる 氷川丸"
"ひかん 避寒 悲観"
"ひかんさん 比換算"
"ひが 彼我 此我 比嘉"
"ひがい 鰉 被害"
"ひがいがく 被害額"
"ひがいとどけ 被害届"
"ひがえり 日帰り"
"ひがき 檜垣 桧垣"
"ひがけ 日掛け"
"ひがさ 日傘"
"ひがし 干菓子 東"
"ひがしあおもり 東青森"
"ひがしあおやま 東青山"
"ひがしあわくら 東粟倉"
"ひがしいけ 東池"
"ひがしいけぶくろ 東池袋"
"ひがしいず 東伊豆"
"ひがしいずも 東出雲"
"ひがしいせざき 東伊勢崎"
"ひがしいちき 東市来"
"ひがしいばらき 東茨城"
"ひがしいややま 東祖谷山"
"ひがしいわい 東磐井"
"ひがしうすき 東臼杵"
"ひがしうめだえき 東梅田駅"
"ひがしうら 東浦"
"ひがしうわ 東宇和"
"ひがしえき 東駅"
"ひがしお 東尾"
"ひがしおうめ 東青梅"
"ひがしおおぎじま 東扇島"
"ひがしおおさか 東大阪"
"ひがしおおしまかん 東大島間"
"ひがしおおじ 東大路"
"ひがしおかざき 東岡崎"
"ひがしかいがん 東海岸"
"ひがしかぐら 東神楽"
"ひがしかすがい 東春日井"
"ひがしかぜ 東風"
"ひがしかた 東方"
"ひがしかつしか 東葛飾"
"ひがしかながわ 東神奈川"
"ひがしかも 東加茂"
"ひがしかるいざわ 東軽井沢"
"ひがしかわ 東川"
"ひがしかわぐち 東川口"
"ひがしかん 東館"
"ひがしかんとう 東関東"
"ひがしかんばら 東蒲原"
"ひがしがわ 東側"
"ひがしきたざわ 東北沢"
"ひがしきゅうしゅうちく 東九州地区"
"ひがしきりゅう 東桐生"
"ひがしぎんざ 東銀座"
"ひがしく 東区"
"ひがしくしろ 東釧路"
"ひがしくち 東口"
"ひがしくにさき 東国東"
"ひがしくびき 東頚城"
"ひがしくるめ 東久留米"
"ひがしぐち 東口"
"ひがしこう 東高"
"ひがしこうえん 東公園"
"ひがしこうえんじ 東高円寺"
"ひがしこうべ 東神戸"
"ひがしこがねい 東小金井"
"ひがしこむすび 東小結"
"ひがししいじ 東椎路"
"ひがししおじり 東塩尻"
"ひがししずおか 東静岡"
"ひがししらかわ 東白川"
"ひがししりいけ 東尻池"
"ひがしじま 東島"
"ひがしじゅうじょう 東十条"
"ひがしじゅうりょう 東十両"
"ひがしじょうもんじん 東縄文人"
"ひがしすみよし 東住吉"
"ひがしせきわけ 東関脇"
"ひがしせふり 東背振"
"ひがしせんだいかん 東仙台間"
"ひがしせんだちく 東千田地区"
"ひがしせんだまち 東千田町"
"ひがしそのぎ 東彼杵"
"ひがしたがわ 東田川"
"ひがしたてやま 東館山"
"ひがしだ 東田"
"ひがしちく 東地区"
"ひがしちくま 東筑摩"
"ひがしちちぶ 東秩父"
"ひがしちば 東千葉"
"ひがしちょう 東町"
"ひがしつがる 東津軽"
"ひがしつの 東津野"
"ひがしでぐち 東出口"
"ひがしとう 東棟"
"ひがしとうきょう 東東京"
"ひがしところざわ 東所沢"
"ひがしとつか 東戸塚"
"ひがしとなみ 東礪波 東砺波"
"ひがしどうり 東通"
"ひがしなか 東中"
"ひがしなかす 東中州"
"ひがしなかの 東中野"
"ひがしながさきちく 東長崎地区"
"ひがしなだ 東灘"
"ひがしなだしんごうじょ 東灘信号所"
"ひがしなりた 東成田"
"ひがしなるせ 東成瀬"
"ひがしにほん 東日本"
"ひがしね 東根"
"ひがしの 東野"
"ひがしのしろ 東能代"
"ひがしはま 東浜"
"ひがしはら 東原"
"ひがしはりだしおおぜき 東張出大関"
"ひがしはりだしせきわけ 東張出関脇"
"ひがしはんきゅう 東半球"
"ひがしはんのう 東飯能"
"ひがしはんぶん 東半分"
"ひがしばる 東原"
"ひがしひろしま 東広島"
"ひがしふしみ 東伏見"
"ひがしふじ 東富士"
"ひがしべついん 東別院"
"ひがしほんがんじまえ 東本願寺前"
"ひがしまいづる 東舞鶴"
"ひがしまち 東町"
"ひがしまつうら 東松浦"
"ひがしまつやま 東松山"
"ひがしむき 東向き"
"ひがしむこうじま 東向島"
"ひがしむら 東村"
"ひがしむろ 東牟婁"
"ひがしむろらん 東室蘭"
"ひがしめいはん 東名阪"
"ひがしもろかた 東諸県"
"ひがしもん 東門"
"ひがしやつしろ 東八代"
"ひがしやま 東山"
"ひがしやまこ 東山湖"
"ひがしやまと 東大和"
"ひがしやまなし 東山梨"
"ひがしゆり 東由利"
"ひがしよか 東与賀"
"ひがしよしの 東吉野"
"ひがしよどがわ 東淀川"
"ひがしりしり 東利尻"
"ひがしわかやま 東和歌山"
"ひがた 干潟"
"ひがら 日柄"
"ひがわり 日変わり"
"ひがん 彼岸 悲願"
"ひがんばな 彼岸花"
"ひき 挽 曳 日置 蟆 蟇 引き 悲喜 比企 疋 引 匹"
"ひきあい 引合い 引合"
"ひきあげ 引き上げ"
"ひきあげせん 引上線"
"ひきあて 引当"
"ひきい 率い"
"ひきうけ 引受け 引受 引き受け"
"ひきおとし 引き落とし"
"ひきかえ 引替 引換 引き換え"
"ひきかえけん 引替券 引換券 引き換え券"
"ひきかた 弾き方"
"ひきかたり 弾き語り"
"ひきがえる 蟾蜍 蟇蛙"
"ひきがたり 弾き語り"
"ひきがね 引金 引き金"
"ひきげき 悲喜劇"
"ひきこみ 引込"
"ひきさげ 引下げ"
"ひきざん 引算 引き算"
"ひきしお 引き潮"
"ひきすう 引数"
"ひきた 疋田 引田"
"ひきたて 引立て"
"ひきだ 疋田 引田"
"ひきだし 抽斗 袖斗 抽出 引出し 引き出し"
"ひきだししき 引出式"
"ひきち 引地"
"ひきつぎ 引きつぎ 引き継ぎ"
"ひきつけ 痙"
"ひきつづき 引続き"
"ひきつる 痙"
"ひきて 引き手"
"ひきでもの 引出物"
"ひきとりさき 引取先"
"ひきとりじょうけん 引取条件"
"ひきとりて 引取手"
"ひきとりにん 引取人"
"ひきど 引戸"
"ひきにく 挽肉"
"ひきにげ 轢き逃げ ひき逃げ"
"ひきのばしき 引伸機"
"ひきみ 匹見"
"ひきめ 蟇目"
"ひきゃく 飛脚"
"ひきゅうせん 飛球線"
"ひきゅうほうこう 飛球方向"
"ひきょう 秘境 卑怯"
"ひきょうもの 卑怯者"
"ひきょり 飛距離"
"ひきわけ 引分"
"ひきわたし 引渡 引渡し"
"ひきん 卑近"
"ひぎ 秘戯 秘儀 秘技"
"ひぎしゃ 被疑者"
"ひぎょう 罷業"
"ひぎんえんしゃしん 非銀塩写真"
"ひく 佗 牽 攣 − 低"
"ひくいどり 火喰鳥"
"ひくう 非空"
"ひくうてい 飛空挺 飛空艇"
"ひくつ 卑屈"
"ひくて 引く手"
"ひくま 曵馬"
"ひくめ 低目"
"ひぐち 樋 樋口"
"ひぐちうち 火口内"
"ひぐま 羆 日熊 ヒグマ"
"ひぐらし 蜩"
"ひぐれ 日暮れ"
"ひけぎわ 引け際"
"ひけた 引田"
"ひけつ 否決 秘訣"
"ひけね 引け値"
"ひけん 比肩 披見 被験"
"ひけんしゃ 被検者"
"ひけんじゃ 被検者 被験者 披験者"
"ひげ 髯 鬚 卑下 髭"
"ひげい 秘芸"
"ひげき 悲劇"
"ひげづら 髭面"
"ひげね 鬚根 ひげ根"
"ひこ 秘湖 曾孫 比古 彦"
"ひこう 肥厚 秘孔 飛光 飛講 非行 飛行"
"ひこうき 飛行"
"ひこうきぐも 飛行機雲"
"ひこうし 飛行士"
"ひこうじょうあと 飛行場跡"
"ひこうせき 飛行石"
"ひこうせん 飛行船"
"ひこうてい 飛行艇"
"ひこえ 彦衛"
"ひこく 被告"
"ひこさぶろう 彦三郎"
"ひこしまぐち 彦島口"
"ひこじま 彦島"
"ひこたろう 彦太郎"
"ひこつ 腓骨"
"ひこね 彦根"
"ひこの 彦野"
"ひこのじょう 彦之丞"
"ひこばえ 蘖"
"ひこぼし 彦星"
"ひご 蜚語 籖 籤 飛語 卑語 庇護 肥後"
"ひごう 非合"
"ひごと 日毎"
"ひごろ 日頃"
"ひさ 壽 央 尚 寿 久"
"ひさあき 久昭"
"ひさい 被災"
"ひさいし 久石"
"ひさえ 寿江 久恵 久栄 寿恵"
"ひさお 尚生 寿雄 尚夫 寿男 久夫 久男 尚勇 久雄"
"ひさか 桶坂 樋坂 日阪"
"ひさかず 永和 久和"
"ひさかた 久方"
"ひさかたぶり 久方振り 久方振"
"ひさかど 久門"
"ひさかわ 久川"
"ひさき 寿樹"
"ひさきち 久吉"
"ひさく 秘策"
"ひさこ 比佐子 寿子 久子"
"ひさご 蠡 瓠 匏 瓢"
"ひさし 尚志 久司 廂 壽 寿史 央 庇 寿 久志 尚 恒 久"
"ひさした 久下"
"ひさしぶり 久しぶり 久し振り"
"ひさしま 久島"
"ひさたか 尚敬"
"ひさだ 久田"
"ひさつせん 肥薩線"
"ひさと 尚登 尚人 久登 久人"
"ひさとし 尚敏 久敏"
"ひさとみ 久富"
"ひさとめ 久留"
"ひさどめ 久留"
"ひさなお 久尚"
"ひさなが 久長 久永"
"ひさの 久野"
"ひさのぶ 久信"
"ひさのり 尚典 寿則 寿憲 久典 久寛"
"ひさはら 久原"
"ひさはる 尚玄 寿春"
"ひさば 久馬"
"ひさひろ 久浩 久寛"
"ひさびさ 久々"
"ひさべつぶらくみん 被差別部落民"
"ひさま 久馬"
"ひさまつ 久松"
"ひさみち 久道"
"ひさみつ 久光"
"ひさみどう 久美堂"
"ひさむら 久村"
"ひさめ 氷雨"
"ひさもと 久本"
"ひさや 久弥 久屋"
"ひさやま 久山"
"ひさよ 久代"
"ひさよし 久吉 久佳"
"ひさん 飛散 非惨 悲惨"
"ひざ 膝"
"ひざうえ 膝上"
"ひざかんせつ 膝関節"
"ひざがしら 膝頭"
"ひざこぞう 膝小僧"
"ひざし 陽射し 陽射 日差 日射し 日ざし 日差し"
"ひざした 膝下"
"ひざまくら 膝枕"
"ひざもと 膝元 ひざ元"
"ひし 蔆 ◇ 菱"
"ひしお 醤"
"ひしかり 菱刈"
"ひしかわ 菱川"
"ひしがた ◇ 菱形"
"ひししょくぶつ 被子植物"
"ひしせん 皮脂腺"
"ひした 菱田"
"ひしだ 菱田"
"ひしつ 皮質"
"ひしと 犇と 緊と"
"ひしぬま 菱沼"
"ひしひし 犇々 緊々"
"ひしまく 皮脂膜"
"ひしむろ 西牟婁"
"ひしゃ 扉車 飛車"
"ひしゃかいしんど 被写界深度"
"ひしゃかく 飛車角"
"ひしゃく 柄杓"
"ひしゃたい 被写体"
"ひしゅ 脾腫 匕首 秘酒"
"ひしょ 避暑 秘書"
"ひしょう 飛翔"
"ひしょうざめ 飛翔鮫"
"ひしょうたい 飛翔体"
"ひしん 皮疹"
"ひじ 日出 樋地 肱 肘"
"ひじあて 肘当"
"ひじうち 肘撃"
"ひじかけ 肘掛"
"ひじかた 土方"
"ひじかたとしぞう 土方歳三"
"ひじかわ 肱川"
"ひじこうげき 肘攻撃"
"ひじてつ 肘鉄"
"ひじでっぽう 肘鉄砲"
"ひじどうかけん 非自動化券"
"ひじゅう 比重"
"ひじゅうふくわ 非重複和"
"ひじゅつ 秘術"
"ひじゅん 批准"
"ひじょ 秘女"
"ひじょう 非情 非常"
"ひじょうぐち 非常口"
"ひじょうとう 非常灯"
"ひじょうに 非常に"
"ひじょうほう 秘情報"
"ひじり 聖"
"ひじりばし 聖橋"
"ひじりばしぐち 聖橋口"
"ひすい 翡翠"
"ひずけ 日付け 日付"
"ひずみ 歪"
"ひずみりつ 歪率"
"ひずみりょう 歪量"
"ひせい 悲悽"
"ひせき 飛跡"
"ひせん 卑賤 非戦"
"ひぜに 日銭"
"ひぜろ 非零"
"ひぜん 肥前"
"ひそ 砒素"
"ひそう 皮層 悲想 皮相 悲壮 悲愴"
"ひそか 密"
"ひそかに 窃"
"ひそみ 顰み"
"ひぞう 脾臓 秘蔵"
"ひぞく 匪賊 卑俗"
"ひた 日田"
"ひたい 額"
"ひたいしょううお 非対象魚"
"ひたいしょうまく 非対称膜"
"ひたき 鶲"
"ひたすら 頓 只管 一向"
"ひたち 肥立 常陸 日立"
"ひたちまくせる 日立マクセル"
"ひたむき 直向"
"ひたん 悲歎 悲嘆"
"ひだ 襞 肥田 樋田 飛騨 飛田"
"ひだい 肥大"
"ひだか 肥高 日高"
"ひだかがわかん 日高川間"
"ひだち 肥立ち"
"ひだね 火種"
"ひだひこやません 日田彦山線"
"ひだまり 陽溜り"
"ひだり 【 （ ＜ 『 「 ← 左"
"ひだりあごした 左顎下"
"ひだりあし 左足"
"ひだりいっぱい 左一杯"
"ひだりうえ 左上"
"ひだりうえすみ 左上隅"
"ひだりうしろ 左後"
"ひだりうで 左腕"
"ひだりえだ 左枝"
"ひだりかた 左肩"
"ひだりかっこ 『 左括弧"
"ひだりかんやくほうそく 左簡約法則"
"ひだりがわ 左側"
"ひだりがわはし 左側端"
"ひだりきんぼう 左近傍"
"ひだりこうほう 左後方"
"ひだりこうりん 左後輪"
"ひだりこし 左腰"
"ひだりさいき 左再帰"
"ひだりした 左下"
"ひだりしたすみ 左下隅"
"ひだりしゃせん 左車線"
"ひだりず 左図"
"ひだりぜんぶ 左前部"
"ひだりぜんぽう 左前方"
"ひだりぜんりん 左前輪"
"ひだりそくほう 左側方"
"ひだりだしゃ 左打者"
"ひだりだせき 左打席"
"ひだりづめ 左詰め"
"ひだりて 左手"
"ひだりてくび 左手首"
"ひだりてんかい 左転回"
"ひだりとうしゅ 左投手"
"ひだりどうろわき 左道路脇"
"ひだりどなり 左隣"
"ひだりなげ 左投げ"
"ひだりのり 左乗"
"ひだりはし 左端"
"ひだりはじ 左端"
"ひだりはんぶん 左半分"
"ひだりはんめん 左半面"
"ひだりひざ 左膝"
"ひだりひじ 左肘"
"ひだりふともも 左太股"
"ひだりぶぶん 左部分"
"ひだりぶんき 左分岐"
"ひだりほうこう 左方向"
"ひだりほほ 左頬"
"ひだりまえ 左前"
"ひだりまえあし 左前脚 左前足"
"ひだりまわり 左回り"
"ひだりみぎはし 左右端"
"ひだりみみ 左耳"
"ひだりむき 左向き"
"ひだりむね 左胸"
"ひだりめ 左目"
"ひだりや ←"
"ひだりやじるし 左矢印"
"ひだりよう 左用"
"ひだりようそ 左要素"
"ひだりよこ 左横"
"ひだりより 左寄り 左寄"
"ひだりわき 左脇"
"ひだん 被弾"
"ひちくじょう 肥畜場"
"ひちそう 七宗"
"ひちゅう 秘中"
"ひちりき 篳篥"
"ひっ 必"
"ひっか 筆禍"
"ひっかけ 引っ掛け"
"ひっき 筆記"
"ひっきぐ 筆記具"
"ひっきたい 筆記体"
"ひっきょう 畢竟"
"ひっけい 必携"
"ひっけん 必見"
"ひっこし 引越 引っ越し 引越し"
"ひっこみ 引込み"
"ひっさつ 必殺"
"ひっさつわざ 必殺技"
"ひっさん 筆算"
"ひっし 必至 必死"
"ひっしゃ 筆写 筆者"
"ひっしゅう 必習 必修"
"ひっしょう 必勝"
"ひっす 必須"
"ひっすい 必衰"
"ひっすかく 必須格"
"ひっせい 畢生"
"ひっせき 筆迹 筆跡"
"ひっそく 逼塞"
"ひっち 筆致"
"ひっちゃく 必着"
"ひっちゅう 筆誅 必中"
"ひっちょう 必聴"
"ひっちょうもの 必聴物"
"ひってき 匹敵"
"ひっと ヒット"
"ひっとう 筆答 筆頭"
"ひっぱい 必敗"
"ひっぱく 逼迫"
"ひっぱつ 必発"
"ひっぱり 引張"
"ひっぽう 筆鋒 筆法"
"ひつ 蹕 謐 篳 櫃 疋 匹 泌 畢 弼 逼 筆 必"
"ひつあつ 筆圧"
"ひつう 悲痛"
"ひつぎ 柩 棺"
"ひつけやく 火付け役"
"ひつじ 日辻 未 羊"
"ひつじかい 羊飼い"
"ひつじさる 坤"
"ひつじゅ 必需"
"ひつじゅん 筆順"
"ひつじょう 必定"
"ひつぜつ 筆舌"
"ひつぜん 謐然 □ 必然"
"ひつだん 筆談"
"ひつどく 必読"
"ひつにょう 泌尿"
"ひつねい 謐寧"
"ひつば 弼馬"
"ひつひつ 謐謐"
"ひつめい 筆名"
"ひつよう 必用 必要"
"ひつようあく 必要悪"
"ひつようがく 必要額"
"ひつようなし 必要無"
"ひつりつ 篳篥"
"ひつりょく 筆力"
"ひづけ 日付け 日付"
"ひづけいん 日付印"
"ひづけじゅん 日付順"
"ひづめ 蹄"
"ひてい 飛程 ¬ 否定"
"ひてつ 非鉄"
"ひてんけいかく 飛天計劃"
"ひてんしゅうさ 非点収差"
"ひで 秀 英"
"ひであき 秀章 英亮 英昭 秀明 英明 秀昭"
"ひでいち 秀市"
"ひでお 映夫 周男 秀郎 日出夫 日出男 秀夫 秀男 秀生 英雄 英朗 英夫 秀雄 英男 英生"
"ひでおき 秀起"
"ひでか 秀加 秀香"
"ひでかず 英和 秀一 英一 秀和"
"ひでかつ 英勝 秀勝"
"ひでき 秀己 偉紀 秀起 秀貴 秀規 秀記 秀紀 英樹 英紀 秀樹"
"ひできち 秀吉"
"ひできよ 英清"
"ひでこ 英子 秀子"
"ひでさく 秀作"
"ひでさち 秀幸"
"ひでし 日出志"
"ひでじ 英司 秀司"
"ひでずみ 秀純"
"ひでぞう 秀三"
"ひでたか 秀孝 栄孝 英孝 秀隆"
"ひでただ 秀忠"
"ひでたつ 英辰"
"ひでつぐ 秀嗣 秀次"
"ひでと 日出登 秀仁 英人 秀人"
"ひでとし 秀利 秀年 英敏 秀敏 英俊"
"ひでとも 英智 秀智"
"ひでなお 秀尚"
"ひでのぶ 秀信 英信"
"ひでのり 英紀 秀典 英憲 英典 秀則 秀紀 英則"
"ひではる 英治 英晴"
"ひでひこ 秀彦 英彦"
"ひでひさ 秀寿"
"ひでひと 秀仁 英仁"
"ひでひろ 英宏 秀博 秀宏 秀浩 英裕"
"ひでふみ 秀文"
"ひでまる 秀丸"
"ひでみ 秀実 英実 英美 英巳 秀美"
"ひでみつ 秀光 英光"
"ひでや 日出谷 秀也 英也 英哉 秀哉"
"ひでやす 英育 秀育 秀康"
"ひでゆき 秀行 秀幸 英行 英幸 英之 秀之"
"ひでよ 秀世 英世"
"ひでよし 秀吉 秀善"
"ひでより 秀頼"
"ひでり 魃 旱 日照り"
"ひでろう 秀郎"
"ひでん 秘伝"
"ひでんか 比電荷"
"ひと 壹 弌 他人 女 壱 ヒト 史 仁 一 人"
"ひとあいて 人相手"
"ひとあき 仁明"
"ひとあし 一足"
"ひとあじ 一味"
"ひとあつめ 人集め"
"ひとあな 一穴"
"ひとあんしん 一安心"
"ひといがい 人以外"
"ひといき 一息"
"ひといじょう 人以上"
"ひといちばい 人一倍"
"ひとう 秘湯"
"ひとうひょうば 被投票馬"
"ひとえ 單 単 一重"
"ひとえき 一駅"
"ひとかい 人買い"
"ひとかげ 人影"
"ひとかぞく 一家族"
"ひとかど 一廉"
"ひとからげ 一絡"
"ひとかわ 一皮"
"ひとかん 一缶"
"ひとがき 人垣"
"ひとがた 人型"
"ひとがら 人柄"
"ひとがんばり 一頑張り"
"ひときり 人斬り"
"ひとく 秘匿"
"ひとくい 人食"
"ひとくいじんしゅ 人喰い人種"
"ひとくぎり 一区切り"
"ひとくち 一口"
"ひとくふう 一工夫"
"ひとくみ 一組"
"ひとくら 一庫"
"ひとくろう 一苦労"
"ひとけ 人気"
"ひとけた 一桁"
"ひとこえ 一声"
"ひとこきゅう 一呼吸"
"ひとこじん 人個人"
"ひとこと 一言"
"ひとこま 一齣"
"ひところ ひと頃 一頃"
"ひとごころ 人心"
"ひとごと 他人事 人事"
"ひとごみ 人混 人混み"
"ひとさしゆび 人差し指 人指し指 人差指"
"ひとさま 人様"
"ひとさら 一皿"
"ひとざいさん 一財産"
"ひとざと 人里"
"ひとし 仁史 斎 倫 斉 仁司 準 仁志 均 等 仁"
"ひとしい 等しい"
"ひとしお 一入"
"ひとしごと 一仕事"
"ひとしだい 人次第"
"ひとしな 一品"
"ひとしなみ 等し並み"
"ひとしょうぶ 一勝負"
"ひとしれず 人知れず"
"ひとじしん 人自身"
"ひとじたい 人自体"
"ひとじち 人質"
"ひとじに 人死"
"ひとすじ 一筋"
"ひとすじなわ 一筋縄"
"ひとせだい 一世代"
"ひとぜんいん 人全員"
"ひとぜんたい 人全体"
"ひとたち 人達"
"ひとたば 一束"
"ひとたび 一度"
"ひとたま 一玉"
"ひとたまり 一溜り"
"ひとだかり 人集り"
"ひとだすけ 人助け"
"ひとだま 人魂"
"ひとだんらく 一段落"
"ひとちがい 人違い"
"ひとつ 非凸 １つ 一つ"
"ひとつき 一月"
"ひとつきほど 一月程"
"ひとつぎ 一木"
"ひとつばし 一ツ橋 一ッ橋 一橋"
"ひとつぶ 一粒"
"ひとつまつ 一松"
"ひとつまみ 一摘み"
"ひとつら 一連 一列 一行"
"ひとづかい 人使い"
"ひとづま 人妻"
"ひとていど 人程度"
"ひとで 人出 人手"
"ひととおり 一通り"
"ひととき 一時"
"ひととせ 稘 一年"
"ひととなり 為人"
"ひとどうし 人同士 人同志"
"ひとどおり 人通り"
"ひとなど 人等"
"ひとなみ 人並 人波"
"ひとなり 仁成"
"ひとにぎり 一握り"
"ひとのみ 一飲み"
"ひとはこ 一箱"
"ひとはしり 一走り"
"ひとはた 一旗"
"ひとはだ 人肌"
"ひとはらん 一波乱"
"ひとばしら 人柱"
"ひとばん 一晩"
"ひとぱっく 一パック"
"ひとひとり 人一人"
"ひとひねり 一ひねり 一捻り"
"ひとひら 一枚 一片"
"ひとびと 人びと 人々"
"ひとふくろ 一袋"
"ひとふで 一筆"
"ひとふでがき 一筆書 一筆書き"
"ひとぶそく 人不足"
"ひとへや 一部屋"
"ひとま 一間"
"ひとまえ 人前"
"ひとまく 一幕"
"ひとまね 人真似"
"ひとまろ 一麿 人麿 人麻呂"
"ひとまわり 一回り"
"ひとみ 一美 人見 仁美 瞳"
"ひとみごくう 人身御供"
"ひとみしり 人見知り"
"ひとみすいしょう 瞳水晶"
"ひとむかし 一昔"
"ひとむね 一棟"
"ひとむら 一叢"
"ひとめ ひと眼 一目 人目"
"ひとめいわく 人迷惑"
"ひとめぼれ 一目惚れ"
"ひともじ 人文字 一文字"
"ひともなげ 人も無げ"
"ひともんちゃく 一悶着"
"ひとやく 一役"
"ひとやすみ 一休み"
"ひとやま 一山"
"ひとよ 一夜"
"ひとよぎり 一節切"
"ひとよし 人吉"
"ひとり 獨り 独 独り １人 一人"
"ひとりあたり 一人当"
"ひとりあるき 一人歩き"
"ひとりいっさつ 一人一殺"
"ひとりうき 一人浮き"
"ひとりうち 一人打ち"
"ひとりぐらし 一人暮らし"
"ひとりごと 一人言 独り言"
"ひとりしずみ 一人沈み"
"ひとりじめ 独り占め 一人占め"
"ひとりずまい 一人住まい"
"ひとりせんよう 一人専任"
"ひとりたび 一人旅"
"ひとりだち 一人立"
"ひとりっこ 一人っ子"
"ひとりぼっち 一人法師"
"ひとりむすめ 一人娘"
"ひとりよがり 一人善がり 独り善がり"
"ひどう 非道"
"ひどのらか ヒドノラ科"
"ひどらすちすあか ヒドラスチス亜科"
"ひどり 日取り"
"ひどろすたきすもく ヒドロスタキス目"
"ひな 鄙 雛"
"ひない 比内"
"ひないどり 比内鶏"
"ひながた ひな型 ひな形 雛形 雛型"
"ひなこ 比奈子 日名子 日向子"
"ひなずし 雛鮨"
"ひなせ 日生"
"ひなた 日向"
"ひなどり 雛鳥"
"ひなまつり 雛祭"
"ひなもと 雛元"
"ひならず 日ならず"
"ひならずして 日ならずして"
"ひなわじゅう 火縄銃"
"ひなん 避難 非難"
"ひなんじょ 避難所"
"ひにく 髀肉 皮肉"
"ひにげんてき 非人間的"
"ひにち 日日 日々"
"ひにゅう 泌乳"
"ひにん 避妊 否認 非人"
"ひね 陳"
"ひねこびる 陳こびる"
"ひねしょうが 陳生姜"
"ひねつ 比熱"
"ひねの 日根野"
"ひねり 捻り"
"ひの 火野 日野"
"ひのいり 日入"
"ひのえ 丙"
"ひのえいぬ 丙戌"
"ひのえうま 丙午"
"ひのえさる 丙申"
"ひのえたつ 丙辰"
"ひのえとら 丙寅"
"ひのえね 丙子"
"ひのえまた 檜枝岐 桧枝岐"
"ひのおか 日ノ岡"
"ひのかげ 日之影"
"ひのき 檜 桧"
"ひのきぶたい 桧舞台"
"ひのくち 樋ノ口"
"ひのくま 日隈"
"ひのこ 火の粉"
"ひのたま 火の玉"
"ひので 日之出 日出 日の出"
"ひのと 丁"
"ひのとい 丁亥"
"ひのとう 丁卯"
"ひのとうし 丁丑"
"ひのととり 丁酉"
"ひのとひつじ 丁未"
"ひのとみ 丁巳"
"ひのとり 火の鳥"
"ひのはら 桧原"
"ひのはる 日之春"
"ひのべ 日延べ"
"ひのまる 日の丸"
"ひのみさき 日御崎"
"ひのめ 日の目"
"ひのもと 日の本"
"ひはく 皮帛"
"ひはなち 樋放"
"ひはら 日原"
"ひはん 批判"
"ひば 比婆"
"ひばい 非売"
"ひばく 被縛 飛瀑 被爆 被曝"
"ひばし 火箸"
"ひばしら 火柱"
"ひばち 火鉢"
"ひばな 火花"
"ひばら 脾腹 檜原 桧原"
"ひばり 雲雀"
"ひばん 非番"
"ひひ 霏霏 比比 狒狒"
"ひひょう 批評"
"ひひょうか 批評家"
"ひび 罅 皹 皸 日日 日比 日々"
"ひびき 響 響き"
"ひびの 日比野"
"ひびや 日比谷"
"ひびややおん 日比谷屋音"
"ひびようかんこくじん 被徴用韓国人"
"ひふ 非負 皮膚"
"ひふえん 皮膚炎"
"ひふかい 皮膚科医"
"ひふがん 皮膚癌"
"ひふく 被覆 被服"
"ひふくきん 腓腹筋"
"ひふくぎ 被覆木"
"ひふびょう 皮膚病"
"ひふみ 日文 一二三"
"ひふやく 皮膚薬"
"ひふん 悲憤"
"ひぶ 日歩"
"ひぶん 碑文 非文"
"ひへい 疲幣 疲斃 疲弊"
"ひほう 秘法 悲報 秘宝"
"ひほんご 日本語"
"ひぼう 篦棒 誹謗"
"ひぼうちゅうしょう 誹謀中傷"
"ひぼし 日干"
"ひぼたん 緋牡丹"
"ひぼん 非凡"
"ひま 隙 閑 暇"
"ひまく 被膜 皮膜"
"ひまし 日増し"
"ひましゆ 蓖麻子油"
"ひまじん 閑人 暇人"
"ひまつ 飛沫"
"ひまつぶし 暇潰し"
"ひまつり 火祭"
"ひまわり 向日葵"
"ひまん 肥満"
"ひまんたい 肥満体"
"ひまんたんどらか ヒマンタンドラ科"
"ひみ 氷見"
"ひみこ 日美子 卑弥呼"
"ひみつ 秘密"
"ひみつり 秘密裏"
"ひみょう 秘妙"
"ひみん 卑民"
"ひむかい 日向"
"ひむら 日村"
"ひむろ 氷室"
"ひめ 媛 姫"
"ひめい 悲鳴"
"ひめかいどう 姫街道"
"ひめかわ 姫川"
"ひめがわ 姫川"
"ひめき 姫木"
"ひめぎみ 姫君"
"ひめこ 姫子"
"ひめさま 姫様"
"ひめしま 姫島"
"ひめしんせん 姫新線"
"ひめじ 姫路"
"ひめじどっきょうだいがく 姫路獨協大学"
"ひめじひがし 姫路東"
"ひめじま 姫嶋"
"ひめど 姫戸"
"ひめの 姫野"
"ひめのき 姫乃樹"
"ひめのぎ 姫丿樹 姫乃樹"
"ひめみや 姫宮"
"ひめん 罷免"
"ひも 綬 紐"
"ひもう 被毛"
"ひもく 皮目 費目"
"ひもじ 火文字"
"ひもじょう 紐状"
"ひもち 日持ち"
"ひもと 火元"
"ひもの 干物"
"ひもよう 紐用"
"ひもんや 碑文谷"
"ひゃく 辟 襞 岶 百"
"ひゃくい 百位"
"ひゃくえん 百円"
"ひゃくえんだま 百円玉"
"ひゃくおく 百億"
"ひゃくがい 百害"
"ひゃくぎょう 百行"
"ひゃくげん 百元"
"ひゃくごぎんこう 百五銀行"
"ひゃくしきしてい 百式司偵"
"ひゃくしきゆそうき 百式輸送機"
"ひゃくしゅうねん 百周年"
"ひゃくしゅつ 百出"
"ひゃくしょう 百勝 百姓"
"ひゃくじゅう 百獣"
"ひゃくじゅうおう 百獣王"
"ひゃくすうじゅう 百数十"
"ひゃくせん 百戦 百選"
"ひゃくそく 百足"
"ひゃくたたき 百叩き"
"ひゃくたろう 百太郎"
"ひゃくだいいじょう 百台以上"
"ひゃくてんまんてん 百点満点"
"ひゃくにじゅうにち 百二十日"
"ひゃくにちぜき 百日咳"
"ひゃくにん 百人"
"ひゃくにんひゃくよう 百人百様"
"ひゃくにんりき 百人力"
"ひゃくねん 百年"
"ひゃくばい 百倍"
"ひゃくぶん 百分 百聞"
"ひゃくまい 百枚"
"ひゃくまん 百万"
"ひゃくまんごく 百万石"
"ひゃくまんべん 百万遍"
"ひゃくまんりょう 百萬両 百万両"
"ひゃくめいざん 百名山"
"ひゃくもじ 百文字"
"ひゃくものがたり 百物語"
"ひゃくやく 百薬"
"ひゃくり 百里"
"ひゃくれつ 百裂"
"ひゃくれんぱつ 百連発"
"ひゃっか 百貨 百花 百家 百科"
"ひゃっかい 百回"
"ひゃっかぜんしょか 百科全書家"
"ひゃっかそうめい 百家争鳴"
"ひゃっかん 百貫"
"ひゃっき 百鬼"
"ひゃっきやぎょう 百鬼夜行"
"ひゃっけん 百間"
"ひゃっぱつ 百発"
"ひゃっぱつひゃくちゅう 百発百中"
"ひゃっぴょう 百票"
"ひゃっぽ 百歩"
"ひやあせ 冷汗"
"ひやく 秘薬 飛躍"
"ひやけ 日焼 日焼け"
"ひやけどめ 日焼止め"
"ひやとい 日雇い"
"ひやま 檜山 樋山 桧山 日山"
"ひやみず 冷水"
"ひやみづ 冷水"
"ひやむぎ 冷麦"
"ひややっこ 冷奴"
"ひゅーまん ヒューマン"
"ひゅーむかん ヒューム管"
"ひゅうが 日向"
"ひゅうま 飛雄馬"
"ひゆ 譬喩 比喩"
"ひょう 拍 髟 驫 驃 馮 飆 飃 飄 縹 殍 慓 嫖 凭 冰 冫 雹 平 兵 憑 俵 剽 彪 漂 瓢 氷 標 豹 評 票 表"
"ひょうあつめ 票集"
"ひょうい 憑依 表意"
"ひょういれ 票入"
"ひょうえ 兵衛"
"ひょうおん 氷温 表音"
"ひょうか 氷菓 瓢果 評価"
"ひょうかい 氷海 氷塊 氷解"
"ひょうかおち 評価落"
"ひょうが 氷河"
"ひょうがわ 豹皮"
"ひょうき 氷期 兵機 標記 表記"
"ひょうきょ 憑拠"
"ひょうきん 標金 剽軽"
"ひょうぎ 評議会 評議"
"ひょうぎん 兵銀"
"ひょうぐ 表具"
"ひょうぐみ 表組み"
"ひょうけい 表敬"
"ひょうけいさん 表計算"
"ひょうけいしき 表形式"
"ひょうけつ 評決 表決 票決 氷結"
"ひょうけん 憑険 憑肩"
"ひょうけんさく 表検索"
"ひょうげん 表現"
"ひょうげんよく 表現欲"
"ひょうこう 標高"
"ひょうご 兵庫 標語"
"ひょうごもじ 表語文字"
"ひょうさ 票差"
"ひょうさくさん 氷酢酸"
"ひょうさつ 表札"
"ひょうざん 氷山"
"ひょうし 拍子 表紙"
"ひょうしえ 表紙絵"
"ひょうしき 表式 標識"
"ひょうしきとう 標識灯"
"ひょうしぎ 拍子木"
"ひょうしけんかんとう 表紙兼巻頭"
"ひょうしゃ 評者"
"ひょうしゅつ 表出"
"ひょうしょう 氷床 標章 表象 表彰"
"ひょうじ 憑恃 票時 表示"
"ひょうじかん 表示管"
"ひょうじざか 表示坂"
"ひょうじとう 表示灯"
"ひょうじばん 表示板"
"ひょうじまど 表示窓"
"ひょうじゅん 標準"
"ひょうじゅんあん 標準案"
"ひょうじゅんかかくまい 標準価格米"
"ひょうじゅんがたりろん 標準型理論"
"ひょうじゅんき 標準軌"
"ひょうじゅんきようしゃりん 標準軌用車輪"
"ひょうじゅんけい 標準形"
"ひょうじゅんのう 標準脳"
"ひょうじゅんふく 標準服"
"ひょうじょう 氷上 平調 表情"
"ひょうじょうがわら 評定河原"
"ひょうじわく 表示枠"
"ひょうすう 票数"
"ひょうせつ 剽窃"
"ひょうぜん 瓢然"
"ひょうそう 表装 表層"
"ひょうそく 表側"
"ひょうたん 瓢箪 氷炭"
"ひょうたんなまず 瓢箪鯰"
"ひょうだい 標題 表題"
"ひょうだいさく 表題作"
"ひょうちゃく 漂着"
"ひょうちゅう 氷中 標註 氷柱 標注 表中"
"ひょうちょう 憑弔"
"ひょうてい 標定 評定"
"ひょうていそくど 表定速度"
"ひょうてき 標的"
"ひょうてん 瓢天 評点 氷点"
"ひょうでん 評伝"
"ひょうとう 表頭"
"ひょうど 表土"
"ひょうどう 兵頭 兵藤"
"ひょうはく 漂泊 漂白"
"ひょうばん 評判"
"ひょうばんごう 表番号"
"ひょうひ 表皮"
"ひょうひょう 瓢々"
"ひょうびょう 縹緲 縹眇 縹渺"
"ひょうぶ 兵部"
"ひょうへき 氷壁 表壁"
"ひょうへん 豹変"
"ひょうほう 兵法"
"ひょうほん 標本"
"ひょうほんびん 標本瓶"
"ひょうぼう 標榜 標傍"
"ひょうま 豹馬"
"ひょうめい 表明"
"ひょうめん 表面"
"ひょうめんせき 表面積"
"ひょうめんは 表面波"
"ひょうもくひょう 標目表"
"ひょうよみ 票読み"
"ひょうり 表裏"
"ひょうりゅう 漂流"
"ひょうりゅうき 漂流記"
"ひょうりょう 兵糧 秤量"
"ひょうろう 兵糧"
"ひょうろん 評論"
"ひょうろんか 評論家"
"ひよう 比容 費用"
"ひようしゃ 被用者"
"ひよく 肥沃"
"ひよけ 日除け"
"ひよし 日義 日吉"
"ひよどり 鵯"
"ひより 日和"
"ひよりざき 日和崎"
"ひよりみ 日和見"
"ひら 比良 比呂 衡 片 平"
"ひらあやまり 平謝り"
"ひらい 避雷 飛来 平井"
"ひらいし 平石"
"ひらいしん 避雷針"
"ひらいずみ 平泉"
"ひらいで 平出"
"ひらいわ 平岩"
"ひらお 平生 平尾"
"ひらおか 平岡"
"ひらおよぎ 平泳ぎ"
"ひらか 平賀 平鹿"
"ひらかた 枚方 平形"
"ひらかな 平仮名"
"ひらかわ 平河 平川"
"ひらが 平賀"
"ひらがな 平假名 平仮名"
"ひらき 開 平木"
"ひらきかげん 開き加減"
"ひらきど 開き戸"
"ひらきなおり 開き直り"
"ひらきふう 開き封"
"ひらく 啓"
"ひらこう 平光"
"ひらさわ 平澤 平沢"
"ひらさん 比良山"
"ひらざら 平皿"
"ひらざわ 平澤"
"ひらしま 平嶋 平島"
"ひらしゃいん 平社員"
"ひらぞこ 平底"
"ひらた 枚田 平田"
"ひらたに 平谷"
"ひらつか 平塚"
"ひらつかおき 平塚沖"
"ひらづみ 平積み"
"ひらて 平手"
"ひらで 平出"
"ひらと 平戸"
"ひらとり 平取"
"ひらど 平戸"
"ひらない 平内"
"ひらなか 平中"
"ひらなが 平長"
"ひらぬま 平沼"
"ひらの 平野"
"ひらはら 平原"
"ひらば 平場"
"ひらばせん 平場戦"
"ひらばやし 平林"
"ひらばり 平針"
"ひらばる 平原"
"ひらぶん 平文"
"ひらま 平間"
"ひらまく 平幕"
"ひらまつ 平松"
"ひらみち 平道"
"ひらみつ 平光"
"ひらめ 鮃"
"ひらめき 閃き"
"ひらもと 平本"
"ひらや 平谷 平屋"
"ひらやま 平山"
"ひらゆ 平湯"
"ひりき 非力"
"ひりつ 比率"
"ひりゅう 飛龍 飛竜"
"ひりゅうづ 飛竜頭"
"ひりょう 肥料"
"ひる 晝 簸 蒜 蛭 昼"
"ひるい 比類"
"ひるいち 昼一"
"ひるかわ 蛭川 比留川"
"ひるがた 昼型"
"ひるげ 昼餉"
"ひるこ 蛭子"
"ひるころ 昼頃"
"ひるごはん 昼御飯"
"ひるごろ 昼頃"
"ひるさがり 昼下がり 昼下り 昼下"
"ひるすぎ 昼過ぎ 昼過"
"ひるぜん 蒜山"
"ひるぜんご 昼前後"
"ひるてい 昼定"
"ひるどき 昼時"
"ひるね 昼寝"
"ひるひなか 昼日中"
"ひるま 晝間 昼間"
"ひるまえ 昼前"
"ひるむしろもく ヒルムシロ目"
"ひるめし 昼飯"
"ひるやすみ 昼休み"
"ひれ 鰭"
"ひれい ∝ 非礼 比例"
"ひれき 披瀝"
"ひれつ 卑劣"
"ひれん 悲恋"
"ひろ 大 宥 洪 愽 仭 仞 祐 伯 拓 泰 太 史 拡 央 恕 啓 絋 紘 比呂 浩 廣 寛 宏 洋 尋 博 弘 広 裕"
"ひろあき 洋明 宏顕 弘昭 洋昭 洋晶 祐昭 浩秋 宏昭 裕章 裕昭 広昭 啓明 宏晃 裕明 弘明 広明 祐彰 博明 浩明 浩昭 宏朗 寛明 弘朗 浩晃 博昭 博章 宏明 広章"
"ひろあきら 寛晰"
"ひろいけ 広池"
"ひろいし 広石"
"ひろいもの 拾い物"
"ひろう 疲勞 披露 疲労"
"ひろうえん 披露宴"
"ひろうち 浩内"
"ひろうひがたしゃかい 非浪費型社会"
"ひろえ 広絵 廣江 裕江 浩江 広恵 宏枝 浩恵 宏江 弘枝 広江"
"ひろえん 広縁"
"ひろお 博雄 宏雄 洋夫 洋男 博生 広尾"
"ひろおか 弘岡 広岡"
"ひろか 裕香 祥加"
"ひろかず 裕和 博和 博万 大一 博一 弘一 宏和 泰一 浩和"
"ひろかみ 広神"
"ひろかわ 廣川 紘川 広川"
"ひろがわ 広川"
"ひろき 浩喜 裕毅 浩基 裕紀 弘毅 寛紀 裕貴 博樹 弘城 寛己 央樹 宏喜 宏樹 博己 博紀 浩貴 裕樹 博基 啓樹 洋樹 弘樹 広樹"
"ひろきち 広吉"
"ひろく 広く"
"ひろくに 裕邦"
"ひろぐ 弘具"
"ひろこ 広子 倫子 宙子 欧子 宏子 裕子 弘子 ひろ子 寛子 紘子 博子 浩子"
"ひろこうじ 広小路"
"ひろさか 広坂"
"ひろさき 広崎 弘前"
"ひろさと 宏郷 浩郷"
"ひろさわ 広沢 廣澤 廣沢"
"ひろし 大志 大 弘司 広史 洋司 浩士 宏志 啓志 ひろ志 熙 煕 愽 廣志 廣 裕司 浩司 弘史 央 比呂志 洋史 大史 裕史 弘志 熈 洋 裕志 裕 博志 博士 博司 浩志 広志 広司 啓之 大士 広 宏史 宏司 弘 浩史 博 博史 寛 浩 宏"
"ひろしげ 博茂 浩重 広重"
"ひろしま 広島"
"ひろしまきた 広島北"
"ひろしまぎんこう 廣島銀行"
"ひろしまくれどうろ 広島呉道路"
"ひろしまさん 広島産"
"ひろしまじ 広島路"
"ひろしません 広島戦"
"ひろしまだい 広島大学"
"ひろしまなづけ 広島菜漬"
"ひろしまひがし 広島東"
"ひろしまやき 広島焼"
"ひろしょう 広商"
"ひろじ 宏治 広治"
"ひろせ 廣瀬 広瀬"
"ひろせどおり 広瀬通"
"ひろぜがわ 広瀬川"
"ひろた 廣田 広田"
"ひろたか 宏高 弘崇 宏貴 弘隆 浩孝 浩貴 博孝 宏孝 宏隆"
"ひろたき 広瀧"
"ひろたけ 博丈"
"ひろただ 裕忠 博唯"
"ひろたつ 広達"
"ひろたに 広谷"
"ひろたまみ 広田まみ"
"ひろだい 広島大学 弘大 広大"
"ひろつ 広津"
"ひろつぐ 裕次 博次 博嗣"
"ひろづ 広津"
"ひろでん 広電"
"ひろと 博人 浩登 裕人 寛人"
"ひろとし 宏寿 浩俊"
"ひろとも 寛知 弘具"
"ひろなお 弘直 弘尚"
"ひろなか 弘仲 弘中 広中"
"ひろなが 広長"
"ひろの 広野"
"ひろのぶ 広宣 博宣 博信 裕信 宏伸"
"ひろのみや 浩宮"
"ひろのり 博典 博徳 博則 博紀 浩則 弘法 裕徳"
"ひろはばとびら 広幅扉"
"ひろはら 広原"
"ひろば 広場"
"ひろひこ 飛呂彦 洋彦 裕彦 博彦 浩彦 恕彦"
"ひろひさ 博久 浩寿 浩久 裕久"
"ひろひと 裕人 宏仁 博人 裕仁"
"ひろびろ 広々"
"ひろふみ 洋文 啓文 廣文 洋史 大史 弘史 宏文 博文 裕文 弘文 寛文"
"ひろぶみ 博文 浩史 弘史"
"ひろべ 広部"
"ひろま 広間"
"ひろまさ 弘真 裕真 裕昌 浩正 洋正 宏昌 弘昌 弘征"
"ひろまつ 廣松"
"ひろまど 広窓"
"ひろみ 弘海 寛美 広見 ひろ美 浩巳 弘巳 拡稔 洋美 裕実 博己 裕美 引美 比呂美 宏美 ヒロミ 弘美 浩美 博美 広美"
"ひろみち 寛道 拓路 弘道 博道 広道"
"ひろみつ 宏光 弘光 廣光 博允 博光 博満"
"ひろめ 披露目"
"ひろもち 裕望"
"ひろや 博也 浩也"
"ひろやす 博保 大和 博泰 浩康 裕康 浩靖 容靖 博康 弘安"
"ひろゆき 弘恭 啓之 浩幸 裕由 祐之 弘征 弘行 弘幸 広幸 陽之 博行 広行 宏之 宏幸 裕行 裕幸 博之 弘之 寛之 宏行 洋之 広之 幸展 裕之 博幸 浩之 周行"
"ひろよし 浩喜 博喜 敬昌 弘恭 浩由 博芳 寛善"
"ひわ 比和 鶸 悲話 秘話"
"ひわい 鄙猥 卑わい 卑猥"
"ひわき 樋脇"
"ひわさ 日和佐"
"ひわさき 日和崎"
"ひわたり 日渡 樋渡"
"ひわり 日割り 日割"
"ひわれ 干割れ"
"ひん 牝 蘋 繽 禀 稟 殯 擯 嬪 濱 顰 彬 斌 浜 瀕 賓 頻 品 貧"
"ひんい 品位"
"ひんかい 頻回"
"ひんかく 品格"
"ひんきゃく 賓客"
"ひんきゅう 貧窮 殯宮"
"ひんけい 牝系"
"ひんけつ 貧血"
"ひんこう 品行"
"ひんこん 貧困"
"ひんし 瀕死 品詞"
"ひんしじゅん 品詞順"
"ひんしつ 品質"
"ひんしぶんかいずみ 品詞分解済"
"ひんしゅ 品種"
"ひんしゅく 顰蹙"
"ひんしゅつ 瀕出 頻出"
"ひんじゃ 貧者"
"ひんじゃく 貧弱"
"ひんせい 品性"
"ひんせいげれつ 品正下劣"
"ひんそう 貧相"
"ひんだ 貧打"
"ひんと ヒント"
"ひんど 頻度"
"ひんどじゅん 頻度順"
"ひんにゅう 貧乳"
"ひんば 牝馬"
"ひんばげんていせん 牝馬限定戦"
"ひんばにかんば 牝馬二冠馬"
"ひんばん 品番"
"ひんぱく 頻拍"
"ひんぱつ 頻発"
"ひんぱん 頻繁"
"ひんぴょう 品評"
"ひんぷ 貧富"
"ひんみん 貧民"
"ひんめい 品名"
"ひんもく 品目"
"ひんよう 頻用"
"び 未 贔 靡 麋 縻 糜 糒 瀰 濔 弭 嵋 寐 比 火 媚 枇 毘 微 尾 琵 眉 鼻 日 備 美"
"びーとるず ビートルズ"
"びーなす ビーナス ヴィーナス"
"びーる 麦酒 ビール"
"びーるけん ビール券"
"びい 微意"
"びいしき 美意識"
"びいん 鼻音"
"びう 眉宇"
"びえい 美瑛"
"びえん 鼻炎"
"びおん 微温 鼻音"
"びか 美化"
"びかん 美観"
"びがく 美学"
"びがん 美顔"
"びき 美姫 引 引き 匹"
"びきょ 美挙"
"びきょう 鼻鏡"
"びく 魚籠 魚篭"
"びくう 鼻腔"
"びくに 比丘尼"
"びけい 美形"
"びけいやく 美形役"
"びげいこう 美藝公"
"びげん 微減"
"びこう 微香 微光 鼻腔 鼻孔 尾行 備考"
"びこうけん 美工研"
"びこうせい 微光星"
"びさ 微差"
"びさい 尾西 微細"
"びさん 靡散"
"びさんちほう 備讃地方"
"びざい 微罪"
"びし 微視"
"びしゃもん 毘沙門"
"びしゃもんてん 毘沙門天"
"びしゅ 美酒"
"びしゅう 美醜"
"びしゅく 糜粥"
"びしょう 微小運動 微小 微笑 微少"
"びしょうかく 微小角"
"びしょうじょ 美少女"
"びしょうねん 美少年"
"びしょく 美食"
"びしょくか 美食家"
"びしん 美神 微震"
"びじ 美辞"
"びじく 糜竺"
"びじねす ビジネス"
"びじゃく 微弱"
"びじゅう 鼻汁"
"びじゅつ 美術"
"びじゅつか 美術家"
"びじゅつかんてん 美術館展"
"びじゅつしにゅうもん 美術史入門"
"びじゅつしょう 美術商"
"びじゅつてん 美術展"
"びじょ 美女"
"びじょぎ 美女木"
"びじょん ビジョン"
"びじん 美人"
"びじんぞう 美人像"
"びすます ビスマス"
"びせい 美星 美声"
"びせき 微積"
"びせん 美泉"
"びぜん 靡然 備前"
"びぜんやき 備前焼"
"びそく 尾側 微速"
"びぞう 微増"
"びた 鐚"
"びたい 媚態"
"びだいそつ 美大卒"
"びだくおん 鼻濁音"
"びだん 美談"
"びちく 備蓄"
"びちょう 微調"
"びっくり 吃驚 ！"
"びっこ 跛"
"びっちゅう 備中"
"びっと ビット"
"びつ 謐"
"びてき 美的"
"びてん 美点"
"びでお ビデオ"
"びと 人"
"びとう 尾藤 尾灯"
"びとく 美徳"
"びどう 微動"
"びなん 美男"
"びにーる ビニール"
"びねつ 微熱"
"びねんまく 鼻粘膜"
"びはく 靡薄"
"びばい 美唄"
"びひん 美品 備品"
"びひんひ 備品費"
"びび 靡靡 微々"
"びびたる 微々たる"
"びびる ビビる"
"びふう 美風 微風"
"びふえ 美笛"
"びふか 美深"
"びぶ 尾部"
"びぶん 微分"
"びぶんしょ 美文書"
"びぶんしょう 美文章"
"びへい 靡敝"
"びほう 彌縫 弥縫 備砲"
"びほろ 美幌"
"びぼいん 鼻母音"
"びぼう 備忘 美貌"
"びまん 靡曼 瀰漫"
"びみ 美味"
"びみょう 微妙"
"びめい 美名"
"びもく 眉目"
"びゃく 帛 辟 闢 百 白"
"びゃくい 白衣"
"びゃくだん 白檀"
"びゃくだんもく ビャクダン目"
"びゃくや 白夜"
"びゃっこ 白虎"
"びやく 媚薬"
"びゅう 繆 謬"
"びょう 憑 藐 緲 眇 渺 杪 屏 猫 ″ 票 廟 描 平 苗 錨 鋲 病 秒"
"びょういん 病因 病院"
"びょうかん 秒間"
"びょうが 描畫 描画"
"びょうがい 病害"
"びょうがいちゅう 病害虫"
"びょうき 病期 病気"
"びょうけつ 病欠"
"びょうげん 病源 病原"
"びょうげんきん 病原菌 病源菌"
"びょうげんたい 病源体 病原体"
"びょうこん 病根"
"びょうご 秒後"
"びょうごと 秒毎"
"びょうさ 秒差"
"びょうし 病死 表紙 拍子"
"びょうしつ 病室"
"びょうしゃ 描写"
"びょうしょ 廟所"
"びょうしょう 病床"
"びょうしん 秒針 病身"
"びょうじつ 病日"
"びょうじゃく 病弱"
"びょうじょう 苗条 病状"
"びょうすう 秒数"
"びょうそう 病巣"
"びょうそく 秒速"
"びょうぞう 描像"
"びょうたい 病態"
"びょうたんい 秒単位"
"びょうち 錨地"
"びょうてき 病的"
"びょうとう 病棟"
"びょうどう 平等"
"びょうどういん 平等院"
"びょうにん 病人"
"びょうはく 錨泊"
"びょうびょう 眇眇 渺渺"
"びょうぶ 病部 廟風 屏風"
"びょうぶえ 屏風絵"
"びょうへい 病弊"
"びょうへん 病変"
"びょうぼつ 病没"
"びょうま 病魔"
"びょうめい 病名"
"びょうよみ 秒読 秒読み"
"びょうり 病理"
"びょうりい 病理医"
"びょうれき 病歴"
"びよう 美容"
"びよういん 美容院"
"びようが 描画"
"びよく 尾翼"
"びより 日和"
"びら ビラ"
"びらん 靡爛 糜爛"
"びりやーど ビリヤード"
"びりゅう 微粒"
"びりょう 微量 鼻梁"
"びりょく 微力"
"びる ビル"
"びるま 緬甸"
"びれい 靡麗"
"びろーど 天鵞絨"
"びろうど 天鵞絨"
"びわ 枇杷 琵琶"
"びわこ 琵琶湖"
"びわこぞい 琵琶湖沿"
"びわじま 枇杷島"
"びん 頻 鬢 閔 罎 緡 紊 泯 檳 梹 旻 愍 岷 壜 貧 秤 憫 敏 瓶 便"
"びんいれ 瓶入"
"びんかつ 敏活"
"びんかん 敏感"
"びんかんはだ 敏感肌"
"びんが 頻伽"
"びんぐし 鬢櫛"
"びんご 備後"
"びんしょう 憫笑 敏捷"
"びんじょう 便乗"
"びんすう 便数"
"びんせん 便船 便箋"
"びんぜん 愍然"
"びんそく 敏速"
"びんだい 瓶代"
"びんづめ 瓶詰め 瓶詰"
"びんほう 便法"
"びんぼう 貧乏"
"びんぼうがみ 貧乏神"
"びんぼうくじ 貧乏籤"
"びんぼうしょう 貧乏性"
"びんぼうしょく 貧乏食"
"びんめい 便名"
"びんらん 紊乱 便覧"
"ぴ 日"
"ぴーく ピーク"
"ぴーす ピース"
"ぴあにすと ピアニスト"
"ぴあの ピアノ"
"ぴか ピカ"
"ぴかいち 光一"
"ぴき 匹"
"ぴっち ピッチ"
"ぴっぷ 比布"
"ぴつ 泌"
"ぴょう 票 憑"
"ぴらふ ピラフ"
"ぴらみっど ピラミッド"
"ぴりおど ピリオド"
"ぴるびんさん ピルビン酸"
"ぴん 品 筒"
"ぴんく ピンク"
"ぴんくれでぃ ピンクレディ"
"ぴんず 筒子"
"ぴんち ピンチ"
"ぴんと ピント"
"ぴんふ 平和"
"ふ 鋪 舗 鮒 風 麩 鯆 郛 趺 賻 誣 訃 蜉 苻 腑 罘 畉 溥 榑 桴 柎 拊 巫 孵 坿 咐 俯 俛 俘 仆 麸 孚 傅 生 埠 歩 斧 扶 婦 怖 富 芙 賦 敷 冨 膚 浮 夫 府 阜 赴 普 符 附 腐 譜 布 父 付 負 不"
"ふーど フード"
"ふぁーすと ファースト"
"ふぁい φ"
"ふぁいば ファイバ"
"ふぁいる ファイル"
"ふぁいんだ ファインダ"
"ふぁくしみり ファクシミリ"
"ふぁくとり ファクトリ"
"ふぁしりてい ファシリテイ"
"ふぁっしょん ファッション"
"ふぁみこん ファミコン"
"ふぁみり ファミリ"
"ふぁん 飜 ファン 翻"
"ふぁんくしょん ファンクション"
"ふぁんたじー ファンタジー"
"ふあつ 負圧"
"ふあん 不安"
"ふあんがお 不安顔"
"ふあんげ 不安気"
"ふあんし 不安視"
"ふあんていかい 不安定解"
"ふぃーと 呎 フィート"
"ふぃーどばっく フィードバック"
"ふぃくしょん フィクション"
"ふぃっと フィット"
"ふぃりぴん 比律賓"
"ふぃりぴんかい フィリピン海"
"ふぃるむ フィルム"
"ふぃんらんど 芬蘭"
"ふい 不意"
"ふいうち 不意打"
"ふいちょう 吹聴"
"ふう 諷 瘋 殕 夫 楓 封 風"
"ふうあつ 風圧"
"ふういき 風域"
"ふういん 風韻 封印"
"ふうう 風雨"
"ふううん 風雲"
"ふううんきゅう 風雲急"
"ふううんじ 風雲児"
"ふうえい 風営"
"ふうか 風化"
"ふうかく 風格"
"ふうからいでん 風火雷電"
"ふうかん 風乾"
"ふうが 風雅"
"ふうがい 風害"
"ふうがわり 風変り"
"ふうき 富貴 風紀"
"ふうきょう 風狂"
"ふうきり 封切 封切り"
"ふうぎ 風儀"
"ふうぎり 封切り"
"ふうけい 風景"
"ふうけつ 風穴"
"ふうげつ 風月"
"ふうこう 風向 風光"
"ふうさ 封鎖"
"ふうさい 風災 風采"
"ふうさつ 封殺"
"ふうさぼう 封鎖棒"
"ふうし 諷刺 封止 風刺"
"ふうしえ 風刺絵"
"ふうしかでん 風姿花伝"
"ふうしゃ 風車"
"ふうしゅう 風習"
"ふうしょ 封書"
"ふうしん 風疹"
"ふうしんき 風信器"
"ふうじん 風神"
"ふうすいがい 風水害"
"ふうすいし 風水士 風水師"
"ふうせい 風声 風勢"
"ふうせつ 風説 風雪"
"ふうせん 風船"
"ふうぜん 風前"
"ふうそう 風騒 風霜 風葬"
"ふうそく 風速"
"ふうそくけい 風速計"
"ふうぞく 風俗"
"ふうぞくぎょう 風俗業"
"ふうぞくし 風俗史"
"ふうたい 風帯 風袋"
"ふうたく 風鐸"
"ふうたろう 風太郎"
"ふうち 風致"
"ふうちょう 風鳥 風潮"
"ふうちん 風鎮"
"ふうつう 風通"
"ふうてい 風体"
"ふうてん 瘋癲"
"ふうとう 封筒"
"ふうとうぼく 風倒木"
"ふうど 風土"
"ふうどう 風洞"
"ふうにゅう 封入"
"ふうにゅうざい 封入材"
"ふうは 風波"
"ふうはく 風伯"
"ふうばいか 風媒花"
"ふうばぎゅう 風馬牛"
"ふうひ 封皮"
"ふうひょう 風評"
"ふうび 風靡"
"ふうふ 夫婦"
"ふうふとも 夫婦共"
"ふうふやく 夫婦役"
"ふうぶつ 風物"
"ふうぶつし 風物詩"
"ふうぶん 風聞"
"ふうぼう 風防 風貌"
"ふうま 風魔"
"ふうみ 風味"
"ふうみんしゃ 風眠舎"
"ふうむ 風夢"
"ふうもん 風紋"
"ふうゆ 諷諭"
"ふうらい 風来"
"ふうらいぼう 風来坊"
"ふうりゅう 風流"
"ふうりょう 風量"
"ふうりょく 風力"
"ふうりょくけい 風力計"
"ふうりん 風鈴"
"ふうりんかざん 風林火山"
"ふうれん 風連"
"ふうろう 風浪 封蝋"
"ふうろそうか フウロソウ科"
"ふうろそうぞく フウロソウ属"
"ふうろそうもく フウロソウ目"
"ふうん 不運"
"ふぇーず フェーズ"
"ふぇあ フェア"
"ふぇいす フェイス"
"ふぇざー フェザー"
"ふぇすてぃばる フェスティバル"
"ふぇっち フェッチ"
"ふぇみにずむ フェミニズム"
"ふぇらちお フェラチオ"
"ふぇりー フェリー"
"ふぇんす フェンス"
"ふえ 鰾 吭 不壊 笛"
"ふえい 府営"
"ふえかた 増え方"
"ふえき 不易"
"ふえふきどうじ 笛吹童子"
"ふえん 敷衍 不縁"
"ふぉーかす フォーカス"
"ふぉーく フォーク"
"ふぉーまっと フォーマット"
"ふぉーむ フォーム"
"ふぉーらむ フォーラム"
"ふぉあ フォア"
"ふぉろー フォロー"
"ふおう 不応"
"ふおん 不穏"
"ふか 孚化 附加 賦課 負化 鱶 鯊 府下 孵化 深 不可 付加 負荷"
"ふかい 腐海 深井 深い 不快"
"ふかいし 深石"
"ふかいり 深入り"
"ふかうら 深浦"
"ふかえ 深江"
"ふかえはま 深江浜"
"ふかお 深尾"
"ふかがわ 深川"
"ふかく 俯角 不覚"
"ふかくさ 深草"
"ふかさ 深さ"
"ふかさく 深作"
"ふかさわ 深澤 深沢"
"ふかざわ 深澤 深沢"
"ふかしょう 不可称"
"ふかしん 不可侵"
"ふかすぎ 深過ぎ"
"ふかせ 深瀬"
"ふかぞり 深剃り"
"ふかたに 深谷"
"ふかだ 深田"
"ふかつ 賦活 深津"
"ふかつか 不活化"
"ふかづめ 深爪"
"ふかなせん 深名線"
"ふかの 深野"
"ふかはた 深畑"
"ふかひ 不可避"
"ふかぶか 深々"
"ふかぶかと 深々と"
"ふかまち 深町"
"ふかみ 深み 深見 深海"
"ふかみず 深水"
"ふかや 深谷"
"ふかやま 深山"
"ふかよみ 深読み"
"ふかわ 府川 布川"
"ふかん 俯瞰 不完 不感"
"ふかんしょう 不感性"
"ふかんぜんさく 不完全作"
"ふがく 富嶽"
"ふがね 府金"
"ふき 不期 苳 吹 附記 葺 蕗 付記"
"ふきあげ 吹上"
"ふきかえ 吹替 吹替え"
"ふきだし 吹出 吹き出し"
"ふきつ 不吉"
"ふきでもの 吹き出物 吹出物"
"ふきぬけ 吹抜 吹抜け"
"ふきの 吹野"
"ふきのとう 蕗の薹"
"ふきゃがく 不可逆"
"ふきや 蕗谷 吹矢"
"ふきゅう 腐朽 不急 不朽 不休 普及"
"ふきょう 富強 不興 不協 不況 布教"
"ふきん 附近 布巾 付近"
"ふぎ 府議 付議 不義"
"ふく 馥 輹 袱 蝠 蔔 茯 箙 愎 匐 吹 富久 含 輻 腹 伏 複 復 覆 幅 福 服 副"
"ふくあん 腹案"
"ふくい 福井"
"ふくいん 幅員 復員 福音"
"ふくうりば 服売場"
"ふくえ 福栄 福江"
"ふくえき 服役"
"ふくえん 復縁"
"ふくえんせん 福塩線"
"ふくおう 福王"
"ふくおか 福岡"
"ふくおかこうたんだい 福岡工短大"
"ふくおかこうだいふ 福岡工大附"
"ふくおん 複音"
"ふくか 複果"
"ふくかわ 福川"
"ふくかん 副官"
"ふくが 腹臥"
"ふくがく 復学"
"ふくがじょう 覆瓦状"
"ふくがん 複眼"
"ふくきょうだい 福教大"
"ふくぎ 副木"
"ふくぎょう 副業"
"ふくくう 腹腔"
"ふくけん 復権"
"ふくげん 復原 復元"
"ふくこう 腹腔"
"ふくこうだいふ 福工大附"
"ふくこうまえ 福高前"
"ふくごう 複号 複合 復号"
"ふくごうざい 複合材"
"ふくごうたい 複合体"
"ふくごうまく 複合膜"
"ふくさ 帛紗 袱紗 副査"
"ふくさや 福砂屋"
"ふくさわ 福澤"
"ふくざ 複座"
"ふくざい 伏在"
"ふくざき 福崎"
"ふくざつ 複雑"
"ふくざつさ 複雑さ"
"ふくざわ 福澤 福沢"
"ふくし 福士 副詞 福祉"
"ふくしき 腹式 複式"
"ふくしく 副詞句"
"ふくしげ 福重"
"ふくしぜい 福祉税"
"ふくしつしき 副室式"
"ふくしま 副島 福嶋 福島"
"ふくしまみんぽうはい 福島民報杯"
"ふくしゃ 輻射 複写"
"ふくしゃし 複写紙"
"ふくしゃねつ 輻射熱"
"ふくしゅ 副手"
"ふくしゅう 復讐 復習"
"ふくしゅうき 復讐鬼"
"ふくしゅうげき 復讐劇"
"ふくしゅうしん 復讐心"
"ふくしゅうせん 復讐戦"
"ふくしょう 副章 復誦 副将 復勝 副賞 復唱 複勝"
"ふくしょうそうひょうすう 複勝総票数"
"ふくしょく 副食 服飾 復職"
"ふくしん 腹心"
"ふくじ 服地 福治 副次"
"ふくじゅう 複重 服従"
"ふくじん 副神 副腎"
"ふくじんづけ 副神漬け 福神漬"
"ふくすい 腹水 覆水"
"ふくすう 複数"
"ふくすうけい 複数形"
"ふくすうじ 複数持"
"ふくすうりょう 複数両"
"ふくすうろ 複数路"
"ふくすけ 福助"
"ふくずみ 福住"
"ふくせい 複製"
"ふくせいわざ 複製技"
"ふくせつ 副節"
"ふくせん 複線 伏線"
"ふくそ 複素"
"ふくそう 副層 複層 輻輳 服装"
"ふくそうかく 輻輳角"
"ふくそうりん 複層林"
"ふくそく 腹側"
"ふくそすうたい 複素数体"
"ふくぞう 腹蔵 福蔵"
"ふくぞく 服属"
"ふくたい 複体"
"ふくたけ 福武"
"ふくたに 福谷"
"ふくたろう 福太郎"
"ふくだ 福田"
"ふくだい 福大 副題"
"ふくち 福地"
"ふくちやま 福知山"
"ふくちょう 副長 復調"
"ふくちょうじく 復調軸"
"ふくつ 不屈"
"ふくつう 腹痛"
"ふくで 福田"
"ふくでん 復電"
"ふくとく 福徳 副読"
"ふくとみ 福富"
"ふくとめ 福留"
"ふくどく 服毒"
"ふくどみ 福富"
"ふくなが 福永"
"ふくにし 福西"
"ふくの 福野"
"ふくはい 腹背 復配"
"ふくはら 復原 福原"
"ふくはんぎゃくどうめい 服反逆同盟"
"ふくびき 福引"
"ふくびこうえん 副鼻腔炎"
"ふくふくせん 複々線"
"ふくぶ 腹部"
"ふくぶくろ 福袋"
"ふくぶん 副文 複文"
"ふくへい 伏兵"
"ふくへいせい 副兵装"
"ふくへき 腹壁"
"ふくべ 福部"
"ふくべっぷ 福別府"
"ふくほう 副砲"
"ふくほん 複本 副本"
"ふくま 福間"
"ふくまく 腹膜"
"ふくまくえん 腹膜炎"
"ふくまさ 福政"
"ふくまさむね 福正宗"
"ふくます 福桝"
"ふくまつ 福松"
"ふくまでん 伏魔殿"
"ふくみ 含み"
"ふくみつ 福光"
"ふくみみ 福耳"
"ふくむ 服務"
"ふくむら 福村"
"ふくめい 復命"
"ふくめん 覆面"
"ふくもと 福元 福本"
"ふくもり 福盛"
"ふくや 福屋 福家"
"ふくやく 服薬"
"ふくやす 福安"
"ふくやま 福山"
"ふくよう 複葉 服用"
"ふくよか 膨よか 脹よか"
"ふくらい 福来"
"ふくらはぎ 腓 脹脛"
"ふくり 複利 福利"
"ふくりこうせいひ 福利厚生費"
"ふくりゅうえん 副流煙"
"ふくろ 副露 嚢 復路 袋"
"ふくろあみ 袋網"
"ふくろい 袋井"
"ふくろいり 袋入"
"ふくろう フクロウ 梟"
"ふくろおび 袋帯"
"ふくろこうじ 袋小路"
"ふくろじょう 袋状"
"ふくろだ 袋田"
"ふくろだたき 袋だたき 袋叩"
"ふくろとじ 袋綴じ 袋とじ 袋閉じ"
"ふくろはり 袋貼り"
"ふくろばら 袋原"
"ふくろばり 袋貼り"
"ふくわじゅつ 腹話術"
"ふぐ 鰒 河豚"
"ふぐう 不遇"
"ふぐか 不具化"
"ふぐごうかく 複合核"
"ふぐしゃ 不具者"
"ふぐたいてん 不倶戴天 不倶載天"
"ふぐり 睾丸"
"ふけ 冨宅 冨家 普家"
"ふけい 府警 不敬 父系 婦警 父兄"
"ふけいざい 不敬罪"
"ふけいせき 父兄席"
"ふけいべつはんだん 父系別判断"
"ふけつ 不潔"
"ふけやく 老役"
"ふけん 父権 府県"
"ふげん 不言 付言"
"ふげんだけ 普賢岳"
"ふこ 巫蠱"
"ふこう 不興 不孝 附高 不幸"
"ふこく 布告"
"ふこくきょうへい 富国強兵 富國強兵"
"ふこころえもの 不心得者"
"ふごう 富豪 符合 負号 符号"
"ふごうちょう 符号帳"
"ふごうなし 符号無し"
"ふさ 惣 絃 總 房 総"
"ふさい 負載 不採 負債 夫妻"
"ふさがる 閼"
"ふさく 不作"
"ふさぐ 閼"
"ふさこ 扶佐子 夫査子 房子"
"ふさざくらか フサザクラ科"
"ふさじょう ふさ状"
"ふさん 不讃"
"ふさんはつ 釜山発"
"ふざ 趺坐"
"ふざい 不在"
"ふざん 釜山"
"ふし 臥 父子 不死 伏 節"
"ふしあな 節穴"
"ふしたに 伏谷"
"ふしちょう 不死鳥"
"ふしつ 不悉"
"ふしづけ 罧"
"ふしてん 節点"
"ふしぶし 節々"
"ふしまわし 節回し"
"ふしみ 伏見"
"ふしみこう 伏見工"
"ふしめ 節目 伏し目"
"ふしゅ 浮腫"
"ふしゅう 腐臭"
"ふしゅつ 不出"
"ふしょう 父称 不肖 不精 不詳 負傷"
"ふしょうじ 不祥事"
"ふしょうぶしょう 不承不承"
"ふしょうわたくし 不肖私"
"ふしょく 腐蝕 腐食 不食"
"ふしょくふ 不織布"
"ふしん 不振 普請 腐心 不審 不信"
"ふしんにんあん 不信任案"
"ふしんび 不審火"
"ふじ 冨士 不治 不時 不二 藤 富士"
"ふじい 藤井"
"ふじいでら 藤井寺"
"ふじいろ 藤色"
"ふじう 藤生"
"ふじうつぎか フジウツギ科"
"ふじうら 藤浦"
"ふじえ 藤江"
"ふじえだ 藤枝"
"ふじえだひがし 藤枝東"
"ふじお 不二夫 不二雄 藤尾 冨士雄 富士雄 藤雄 富士夫"
"ふじおか 富士岡 藤岡"
"ふじか 藤花"
"ふじかけ 藤掛"
"ふじかわ 富士川 藤川"
"ふじがおか 藤ヶ丘 藤が丘"
"ふじき 藤木"
"ふじきゅう 富士急"
"ふじぎん 富士銀"
"ふじくら 藤倉"
"ふじけい フジ系"
"ふじこ 冨士子 富士子 不二子 藤子"
"ふじこし 藤越 不二越"
"ふじごこ 富士五湖"
"ふじさき 藤崎"
"ふじさと 藤里"
"ふじさわ 藤澤 藤沢"
"ふじさわしみんまつり 藤沢市民祭"
"ふじさん 富士山"
"ふじしま 藤嶋 藤島"
"ふじしろ 藤城 藤代"
"ふじせ 藤瀬"
"ふじぜろっくす 富士ゼロックス"
"ふじた 藤田"
"ふじたか 藤孝"
"ふじたに 藤谷"
"ふじだな 藤棚"
"ふじつ 不実 藤津"
"ふじつうぜねらる 富士通ゼネラル"
"ふじつか 藤塚"
"ふじつぼ 藤壷"
"ふじと 藤戸"
"ふじなが 藤永"
"ふじなみ 藤波"
"ふじの 藤野"
"ふじのみや 藤ノ宮 富士宮"
"ふじのもり 藤森"
"ふじはし 藤橋"
"ふじはら 冨士原"
"ふじばかま 藤袴"
"ふじばなさんそう 藤花山荘"
"ふじばやし 藤林"
"ふじひこ 不二彦"
"ふじひろ 不二洋"
"ふじま 藤間"
"ふじまき 藤巻"
"ふじまつ 藤松"
"ふじまりゅう 藤間流"
"ふじみ 不死身 富士美 富士見"
"ふじみがおか 富士見丘"
"ふじむら 藤村"
"ふじもと 藤元 藤本"
"ふじもり 藤森"
"ふじゃくしんみょう 不惜身命"
"ふじや 藤屋 不二家"
"ふじやま 藤山"
"ふじやまかんび 藤山寛美"
"ふじゅう 藤生"
"ふじゅん 不純 不順"
"ふじょ 巫女 扶助 婦女"
"ふじょう 不浄 浮上"
"ふじよし 藤吉"
"ふじわか 藤若"
"ふじわら 冨士原 藤原"
"ふじん 布陣 婦人 夫人"
"ふじんしゃ 婦人車"
"ふじんふく 婦人服"
"ふすう 負数"
"ふすま 衾 襖"
"ふすまえ 襖絵"
"ふず 付図"
"ふずい 不随 附随 付随"
"ふずいか 付随果"
"ふずいしゃ 付随車"
"ふせ 布施 防"
"ふせい 夫姓 負性 不整 不正"
"ふせいげんり 父性原理"
"ふせいしゅつ 不世出"
"ふせいてき 父性的"
"ふせいほんのう 父性本能"
"ふせいみゃく 不整脈"
"ふせき 布石"
"ふせじ △△△ □□□ ○○○ ××× 伏字 ふせ字 伏せ字"
"ふせつ 負節 布設 付設 敷設"
"ふせん 附箋 付箋 不戦"
"ふせんぱい 不戦敗"
"ふぜい 風情"
"ふぜん 不全"
"ふそう 扶桑"
"ふそく 付則 不測 附則 不足"
"ふそくがく 不足額"
"ふそびょう 腐蛆病"
"ふそん 不遜"
"ふぞく 付属 附属"
"ふぞくひんとも 付属品共"
"ふぞろい 不揃い"
"ふた 葢 盖 弍 蓋 二"
"ふたあし 二足"
"ふたあじ 二味"
"ふたい 付帯"
"ふたいてん 不退転"
"ふたえ 二重"
"ふたえき 二駅"
"ふたかた 二方"
"ふたかみ 二上"
"ふたかわ 二川"
"ふたがみ 二神 二上"
"ふたがわ 二川"
"ふたく 負託 付託"
"ふたくみ 二組"
"ふたけた 二桁"
"ふたこ 二子"
"ふたこと 二言"
"ふたことみこと 二言三言"
"ふたご 双子"
"ふたござ 双子座"
"ふたごたまがわ 二子多摩川 二子玉川"
"ふたごやま 二子山"
"ふたごやまぜい 二子山勢"
"ふたせ 二瀬"
"ふたたび 再び"
"ふたたま 二玉"
"ふたつ 弍 双 ２つ 二 二つ"
"ふたつい 二ツ井"
"ふたつき 二月"
"ふたつぎ 二木"
"ふたつざわ 二ツ沢"
"ふたつつうち 不達通知"
"ふたつめ 二つめ"
"ふたつや 二ッ谷"
"ふたて 二手"
"ふたとおり 二通り"
"ふたなり 二形"
"ふたはこ 二箱"
"ふたば 雙葉 二葉 双葉"
"ふたばん 二晩"
"ふたへや 二部屋"
"ふたま 二間"
"ふたませ 二間瀬"
"ふたまた 二又 二股"
"ふたまたがわ 二俣川"
"ふたまたせん 二俣線"
"ふたまたみゃく 二又脈"
"ふたみ 双海 双三 二美 二見"
"ふたむかしまえ 二昔前"
"ふたむら 二村"
"ふたもじ 二文字"
"ふたり ２人 二人"
"ふたりたび 二人旅"
"ふたりとも 二人共"
"ふたりのり 二人乗"
"ふたわ 二和"
"ふたん 負担"
"ふたんがく 負担額"
"ふたんげん 負担減"
"ふたんぞう 負担増"
"ふだ 布田 札"
"ふだい 普代 譜代 府大"
"ふだしょ 札所"
"ふだつき 札付"
"ふだどめ 札止"
"ふだらく 補陀洛"
"ふだん 不断 普段"
"ふだんぎ 普段着"
"ふち 附置 付値 扶持 渊 負値 付置 渕 縁 淵"
"ふちかざり 縁飾り"
"ふちがみ 渕上"
"ふちざき 渕崎"
"ふちじ 府知事"
"ふちの 渕野"
"ふちのべ 渕野辺 淵野辺"
"ふちまい 扶持米"
"ふちゃく 不着 付着"
"ふちゅう 婦中 不忠 府中"
"ふちゅうひんとく 府中牝特"
"ふちょう 符丁 婦長 府庁 符牒 不調"
"ふちょうしゃ 府庁舎"
"ふちん 不沈 浮沈"
"ふっか フッ化"
"ふっかい 復改"
"ふっかつ 復活"
"ふっかつげき 復活劇"
"ふっかつさい 復活祭"
"ふっかつせつ 復活説"
"ふっかん 復刊"
"ふっき 復帰"
"ふっきせつ 復帰説"
"ふっきせん 復帰戦"
"ふっきゅう 復仇 復旧"
"ふっきゅうしゃ 復旧車"
"ふっきん 腹筋"
"ふっけん 復権"
"ふっけんご 福建語"
"ふっこ 復古"
"ふっこう 復航 腹腔 復交 復興"
"ふっこうだい 福工大"
"ふっこく 覆刻 復刻"
"ふっこしゅ 復古酒"
"ふっさ 福生"
"ふっしょく 払拭"
"ふっせき 沸石"
"ふった フッタ"
"ふっつ 富津"
"ふってい 払底"
"ふってん 沸点"
"ふっとう 拂騰 沸騰"
"ふっとうせき 沸騰石"
"ふっとぼーる フットボール"
"ふつ 布津 黻 髴 祓 拂 怫 佛 彿 仏 弗 払 沸"
"ふついん 仏印"
"ふつう ふつ〜 不通 普通"
"ふつうし 普通紙"
"ふつうしゃ 普通車"
"ふつうせき 普通席"
"ふつうば 普通馬"
"ふつうもり 普通盛り"
"ふつか 二日 ２日"
"ふつかよい 宿酔 二日酔"
"ふつぎょう 払暁"
"ふつぐん 仏軍"
"ふつご 仏語"
"ふつしゃ 仏車"
"ふつつか 不束"
"ふつふつ 勿勿"
"ふつぶん 仏文"
"ふつりあい 不釣合い"
"ふつれき 仏暦"
"ふつわ 仏和"
"ふづき 文月"
"ふづくえ 文机"
"ふてい 婦弟 不悌 不弟 不逞 不貞 不定"
"ふていこん 不定根"
"ふていせきぶいん 不定積分"
"ふていのやから 不逞の輩"
"ふてき 不敵 不適"
"ふてくされる 不貞腐れる"
"ふてん 符点"
"ふで 筆"
"ふでいれ 筆入れ"
"ふでが 筆画"
"ふでさき 筆先"
"ふでたて 筆立て"
"ふでづかい 筆遣い"
"ふではこび 筆運び"
"ふでばこ 筆箱"
"ふでぶしょう 筆無精"
"ふでぺん 筆ペン"
"ふでもじ 筆文字"
"ふと 富戸 不図 太"
"ふとう 不党 不凍 不撓 不等 埠頭 不倒 不当"
"ふとうえき 不凍液"
"ふとうおう 不倒翁"
"ふとうこう 不凍港"
"ふとうごう ＜ ＞"
"ふとがき 太書き"
"ふとく 不徳"
"ふとぐち 太口"
"ふところ 懷 懐"
"ふところがたな 懐刀"
"ふところぐあい 懐具合"
"ふとし 太司 太"
"ふとじ 太字"
"ふとせん 太線"
"ふとっぱら 太腹 太っ腹"
"ふとどき 不届 不届き"
"ふとまき 太巻"
"ふとめ 太目 太め"
"ふともじ 太文字"
"ふともも 太股 太もも"
"ふともももく フトモモ目"
"ふとわく 太枠"
"ふとん 蒲団 布団"
"ふどう 府道 不動 不同 浮動"
"ふどうにょざん 不動如山"
"ふどき 風土記"
"ふな 舩 舟 船 鮒"
"ふなあし 船足 船脚"
"ふない 府内 船井"
"ふないり 舟入"
"ふなうた 舟歌"
"ふなおか 船岡"
"ふなか 不仲"
"ふなかた 船方"
"ふながいしゃ 船会社"
"ふながた 舟形 船形"
"ふなき 舟木 船木"
"ふなくぼ 舟久保"
"ふなぐら 艙 船蔵 船倉"
"ふなこう 船高"
"ふなこし 船越"
"ふなぞこ 船底"
"ふなたび 船旅"
"ふなだ 船田"
"ふなちん 船賃"
"ふなつ 舟津 船津"
"ふなつきば 船付場 船着場"
"ふなづみ 船積み"
"ふなづみこう 船積港"
"ふなづり 船釣り 舟釣 船釣"
"ふなで 船出"
"ふなと 船渡 舟渡"
"ふなど 船戸"
"ふなに 船荷"
"ふなぬし 船主"
"ふなのり 船乗 舟乗 船乗り"
"ふなはし 舟橋 船橋"
"ふなばし 舟橋 船橋"
"ふなばた 舷端"
"ふなびき 船曳"
"ふなびと 舟人"
"ふなびん 船便"
"ふなべり 舷縁"
"ふなほ 船穂"
"ふなま 船間"
"ふなみず 船水"
"ふなむら 舟村"
"ふなやど 船宿"
"ふなやま 舩山 舟山 船山"
"ふなよい 船酔 船酔い"
"ふなり 不成"
"ふなわ 舟和"
"ふにく 腐肉"
"ふにゅう 腐乳 船生"
"ふにん 不妊 赴任"
"ふにんきしゃ 不人気車"
"ふぬけ 腑抜け"
"ふね 舩 艦 舟 船"
"ふねかんけい 船関係"
"ふねひき 船引"
"ふねや 船屋"
"ふねよう 船用"
"ふねん 不稔 不燃"
"ふの 布野"
"ふのあたい 負の値"
"ふのう 不能"
"ふは 不破"
"ふはい 不敗 腐敗"
"ふはいしゅう 腐敗臭"
"ふはく 布帛 浮薄"
"ふはつ 不発"
"ふはつだん 不発弾"
"ふばい 不買"
"ふばらい 不払い"
"ふばん 符番"
"ふばんたいけい 付番体系"
"ふひょう 附票 浮標 不評 付表"
"ふび 不備"
"ふびん 不敏 不便 不憫"
"ふふく 不服"
"ふぶ 布武"
"ふぶき 風吹 吹雪"
"ふぶん 腑分"
"ふぶんりつ 不文律"
"ふへい 不平"
"ふへん 不遍 不偏 普遍 不変"
"ふへんぱたあんにんしき 不変パターン認識"
"ふべん 不便"
"ふべんきょうもの 不勉強者"
"ふほ 付保"
"ふほう 訃報 不法"
"ふぼ 父母"
"ふぼん 不犯"
"ふまい 不昧"
"ふまじめ 不まじめ"
"ふまん 不満"
"ふまんがお 不満顔"
"ふみ 二三 章 郁 史 踏み 文"
"ふみあき 文明 史光 文昭"
"ふみあけ 文朱"
"ふみえ 踏絵 文絵 踏み絵"
"ふみお 史夫 文郎 史男 史緒 二三男 文雄 文夫 文男"
"ふみか 史佳"
"ふみかず 文一"
"ふみきり 踏み切り 踏切"
"ふみこ ふみ子 史子 文子 冨美子 富美子"
"ふみこみ 踏込み 踏みこみ"
"ふみし 二三四"
"ふみたか 文孝 文隆"
"ふみたけ 文武"
"ふみただ 文忠"
"ふみだい 踏台"
"ふみづき 文月"
"ふみと 文人"
"ふみとし 文俊 文敏"
"ふみとよ 文豊"
"ふみのぶ 文信"
"ふみのり 文典"
"ふみひこ 史彦 郁彦 文彦"
"ふみひで 文秀"
"ふみひと 文仁"
"ふみひろ 文浩 文博 史裕"
"ふみまさ 章雅"
"ふみや 文也 郁也"
"ふみやす 文保 文康"
"ふみゆき 文行 文之"
"ふみよ 扶三代 文代"
"ふみよし 文嘉 文良"
"ふみん 府民 不眠"
"ふめい 不明"
"ふめつ 不滅"
"ふめん 符面 譜面"
"ふもう 不毛"
"ふもと 梺 麓"
"ふもん 不問"
"ふやじょう 不夜城"
"ふゆ 冬"
"ふゆいがい 冬以外"
"ふゆいらい 冬以来"
"ふゆう 浮有 富有 富裕 浮遊"
"ふゆうせき 浮遊石"
"ふゆうれい 浮遊霊"
"ふゆがた 冬型"
"ふゆがっしゅく 冬合宿"
"ふゆがれ 冬枯れ"
"ふゆき 冬木 冬樹"
"ふゆきとどき 不行届き"
"ふゆげ 冬毛"
"ふゆげしき 冬景色"
"ふゆこ 冬子"
"ふゆごう 冬号"
"ふゆごし 冬越し"
"ふゆごろ 冬頃"
"ふゆしょうぐん 冬将軍"
"ふゆじかん 冬時間"
"ふゆじたく 冬支度"
"ふゆとうらい 冬到来"
"ふゆば 冬場"
"ふゆひこ 冬彦"
"ふゆび 冬日"
"ふゆふく 冬服"
"ふゆみ 冬美"
"ふゆみち 冬道"
"ふゆもの 冬物"
"ふゆものがたり 冬物語"
"ふゆやすみ 冬休み"
"ふゆやま 冬山"
"ふゆよう 冬用"
"ふよ 賦与 付与"
"ふよう 芙蓉 浮揚 芙容 不用 扶養 不要"
"ふようしゃこうじょ 扶養者控除"
"ふようしゃてあて 扶養者手当"
"ふようせい 不溶性"
"ふようど 腐葉土"
"ふらい フライ"
"ふらいと フライト"
"ふらいんぐ フライング"
"ふらち 不埒 不埓"
"ふらっしゅ フラッシュ"
"ふらっと フラット ♭"
"ふらの 富良野"
"ふらわー フラワー"
"ふらん 孵卵 腐爛 腐乱 不乱"
"ふらんす 佛蘭西 仏蘭西 フランス"
"ふり 振 不利"
"ふりー フリー"
"ふりーく フリーク"
"ふりあて 振り当て"
"ふりかえ 振替"
"ふりかた 振り方"
"ふりがな 振り仮名 振仮名"
"ふりこ 振子 振り子"
"ふりこぐるま 振子車"
"ふりこみ 振り込み 振込 振込み"
"ふりこみしゃめい 振込者名"
"ふりごま 振り駒"
"ふりすびー フリスビー"
"ふりそで 振袖 振り袖"
"ふりだし 振出"
"ふりつ 振津 府立"
"ふりつけ 振付 振付け 振り付け"
"ふりてん 振聴"
"ふりなじょうけん 不利な条件"
"ふりはた 降籏"
"ふりびしゃ 振り飛車"
"ふりむき 振り向き"
"ふりょ 俘虜 俘慮 不慮"
"ふりょう 不漁 不良"
"ふりょうせくた 不良セクタ"
"ふりょく 浮力"
"ふりわけ 振分 振り分け"
"ふりん 不倫"
"ふる フル 古"
"ふるーつ フルーツ"
"ふるい 篩 古い 古井"
"ふるいち 古市"
"ふるいど 古井戸"
"ふるう 古宇"
"ふるうち 古内"
"ふるえ 古恵 震え"
"ふるおや 古尾谷"
"ふるかぶ 古株"
"ふるかわ 古河 古川"
"ふるかわえきにしぐち 古河駅西口"
"ふるがっき 古楽器"
"ふるきず 古傷"
"ふるぎ 古着"
"ふるぎって 古切手"
"ふるくさい 古臭い"
"ふるこおり 古郡"
"ふるごう 古国府"
"ふるさか 古坂"
"ふるさと 故里 古里 故郷"
"ふるさわ 古澤 古沢"
"ふるざけ 古酒"
"ふるざっし 古雑誌"
"ふるしま 古島"
"ふるしんぶん 古新聞"
"ふるす 古巣"
"ふるせ 古瀬"
"ふるそう 古荘"
"ふるた 古田"
"ふるたか 古鷹"
"ふるたち 古舘 古館"
"ふるたて 古舘"
"ふるたに 古谷"
"ふるだち 古舘"
"ふるだて 古舘"
"ふるだぬき 古狸"
"ふるつわもの 古兵 古強者"
"ふるて 古手"
"ふるでら 古寺"
"ふると 古戸"
"ふるとり 隹"
"ふるどうぐ 古道具"
"ふるどけい 古時計"
"ふるどの 古殿"
"ふるどり 隹"
"ふるの 古野"
"ふるはし 古橋"
"ふるはた 古籏 古畑"
"ふるびら 古平"
"ふるほん 古本"
"ふるまい 振舞 振舞い"
"ふるまち 古町"
"ふるむら 古村"
"ふるもと 古本"
"ふるもの 古物"
"ふるや 古矢 古谷 古屋"
"ふるやま 古山"
"ふれ 振れ"
"ふれーく フレーク"
"ふれあい ふれ合い"
"ふれい 負例 布令 譜例"
"ふれかく 振れ角"
"ふれる 振れる"
"ふれんち フレンチ"
"ふれんど 普連土"
"ふろ 風炉 風呂"
"ふろあ フロア"
"ふろあがり 風呂あがり"
"ふろう 浮浪 不労 不老"
"ふろうりん 不老林"
"ふろおけ 風呂桶"
"ふろく 附録 付録"
"ふろしき 風呂敷"
"ふろっぴー フロッピー"
"ふろば 風呂場"
"ふろんと フロント"
"ふわ 付和 不破 不和"
"ふわく 不惑"
"ふわけ 腑分け"
"ふわたり 不渡り"
"ふわり 譜割"
"ふん 賁 芬 濆 汾 氛 枌 忿 吩 刎 ′ 吻 墳 憤 扮 焚 噴 奮 粉 紛 雰 糞 分"
"ふんあつ 分圧"
"ふんい 雰囲"
"ふんいき 氛圍氣 雰囲気"
"ふんいんき 雰囲気"
"ふんえん 噴煙"
"ふんか 噴火"
"ふんかこう 噴火口"
"ふんかわん 噴火湾"
"ふんかん 分間"
"ふんかんかく 分間隔"
"ふんがい 憤慨 憤概"
"ふんき 奮起"
"ふんきゅう 紛糾"
"ふんぎ 紛議"
"ふんけい 刎頸 刎頚"
"ふんげき 憤激"
"ふんころ 分頃"
"ふんご 分後"
"ふんごう 吻合"
"ふんごと 分毎"
"ふんさい 粉砕"
"ふんさつ 焚殺"
"ふんし 憤死"
"ふんしつ 粉失 紛失"
"ふんしつきゅう 紛失球"
"ふんしつとどけ 紛失届"
"ふんしゃ 噴射"
"ふんしゅうは 分周波"
"ふんしゅつ 噴出"
"ふんしょ 焚書"
"ふんしょく 粉飾"
"ふんしん 分針"
"ふんじん 粉塵"
"ふんすい 噴水"
"ふんせん 奮戦"
"ふんせんき 奮戦記"
"ふんぜん 憤然 奮然"
"ふんそう 粉争 紛争 扮装"
"ふんそく 吻側 分速"
"ふんたい 粉体"
"ふんたんい 分単位"
"ふんとう 奮闘"
"ふんとうき 奮闘記"
"ふんど 忿怒 憤怒"
"ふんどう 分銅"
"ふんどし 褌"
"ふんにゅう 粉乳"
"ふんにょう 糞尿"
"ふんぬ 忿怒 憤怒"
"ふんはん 分半"
"ふんぱつ 奮発"
"ふんぱん 噴飯"
"ふんびょう 分秒"
"ふんぷん 紛々"
"ふんべつ 分別"
"ふんぼ 墳墓"
"ふんまえ 分前"
"ふんまつ 粉末"
"ふんまん 忿懣 憤懣"
"ふんみまん 分未満"
"ふんむ 噴霧"
"ふんめつ 焚滅"
"ふんりゅう 噴流"
"ふんれい 奮励"
"ぶ 悔 錻 誣 毋 憮 廡 嘸 蒲 歩 不 侮 撫 葡 舞 蕪 武 無 分 部"
"ぶーす ブース"
"ぶーすた ブースタ"
"ぶーつ ブーツ"
"ぶーむ ブーム"
"ぶあい 部合 歩合"
"ぶあいきゅう 歩合給"
"ぶあいそ 不愛想 無愛想"
"ぶあいそう 無愛想"
"ぶあく 武悪"
"ぶあつい ぶ厚い"
"ぶあんない 不案内"
"ぶい 部位"
"ぶいち 武一"
"ぶいん 部員"
"ぶえ 笛"
"ぶえんりょ 無遠慮"
"ぶおとこ 醜男"
"ぶおんぷ 分音符"
"ぶか 部課 部科 深 部下"
"ぶかい 部会"
"ぶかっこう 不格好"
"ぶかつ 部活"
"ぶかつどう 部活動"
"ぶかん 武漢 武官"
"ぶがい 部外"
"ぶがいひ 部外秘"
"ぶき 武器"
"ぶきみ 不気味"
"ぶきょく 舞曲 部局"
"ぶきょくじゅん 部局順"
"ぶきよう 不器用"
"ぶぎ 部議"
"ぶぎょう 奉行"
"ぶく 伏"
"ぶくうじゅつ 舞空術"
"ぶくろ 袋"
"ぶくん 武勲"
"ぶぐ 武具"
"ぶけ 武家"
"ぶけん 武見"
"ぶげいちょう 武芸帳"
"ぶげいひゃっぱん 武芸百般"
"ぶげん 無限"
"ぶこう 武功"
"ぶこく 誣告"
"ぶこつ 無骨 武骨"
"ぶさいく 不細工"
"ぶさく 部作"
"ぶさた 無沙汰"
"ぶさつ 撫擦"
"ぶさほう 不作法 無作法"
"ぶざー ブザー"
"ぶざい ξ 部材"
"ぶざま 無様 不様"
"ぶし 部誌 節 武士"
"ぶしつ 部室"
"ぶしつけ 不躾 不しつけ"
"ぶしゅ 部首"
"ぶしゅうぎ 不祝儀"
"ぶしゅべつさくいん 部首別索引"
"ぶしょ 部所 部署"
"ぶしょう 武将 無精 不精"
"ぶしょうひげ 無精髭 不精髭"
"ぶしょうもの 不精者"
"ぶじ 無事"
"ぶじこれめいば 無事是名馬"
"ぶじに 無事に"
"ぶじょく 侮辱"
"ぶじょくざい 侮辱罪"
"ぶじん 武人"
"ぶす ブス"
"ぶすい 無粋 不粋"
"ぶすう 部数"
"ぶすじま 毒島"
"ぶせい 部制"
"ぶぜい 無勢"
"ぶぜん 憮然 豊前"
"ぶそう 武装"
"ぶそく 不足"
"ぶそん 武尊"
"ぶぞく 部族"
"ぶた 葢 盖 蓋 豚"
"ぶたい 舞台 部隊"
"ぶたいうら 舞台裏"
"ぶたいげき 舞台劇"
"ぶたいそで 舞台袖"
"ぶたいゆか 舞台床"
"ぶたごや 豚小屋"
"ぶたじる 豚汁"
"ぶたたま 豚玉"
"ぶたたまてん 豚玉天"
"ぶたどん 豚丼"
"ぶたにく 豚肉"
"ぶたばこ 豚箱"
"ぶたまんや 豚饅屋"
"ぶだいか 舞台化"
"ぶち ブチ 渊 斑 渕 淵"
"ぶちょう 部長"
"ぶちょうせき 部長席"
"ぶちょうづき 部長付"
"ぶちょうほう 不調法"
"ぶっか 物価"
"ぶっかく 物覚 仏閣"
"ぶっかだか 物価高"
"ぶっきょう 佛教 仏教"
"ぶっきょうし 仏教史"
"ぶっきょうと 仏教徒"
"ぶっく ブック"
"ぶっくす ブックス"
"ぶっくまーと ブックマート"
"ぶっけん 物研 物件"
"ぶっけんひ 物件費"
"ぶっけんほう 物権法"
"ぶっこ 物故"
"ぶっこう 物工"
"ぶっさん 物産"
"ぶっし 仏師 物資"
"ぶっしき 仏式"
"ぶっしつ 物質"
"ぶっしつば 物質場"
"ぶっしでんそう 物質伝送"
"ぶっしょう 物証"
"ぶっしょうい 仏正意"
"ぶっしょく 物色"
"ぶっしん 物心"
"ぶっせい 仏性 物性"
"ぶっそう 物騒"
"ぶっそん 物損"
"ぶったい 物体"
"ぶっだ 仏陀"
"ぶっちょうずら 仏頂面"
"ぶっちょうづら 仏頂面"
"ぶってき 物的"
"ぶってん 仏典"
"ぶっとう 仏塔"
"ぶっぴん 物品"
"ぶっぴんぜい 物品税"
"ぶっぽう 仏法"
"ぶっぽうそう 仏法僧"
"ぶつ 佛 勿 仏 物"
"ぶつえん 仏縁"
"ぶつえんほう 仏炎苞"
"ぶつぎ 物議"
"ぶつじ 仏事"
"ぶつぜん 仏前"
"ぶつぞう 仏像"
"ぶつだい 仏大"
"ぶつだん 仏壇"
"ぶつのう 物納"
"ぶつぶつ 勿勿 物々"
"ぶつま 仏間"
"ぶつめつ 仏滅"
"ぶつもう 勿罔"
"ぶつもん 仏門"
"ぶつよく 物欲"
"ぶつり 物理"
"ぶつりがく 物理學"
"ぶつりがくし 物理学史"
"ぶつりゅう 物流"
"ぶつりょう 物療 物量"
"ぶてぃっく ブティック"
"ぶでん 舞殿"
"ぶと 太"
"ぶとう 舞踊 舞踏"
"ぶとうか 舞踊家 武闘家"
"ぶとうかい 武闘会"
"ぶとうたいかい 武闘大会"
"ぶどう 武道 葡萄"
"ぶどうか 武道家 ブドウ科"
"ぶどうかん 武道舘"
"ぶどうかんとも 武道館共"
"ぶどうじょ 武道所"
"ぶどうとう 葡萄糖"
"ぶどうばたけ 葡萄畑"
"ぶどまり 歩留まり"
"ぶな 樗"
"ぶない 部内"
"ぶなもく ブナ目"
"ぶなん 武南 無難"
"ぶね 船"
"ぶばいがわら 分倍河原"
"ぶひ 部費"
"ぶひん 部品"
"ぶひんきょうはん 部品共販"
"ぶびき 歩引き"
"ぶぶん 部分"
"ぶぶんぎ 部分木"
"ぶぶんし 部分枝"
"ぶぶんしょく 部分食"
"ぶぶんわ 部分和"
"ぶぶんを 部分"
"ぶべつ 侮蔑"
"ぶめん 部面"
"ぶもん 武門 部門"
"ぶもんごと 部門毎"
"ぶもんひ 部門費"
"ぶゆ 蚋"
"ぶゆう 武勇"
"ぶゆうでん 武勇伝"
"ぶよ 蚋"
"ぶよう 舞踊"
"ぶようじん 不用心"
"ぶようどう 武揚堂"
"ぶらい 無頼"
"ぶらいんど ブラインド"
"ぶらうす ブラウス"
"ぶらうんかん ブラウン管"
"ぶらく 部落"
"ぶらじゃー ブラジャー"
"ぶらじる 伯剌西爾"
"ぶらっく ブラック"
"ぶらんく ブランク"
"ぶらんでー ブランデー"
"ぶらんど ブランド"
"ぶり 鰤"
"ぶりっじ ブリッジ"
"ぶりつてき 物理的"
"ぶりょく 武力"
"ぶるー ブルー"
"ぶるい 部類"
"ぶるがりあ 勃牙利"
"ぶれーき ブレーキ"
"ぶれい 無礼"
"ぶれいこう 無礼講"
"ぶれいもの 無礼者"
"ぶろ 風呂"
"ぶろーか ブローカ"
"ぶろっく ブロック"
"ぶわり 歩割"
"ぶん 蚊 馼 紊 聞 文 分"
"ぶんあつ 分圧"
"ぶんあん 文案"
"ぶんい 文意"
"ぶんいき 分域"
"ぶんいち 文一"
"ぶんいん 分院"
"ぶんえいどう 文永堂"
"ぶんえん 分園 分煙"
"ぶんえんどう 文苑堂"
"ぶんか 分果 文華 文科 分化 分科 文化"
"ぶんかい 分界 分会 分解"
"ぶんかいせき 文解析"
"ぶんかいのう 分解能"
"ぶんかく 分画 文革"
"ぶんかさい 文化祭"
"ぶんかざい 文化財"
"ぶんかし 文化史"
"ぶんかちょう 文化庁"
"ぶんかつ 分割"
"ぶんかつあん 分割案"
"ぶんかどう 文華堂 文化堂"
"ぶんかん 文官 分館"
"ぶんかんすう 文関数"
"ぶんがく 文學 文学"
"ぶんがっか 文学科"
"ぶんき 分岐"
"ぶんきょう 文教 文京"
"ぶんきょく 分極"
"ぶんきん 分近"
"ぶんぎ 分木"
"ぶんぎょう 分業"
"ぶんく 分区"
"ぶんぐ 文具"
"ぶんけ 分家"
"ぶんけい 文型 文系"
"ぶんけん 分権 文献"
"ぶんけんちず 分県地図"
"ぶんげい 文藝 文芸"
"ぶんげいか 文芸家"
"ぶんげいざ 文芸座 文芸坐"
"ぶんげん 分限"
"ぶんこ 文庫"
"ぶんこう 分校 分光"
"ぶんこうぞう 文構造"
"ぶんこかん 文庫刊"
"ぶんことも 文庫共"
"ぶんこばん 文庫判"
"ぶんご 豊後 文語"
"ぶんごう 文豪"
"ぶんごたい 文語体"
"ぶんさい 文才"
"ぶんさく 文作"
"ぶんさつ 分冊"
"ぶんさん 分散"
"ぶんざい 分際"
"ぶんし 分枝 文士 分詞 分子"
"ぶんしつ 分室"
"ぶんしないしんどう 分子内振動"
"ぶんしゃか 分社化"
"ぶんしゅう 文集 分周"
"ぶんしゅく 分宿"
"ぶんしゅつ 分出"
"ぶんしゅん 文春"
"ぶんしょ 文書"
"ぶんしょう 文相 分掌 文章"
"ぶんしょがたていぎ 文書型定義"
"ぶんしょく 文飾"
"ぶんしょこ 文書庫"
"ぶんしょわりつけ 文書割付け"
"ぶんしん 分身"
"ぶんじ 文二 文治"
"ぶんじたい 文自体"
"ぶんじょう 分譲 分乗"
"ぶんじょうしゃ 分乗車"
"ぶんじん 文人"
"ぶんすい 分水"
"ぶんすいれい 分水嶺"
"ぶんすう 分数"
"ぶんせいせい 文生成"
"ぶんせいどう 文盛堂"
"ぶんせき 文責 分析"
"ぶんせつ 文節"
"ぶんせつぎり 文節切"
"ぶんせつせい 分節性"
"ぶんせつちゅう 分節中"
"ぶんせん 文選"
"ぶんせんどう 文泉堂"
"ぶんせんめい 文鮮明"
"ぶんぜんたい 文全体"
"ぶんそう 分奏"
"ぶんそうおう 分相応"
"ぶんそん 分損"
"ぶんたい 分隊 文体"
"ぶんたいおう 文対応"
"ぶんたいし 分隊士"
"ぶんたん 分担"
"ぶんだい 分大"
"ぶんだん 分団 文壇 分断"
"ぶんちゅう 分注 文中"
"ぶんちゅうじょ 分駐所"
"ぶんちょう 文調 文鳥"
"ぶんちん 文珍 文鎮"
"ぶんつう 文通"
"ぶんてん 分点"
"ぶんでん 分電"
"ぶんとう 文頭"
"ぶんとん 分屯"
"ぶんどき 分度器"
"ぶんのいち 分の１"
"ぶんのう 分納"
"ぶんは 分派"
"ぶんばい 分売"
"ぶんばんごう 文番号"
"ぶんぱ 分波 分派"
"ぶんぱい 分配"
"ぶんぱいそく 分配束"
"ぶんぱいりつ 分配律"
"ぶんぴ 分泌"
"ぶんぴつ 分筆 文筆 分泌"
"ぶんぴつえき 分泌液"
"ぶんぴつぎょう 文筆業"
"ぶんぶ 文武"
"ぶんぶつ 文物"
"ぶんぷ 分布"
"ぶんべつ 分別"
"ぶんべん 分娩"
"ぶんぺい 文平"
"ぶんぼ 分母"
"ぶんぼうぐ 文房具"
"ぶんぼぶんりけい 分母分離形"
"ぶんぽう 文法"
"ぶんまつ 文末"
"ぶんみゃく 文脈"
"ぶんみん 文民"
"ぶんめい 文明"
"ぶんめいし 文明史"
"ぶんめいどう 文明堂"
"ぶんめん 文面"
"ぶんや 分野"
"ぶんよ 分与"
"ぶんよう 文葉"
"ぶんらく 文楽"
"ぶんらん 紊乱"
"ぶんり 文理 分離"
"ぶんりあん 分離案"
"ぶんりか 分離果"
"ぶんりつ 分率 分立"
"ぶんりのう 分離脳"
"ぶんりゅう 分溜 分流 分留"
"ぶんりょう 分量"
"ぶんるい 分類"
"ぶんるいぎ 分類木"
"ぶんれい 文例"
"ぶんれつ 分列 分裂"
"ぶんれつか 分裂果"
"ぶんれつびょう 分裂病"
"ぷ 布 腐"
"ぷーどる プードル"
"ぷーる プール"
"ぷう 風"
"ぷさん 釜山"
"ぷらいばし プライバシ"
"ぷらいばしー プライバシー"
"ぷらいべーと プライベート"
"ぷらぐ プラグ"
"ぷらざ プラザ"
"ぷらす ＋ プラス"
"ぷらすちっく プラスチック"
"ぷらすまいなす ±"
"ぷらちな プラチナ"
"ぷらっと プラット"
"ぷらまい ±"
"ぷらん プラン"
"ぷらんくていすう プランク定数"
"ぷらんと プラント"
"ぷらんにんぐ プランニング"
"ぷりずむ プリズム"
"ぷりぷり プリプリ"
"ぷりんす プリンス"
"ぷりんせす プリンセス"
"ぷりんた プリンタ"
"ぷりんたー プリンター"
"ぷりんと プリント"
"ぷれー プレー"
"ぷれーと プレート"
"ぷれーにんぐ プレーニング"
"ぷれーやー プレーヤー"
"ぷれいや プレイヤ"
"ぷれいやー プレイヤー"
"ぷれじでんと プレジデント"
"ぷれす プレス"
"ぷれぜんと プレゼント"
"ぷろ プロ"
"ぷろぐらま プログラマ"
"ぷろぐらみんぐ プログラミング"
"ぷろしあ 普魯西"
"ぷろじぇくと プロジェクト"
"ぷろせす プロセス"
"ぷろだくしょん プロダクション"
"ぷろてくと プロテクト"
"ぷろでゅーさ プロデューサ"
"ぷろでゅーす プロデュース"
"ぷろとたいぷ プロトタイプ"
"ぷろふぃーる プロフィール"
"ぷろふぇっしょなる プロフェッショナル"
"ぷろぺら プロペラ"
"ぷろぽーざる プロポーザル"
"ぷろもうと プロモウト"
"ぷん 分"
"ぷんかん 分間"
"ぷんはん 分半"
"ぷんぴつえき 分泌液"
"へ 邉 邊 経 辺 戸 屁"
"へーべー 平米"
"へい 餅 箆 瓶 坪 炳 閇 竝 睥 斃 敝 并 幤 嬖 娉 聘 丙 幣 塀 柄 弊 蔽 並 陛 併 兵 閉 平"
"へいあん 平安"
"へいあんきょう 平安京"
"へいあんどう 平安堂"
"へいい 平易"
"へいいき 閉域"
"へいいち 平一"
"へいいん 兵員"
"へいえい 兵営 併映"
"へいえき 兵役"
"へいえん 閉園 閉宴"
"へいおん 併音 平温 平穏"
"へいか 閉果 閉架 兵科 平価 陛下"
"へいかい 閉会"
"へいかつ 平滑"
"へいかつきん 平滑筋"
"へいかん 閉館 閉管"
"へいがい 弊害"
"へいがっこう 兵学校"
"へいき 並記 兵器 併記 平気"
"へいきち 平吉"
"へいきん 平均"
"へいきんねんぼう 平均年棒"
"へいきんば 平均場"
"へいきんりつ 平均律"
"へいきんりゅう 平均流"
"へいけ 平家"
"へいけい 閉経"
"へいけつ 併結"
"へいげい 辟睨 睥睨"
"へいげん 平原"
"へいこう 敝垢 閉校 併行 閉項 平向 平衡 平行 閉口 並行"
"へいこういぬしょり 平行犬処理"
"へいこうかくかんきょり 平衡核間距離"
"へいこうこう 平行光"
"へいこうし 平行視"
"へいこうぼう 平行棒"
"へいこうみゃく 平行脈"
"へいこうみゃくよう 平行脈葉"
"へいごう 并合 併合"
"へいさ 閉鎖"
"へいさい 併催"
"へいさつ 併殺"
"へいさつだ 併殺打"
"へいざん 閉山"
"へいし 斃死 閉止 弊誌 弊紙 平氏 瓶子 兵士"
"へいしき 閉式"
"へいしつかいぞう 閉室改造"
"へいしゃ 弊社"
"へいしゅ 兵種"
"へいしん 並進"
"へいしんていとう 平身抵当 平身低頭"
"へいじ 平次 平時"
"へいじつ 平日"
"へいじつあさ 平日朝"
"へいじょう 平壌 平城 閉場 平常"
"へいじょうしん 平常心"
"へいじん 敝人"
"へいすいめん 平水面"
"へいすう 兵数"
"へいすけ 平祐"
"へいせい 平静 平成"
"へいせき 平積"
"へいせつ 併設"
"へいぜい 平生"
"へいぜいごうじょう 平生業成"
"へいぜん 平然"
"へいそ 平素"
"へいそう 兵装 併走 並走"
"へいそく 閉塞"
"へいそつ 兵卒"
"へいそん 併存"
"へいぞん 並存"
"へいたい 兵隊"
"へいたん 兵站 平坦"
"へいだん 兵団"
"へいち 併置 並置 平地"
"へいちょう 敝腸 閉庁 兵長"
"へいてい 閉廷 平定"
"へいてん 弊店 閉店"
"へいどく 併読"
"へいどん 并呑"
"へいにん 併任"
"へいねつ 平熱"
"へいねん 平年"
"へいねんなみ 平年並"
"へいのうぶんり 兵農分離"
"へいのうみぶんり 兵農未分離"
"へいはく 幣帛"
"へいはち 平八"
"へいはちろう 平八郎"
"へいはつ 併発"
"へいはん 平版"
"へいばん 平板"
"へいふ 敝賦"
"へいふく 平伏 平服"
"へいぶん 平文"
"へいへい 平平"
"へいへいぼんぼん 平平凡凡"
"へいべい 平米"
"へいほう 兵法 平方 閉包"
"へいほうこん 平方根"
"へいほうめーとる 平方米"
"へいぼん 平凡"
"へいまく 閉幕"
"へいみん 平民"
"へいめい 平明"
"へいめん 平面"
"へいめんきょう 平面鏡"
"へいめんは 平面波"
"へいめんばん 平面板"
"へいもん 閉門"
"へいや 平野"
"へいゆ 平癒"
"へいゆう 併有"
"へいよう 並用 併用"
"へいようきょう 併用橋"
"へいり 弊履"
"へいりつ 並立"
"へいりょく 兵力"
"へいれつ 並列"
"へいれつきでん 並列饋電"
"へいれつけいてきおう 並列形適応"
"へいれつでえたひょうげん 並列データ表現"
"へいろ 平炉 閉路"
"へいろく 併録"
"へいわ 平和"
"へいわいじぐん 平和維持軍"
"へいわきねんどう 平和祈念堂"
"へいわじま 平和島"
"へいわとう 平和党"
"へき 日置 闢 辟 躄 甓 劈 璧 僻 碧 癖 壁"
"へきえき 辟易 へき易"
"へきえん 僻遠"
"へきかい 劈開 碧海"
"へきかん 壁間"
"へきが 壁画"
"へきがん 碧眼"
"へきくう 碧空"
"へきこういき 壁孔域"
"へきすう 僻陬"
"へきたい 壁体"
"へきち 隔地 僻地"
"へきちゅう 壁中"
"へきとう 劈頭"
"へきない 壁内"
"へきなん 碧南"
"へきはく 璧帛"
"へきめん 壁面"
"へきれき 霹靂"
"へくたーる ヘクタール"
"へくとぐらむ 瓸"
"へくとめーとる 粨"
"へくとりっとる 竡"
"へぐり 平群"
"へさき 舳先 舳"
"へそ 臍"
"へそのお 臍の緒"
"へた 戸田 蔕 蒂 下手"
"へたくそ 下手糞"
"へだ 戸田"
"へだたり 隔"
"へちま 糸瓜"
"へっど ヘッド"
"へっどほん ヘッドホン"
"へつ 暼 丿"
"へなちょこ 埴猪口"
"へび 蛇"
"へびどく 蛇毒"
"へぶ ヘブ"
"へぼんしき ヘボン式"
"へみ 逸見"
"へや 廰 廳 部屋"
"へやかず 部屋数"
"へやぎ 部屋着"
"へら 箆"
"へり 邉 邊 縁 辺"
"へりうむ ヘリウム"
"へりくつ 屁理屈"
"へるめっと ヘルメット"
"へん 騙 駢 邉 貶 諞 褊 蝙 胼 翩 變 扁 邊 偏 篇 遍 返 片 編 辺 変"
"へんあつ 変圧"
"へんい 変異 偏位 変移 偏移 変位"
"へんいき 変域"
"へんいたん 変異譚"
"へんえん 辺縁"
"へんおん 変音 変温"
"へんか 返歌 変化"
"へんかきゅう 変化球"
"へんかく 偏角 変革"
"へんかけい 変化形"
"へんかん 返環 返還 変換"
"へんかんし 変換史"
"へんき 偏倚"
"へんきゃく 返却"
"へんきゅう 返球"
"へんきょう 辺境 偏狭"
"へんきょく 偏極 編曲"
"へんきょくてん 変曲点"
"へんきん 返金"
"へんくつ 偏屈"
"へんけい 変型 辺形 変形"
"へんけいたい 変形体"
"へんけん 偏見"
"へんけんし 偏見視"
"へんげ 変化"
"へんこう 変光 偏向 偏光 変更"
"へんこうあん 変更案"
"へんこうこう 偏向光"
"へんこうせい 変光星"
"へんこうとどけ 変更届"
"へんこうばん 偏光板"
"へんこうまく 偏光膜"
"へんごう 辺合"
"へんさ 偏差"
"へんさい 返済"
"へんさん 編纂"
"へんざい 偏在 遍在"
"へんし 返詩 変死"
"へんしつ 偏執 変質"
"へんしつきょう 偏執狂"
"へんしゃ 編者"
"へんしゅ 騙取 変種"
"へんしゅう 編輯 偏執 編修 編集"
"へんしゅうきょう 偏執狂"
"へんしゅうずみ 編集済"
"へんしゅうびょう 偏執病"
"へんしゅうもの 編集物"
"へんしょ 返書"
"へんしょく 偏食 変色"
"へんしん 変心 偏心 変身 返信"
"へんじ 変事 返事"
"へんじこ 偏自己"
"へんじまち 返事待"
"へんじゃ 編者"
"へんじゅんいそうかん 偏順位相関"
"へんじょう 辺上 返上"
"へんじん 變人 変人"
"へんすう 変数"
"へんずつう 偏頭痛"
"へんせい 変性 遍性 編制 変成 編成"
"へんせいがん 変成岩"
"へんせいき 変声期"
"へんせいたん 編成端"
"へんせいふ 変成譜"
"へんせいふう 偏西風"
"へんせいもの 編成物"
"へんせつ 変節"
"へんせん 変遷"
"へんせんし 変遷史"
"へんそ 辺素"
"へんそう 変奏 変装 返送"
"へんそく 変速 変則"
"へんぞう 変造"
"へんたい 編隊 変体 変態"
"へんたいごと 編隊毎"
"へんち 辺地"
"へんちゅう 編注"
"へんちょ 編著"
"へんちょう 変長 偏重 変調"
"へんちょうは 変調波"
"へんてつ 変哲"
"へんてん 変転"
"へんでん 返電 変電"
"へんでんじょ 変電所"
"へんとう 扁桃 返答"
"へんとうえん 扁桃炎"
"へんとうせん 扁桃腺"
"へんどう 変動"
"へんどうかんすう 偏導関数"
"へんどうひ 変動費"
"へんなひと 變な人"
"へんにゅう 編入"
"へんのう 返納"
"へんばい 変倍"
"へんぱ 偏波"
"へんびぶん 偏微分"
"へんびょうし 変拍子"
"へんぴ 辺鄙"
"へんぴん 返品"
"へんふく 蝙蝠"
"へんふくちょう 変復調"
"へんぶん 変分"
"へんぷ 返付"
"へんぺい 扁平"
"へんぺいそく 扁平足 偏平足"
"へんぺいりつ 偏平率"
"へんぺん 辺々"
"へんぼう 変貌"
"へんぽう 偏法 返報"
"へんぽん 返本"
"へんまもう 偏摩耗"
"へんみ 逸見 辺見"
"へんめい 変名"
"へんよう 遍用 変容"
"へんりょう 変量"
"へんりん 辺燐 片鱗"
"へんれい 返戻 返礼"
"へんれき 遍歴"
"へんろ 遍路"
"べ 邉 邊 倍 部 辺"
"べーこん ベーコン"
"べーす ベース"
"べーた β"
"べーたせん β線"
"べーたは β波"
"べあ ベア"
"べい 米"
"べいえい 米英"
"べいえいが 米映画"
"べいえいぐん 米英軍"
"べいえいらん 米英蘭"
"べいか 米価"
"べいかんたい 米艦隊"
"べいがわ 米側"
"べいくうぼ 米空母"
"べいぐん 米軍"
"べいこく 米穀 米国"
"べいこくさん 米国産"
"べいこくぼうしょう 米国防省"
"べいご 米語"
"べいさく 米作"
"べいさん 米産"
"べいしきしゅうきゅう 米式蹴球"
"べいしゃ 米車"
"べいしゅう 米収"
"べいしゅん 米春"
"べいしょく 米食"
"べいじゅ 米寿"
"べいじょういん 米上院"
"べいじょうほうぶ 米情報部"
"べいじん 米人"
"べいせいせんそう 米西戦争"
"べいせいふ 米政府"
"べいそ 米ソ"
"べいだいがく 米大学"
"べいだいとうりょう 米大統領"
"べいちゅう 米駐"
"べいちょう 米朝"
"べいてい 米帝"
"べいはん 米飯"
"べいふん 米粉"
"べいへい 米兵"
"べいべつ 袂別"
"べいほんごく 米本国"
"べえ 兵衛"
"べえた β"
"べき 覓 汨 幎 冪 冖 巾 羃"
"べきじょう 冪乗 巾乗 べき乗 羃乗"
"べきすう 冪数"
"べく 可"
"べくさかずき 可杯"
"べくとる ベクトル"
"べすと ベスト"
"べすとせらー ベストセラー"
"べっかい 別解"
"べっかく 別格"
"べっかん 別巻 別館"
"べっき 別記"
"べっきょ 別居"
"べっけん 瞥見 別件"
"べっこ 別箇 別個"
"べっこう 別敲 鼈甲 別項"
"べっさつ 別冊"
"べっさつもの 別冊物"
"べっし 別使 蔑視 別紙"
"べっしつ 別室"
"べっしやま 別子山"
"べっしゅ 別種"
"べっしょ 別所"
"べっしょう 蔑称 別証 別称"
"べっせい 別姓"
"べっせかい 別世界"
"べっせつ 別節"
"べっせん 別線"
"べっそう 別送 別荘"
"べったい 別体"
"べったく 別宅"
"べっちゃく 別役"
"べっちゅう 別注"
"べってい 別邸 別定"
"べってん 別添"
"べってんち 別天地"
"べっと 別途"
"べっとう 別当"
"べっとうや 別当家"
"べっど ベッド"
"べっぴょう 別表"
"べっぴん 別嬪"
"べっぷ 別府"
"べっぷう 別封"
"べっぽう 別法 別報"
"べつ 捌 鼈 韈 瞥 蔑 別"
"べつあつかい 別扱い"
"べつあん 別案"
"べついけん 別意見"
"べつうちゅう 別宇宙"
"べつうり 別売"
"べつかい 別海"
"べつかいけい 別会計"
"べつかいひ 別会費"
"べつかんり 別管理"
"べつがいしゃ 別会社"
"べつがいねん 別概念"
"べつがっこう 別学校"
"べつきかく 別規格"
"べつきじ 別記事"
"べつぎ 別儀"
"べつぎょうしゅ 別業種"
"べつくち 別口"
"べつけいえい 別経営"
"べつけいしき 別形式"
"べつけいとう 別系統"
"べつけいやく 別契約"
"べつけいゆ 別経由"
"べつけいろ 別経路"
"べつこう 別稿"
"べつこうどう 別行動"
"べつこうほち 別候補地"
"べつさくひん 別作品"
"べつしほん 別資本"
"べつしゃしゅ 別車種"
"べつしょうひん 別商品"
"べつしょり 別処理"
"べつしんごう 別信号"
"べつしんぱん 別審判"
"べつじ 別字"
"べつじげん 別次元"
"べつじゅうしょ 別住所"
"べつじょう 別状"
"べつじん 別人"
"べつじんかく 別人格"
"べつすじ 別筋"
"べつず 別図"
"べつずり 別刷り 別刷"
"べつせかい 別世界"
"べつせっけい 別設計"
"べつせんめい 別線名"
"べつそしき 別組織"
"べつそんざい 別存在"
"べつたいけい 別体系"
"べつたいしき 別体式"
"べつだい 別大"
"べつだん 別段"
"べつだんたい 別団体"
"べつとうこう 別投稿"
"べつとうひょう 別投票"
"べつどうたい 別動隊"
"べつどり 別録り"
"べつに 別に"
"べつにゅうじょう 別入場"
"べつのう 別納"
"べつばい 別売"
"べつばんぐみ 別番組"
"べつばんごう 別番号"
"べつびん 別便"
"べつふ 別布"
"べつぶんしょ 別文書"
"べつぶんや 別分野"
"べつべつ 別々"
"べつべや 別部屋"
"べつほうこう 別方向"
"べつみや 別宮"
"べつむね 別棟"
"べつめい 別名"
"べつめいあて 別名宛"
"べつめいれい 別命令"
"べつめん 別面"
"べつもじ 別文字"
"べつもの 別物"
"べつもんだい 別問題"
"べつやく 別役"
"べつようそ 別要素"
"べつり 別離"
"べつりょうきん 別料金"
"べつれっしゃ 別列車"
"べつろく 別録"
"べつろせん 別路線"
"べつわく 別枠"
"べてらん ベテラン"
"べとなむせんそう ベトナム戦争"
"べに 紅"
"べにいろ 紅色"
"べにお 紅緒"
"べにくじらだん 紅鯨団"
"べにしゃけ 紅鮭"
"べにじゃけ 紅鮭"
"べにはぎ 紅萩"
"べにばな 紅花"
"べにばなゆ 紅花油"
"べにばやし 紅林"
"べにまる 紅丸"
"べびー ベビー"
"べふ 別府"
"べや 部屋"
"べらぼう 箆棒"
"べりーず ベリーズ"
"べる ベル"
"べるぎー 白耳義"
"べると ベルト"
"べるりん 伯林"
"べん 采 辯 辮 眄 瓣 湎 汳 抃 宀 卞 辧 辨 冕 娩 鞭 便 勉 弁"
"べんい 便意"
"べんえき 便益"
"べんかい 弁解"
"べんがく 勉学"
"べんき 便器"
"べんきょう 勉強"
"べんきょうか 勉強家"
"べんぎ 便宣 便宜"
"べんけい 弁慶"
"べんげい 眄睨"
"べんご 弁護"
"べんごし 弁護士"
"べんさい 弁済"
"べんざ 便座"
"べんざいてん 弁財天"
"べんし 弁士"
"べんしつ 弁室"
"べんしょう 弁償"
"べんしょうほう 弁証法"
"べんじょ 便所"
"べんぜつ 弁舌"
"べんぞう 勉三"
"べんたつ 鞭撻"
"べんだ ベンダ"
"べんちゃ ベンチャ"
"べんちゃー ベンチャー"
"べんつう 便通"
"べんてん 弁天"
"べんてんじま 弁天島"
"べんとう 弁当"
"べんとうばこ 弁当箱"
"べんとうぶくろ 弁当袋"
"べんぱつ 辮髪 弁髪"
"べんぴ 便秘"
"べんぴやく 便秘薬"
"べんべつ 弁別"
"べんべつげん 弁別限"
"べんぽう 便法"
"べんむかん 弁務官"
"べんめい 弁明"
"べんもう 鞭毛"
"べんらん 便覧"
"べんり 弁理 便利"
"べんりし 弁理士"
"べんりちょう 便利帖 便利帳"
"べんれい 勉励"
"べんろん 弁論"
"ぺーじ ページ 頁"
"ぺーす ペース"
"ぺーすと ペースト"
"ぺーぱー ペーパー"
"ぺあ ペア"
"ぺい 北 閇 蔽 併 閉 平"
"ぺいがん 頁岩"
"ぺいじ 頁"
"ぺえ 北"
"ぺえじ 頁"
"ぺがさす ペガサス"
"ぺき 北"
"ぺきん 北京"
"ぺけ ×"
"ぺけぺけ ××"
"ぺしみすと ペシミスト"
"ぺってぃんぐ ペッティング"
"ぺっと ペット"
"ぺとりさら ペトリ皿"
"ぺなるてぃ ペナルティ"
"ぺにーれいん ペニーレイン"
"ぺふちょう 別府町"
"ぺるー 祕露 祕魯"
"ぺるしあ 波斯"
"ぺるしゃ ペルシャ"
"ぺるしゃわん ペルシャ湾"
"ぺん 邉 邊 ペン 辺 片"
"ぺんき ペンキ"
"ぺんぎん ペンギン"
"ぺんしょん ペンション"
"ぺんときしろんあこう ペントキシロン亜綱"
"ぺんとはうす ペントハウス"
"ほ 葡 畝 蒲 浦 黼 鯆 餔 逋 葆 舖 脯 穗 堡 埔 匍 哺 舗 鋪 圃 帆 捕 輔 甫 歩 補 保 穂"
"ほーていらおゆい 河底撈魚"
"ほーみんぐ ホーミング"
"ほーむ ホーム"
"ほーる ホール"
"ほあん 保安"
"ほあんちょう 保安庁"
"ほあんりん 保安林"
"ほい 補遺"
"ほいく 哺育 保育"
"ほいくじょ 保育所"
"ほいこうろう 回鍋肉"
"ほいだ 穂井田"
"ほう 朴 棒 鴇 蔀 鞄 瀑 縫 麭 魴 髣 迸 豐 襃 褓 袍 萠 苞 舫 繃 篷 磅 硼 皰 疱 琺 焙 炮 澎 泙 枋 抛 抔 怦 彭 弸 幇 寶 堋 垉 咆 匚 匏 勹 保 逢 烽 寳 奉 峰 彷 俸 庖 倣 烹 捧 宝 峯 呆 萌 蜂 褒 包 芳 鋒 飽 鳳 抱 朋 蓬 胞 鵬 訪 豊 崩 邦 砲 泡 放 報 法 方"
"ほうあん 法案"
"ほうい 法衣 包囲 方位"
"ほういかいぼう 法医解剖"
"ほういかく 方位角"
"ほういがく 法医学"
"ほういけん 放医研"
"ほういせん 包囲戦"
"ほういつ 放逸"
"ほうえい 訪英 放映"
"ほうえいじかんやく 放映時間約"
"ほうえいじゅん 放映順"
"ほうえつ 法悦"
"ほうおう 鳳凰 訪欧 鳳王 法皇 法王"
"ほうか 砲火 法家 放課 烽火 邦貨 法科 放火"
"ほうかい 崩潰 崩解 崩壊"
"ほうかいしゃく 法解釈"
"ほうかいせい 法改正"
"ほうかいせき 方解石"
"ほうかだて 邦貨建"
"ほうかつ 包括"
"ほうかん 幇間 訪韓 奉還"
"ほうかんじょう 法感情"
"ほうが 萠芽 萌茅 萌芽 邦画 奉賀"
"ほうがい 法外"
"ほうがいねん 法概念"
"ほうがく 法学 邦楽 方角"
"ほうがっか 法学科"
"ほうがっき 邦楽器"
"ほうがてき 胞芽的"
"ほうがん 砲丸 方眼 包含"
"ほうがんし 方眼紙"
"ほうがんなげ 砲丸投げ"
"ほうき 抛棄 菷 筝 箏 箒 彗 帚 蜂起 伯耆 法規 放棄"
"ほうきはん 法規班"
"ほうきぼし 箒星 彗星"
"ほうきゅう 俸給"
"ほうきょう 法橋"
"ほうきん 宝金"
"ほうぎょ 崩御"
"ほうぎょく 宝玉"
"ほうけい 法経 方形 包茎"
"ほうけいけいがくぶ 法経系学部"
"ほうけいは 方形波"
"ほうけん 封建"
"ほうげ 放下"
"ほうげき 崩撃 砲撃"
"ほうげきしゅ 砲撃手"
"ほうげきせん 砲撃戦"
"ほうげん 放言 方言"
"ほうこ 宝庫"
"ほうこう 彷徨 咆哮 放校 奉公 芳香 奉行 方向"
"ほうこうあわせ 方向合わせ"
"ほうこうかんてき 報交換的"
"ほうこうしゅう 芳香臭"
"ほうこうだ 方向舵"
"ほうこうまく 方向幕"
"ほうこく 豊国 報国 報告"
"ほうこくき 報告記"
"ほうごう 抱合 縫合"
"ほうさい 朋斎"
"ほうさか 逢坂"
"ほうさく 豊作 方策"
"ほうさん 硼酸 放散"
"ほうざ 砲座"
"ほうざい 包材"
"ほうざわ 寶澤"
"ほうし 芳志 胞子 法師 奉仕 包子"
"ほうしき 方式"
"ほうしゃ 放射"
"ほうしゃかいがく 法社会学"
"ほうしゃげん 放射源"
"ほうしゃこう 放射光"
"ほうしゃせんしょうい 放射線照射"
"ほうしゃのう 放射能"
"ほうしゅう 報酬"
"ほうしゅく 奉祝"
"ほうしゅつ 放出"
"ほうしゅやま 宝珠山"
"ほうしょ 邦書"
"ほうしょう 褒章 法相 報賞 報奨 報償 宝商 褒賞 宝生 放縦"
"ほうしょうじ 宝生寺"
"ほうしょうりゅう 宝生流"
"ほうしょがみ 奉書紙"
"ほうしょく 飽食 奉職"
"ほうしん 疱疹 庖疹 砲身 放心 方針"
"ほうじ 法事"
"ほうじちゃ 焙じ茶"
"ほうじゅう 放縱 放縦 放銃"
"ほうじゅく 豊熟"
"ほうじゅつ 砲術"
"ほうじゅん 芳醇"
"ほうじょ 幇助"
"ほうじょう 方城 豊饒 豊穰 豊穣 方乗 北条 宝条 北條"
"ほうじょうえ 放生会"
"ほうじょうや 放生会"
"ほうじん 邦人 法人"
"ほうじんかく 法人格"
"ほうじんぜい 法人税"
"ほうすい 豊水 放水"
"ほうすいしゃ 放水車"
"ほうすいろ 放水路"
"ほうすう 砲数"
"ほうすけ 保介"
"ほうすん 方寸"
"ほうせい 砲声 縫製 法制 法政 方正"
"ほうせいだいこう 法政大工"
"ほうせいび 法整備"
"ほうせき 宝石"
"ほうせきしょう 宝石商"
"ほうせきばこ 宝石箱"
"ほうせつ 包摂"
"ほうせつかごうぶつ 包接化合物"
"ほうせん 砲戦 奉先 芳泉 法線 豊泉"
"ほうせんか 鳳仙花"
"ほうせんがくえん 宝仙学園"
"ほうそ 硼素"
"ほうそう 法曽 疱瘡 法曹 包装 放送"
"ほうそうききてん 放送機器展"
"ほうそうきょう 放送響"
"ほうそうし 包装紙"
"ほうそうじゅん 放送順"
"ほうそうせき 放送席"
"ほうそうとうむき 放送塔向"
"ほうそうは 放送波"
"ほうそうはん 放送班"
"ほうそうわく 放送枠"
"ほうそく 法則"
"ほうぞう 法蔵 包蔵"
"ほうたい 繃帯 胞体 方体 包帯"
"ほうたいけい 法体系"
"ほうたく 飽託"
"ほうだ 法田"
"ほうだい 法大 邦題 砲台 放題"
"ほうだん 砲彈 砲弾 放談"
"ほうち 報知 法治 放置"
"ほうちく 放逐"
"ほうちしき 法知識"
"ほうちしゃ 放置車"
"ほうちゃく 縫着 逢着"
"ほうちゅう 訪中"
"ほうちょう 庖丁 包丁"
"ほうてい 法定 法廷"
"ほうていけい 法定刑"
"ほうていしき 方程式"
"ほうてき 法的"
"ほうてきばつ 法的罰"
"ほうてつがく 法哲学"
"ほうてん 方転 奉天 宝典 法典"
"ほうでん 宝殿 放電"
"ほうと 方途"
"ほうとう 砲塔 放蕩 宝刀"
"ほうとくがくえん 報徳学園"
"ほうとり 放取"
"ほうど 封土"
"ほうどう 報導 報道"
"ほうどく 奉読"
"ほうなん 方南 豊南"
"ほうにち 訪日"
"ほうにょう 放尿"
"ほうにん 放任"
"ほうねつ 放熱"
"ほうねつばん 放熱板"
"ほうねん 法然 豊年 放念"
"ほうのう 奉納"
"ほうはく 鵬搏"
"ほうば 放馬"
"ほうばい 傍輩"
"ほうひ 豊肥 放屁"
"ほうび 褒美"
"ほうふ 豊府 防府 豊冨 抱負 豊富"
"ほうふく 抱腹 報復"
"ほうふくじ 豊福寺"
"ほうふくぜっとう 抱腹絶倒"
"ほうふつ 髣髴 彷彿"
"ほうぶつ 放物"
"ほうぶつせん 抛物線"
"ほうぶん 法文 報文 邦文"
"ほうぶんしゃ 芳文社"
"ほうへい 砲兵"
"ほうへきざん 豊碧山"
"ほうへん 褒貶"
"ほうべい 訪米"
"ほうべん 方便"
"ほうほう 方法"
"ほうほく 豊北"
"ほうぼう 謗法 竹麦魚 魴ボウ 鋒鋩 蜂房 宝坊 方方 方々"
"ほうぼく 放牧"
"ほうまつ 泡沫"
"ほうまん 豊満 放漫"
"ほうみょう 法名"
"ほうむ 放夢 法務"
"ほうむしょう 法務省"
"ほうむちょうけんかい 法務庁見解"
"ほうめい 邦名 法明 芳名"
"ほうめいちょう 芳名帳"
"ほうめいぼ 芳名簿"
"ほうめん 放免 方面"
"ほうめんぐん 方面軍"
"ほうもう 法網"
"ほうもつ 宝物"
"ほうもん 砲門 訪問"
"ほうもんきゃく 訪問客"
"ほうもんぎ 訪問着"
"ほうや 保谷"
"ほうやく 邦訳"
"ほうやくずみ 邦訳済"
"ほうよう 苞葉 放鷹 包葉 法要 包容 抱擁"
"ほうら 和了"
"ほうらい 鳳来 寳来 蓬莢 宝来"
"ほうらいじ 鳳来寺"
"ほうらく 炮烙 崩落 包絡"
"ほうらくのうたげ 炮烙の宴 炮烙之宴"
"ほうらくのけい 炮烙之刑"
"ほうらくまんじゅう 蜂楽饅頭"
"ほうらけい 和了形"
"ほうらつ 放埒"
"ほうり 法理 宝利"
"ほうりき 法力"
"ほうりつ 法律"
"ほうりつあん 法律案"
"ほうりつか 法律家"
"ほうりつこん 法律婚"
"ほうりゃく 方略"
"ほうりゅう 放流"
"ほうりゅうぎょ 放流魚"
"ほうりゅうじ 法隆寺"
"ほうりょう 豊漁"
"ほうりん 法林"
"ほうりんどうしょてん 芳林堂書店"
"ほうるい 堡塁"
"ほうれい 法例 法令"
"ほうれきほん 宝暦本"
"ほうれん 法蓮"
"ほうれんそう 菠薐草 ほうれん草 法蓮草"
"ほうろう 琺瑯 放浪"
"ほうろうき 放浪記"
"ほうろうへき 放浪癖"
"ほうろく 焙烙"
"ほうろん 放論"
"ほうわ 豊和 法話 飽和"
"ほうわすいじょうきあつ 飽和水蒸気圧"
"ほえづら 吠面"
"ほお 頬"
"ほおずり 頬擦り ほお擦り"
"ほおづえ 頬杖"
"ほおひげ 髯"
"ほおべに 頬紅"
"ほおぼね 頬骨"
"ほおん 保温"
"ほおんなべ 保温鍋"
"ほか 外 他"
"ほかいちめい 他一名"
"ほかおおぜい 他多勢 他大勢"
"ほかく 捕獲 保革"
"ほかげ 帆影 灯かげ"
"ほかすうめい 他数名"
"ほかたすう 他多数"
"ほかなんにん 他何人"
"ほかに 他に"
"ほかの 他の"
"ほかふたり 他二人"
"ほかぶり 頬被り"
"ほかん 補間 補完 保管"
"ほかんじょ 保管所"
"ほがい 補外"
"ほがらか 朗らか"
"ほき 補機 補記"
"ほきもと 保木本"
"ほきゅう 捕球 補給"
"ほきゅうへい 補給兵"
"ほきょう 補強"
"ほきょうざい 補強材"
"ほきょうようぶひん 補強用部品"
"ほきん 保菌"
"ほぎうた 寿歌"
"ほく 瀑 蹼 殕 攵 攴 北"
"ほくい 北緯"
"ほくうかん 補空間"
"ほくえい 北瑛"
"ほくえつ 北越"
"ほくおう 北欧"
"ほくがん 北岸"
"ほくげん 北限"
"ほくこう 北興"
"ほくさい 北斎"
"ほくさつほうげん 北薩方言"
"ほくしゅう 北州"
"ほくしん 北辰"
"ほくしんえつ 北信越"
"ほくしんきゅうこう 北神急行"
"ほくじょう 北上"
"ほくせい 北勢 北西"
"ほくせいそう 北誠荘"
"ほくせつ 北摂"
"ほくせん 北線"
"ほくそ 樮"
"ほくそうかいはつてつどう 北総開発鉄道"
"ほくそうせん 北総線"
"ほくそうちいき 北総地域"
"ほくそうてつどう 北総鉄道"
"ほくたん 北端"
"ほくたんてつどう 北丹鉄道"
"ほくだい 北海道大学 北大"
"ほくだん 北淡"
"ほくちょう 北朝"
"ほくてき 北狄"
"ほくてつ 北鉄"
"ほくてん 北天"
"ほくてんゆう 北天佑"
"ほくと 北斗"
"ほくとう 北東"
"ほくとうみ 北勝海"
"ほくとき 北斗旗"
"ほくとせい 北斗星"
"ほくとのけん 北斗の拳"
"ほくばく 北爆"
"ほくぶ 北部"
"ほくへき 北壁"
"ほくべい 北米"
"ほくべいさん 北米産"
"ほくほくせい 北北西"
"ほくほくとう 北々東 北北東"
"ほくぼう 北房"
"ほくめい 北溟"
"ほくよう 北洋"
"ほくようだい 北陽台"
"ほくりく 北陸"
"ほくりくさんけん 北陸三県"
"ほくりくじ 北陸路"
"ほくりじ 北陸路"
"ほくりゅう 北龍 北竜"
"ほくりょう 北陵"
"ほくりょなんわ 北虜南倭"
"ほけきょう 法華経"
"ほけつ 補欠"
"ほけつば 補欠馬"
"ほけん 保健 保険"
"ほけんがく 保険額"
"ほけんじょ 保健所"
"ほけんふ 保健婦"
"ほけんやく 保険薬"
"ほげい 捕鯨"
"ほげいせん 捕鯨船"
"ほげん 補元"
"ほこ 桙 矛 鉾"
"ほこう 補講 歩行"
"ほこうそ 補酵素"
"ほこさき 鋒 鋒先 矛先"
"ほこた 鉾田"
"ほこてん 歩行者天国"
"ほこら 祠 叢祠"
"ほこり 誇り 埃 ホコリ"
"ほこりたいさく 埃対策"
"ほご 反故 反古 補語 保護"
"ほごえき 保護液"
"ほごたいさく 保護政策"
"ほごりん 保護林"
"ほごわく 保護枠"
"ほさ 輔佐 補佐"
"ほさか 保坂"
"ほさき 芒 穂先"
"ほさく 補作"
"ほさやく 補佐役"
"ほざわ 保沢"
"ほし 干し ＊ ※ ★ ☆ 星"
"ほしあい 星合"
"ほしい 星井 欲しい"
"ほしいってつ 星一徹"
"ほしいまま 恣"
"ほしおき 星置"
"ほしかげ 星影"
"ほしかわ 星川"
"ほしがおか 星ヶ丘"
"ほしがた 星型"
"ほしくさ 干し草"
"ほしくさもく ホシクサ目"
"ほしくず 星屑"
"ほしくら 星倉"
"ほしぐみ 星組"
"ほしさと 星里"
"ほしざわ 星沢"
"ほししいたけ 干椎茸"
"ほししんいち 星新一"
"ほしじし 干肉"
"ほしじるし 星印"
"ほしぞら 星空"
"ほしたに 星谷"
"ほしつえき 保湿液"
"ほしつりょく 保湿力"
"ほしで 星出"
"ほしとり 星取"
"ほしな 星名 保科"
"ほしの 星野"
"ほしば 保志場 干場"
"ほしひょうめん 星表面"
"ほしぼし 星々"
"ほしみや 星宮"
"ほしもと 星本"
"ほしゃく 保釈"
"ほしや 星谷 星矢"
"ほしやま 星山"
"ほしゅ 補手 捕手 保守"
"ほしゅう 捕囚 補習 補修"
"ほしゅうごう 補集合"
"ほしゅうひ 補修費"
"ほしゅとう 保守党"
"ほしゅひ 保守費"
"ほしゅようしゃ 保守用車"
"ほしょう 歩哨 堡礁 補償 保障 保証"
"ほしょうがく 保証額"
"ほしょうぎれ 保証切れ"
"ほしょうでんりょくげん 補償電力源"
"ほしょく 補色 捕食 補食"
"ほしよう 補仕様"
"ほしん 保身"
"ほじ 保持"
"ほじゅう 補充"
"ほじゅうえき 補充液"
"ほじょ 補助"
"ほじょぐ 補助具"
"ほじょけん 補助券"
"ほじょこう 補助光"
"ほじょせき 補助席"
"ほじょとう 補助灯"
"ほじょろ 補助路"
"ほじりょく 保磁力"
"ほすい 保水"
"ほすう 歩数 補数"
"ほすてす ホステス"
"ほすと ホスト"
"ほずみ 穂積"
"ほせい 補整 補正"
"ほせいいた 補正板"
"ほせいかじょう 補性過剰"
"ほせつ 補綴 補説"
"ほせん 保線 補選"
"ほぜい 保税"
"ほぜん 保全"
"ほそ 細"
"ほそい 細井"
"ほそいり 細入"
"ほそう 鋪装 舗装"
"ほそうろ 舗装路"
"ほそえ 細江"
"ほそおか 細岡"
"ほそかわ 細川"
"ほそがい 細貝"
"ほそき 細木"
"ほそぎ 細木"
"ほそく 歩速 歩測 捕捉 補則 補足"
"ほそくら 細倉"
"ほそざわ 細澤"
"ほそじ 細字"
"ほそだ 細田"
"ほその 細野"
"ほそはら 細原"
"ほそぶち 細渕"
"ほそべ 細部"
"ほそぼそ 細々"
"ほそまる 細丸"
"ほそみ 細見 細身"
"ほそみち 細道"
"ほそみんちょうたい 細明朝体"
"ほそめ 細目"
"ほそめん 細麺"
"ほそや 細矢 細谷"
"ほそよこちょう 細横町"
"ほぞ 臍"
"ほぞく 保続"
"ほぞん 保存"
"ほぞんこ 保存庫"
"ほぞんしゃ 保存車"
"ほぞんしょく 保存食"
"ほたい 補体 保体"
"ほたか 穂高"
"ほたて 帆立"
"ほたに 保谷"
"ほたる 火垂る 螢 蛍"
"ほたるいし 蛍石"
"ほたるがいけ 蛍ケ池 蛍池"
"ほたるがわ 蛍川"
"ほたるじゃや 蛍茶屋"
"ほたるぞく 蛍族"
"ほたるまつり 蛍祭"
"ほだい 補題"
"ほだか 穂高"
"ほちゅう 補注"
"ほちょう 補聴 歩調"
"ほっ 發 発"
"ほっかい 法界 北海"
"ほっかいどうさん 北海道産"
"ほっかいどうさんまい 北海道産米"
"ほっかいどうてん 北海道展"
"ほっかいどうみなみ 北海道南"
"ほっき 発起"
"ほっきょく 北極"
"ほっきょくかん 北極冠"
"ほっきょくせい 北極星"
"ほっけ 法華"
"ほっけー ホッケー"
"ほっこく 北国"
"ほっこくぎんこう 北國銀行"
"ほっさ 発作"
"ほっしん 発疹 発心"
"ほっす 法主 法子 払子"
"ほっせき 発赤"
"ほっそく 発足"
"ほった 掘田 堀田"
"ほったて 掘建"
"ほったん 発端"
"ほっちきす ホッチキス"
"ほっと ホット"
"ほっぽう 北方"
"ほっぽうよんとうえんがん 北方四島沿岸"
"ほつ 発"
"ほつうきょう 保通協"
"ほづ 保津"
"ほづきょう 保津峡"
"ほづみ 穂積"
"ほてい 保定 補綴 布袋"
"ほてつ 補綴"
"ほてる ホテル"
"ほてん 保典 補填"
"ほとけ 佛 仏"
"ほとけさま 仏様"
"ほととぎす 子規 不如帰 蜀魂 杜鵑"
"ほとり 邉 邊 滸 畔 辺"
"ほとんど 殆んど 殆 幾ど 殆ど"
"ほど 程"
"ほどあい 程合"
"ほどう 舖道 舗道 歩道 補導"
"ほどうきょう 補導協 歩道橋"
"ほどがや 保土ヶ谷 保土が谷"
"ほどこし 施し"
"ほどほど 程々"
"ほない 保内"
"ほなが 保永"
"ほなみ 穂波 保奈美"
"ほにゅう 哺乳"
"ほにゅうびん 哺乳瓶"
"ほね 骨"
"ほねおり 骨折り"
"ほねかわ 骨川"
"ほねぐみ 骨組 骨組み"
"ほねざかな 骨魚"
"ほねつぎ 骨接ぎ"
"ほねつりょく 保熱力"
"ほねぬき 骨抜き 骨抜"
"ほねぶと 骨太"
"ほねみ 骨身"
"ほねやすみ 骨休み"
"ほねやすめ 骨休め"
"ほのお 焔 炎"
"ほのか 仄か"
"ほのぼの 仄仄 仄々"
"ほはば 歩幅"
"ほばしら 艢 檣 帆柱"
"ほばら 保原"
"ほひつ 補弼 補筆"
"ほびー ホビー"
"ほふ 保父"
"ほふく 匍匐"
"ほへい 歩兵"
"ほべつ 穂別"
"ほほ 頬"
"ほほえみ 微笑 微笑み"
"ほほずゑ 頬杖"
"ほほづえ 頬杖"
"ほぼ 保姆 保母"
"ほまえ 帆前"
"ほまれ 誉 誉れ"
"ほむら 焔"
"ほめことば 褒め言葉"
"ほやがらす 保谷硝子"
"ほやなぎ 保柳"
"ほゆう 保有"
"ほゆうぜい 保有税"
"ほよう 歩容 保養"
"ほようじょ 保養所"
"ほら 法螺 洞"
"ほらー ホラー"
"ほらあな 洞穴"
"ほらがい 法螺貝"
"ほらがとうげ 洞ヶ峠"
"ほらど 洞戸"
"ほり 濠 壕 堀"
"ほりい 堀居 堀井"
"ほりいけ 堀池"
"ほりうち 堀内"
"ほりえ 堀江"
"ほりお 堀尾"
"ほりかわ 堀河 堀川"
"ほりがね 堀金"
"ほりぐち 堀口"
"ほりげん 堀玄"
"ほりこし 堀越"
"ほりごめ 堀米 堀込"
"ほりさき 堀崎"
"ほりた 堀田"
"ほりたつお 堀辰雄"
"ほりだし 掘り出し"
"ほりだしもの 掘り出し物"
"ほりの 堀野"
"ほりのうち 堀之内"
"ほりのくち 堀之口"
"ほりば 堀場"
"ほりばた 堀端"
"ほりべ 堀辺 堀部"
"ほりまつ 堀松"
"ほりもと 堀本"
"ほりもの 彫物"
"ほりゅう 保留"
"ほりょ 捕虜"
"ほるい 堡塁"
"ほれい 保冷"
"ほれいざい 保冷材"
"ほろ 袰 幌"
"ほろいずみ 幌泉"
"ほろいわやまてんぼうだい 幌岩山展望台"
"ほろかない 幌加内"
"ほろぐらふぃ ホログラフィ"
"ほろつき 幌付き"
"ほろのべ 幌延"
"ほろばしゃ 幌馬車"
"ほろべつ 幌別"
"ほわいと ホワイト"
"ほわんちゅー 黄酒"
"ほん 叛 飜 笨 畚 犇 奔 翻 本"
"ほんあざ 本字"
"ほんあん 翻案 本案"
"ほんい 翻意 本意 本位"
"ほんいだ 本位田"
"ほんいでん 本位田"
"ほんいん 本因"
"ほんいんぼう 本因坊"
"ほんいんぼうせん 本因坊戦"
"ほんえい 本影 本営"
"ほんか 本歌 本科"
"ほんかい 本懐 本会"
"ほんかく 本格"
"ほんかくもの 本格物"
"ほんかわ 本革"
"ほんかん 本管 本官 本艦 本館"
"ほんがかり 本係"
"ほんがく 本学"
"ほんがわ 本川"
"ほんがん 本願"
"ほんがんじ 本願寺"
"ほんき 本機 本期 本気"
"ほんきゅう 本給"
"ほんきょ 本挙 本拠"
"ほんきょく 本局"
"ほんぎ 本義"
"ほんぎまり 本決まり"
"ほんぎょう 本業"
"ほんぐう 本宮"
"ほんぐうさん 本宮山"
"ほんけ 本家"
"ほんけい 本慧"
"ほんけつ 本決"
"ほんけん 本券 本件"
"ほんけんきゅじょ 本研究所"
"ほんげい 本芸"
"ほんげつ 本月"
"ほんこう 本校 本項 本稿"
"ほんこく 翻刻"
"ほんこん 香港"
"ほんこんかんりちく 港湾管理地区"
"ほんこんとう 香港島"
"ほんこんもの 香港物"
"ほんご 本語"
"ほんごう 本号 本郷"
"ほんごうそうもく ホンゴウソウ目"
"ほんごく 本国"
"ほんごくむけ 本国向け"
"ほんごし 本腰"
"ほんさい 本妻"
"ほんさく 本作"
"ほんさん 本三"
"ほんざん 本山"
"ほんし 本四 本紙 本旨 本誌"
"ほんしき 本式"
"ほんしつ 本質"
"ほんしびさんせん 本四備讃線"
"ほんしゃ 本社"
"ほんしゅう 本州"
"ほんしゅつ 奔出 本出"
"ほんしょ 本所 本署 本書"
"ほんしょう 本荘 本症 本賞 本省 本性 本章"
"ほんしょく 本職"
"ほんしん 本震 本審 本心"
"ほんじ 本字"
"ほんじつ 本日"
"ほんじつよる 本日夜"
"ほんじょあずまばし 本所吾妻橋"
"ほんじょう 本匠 本状 本条 本城 本庄"
"ほんじん 本陣"
"ほんすう 本数"
"ほんすじ 本筋"
"ほんずき 本好き"
"ほんせい 本制 本性"
"ほんせき 本籍"
"ほんせつ 本節"
"ほんせん 本戦 本船 本線"
"ほんせんかい 本選会"
"ほんせんぞい 本線沿い"
"ほんせんもけい 帆船模型"
"ほんぜん 本然"
"ほんそう 本送 奔走"
"ほんそく 本則"
"ほんぞん 本尊"
"ほんたい 本隊 本体"
"ほんたく 本宅"
"ほんたて 本立"
"ほんだ 誉田 本多 本田"
"ほんだい 本代 本題"
"ほんだて 本立"
"ほんだな 本棚"
"ほんち 本地"
"ほんちすいしゃくせつ 本地垂迹説"
"ほんちすいじゃくせつ 本地垂迹説"
"ほんちゅう 本中"
"ほんちょう 本朝 本庁 本町"
"ほんづけ 本付"
"ほんて 本手"
"ほんてき 本的"
"ほんてん 本店"
"ほんでん 本殿"
"ほんと 本当"
"ほんとう 本棟 本島 奔騰 本当"
"ほんど 本渡 本土"
"ほんどう 本堂 本道"
"ほんどく 本読"
"ほんどないけいゆ 本土内経由"
"ほんにん 本人"
"ほんにんあて 本人宛"
"ほんね 本音"
"ほんねん 本年"
"ほんのう 本能"
"ほんのうじ 本能寺"
"ほんのまち 本の街"
"ほんば 本場"
"ほんばこ 本箱"
"ほんばもの 本場物"
"ほんばん 本番"
"ほんぱん 紅幇"
"ほんびき 本引"
"ほんぴん 本品"
"ほんぶ 本部"
"ほんぶせき 本部席"
"ほんぶん 本分 本文"
"ほんぶんりゃく 本文略"
"ほんぷ 本譜"
"ほんべつ 本別"
"ほんぺん 本篇 本編"
"ほんほうそうだい 本放送第"
"ほんぽ 本舗"
"ほんぽう 本報 本俸 本邦 奔放"
"ほんぽうはつ 本邦初"
"ほんま 本間"
"ほんまち 本町"
"ほんまつ 本末"
"ほんまる 本丸"
"ほんみょう 本名"
"ほんむ 本務"
"ほんめ 本目"
"ほんめい 本名 本命"
"ほんめいし 本命視"
"ほんめいば 本命馬"
"ほんもう 本望"
"ほんもく 本牧"
"ほんもと 本元"
"ほんもの 本物"
"ほんもん 本文 本問"
"ほんや 本屋"
"ほんやく 飜訳 翻訳"
"ほんやくか 翻訳家"
"ほんやくもの 翻訳物"
"ほんらい 本来"
"ほんらん 本欄"
"ほんりゅう 奔流 本流"
"ほんりょう 本領"
"ほんるい 本塁"
"ほんるいだ 本塁打"
"ほんるいだおう 本塁打王"
"ほんろう 翻弄"
"ほんろん 本論"
"ぼ 姥 謨 拇 姆 牡 墓 保 模 戊 募 菩 慕 暮 母 簿"
"ぼーい ボーイ"
"ぼーかる ボーカル"
"ぼーと ボート"
"ぼーなす ボーナス"
"ぼーりんぐ ボーリング"
"ぼーる ボール"
"ぼいこっと ボイコット"
"ぼいす ボイス"
"ぼいん 拇印 母音"
"ぼう 牟 茅 卯 虻 罔 瀑 鵬 黽 髦 鋩 謗 袤 蟒 蠎 蒡 茆 冐 网 眸 甍 瑁 滂 榜 旄 旁 懋 惘 尨 厖 儚 芒 膀 氓 胞 抱 茫 呆 乏 剖 膨 肪 紡 謀 亡 傍 帽 冒 忘 望 坊 房 暴 貿 忙 貌 鉾 棒 妨 防 某"
"ぼうい 暴威"
"ぼういん 暴飲"
"ぼうえい 防衛"
"ぼうえいきせい 防衛期成"
"ぼうえいぐん 防衛軍"
"ぼうえいしせつちょう 防衛施設庁"
"ぼうえいせん 防衛戦"
"ぼうえいちょう 防衛庁"
"ぼうえいひ 防衛費"
"ぼうえいもう 防衛網"
"ぼうえき 防疫 某駅 貿易"
"ぼうえきしょう 貿易商"
"ぼうえん 望遠"
"ぼうえんきょう 望遠鏡"
"ぼうえんしゃ 暴煙者"
"ぼうえんぞく 暴煙族"
"ぼうおん 忘恩 防音"
"ぼうおんざい 防音材"
"ぼうおんへき 防音壁"
"ぼうか 膨化 防火"
"ぼうかとびら 防火扉"
"ぼうかふく 防火服"
"ぼうかへき 防火壁"
"ぼうかん 暴漢 望観 防寒 傍観"
"ぼうかんぎ 防寒着"
"ぼうかんぐ 防寒具"
"ぼうかんふく 防寒服"
"ぼうがい 望外 妨害"
"ぼうきゃく 忘却"
"ぼうきょ 暴挙"
"ぼうきょう 防共 望郷"
"ぼうきょく 某局"
"ぼうぎ 謀議"
"ぼうぎゃく 暴虐"
"ぼうぎょ 防禦 防御"
"ぼうくう 防空"
"ぼうくうごう 防空壕"
"ぼうくん 某君 暴君"
"ぼうぐ 防具"
"ぼうぐみ 棒組"
"ぼうけい 傍系"
"ぼうけん 剖検 冒険"
"ぼうけんおう 冒険王"
"ぼうけんか 冒険家"
"ぼうけんき 冒険記"
"ぼうけんしん 冒険心"
"ぼうけんたん 冒険譚"
"ぼうけんもの 冒険物"
"ぼうげつ 某月"
"ぼうげん 暴言"
"ぼうこう 膀胱 暴行"
"ぼうこうえん 膀胱炎"
"ぼうこうざい 暴行罪"
"ぼうこく 亡國 亡国 某国"
"ぼうことう 澎湖島"
"ぼうご 防護"
"ぼうごへき 防護壁"
"ぼうさ 防砂"
"ぼうさい 防災"
"ぼうさいかぎけん 防災科技研"
"ぼうさつ 謀殺 忙殺"
"ぼうさま 坊様"
"ぼうさりん 防砂林"
"ぼうし 望祀 某紙 某誌 某氏 帽子 防止"
"ぼうしさく 防止作"
"ぼうしつ 防湿 忘失 亡失"
"ぼうしゃ 某社"
"ぼうしゅ 忙種"
"ぼうしゅう 防臭"
"ぼうしょ 防暑 某所"
"ぼうしょう 傍証"
"ぼうしょく 紡織 望蜀 暴食"
"ぼうしょくざい 防食剤"
"ぼうしん 防振 冒進"
"ぼうじ 防磁"
"ぼうじつ 某日"
"ぼうじゃくぶじん 傍若無人"
"ぼうじゅ 傍受"
"ぼうじょ 防除"
"ぼうじょう 坊城 棒状"
"ぼうじん 防塵"
"ぼうすい 紡錐 防水 紡錘"
"ぼうすいえき 防水液"
"ぼうすいふ 防水布"
"ぼうすじ 某筋"
"ぼうず 坊子 坊主"
"ぼうずあたま 坊主頭"
"ぼうせい 防錆 暴政"
"ぼうせき 紡績"
"ぼうせつ 防雪"
"ぼうせつりん 防雪林"
"ぼうせん 棒線 傍線 防戦"
"ぼうぜん 茫然 呆然"
"ぼうそう 房総 暴走"
"ぼうそうしゃ 暴走車"
"ぼうたかとび 棒高飛び"
"ぼうたて 棒立て"
"ぼうだい 尨大 厖大 防大 某大 膨大"
"ぼうだち 棒立ち"
"ぼうだん 防弾"
"ぼうちゅう 忙中 防虫 傍注"
"ぼうちょう 防諜 膨脹 傍聴 膨張"
"ぼうちょうせき 傍聴席"
"ぼうちょうへき 防潮壁"
"ぼうてつ 耄耋"
"ぼうてん 某店 傍点"
"ぼうと 暴徒"
"ぼうとう 暴投 暴騰 冒頭"
"ぼうとく 冒涜"
"ぼうどう 暴動"
"ぼうどく 防毒"
"ぼうねん 忘年"
"ぼうの 坊野"
"ぼうのつ 坊津"
"ぼうはい 暴牌"
"ぼうはつ 暴発"
"ぼうはてい 防波堤"
"ぼうはん 防犯"
"ぼうはんとう 防犯灯"
"ぼうばく 茫漠"
"ぼうび 防備"
"ぼうびき 棒引き"
"ぼうふ 防腐 亡父 亡夫"
"ぼうふう 防風 暴風"
"ぼうふうう 暴風雨"
"ぼうふうりん 防風林"
"ぼうへき 防壁"
"ぼうぼう 茫茫 某々"
"ぼうまい 茫昧"
"ぼうめい 亡命"
"ぼうや 坊や"
"ぼうよう 茫洋 滂洋 望洋"
"ぼうよみ 棒読 棒読み"
"ぼうらく 暴落"
"ぼうり 暴利"
"ぼうりゃく 謀略"
"ぼうりゃくせつ 謀略説"
"ぼうりょく 暴力"
"ぼうる ボウル"
"ぼうれい 暴戻 亡霊"
"ぼうろう 望楼"
"ぼうろく 俸禄"
"ぼうろん 暴論"
"ぼおん 母音"
"ぼか 簿価"
"ぼかい 暮改"
"ぼかん 母管 母艦"
"ぼかんすう 母関数"
"ぼき 簿記"
"ぼきょくせん 母曲線"
"ぼきょくめん 母曲面"
"ぼきん 募金"
"ぼきんがく 募金額"
"ぼく 瀑 濮 樸 攵 攴 目 卜 墨 撲 朴 穆 木 牧 睦 僕"
"ぼくあて 僕宛"
"ぼくいがい 僕以外"
"ぼくこう 墨攻"
"ぼくこじん 僕個人"
"ぼくさつ 撲殺"
"ぼくし 墨子 牧師"
"ぼくしゃ 牧舎"
"ぼくしんぐ ボクシング"
"ぼくじしん 僕自身"
"ぼくじゅう 墨汁"
"ぼくじょう 牧場"
"ぼくすい 牧水"
"ぼくせき 木石"
"ぼくせん 卜占"
"ぼくそう 牧草"
"ぼくたく 木鐸"
"ぼくたち 僕達"
"ぼくちく 木竹 牧畜"
"ぼくとう 墨東 木刀"
"ぼくとつ 朴訥"
"ぼくどう 牧童"
"ぼくねんじん 朴念仁"
"ぼくは 僕は"
"ぼくひとり 僕一人"
"ぼくめつ 僕滅 撲滅"
"ぼくら 僕ら 僕等"
"ぼけ 木瓜 ボケ 惚け"
"ぼけい 母型 母系"
"ぼけつ 墓穴"
"ぼこう 母港 母校"
"ぼこく 母国"
"ぼご 母語"
"ぼさつ 菩薩"
"ぼさん 墓参"
"ぼし 拇指 星 母子"
"ぼしき 母式"
"ぼしゅう 募集"
"ぼしゅうだん 母集団"
"ぼしん 戊辰"
"ぼじょう 慕情"
"ぼす ボス"
"ぼすう 母数"
"ぼせい 母性 母星"
"ぼせき 墓石"
"ぼせん 母線 母船"
"ぼぜん 墓前"
"ぼたい 母体"
"ぼたもち 牡丹餅"
"ぼたん 鈕 牡丹 ボタン 釦"
"ぼたんどうろう 牡丹灯籠"
"ぼだい 菩提"
"ぼだいじゅ 菩提樹"
"ぼち 墓地"
"ぼっ 沒 没"
"ぼっか 牧歌"
"ぼっかい 渤海"
"ぼっかく 墨客"
"ぼっき 勃起"
"ぼっきゃく 没却"
"ぼっくす ボックス"
"ぼっこう 勃興"
"ぼっこせい 没個性"
"ぼっこん 墨痕"
"ぼっしゅう 没収"
"ぼっしょ 没書"
"ぼっちゃん 坊っちゃん"
"ぼっとう 没頭"
"ぼっぱつ 勃発"
"ぼつ 渤 沒 歿 勃 没"
"ぼつこうしょうてき 没交渉的"
"ぼつご 歿後 没後"
"ぼつにゅう 没入"
"ぼつねん 歿年"
"ぼつらく 没落"
"ぼつれきしてき 没歴史的"
"ぼてん 母点"
"ぼてんたい 母天体"
"ぼでぃ ボディ"
"ぼとる ボトル"
"ぼどう 母堂"
"ぼにゅう 母乳"
"ぼば 牡馬"
"ぼひ 墓碑"
"ぼひめい 墓碑銘"
"ぼひょう 墓標"
"ぼふ 母父"
"ぼぶんさん 母分散"
"ぼへいきん 母平均"
"ぼや 小火"
"ぼら 鰡 鯔"
"ぼらんてぃあ ボランティア"
"ぼり 堀"
"ぼりょう 墓陵"
"ぼると ボルト"
"ぼろ 襤褸 ボロ"
"ぼろくず ボロ屑"
"ぼん 梵 煩 本 凡 盆"
"ぼんおどり 盆踊り"
"ぼんくれ 盆暮"
"ぼんご 梵語"
"ぼんさい 凡才 盆栽"
"ぼんさく 凡作"
"ぼんしょう 梵鐘"
"ぼんじ 梵字"
"ぼんじん 凡人"
"ぼんせん 凡戦"
"ぼんそう 凡走"
"ぼんぞく 凡俗"
"ぼんたい 凡退"
"ぼんだて 盆点"
"ぼんち 盆地"
"ぼんてん 梵天"
"ぼんど ボンド"
"ぼんのう 煩悩"
"ぼんべい 孟買"
"ぼんぺい 凡平"
"ぼんよう 凡庸"
"ぼんわじてん 梵和辞典"
"ぽ 舖 歩 舗"
"ぽーず ポーズ"
"ぽーたぶる ポータブル"
"ぽーらんど 波蘭"
"ぽいんた ポインタ"
"ぽいんと ポイント"
"ぽう 法 方 砲 烹 報 包"
"ぽけっと ポケット"
"ぽじしょん ポジション"
"ぽすたー ポスター"
"ぽすと ポスト"
"ぽち ・"
"ぽっと ポット"
"ぽっぷあっぷ ポップアップ"
"ぽっぷす ポップス"
"ぽつ ・"
"ぽてと ポテト"
"ぽぴゅらー ポピュラー"
"ぽぴんず ポピンズ"
"ぽりしー ポリシー"
"ぽりぺぷちどさ ポリペプチド鎖"
"ぽるとがる 葡萄牙"
"ぽん 椪 本"
"ぽんかん 椪柑"
"ぽんず ポン酢"
"ぽんとちょう 先斗町"
"ぽんど 磅 £"
"ま 茉 痲 麼 媽 墹 嘛 満 万 眞 馬 磨 摩 麻 目 魔 真 間"
"まーく マーク"
"まーけっと マーケット"
"まーけてぃんぐ マーケティング"
"まーじゃん マージャン 麻雀"
"まーじん マージン"
"まーぼ 麻婆"
"まーぼどーふ 麻婆豆腐"
"まあい 間合い"
"まあじゃん 麻雀"
"まあぼうどうふ 麻婆豆腐"
"まい 舞衣 真衣 邁 眛 瑁 麻衣 米 埋 舞 昧 妹 毎 枚"
"まいあきら 舞アキラ"
"まいあさ 毎朝"
"まいいがい 枚以外"
"まいおか 舞岡"
"まいかー マイカー"
"まいかい 毎回"
"まいかたし 枚方市"
"まいき 毎期"
"まいきょ 枚挙"
"まいく マイク"
"まいくろ μ マイクロ"
"まいくろは マイクロ波"
"まいぐみ 枚組"
"まいげつ 毎月"
"まいげつだい 毎月第"
"まいこ 磨衣子 舞妓 舞姑 麻衣子 舞子"
"まいこん マイコン"
"まいご 迷子"
"まいごう 毎号"
"まいさか 舞阪"
"まいしゅう 毎週"
"まいしょく 毎食"
"まいしん 邁進"
"まいじ 毎時"
"まいすう 枚数"
"まいせつ 埋設"
"まいそう 埋葬"
"まいぞう 埋蔵"
"まいた 毎田"
"まいたけ 舞茸"
"まいだ 枚田"
"まいつき 毎月"
"まいづる 舞鶴"
"まいとし 毎年"
"まいど 毎度"
"まいなー マイナー"
"まいなす − マイナス"
"まいなつ 毎夏"
"まいにち 毎日"
"まいねん 毎年"
"まいのうみ 舞の海"
"まいはま 舞浜"
"まいはら 米原"
"まいばら 米原"
"まいばん 毎晩"
"まいひめ 舞姫"
"まいびょう 毎秒"
"まいふん 毎分"
"まいぺーす マイペース"
"まいほーむ マイホーム"
"まいぼつ 埋没"
"まいまい 毎々"
"まいめ 枚目"
"まいや 米谷 毎夜"
"まいよ 毎夜"
"まいる マイル 哩"
"まうえ 真上"
"まうしろ 真後"
"まうら 真裏"
"まうんてん マウンテン"
"まえ 前"
"まえあし 前脚 前足"
"まえいわい 前祝い"
"まえうけ 前受"
"まえうり 前売り 前売"
"まえうりけん 前売券"
"まえお 前尾"
"まえおか 前岡"
"まえおき 前置 前置き"
"まえかわ 前川"
"まえかんじょう 前勘定"
"まえがき 前書き"
"まえがし 前貸し"
"まえがしきん 前貸金"
"まえがしらかい 前頭下位"
"まえがしらじょうい 前頭上位"
"まえがしらひっとう 前頭筆頭"
"まえがみ 前髪"
"まえがり 前借り"
"まえがりきん 前借金"
"まえがわ 前川 前側"
"まえきん 前金"
"まえこうか 前効果"
"まえこうてい 前工程"
"まえさと 前里"
"まえさわ 前沢"
"まえさんしょう 前参照"
"まえざわ 前澤 前沢"
"まえしま 前島"
"まえしょうとう 前照灯"
"まえしょり 前処理"
"まえじ 前地"
"まえじま 前嶋 前島"
"まえじゅんび 前準備"
"まえすうれつ 前数列"
"まえずもう 前相撲"
"まえずり 前刷り 前刷"
"まえせんでん 前宣伝"
"まえぜつ 前説"
"まえだ 前多 前田"
"まえだおし 前倒し"
"まえち 前地"
"まえつえ 前津江"
"まえとびらふきん 前扉付近"
"まえどうさ 前動作"
"まえどなり 前隣"
"まえどまり 前泊"
"まえどり 前録り"
"まえの 前野"
"まえのひ 前の日"
"まえのぶ 前信"
"まえのり 前ノリ"
"まえはし 前橋"
"まえはた 前畑"
"まえはら 前原"
"まえば 前場 前歯"
"まえばし 前橋"
"まえばらい 前払 前払い"
"まえばり 前貼り"
"まえばる 前原"
"まえばんぐみ 前番組"
"まえひょうばん 前評判"
"まえび 前日"
"まえふり 前振"
"まえぶれ 前触れ"
"まえほ 前穂"
"まえほうこう 前方向"
"まえほり 前堀"
"まえまえ 前々"
"まえむき 前向き"
"まえもって 前もって 豫て"
"まえやく 前厄"
"まえやち 前谷地"
"まえやま 前山"
"まえやまだ 前山田"
"まえわたし 前渡し"
"まえわたしきん 前渡金"
"まお 真央"
"まおう 魔王"
"まおたいちゅー 茅台酒"
"まおとこ 間男"
"まか 摩訶 摩可"
"まかい 魔界"
"まかいの 馬飼野"
"まかお 澳門"
"まかべ 真壁"
"まかり 真狩"
"まがい 紛 擬"
"まがいもの 紛物 擬物"
"まがお 真顔"
"まがき 籬"
"まがし 間貸し"
"まがじん マガジン"
"まがた 澗潟"
"まがたま 勾玉"
"まがどり 凶鳥"
"まがら 真柄"
"まがり 間借り"
"まがりかど 曲り角"
"まき 真季 真希 蒔 麻希 真城 卷 槇 麻貴 真木 真紀 麻紀 真樹 真貴 薪 槙 巻 牧"
"まきあげ 巻揚 巻上"
"まきえ 蒔絵"
"まきお 真紀夫 真樹夫 牧尾 牧朗"
"まきおか 牧丘 牧岡"
"まきおとし 巻き落とし"
"まきかえし 巻き返し"
"まきかわ 巻川"
"まきがみ 巻紙"
"まきぐち 牧口"
"まきげ 巻き毛"
"まきこ 牧子 真生子 真木子 真喜子 真貴子 満紀子 万紀子 麻紀子 正希子 真樹子 マキ子 満喜子 麻起子"
"まきしー マキシー"
"まきしま 槙島"
"まきしょてん 槇書店"
"まきじた 巻舌"
"まきじゃく 巻尺"
"まきすう 巻数"
"まきせ 牧瀬"
"まきせん 巻線 巻き線"
"まきそのちょう 牧園町"
"まきぞえ 巻添 巻き添え"
"まきぞの 牧園"
"まきた 牧田 真北"
"まきつき 巻きつき 巻き付き"
"まきつけ 巻きつけ 巻き付け"
"まきとり 巻取"
"まきの 槙野 牧野"
"まきのうち 牧之内"
"まきのお 槇尾"
"まきのこう 牧の郷 牧之郷"
"まきのせ 牧之瀬"
"まきのはら 牧の原"
"まきはら 牧原 槇原 槙原"
"まきば 牧葉 牧場"
"まきひげ 巻きひげ 巻鬚 巻ひげ"
"まきひこ 眞木彦"
"まきびと 牧人"
"まきぼー まきボー"
"まきむら 槙村 牧村"
"まきもと 牧本"
"まきもどし 巻き戻し"
"まきもの 巻物"
"まきゅう 魔球"
"まきょう 魔鏡 魔境"
"まきりん マキリン"
"まぎょう マ行"
"まぎわ 真際 間際"
"まく 幕 膜"
"まくあい 幕間 幕合"
"まくあいげき 幕合劇"
"まくあけ 幕開け"
"まくあつ 膜厚"
"まくうち 幕内"
"まくぎれ 幕切 幕切れ"
"まくしき 幕式"
"まくした 幕下"
"まくつ 魔窟"
"まくでんい 膜電位"
"まくない 膜内"
"まくのうち 幕の内"
"まくはり 幕張"
"まくべつ 幕別"
"まくま 幕間"
"まくら 枕"
"まくらぎ 鍖 枕木"
"まくらことば 枕言葉 枕詞"
"まくらざき 枕崎"
"まくらのそうし 枕草子"
"まくらもと 枕元"
"まぐさ 蒭 芻 秣"
"まぐち 間口"
"まぐまだまり マグマ溜り"
"まぐろ 鮪"
"まぐわ 耙"
"まけ 敗け 負け"
"まけいぬ 負け犬 負犬"
"まけん 魔剣"
"まげ 髷 曲"
"まげごうせい 曲げ剛性"
"まげしんどう 曲げ振動"
"まげは 曲げ波"
"まこ マコ 眞子 魔子 真子 麻子"
"まこう 磨香"
"まこと 亮 純 真湖人 真人 信 誠人 眞 真琴 真 誠"
"まご 馬子 孫"
"まごうた 馬子唄"
"まごおり 馬郡"
"まごこ 孫子"
"まごころ 真心"
"まごでし 孫弟子"
"まごびき 孫引き"
"まごむすめ 孫娘"
"まごめ 馬込"
"まさ マサ 眞 成 将 匡 麻早 征 真 政 昌 昌之 柾 雅 正"
"まさあき 政明 真昭 昌之 昌昭 雅章 政秋 政昭 正昭 正晃 雅明 正章 昌明 雅昭 正彰 昌晃 正明"
"まさいち 正一 政一"
"まさいちろう 雅一郎"
"まさえ 正江 昌枝 雅江 優江 正恵 雅恵"
"まさお 眞生 政男 方夫 誠夫 希男 雅雄 昌男 征男 真夫 正夫 政雄 将生 雅夫 正男 昌夫 雅勇 雅男 昌生 政夫 正雄"
"まさおか 政岡"
"まさおき 正興"
"まさおみ 正臣"
"まさか 雅香"
"まさかず 政和 昌一 雅和 賢和 正一 正和"
"まさかつ 誠勝 正勝 政勝"
"まさかど 将門"
"まさかね 斉加年"
"まさかり 鉞"
"まさがね 正金"
"まさき 誠樹 眞幸 正記 真幸 松前 正宣 正紀 政木 昌樹 真先 公輝 雅基 眞希 政輝 昌己 正毅 正揮 正喜 真樹 正規 正木 仁樹 雅樹 真咲 正輝 政樹 正樹"
"まさきち 政吉"
"まさきよ 政清"
"まさこ 誠子 真紗子 晶子 まさ子 眞砂子 真砂子 真沙子 政子 真佐子 正沙子 昌子 正子 雅子"
"まさこひ 雅子妃"
"まさご 真砂"
"まさし 真史 真志 正 昌嗣 昌 政志 將 祐史 正司 政資 昌史 将史 将司 匡史 匡 昌志 昌士 将 雅志 雅史 正志 政司 正史 雅司 仁"
"まさしく 正しく"
"まさしげ 政重 正茂 雅重 正成"
"まさしち 政七"
"まさじ 政司 雅二 正治 正次 政治 政次"
"まさすけ 正祐"
"まさずみ 正純"
"まさたか 政貴 誠孝 政敬 雅隆 政隆 正隆 正孝 政孝 正高 昌孝"
"まさたけ 正武"
"まさつ 摩擦"
"まさつぐ 仁継 雅紹 正継"
"まさつね 正恒"
"まさてつ 正哲"
"まさてる 正輝 政輝 雅照"
"まさと 昌人 雅刀 雅斗 真人 雅人 政人 正人"
"まさとし 真俊 雅敏 盛敏 正利 政利 昌利 正俊 雅俊 正敏"
"まさとみ 政富 正富 正美"
"まさな 雅名"
"まさなお 雅尚 正尚 政直 正直"
"まさなり 政成 正成"
"まさの 雅野"
"まさのぶ 雅宣 雅信 昌延 正亘 匡伸 雅修 政信 昌信 正信 正伸"
"まさのり 真典 正規 正徳 正則 政宣 成憲 雅典 正範 雅則 正典 正紀 昌典 昌則 政典 公則"
"まさはる 政春 昌治 雅春 正春 正治 正晴"
"まさひこ 眞彦 允彦 政彦 昌彦 正彦 真彦 雅彦"
"まさひさ 真久 昌久"
"まさひで 正秀 正英 昌英"
"まさひと 賢人 昌人 正仁 正人 雅仁"
"まさひろ 昌広 昌寛 匡弘 誠広 正浩 正央 政浩 雅宏 真弘 正寛 征洋 雅浩 正弘 正広 政弘 政広 政宏 昌弘 雅博 正博 正洋 昌宏 雅裕 正宏 雅弘 正裕 雅洋"
"まさふさ 政房"
"まさふみ 雅史 将史 昌文 雅文 将文 真詞 正文"
"まさみ 真己 正巳 正実 正己 政美 雅三 昌巳 眞美 雅実 雅己 昌未 昌美 公美 雅美 雅巳 正美 昌己"
"まさみち 真理 雅道 正道"
"まさみつ 昌光 真光 正光"
"まさむね 正宗 政宗"
"まさめ 正目"
"まさもと 政本 理元"
"まさや 正弥 匡哉 正也 正哉 昌哉 昌也 雅哉 雅也"
"まさやす 正泰 雅康 誠康 政康 昌泰 正康 雅保"
"まさゆき 将行 誠之 政征 真幸 雅幸 雅行 正幸 政行 昌幸 雅祐 政之 正行 正之 理之 雅之 政幸 昌之"
"まさゆめ 正夢"
"まさよ 昌代 雅代"
"まさよう 将容"
"まさよし 正元 雅義 正芳 正良 正善 昌義 正好 政義 昌吉 正義"
"まさより 政頼"
"まさる 大 太 秀 賢 優 勝"
"ましき 益城"
"ましけ 増毛"
"ましこ 増子 益子"
"ました 間下 真下"
"まして 況して"
"ましど 益戸"
"ましば 間柴"
"ましも 真下"
"ましゃく 間尺"
"ましゅう 摩周"
"ましゅうこ 摩周湖"
"ましょう 魔性"
"ましょうねん 魔少年"
"ましら 猿"
"ましん 真芯 麻疹 マシン"
"まじ 真風 マジ"
"まじか 間近 真近"
"まじきり 間仕切り"
"まじっく マジック"
"まじま 間島 間嶋"
"まじめ 真面目"
"まじゅう 魔獣"
"まじゅつ 魔術"
"まじょ 魔女"
"まじょおう 魔女王"
"まじり 交じり"
"まじわり ∩ 交わり"
"まじん 魔人 魔神"
"ます 枡 マス 舛 升 増 益 桝 鱒"
"ますい 桝井 麻酔 増井"
"ますいかい 麻酔科医"
"ますいち 増市"
"ますいやく 麻酔薬"
"ますお 増尾 満寿夫 益夫"
"ますおか 舛岡 増岡 益岡"
"ますかわ 増川"
"ますき 増木"
"ますこ 万寿子 増子 益子"
"ますこみ マスコミ"
"ますざわ 増澤 増沢"
"ますじ 鱒二"
"ますじろう 益治郎"
"ますずし 鱒寿司"
"ますせき 桝席"
"ますぞう 益造"
"ますぞえ 舛添 桝添"
"ますた マスタ"
"ますたー マスター"
"ますたーべーしょん マスターベーション"
"ますたに 益谷 升谷 増谷"
"ますだ 舛田 升田 桝田 益田 増田"
"ますづり 鱒釣"
"ますとみおんせん 増富温泉"
"ますど 益戸"
"ますなが 増永"
"ますの 増野"
"ますはら 増原"
"ますひこ 益彦"
"ますぶち 増淵"
"ますほ 増穂"
"ますます 益々"
"ますみ 益美 満寿美 真純 眞澄 増実 真寿 真澄 萬純"
"ますめ 枡目 桝目 升目"
"ますもと 桝本 増本 升本"
"ますや 升谷"
"ますやま 益山 増山"
"ますらお 丈夫 益荒男"
"まず 先ず"
"ませ 真瀬 間瀬"
"ませき 魔石"
"まぜ 馬瀬"
"まそん 摩損"
"また 亦 俣 股 又"
"またがし 又貸し"
"またがり 又借り"
"またぎき 又聞き"
"またさぶろう 又三郎 又三朗"
"またした 股下"
"またぞろ 又候"
"またたくま 瞬く間"
"またたびもの 股旅者"
"または 又は"
"またま 真玉"
"またもの 又者 陪臣"
"またわり 股割"
"まだ 未だ"
"まだし 未だし"
"まだむ マダム"
"まだら 真鱈 斑"
"まだらお 斑尾"
"まち 待ち 襠 甼 万智 真知 街 町"
"まちあい 待合"
"まちあいしつ 待合い室"
"まちあるき 街歩き"
"まちあわせ 待合 待ち合わせ"
"まちい 町井"
"まちいしゃ 町医者"
"まちかど 街角"
"まちかねやまちょう 待兼山町"
"まちがい 間違い"
"まちぎょうれつ 待行列"
"まちこ 麻知子 満智子 街子 真知子 眞智子"
"まちこうじょう 町工場"
"まちこうば 町工場"
"まちざわ 町澤 町沢"
"まちしゅうへん 町周辺"
"まちじかん 待時間"
"まちじゅう 町中 街中"
"まちぜんたい 町全体"
"まちだ 町田"
"まちぢゅう 町中"
"まちっこ 町っ子"
"まちでら 待寺"
"まちなか 町中 街中"
"まちなみ 町並 町並み 街並"
"まちはずれ 町外れ"
"まちぼうけ 待ちぼうけ"
"まちむすめ 街娘"
"まちや 町屋 町谷"
"まちやくば 町役場"
"まちんか マチン科"
"まぢか 間近 真近"
"まっか 真っ赤 真赤"
"まっかっか 真赤っか"
"まっかり 真狩"
"まっき 末岐 末期"
"まっきがん 末期癌"
"まっきゃく 末脚"
"まっくら 真暗 真っ暗"
"まっくろ 真黒 真っ黒"
"まっこう 真向 真っ向"
"まっさいちゅう 真っ最中"
"まっさお 真青 真っ青"
"まっさかさま 真っ逆さま"
"まっさかり 真っ盛り"
"まっさき 真先 真っ先"
"まっさつ 抹殺"
"まっし 末子"
"まっしゅう 末秋"
"まっしょう 末梢 抹消"
"まっしょうけつ 末梢血"
"まっしろ 真白 真っ白"
"まっすぐ 真っ直"
"まっせ 末世"
"まっせき 末席"
"まっせつ 末節"
"まったく 全 全く"
"まっただなか 真っ只中"
"まったん 末端"
"まっち 燐寸 マッチ"
"まっちゃ 抹茶"
"まっちょう 末長"
"まってい 末弟"
"まっとう 松任"
"まっとうや 松任谷"
"まっぴつ 末筆"
"まっぴら 真平"
"まっぴるま 真昼間 真っ昼間"
"まっぴんぐ マッピング"
"まっぽう 末法"
"まつ 靺 茉 秣 枩 待つ 抹 沫 松 末"
"まつい 松為 松居 松井"
"まついし 松石"
"まついだ 松井田"
"まついち 松一"
"まつうら 松浦"
"まつえ 松江"
"まつえい 未裔 末裔"
"まつえだ 松枝"
"まつお 松雄 松夫 松男 松尾"
"まつおか 松岡"
"まつかざり 松飾り"
"まつかぜ 松風"
"まつかた 松方"
"まつかつ 靺鞨"
"まつかわ 松河 松川"
"まつがおか 松が丘"
"まつがさき 松ヶ崎"
"まつがや 松ヶ谷"
"まつき 松木"
"まつきがわきょうりょう 松木川橋梁"
"まつくら 松倉"
"まつげ 睫毛 睫"
"まつご 末期"
"まつごろう 松吾郎 松五郎"
"まつさか 松阪 松坂"
"まつさかぎゅう 松坂牛"
"まつさき 松崎"
"まつさわ 松沢"
"まつざか 松阪 松坂"
"まつざかぎゅう 松坂牛"
"まつざかにく 松坂肉"
"まつざき 松嵜 松崎"
"まつざわ 松澤 松沢"
"まつしげ 松茂 松重"
"まつした 松下"
"まつしたせいけいじゅく 松下政経塾"
"まつしま 松嶋 松島"
"まつしろ 松代"
"まつじつ 末日"
"まつじつせいと 末日聖徒"
"まつじめ 末締め"
"まつた 松田"
"まつたか 松高"
"まつたけ 松茸"
"まつたに 松谷"
"まつたろう 松太郎"
"まつだ 松田"
"まつだい 松代 末代"
"まつだいら 松平"
"まつだいらただてる 松平忠輝"
"まつつか 松塚"
"まつづき 松月"
"まつとうや 松任谷"
"まつとも 松友"
"まつど 松戸"
"まつなえ 松苗"
"まつなか 松中"
"まつなが 松長 末永 松永"
"まつなみ 松波"
"まつぬま 松沼"
"まつの 松乃 松野"
"まつのうち 松の内"
"まつのぶ 松延"
"まつのべ 松延"
"まつのやま 松之山"
"まつはた 松畑"
"まつば 松葉"
"まつばせ 松橋"
"まつばづえ 松葉杖"
"まつばやし 松林"
"まつばら 松原"
"まつばらこ 松原湖"
"まつひろ 松弘"
"まつび 末尾"
"まつびし 松菱"
"まつふじ 松藤"
"まつふる 松古"
"まつぶさか マツブサ科"
"まつぶし 松伏"
"まつぶん 末文"
"まつぼうきき 松貿機器"
"まつまい 末妹"
"まつまえ 松前"
"まつまる 松丸"
"まつみ 松見"
"まつむら 松村"
"まつもか マツモ科"
"まつもと 松元 松本"
"まつもり 松森"
"まつや 松屋"
"まつやに 松脂"
"まつやま 松山"
"まつやましょう 松山商"
"まつゆき 松雪"
"まつよし 松吉"
"まつり 祀 祀り 祭り 祭"
"まつりごと 祭事 政"
"まつろ 末路"
"まつわこう 松輪港"
"まづ 先づ"
"まて 蟶 待て"
"まてがい 蟶貝"
"まてき 魔笛"
"まてんろう 摩天楼"
"まで 迄"
"まと 魔都 的"
"まとい 纒い 纒 纏"
"まとうだい 的鯛"
"まとば 的場"
"まとまり 纒まり"
"まとりっくす マトリックス"
"まど 窗 窓"
"まどう 魔道 魔導"
"まどうし 魔道士 魔導士"
"まどか 円"
"まどかんすう 窓関数"
"まどがらす 窓ガラス"
"まどがわ 窓側"
"まどぎわ 窓際"
"まどぎわせき 窓際席"
"まどぐち 窓口"
"まどぐちおく 窓口奥"
"まどぐちやく 窓口役"
"まどぜんかい 窓全開"
"まどぜんたい 窓全体"
"まどちょう 窓長"
"まどない 窓内"
"まどはいち 窓配置"
"まどべ 窓辺"
"まどよう 窓用"
"まどり 間取り"
"まどりーど 馬徳里"
"まどわく 窓枠"
"まどわり 窓割"
"まな 真名 真奈 愛 麻奈"
"まなー マナー"
"まないた 俎板 俎"
"まなか 愛香"
"まなこ 眼"
"まなざし 眼差し"
"まなじり 眦 眥"
"まなつ 真夏"
"まなつる 真鶴"
"まなつるこう 真鶴港"
"まなづる 真鶴"
"まなでし 愛弟子"
"まなびや 学舎"
"まなぶ 斈 學 学"
"まなべ 真部 真鍋"
"まなみ 愛美"
"まにあ マニア"
"まにあわせ 間に合わせ"
"まにぴゅれーしょん マニピュレーション"
"まにぴゅれーた マニピュレータ"
"まにまに 随に"
"まにゅある マニュアル"
"まにら 馬尼剌"
"まにわ 真庭"
"まぬけ 間抜け"
"まぬけづら 間抜面"
"まね 真似"
"まねーじゃ マネージャ"
"まねきねこ 招き猫"
"まねきん マネキン"
"まねごと 真似事"
"まねじめんと マネジメント"
"まねじゃー マネジャー"
"まねもの 真似物"
"まの 間野 真野"
"まのあたり 目の当たり"
"まのび 間延 間延び"
"まは 万葉"
"まばし 馬橋"
"まばしら 間柱"
"まばたき 瞬き"
"まばら 疎"
"まばらぶんさんきおく まばら分散記憶"
"まひ 痲痺 麻痺"
"まひかり 真光"
"まひがし 真東"
"まひと 真人"
"まひる 真昼"
"まび 魔美"
"まびき 間引"
"まふじえき 間藤駅"
"まふね 真船"
"まふゆ 真冬"
"まぶか 目深"
"まぶしさ 眩しさ"
"まぶた 目蓋 瞼"
"まぶち 馬淵 馬渕"
"まほ 真秀 真帆"
"まほう 魔法"
"まほうけん 魔法剣"
"まほうじん 魔方陣"
"まほうせき 魔法石"
"まほうせん 魔法戦"
"まほうびん 魔法瓶"
"まほか 真帆香"
"まほりかん 馬堀間"
"まぼろし 幻"
"まま 随 媽媽 壗 墹 圸 儘 ママ 侭"
"ままこ 継子"
"ままちち 継父"
"ままはは 継母"
"まみ 舞美 茉美 魔美 眞美 マミ 麻弥 麻実 磨美 麻美 真実 昌未 真美"
"まみこ 麻美子 麻巳子"
"まみず 真水"
"まみなみ 真南"
"まみや 魔実也 間宮"
"まむし 蝮"
"まむろがわ 真室川"
"まめ 荳 豆"
"まめおか 豆岡"
"まめか マメ科 豆科"
"まめきゅう 豆球"
"まめせいひん 豆製品"
"まめたん 豆単 豆炭"
"まめだ 豆田"
"まめちしき 豆知識"
"まめつ 磨滅 摩滅"
"まめつぶ 豆粒"
"まめでんきゅう 豆電球"
"まめほん 豆本"
"まめまき 豆まき"
"まめみそ 豆味噌"
"まめもよう 豆模様"
"まめや 豆屋"
"まもう 磨耗 摩耗"
"まもなく 間も無く"
"まもの 魔物"
"まもり 護"
"まもる 衞 守 衛"
"まや 麻那 麻矢 魔夜 摩耶 麻弥"
"まやく 麻薬"
"まやくたんちけん 麻薬探知犬"
"まやこ 麻也子"
"まやま 真山 間山"
"まゆ 麻愉 真由 麻由 眉 繭"
"まゆげ 眉毛"
"まゆこ 眉子 万由子 繭子 真由子"
"まゆずみ 黛"
"まゆつば 眉唾"
"まゆみ 魔弓 誠由美 万友美 檀 麻由美 真弓"
"まゆむら 眉村"
"まよ 麻世 真世 眞夜 真代"
"まよい 迷い"
"まよけ 魔除け"
"まよこ 真横"
"まら 摩羅"
"まらそん マラソン"
"まらや 馬來"
"まり マリ 麻理 茉利 毬 満利 鞠 掬 茉莉 万里 真里 麻里 真理"
"まりあ 万梨阿 真利亜 マリア"
"まりい 麻利衣"
"まりえ 麻里絵"
"まりお 麻利夫 眞理雄 真理雄"
"まりこ 鞠子 まり子 茉里子 満利子 万里子 麻里子 麻理子 真梨子 真利子 真璃子 真里子 真理子"
"まりこうじ 鞠小路"
"まりな 満里奈"
"まりのす 横浜マリノス"
"まりょく 魔力"
"まりりん マリリン"
"まりん まりン"
"まる 〇 圓 ． マル ・ ◯ 。 円 ◎ ● 丸 ○"
"まるあな 丸穴"
"まるあらい 丸洗い"
"まるあんき 丸暗記"
"まるい 丸井"
"まるいけ 丸池"
"まるいす 丸椅子"
"まるいち 丸一"
"まるうつし 丸写し"
"まるえい 丸栄"
"まるお 丸生 丸尾"
"まるおか 丸岡"
"まるかっこ 丸括弧"
"まるかめかん 丸亀間"
"まるかめがわ 丸亀側"
"まるかわ 丸川"
"まるかん 丸漢"
"まるがお 丸顔"
"まるがかえ 丸抱え"
"まるがた 丸形 丸型"
"まるがめ 丸亀"
"まるがめこう 丸亀高"
"まるきゅう 丸久"
"まるきん 丸金"
"まるく マルク"
"まるくに 丸国"
"まるこ 丸子"
"まるこう 丸興"
"まるこし 丸腰"
"まるごし 丸腰"
"まるさん 丸三"
"まるしあ マルシア"
"まるしょう 丸正"
"まるじるし 丸印"
"まるす マルス"
"まるすうじ 丸数字"
"まるせいゆ 馬耳塞"
"まるせっぷ 丸瀬布"
"まるぜん 丸全 丸善"
"まるた 丸太 丸田"
"まるたに 丸谷"
"まるだいしょくひん 丸大食品"
"まるだし 丸出し"
"まるち マルチ"
"まるつきすうじ 丸付数字"
"まるてーぶる 丸テーブル"
"まるてん 丸天"
"まるとう 丸東"
"まるどけい 丸時計"
"まるにし 丸西"
"まるにねん 丸二年"
"まるぬま 丸沼"
"まるの 丸野"
"まるのうち 丸ノ内 丸の内"
"まるのこ 丸鋸"
"まるはい 丸灰"
"まるはし 丸橋"
"まるはだか 丸裸"
"まるはち 丸八"
"まるはんにち 丸半日"
"まるばつ ○×"
"まるばやし 丸林"
"まるひじょうほう 丸秘情報"
"まるひほうこく 丸秘報告"
"まるふく 丸福"
"まるぶつ 丸物"
"まるぶん 丸文"
"まるべに 丸紅"
"まるぼうず 丸坊主"
"まるまげ 丸髷"
"まるまどでんしゃ 丸窓電車"
"まるまる 丸々 ○○"
"まるみ 円美 丸見"
"まるみえ 丸見え"
"まるみつ 丸光"
"まるめ 丸め"
"まるめごさ 丸目誤差"
"まるもじ 丸文字"
"まるもち 丸餅"
"まるもと 丸本 丸元"
"まるもり 丸森"
"まるや 丸谷 丸屋"
"まるやき 丸焼"
"まるやね 丸屋根"
"まるやま 円山 丸山"
"まるゆう マル優"
"まるわ 丸和"
"まれ 希 稀"
"まれき 希樹"
"まれすけ 希典"
"まろ 麻呂 麿"
"まわし 廻 回し"
"まわしげり 廻し蹴り"
"まわた 真綿"
"まわたり 馬渡"
"まわり 回り 周り 廻り"
"まわりみち 回り道"
"まん 鬘 蹣 謾 縵 瞞 滿 懣 悗 幔 曼 幡 鰻 饅 萬 蔓 慢 漫 満 万"
"まんいち 万一"
"まんいん 満員"
"まんえつ 満悦"
"まんえん 満塩 蔓延 万円"
"まんえんさつ 万円札"
"まんかい 万回 満開"
"まんかん 満貫"
"まんが マンガ 漫画"
"まんがいち 万一 万が一"
"まんがおう 漫画王"
"まんがか 漫画家"
"まんがく 満額"
"まんがのもり まんがの森"
"まんがん 満願 満貫"
"まんき 満期"
"まんきじつ 満期日"
"まんきつ 満喫"
"まんぎょう 万行"
"まんけん 漫研"
"まんげきょう 万華鏡"
"まんげつ 満月"
"まんこ 万個"
"まんこう 満腔"
"まんごく 万石"
"まんごじしょ 万語辞書"
"まんさい 満載"
"まんさく 万作"
"まんさくもく マンサク目"
"まんさつ 万冊"
"まんざ 満座 万座"
"まんざい 漫才"
"まんざいらく 萬歳楽"
"まんざら 満更"
"まんしつ 満室"
"まんしゃ 満車"
"まんしゅいん 曼殊院"
"まんしゅう 滿洲 満州"
"まんしゅうかいたくみん 満州開拓民"
"まんしゅうこく 滿洲國"
"まんしょく 万色"
"まんしょん マンション"
"まんしん 慢心 満身 万進"
"まんじ 卍"
"まんじがため 卍固"
"まんじどもえ 卍巴"
"まんじゅう 饅頭"
"まんじゅしゃげ 曼珠沙華"
"まんじょう 満場"
"まんすい 満水"
"まんず 萬子"
"まんせい 慢性"
"まんせいしん 慢性心"
"まんせいばし 万世橋"
"まんせいびょう 慢性病"
"まんせき 満席"
"まんせん 満船"
"まんぜん 慢然 漫然"
"まんぞく 満足"
"まんた 万太"
"まんたに 萬谷"
"まんたん 満タン"
"まんたんい 万単位"
"まんだい 万代"
"まんだら 曼陀羅"
"まんだん 漫談"
"まんちゃく 瞞着"
"まんちょう 満潮"
"まんちんろう 萬珍楼"
"まんてつ 滿鐵 満鉄"
"まんてん 満天 万点 満点"
"まんとみ 万富"
"まんなか まん中 真ん中 真中"
"まんにょうしゅう 万葉集"
"まんにん 万人"
"まんねん 萬年 万年"
"まんねんひつ 万年筆"
"まんねんびと 毎年人"
"まんねんゆき 万年雪"
"まんねんれき 万年暦"
"まんのう 満濃"
"まんば 万馬 万場"
"まんばい 万倍"
"まんばけん 万馬券"
"まんぱ 万波"
"まんぱい 満配 満杯"
"まんぱん 満帆"
"まんびき 万引き 万引"
"まんびょう 万病"
"まんぴょう 満票"
"まんぶ 万部"
"まんぷく 満腹"
"まんべん 万便 万遍"
"まんぽ 漫歩"
"まんぽけい 万歩計"
"まんまい 万枚"
"まんまえ 真ん前"
"まんまく 幔幕"
"まんまる 真円"
"まんまん 満々"
"まんめん 満面"
"まんもう 滿蒙"
"まんゆう 漫遊"
"まんよう 万葉"
"まんりき 万力"
"まんりょう 満了"
"まんるい 満塁"
"まんるいだん 満塁弾"
"み 壬 深 靡 弥 稔 御 己 魅 箕 巳 三 実 美 味 未 身 見"
"みーてぃんぐ ミーティング"
"みあ 未亜"
"みあい 美合 見合 見合い"
"みあけ 三宅"
"みあさ 美麻"
"みあま 三甘"
"みい 魅衣 三井"
"みいけ 三池"
"みいけこう 三池港"
"みいでら 三井寺"
"みいら 木乃伊"
"みいらく 三井楽"
"みいり 実入り"
"みうけ 身請"
"みうごき 身動き"
"みうち 身内"
"みうら 三浦"
"みうらきた 美浦北"
"みうらわん 三浦湾"
"みうり 身売り 身売"
"みえ 美恵 水絵 美瑛 見得 美江 美枝 見栄 三重"
"みえかくれ 見え隠れ 見えかくれ"
"みえかた 見え方"
"みえこ 三恵子 実枝子 美枝子 美恵子 三重子 三枝子"
"みえせん 三江線"
"みえだ 三枝"
"みえだいこう 三重大工"
"みえっぱり 見栄張り"
"みお 水脈 未緒 実音 美緒 美尾 美央 三尾 澪 未央 美織"
"みおくり 見送り"
"みおこ 美央子"
"みおさめ 見納め"
"みおつくし 澪標"
"みおとし 見落し 見落とし"
"みおとり 見劣り"
"みおぼえ 見覚え"
"みおも 身重"
"みおり 美織"
"みか 実可 甕 美夏 三香 美華 美歌 美佳 美伽 実花 ミカ 美加 美香"
"みかい 未開"
"みかえし 見返し"
"みかえり 見返り"
"みかく 味覚"
"みかくにんじょうほう 見確認情報"
"みかけ 見掛け 見かけ"
"みかげ 御影"
"みかげいし 御影石"
"みかげつ 三ケ月"
"みかこ 美香子 美加子 美佳子"
"みかさ 三笠"
"みかた 美方 三方 見方 味方"
"みかたはら 三方原"
"みかだ 三ヶ田"
"みかつき 三日月"
"みかづき 三日月"
"みかど 帝 御門 三門"
"みかほ 美華保"
"みかみ 見上 三神 三上"
"みかみね 三神峯"
"みかめ 三瓶"
"みかも 美甘 三加茂"
"みかり 美加理"
"みかわ 三加和 見川 実川 三川 美川 三河"
"みかわしま 三河島"
"みかわもの 三河者"
"みかわわん 三河湾"
"みかん 蜜柑 未刊 未完"
"みかんか ミカン科"
"みかんもく ミカン目"
"みがきこ 磨き粉"
"みがきずな 磨き砂"
"みがく 研"
"みがため 身固め"
"みがって 身勝手"
"みがまえ 身構え"
"みがら 見柄 身柄"
"みがる 身軽"
"みがわり 身代り"
"みき 三喜 ミキ 未来 未希 美季 三樹 光希 御木 未木 実紀 三城 三基 美来 美貴 未稀 美希 美喜 三紀 幹 美樹 美紀 三木"
"みきお 三起男 幹男 幹夫 幹雄"
"みきき 見聞き"
"みきこ 美貴子 実希子 美樹子 美紀子 幹子 美希子 ミキコ"
"みきのり 幹典"
"みきはら 美樹原"
"みきひこ 未来彦 幹彦 三紀彦"
"みきほ 美喜帆"
"みきもと 美樹本"
"みきや 御喜家"
"みきょうらん 美狂乱"
"みきよ 幹代"
"みきり 見切り"
"みきわめ 見極め"
"みぎ 』 】 ） ＞ → 右"
"みぎあし 右脚 右足"
"みぎいっぱい 右一杯"
"みぎうえ 右上"
"みぎうえすみ 右上隅"
"みぎうしろ 右後"
"みぎうで 右腕"
"みぎえだ 右枝"
"みぎおく 右奥"
"みぎかいてん 右回転"
"みぎかた 右肩"
"みぎかっこ 』 右括弧"
"みぎがわ 右側"
"みぎきき 右利き 右利"
"みぎぎし 右岸"
"みぎけつごう 右結合"
"みぎこ 右子"
"みぎこし 右腰"
"みぎした 右下"
"みぎしたすみ 右下隅"
"みぎしもて 右下手"
"みぎしゃせん 右車線"
"みぎしゃめん 右斜面"
"みぎすみ 右隅"
"みぎず 右図"
"みぎぜんぽう 右前方"
"みぎぜんりん 右前輪"
"みぎそくめん 右側面"
"みぎそろえ 右揃え"
"みぎだしゃ 右打者"
"みぎだせき 右打席"
"みぎちゅうだん 右中段"
"みぎづめ 右詰め"
"みぎて 右手"
"みぎてくび 右手首"
"みぎてんかい 右転回"
"みぎどなり 右隣り 右隣"
"みぎのり 右乗"
"みぎはし 右端"
"みぎはんぶん 右半分"
"みぎはんめん 右半面"
"みぎひざ 右膝"
"みぎひじ 右肘"
"みぎひだり 右左"
"みぎほうこう 右方向"
"みぎまえ 右前"
"みぎまえあし 右前足 右前脚"
"みぎまがり 右曲り"
"みぎまつ 右末 右松"
"みぎみみ 右耳"
"みぎむき 右向き"
"みぎむね 右胸"
"みぎめ 右目"
"みぎや ⇒ →"
"みぎやじるし 右矢印 ⇒ →"
"みぎようそ 右要素"
"みぎよこ 右横"
"みぎよせ 右寄"
"みぎより 右寄"
"みぎり 砌"
"みぎわ 頻 汀"
"みく 美来 未来 美久 ミク"
"みくだりはん 三行半"
"みくち 三口"
"みくに 皇國 御國 三国 三國"
"みくにれんたろう 三國連太郎"
"みくま 三隈"
"みくも 三雲"
"みくらしま 御蔵島"
"みくりや 御厨"
"みくるま 御車"
"みくろ ミクロ"
"みくろん μm"
"みぐ ミグ"
"みけ 三毛"
"みけた 三桁"
"みけつ 未決"
"みけねこ 三毛猫"
"みけん 未見 眉間"
"みこ 巫 巫女 御子 美子"
"みこう 未稿"
"みこころ 御心"
"みこし 御輿"
"みこしば 御子柴"
"みこと 命 尊 美琴"
"みことのり 敕 勅 詔"
"みことば 御言葉"
"みこみ 見込 見込み"
"みこみがく 見込額"
"みこん 未婚"
"みごしらえ 身拵え"
"みごと 見事"
"みごろ 見頃"
"みさ 魅紗 未沙 美紗 美沙 美砂 美佐"
"みさい 未済"
"みさいる ミサイル"
"みさお 操 美沙緒"
"みさか 三阪 御坂"
"みさかい 見境"
"みさき 三咲 美沙紀 美咲 御前 三崎 岬"
"みさきぐち 三崎口"
"みさきこう 三崎港"
"みさくぼ 水窪"
"みさこ 美咲子 美砂子 美沙子 美佐子"
"みさご 鶚"
"みささ 三朝 三篠 三笹"
"みささぎ 山陵 陵 御陵"
"みさと 箕郷 美郷 三郷 美里"
"みさわ 三沢 三澤"
"みさわやま 実沢山"
"みしお 美潮"
"みしな 三品"
"みしま 三嶋 三島"
"みしゅう 未収"
"みしゅく 三宿"
"みしょう 御荘"
"みしょうりせん 未勝利戦"
"みしょうりば 未勝利馬"
"みしん ミシン"
"みじか 身近"
"みじたく 身仕度 身支度"
"みじゅく 未熟"
"みじゅくじ 未熟児"
"みじゅくもの 未熟者"
"みじゅつかんあんない 美術館案内"
"みじん 微塵"
"みじんこ 微塵子"
"みす 簾 三栖 ミス"
"みすい 未遂"
"みすいざい 未遂罪"
"みすえ 御末 三末"
"みすか 美須賀"
"みすがた 御姿"
"みすぎ 美杉"
"みすぎいそ 三杉磯"
"みすぎさと 三杉里"
"みすず 三鈴 美鈴"
"みすぷり ミスプリ"
"みすみ 三隅 三角"
"みず 瑞 水"
"みずあか 水垢"
"みずあげ 水揚げ"
"みずあび 水浴び"
"みずあめ 水飴"
"みずあらい 水洗い"
"みずい 水井"
"みずいけ 水池"
"みずいで 水出"
"みずいらず 水入らず"
"みずいろ 水色"
"みずうみ 湖"
"みずうみふきん 湖付近"
"みずえ 瑞江 水絵"
"みずお 瑞生 瑞男"
"みずおけ 水桶"
"みずおと 水音"
"みずかき 水掻き 蹼"
"みずかけろん 水掛論"
"みずかげん 水加減"
"みずかさ 水かさ"
"みずかみ 水上"
"みずから 自ら"
"みずかわ 水川"
"みずがかり 水掛"
"みずがき 水柿"
"みずがめ 水瓶"
"みずがめざ 水瓶座"
"みずき 未図紀 美寿紀 瑞季 水樹 水木"
"みずきり 水切り"
"みずぎ 水着"
"みずぎすがた 水着姿"
"みずぎわ 水際"
"みずくさ 水草"
"みずくぼ 水窪"
"みずくぼこ 水窪湖"
"みずぐち 水口"
"みずけ 水気"
"みずけむり 水煙"
"みずげい 水芸"
"みずこ 水子"
"みずこし 水越"
"みずさき 水崎 水先"
"みずさし 水差し"
"みずさわ 水澤 水沢"
"みずさわぼたる 水沢蛍"
"みずし 瑞史"
"みずしげん 水資源"
"みずしぶき 水飛沫"
"みずしま 水縞 水嶌 水嶋 水島"
"みずしょうばい 水商売"
"みずしらず 見ず知らず"
"みずしろ 水城"
"みずせつやく 水節約"
"みずせん 水栓"
"みずぜき 水関"
"みずた 水田"
"みずたに 水谷"
"みずたま 水玉"
"みずたまり 水溜まり 水溜"
"みずち 蛟"
"みずてきりょう 水適量"
"みずてん 不見点 不見転"
"みずでっぽう 水鉄砲"
"みずとり 水鳥"
"みずどけい 水時計"
"みずなし 水梨 水無"
"みずなみ 瑞浪"
"みずに 水煮"
"みずぬき 水抜"
"みずぬま 水沼"
"みずの 水野"
"みずのあわ 水の泡"
"みずのえ 壬"
"みずのえいぬ 壬戌"
"みずのえうま 壬午"
"みずのえさる 壬申"
"みずのえたつ 壬辰"
"みずのえとら 壬寅"
"みずのえね 壬子"
"みずのきえき 水軒駅"
"みずのと 癸"
"みずのとい 癸亥"
"みずのとう 癸卯"
"みずのとうし 癸丑"
"みずのととり 癸酉"
"みずのとひつじ 癸未"
"みずのとみ 癸巳"
"みずのみ 水飲み"
"みずのもり 水の森"
"みずはら 水原"
"みずば 水場"
"みずばしら 水柱"
"みずひき 水引"
"みずひと 瑞史"
"みずひろ 瑞洋"
"みずびたし 水浸し"
"みずぶそく 水不足"
"みずぶろ 水風呂"
"みずぶんし 水分子"
"みずべ 水辺"
"みずほ 瑞穂"
"みずぼうそう 水疱瘡"
"みずま 水間 三瀦"
"みずまき 水巻"
"みずまくら 水枕"
"みずまし 水増 水増し"
"みずまち 水町"
"みずむし 水虫"
"みずもと 水本"
"みずもり 水杜"
"みずやま 水山"
"みずよ 瑞代"
"みずら 鬟 髻"
"みずわり 水割り"
"みせ 三瀬 廛 壥 店"
"みせかた 見せ方"
"みせがね 見せ金"
"みせがまえ 店構え"
"みせがわ 店側"
"みせさき 店先"
"みせじたい 店自体"
"みせじまい 店仕舞 店じまい"
"みせす ミセス"
"みせば 見せ場"
"みせばん 店番"
"みせびらき 店開き"
"みせもの 見世物 見せ物"
"みせや 店屋"
"みぜに 身銭"
"みぜん 未然"
"みそ 晦 三十 ミソ 味噌"
"みそあじ 味噌味"
"みそか 晦 晦日"
"みそぎ 禊"
"みそさざい 鷦鷯"
"みそしる 味噌汁"
"みそじ 三十路"
"みそっかす 味噌っ滓"
"みそに 味噌煮"
"みその 三園 御園 美薗"
"みそまめ 味噌豆"
"みそら 身空 美空"
"みそらひばり 美空ひばり"
"みそんじ 見損じ"
"みぞ 渠 溝"
"みぞい 溝井"
"みぞう 未曾有"
"みぞうえ 溝上"
"みぞうち 溝内"
"みぞおち 鳩落ち"
"みぞぐち 溝口"
"みぞた 溝田"
"みぞて 溝手"
"みぞのくち 溝の口"
"みぞぶち 溝渕"
"みぞべ 溝辺"
"みぞれ 霙"
"みた 見田 美田 三田"
"みたか 三鷹"
"みたけ 御岳 三嶽 三岳 御嵩 身丈"
"みたさいぜんやさい 三田祭前夜祭"
"みたて 見立て"
"みたに 見谷 三谷"
"みたび 三度"
"みたま 三珠"
"みため 見た目"
"みたらい 御手洗"
"みだ 弥陀"
"みだい 見台"
"みだし ※ ■ ◇ ＊ 見出し"
"みだしなみ 身嗜み 身だしなみ"
"みだら 婬"
"みだれ 乱れ"
"みだれがみ 乱れ髪"
"みち 途 謐 蹊 倫 美知 通 未知 路 道"
"みちあき 道朗 道明 通明 通晃"
"みちあんない 道案内"
"みちいと 道糸"
"みちうえ 道上"
"みちえ 美智恵 道恵"
"みちお 道央 三千雄 三千夫 道雄 道男 通夫 道夫 道生"
"みちか 美智香"
"みちがい 見違い"
"みちがみ 道上"
"みちがわ 道側"
"みちくさ 道草"
"みちこ 美知子 三智子 満子 倫子 光知子 通子 美千子 道子 美智子 路子"
"みちさと 満里"
"みちしお 満ち潮"
"みちしるべ 道標"
"みちじゅん 道順"
"みちすじ 道筋"
"みちぞい 道沿"
"みちた 道田"
"みちたか 充隆 道隆 通隆 命孝"
"みちつた 道蔦"
"みちづれ 道連れ"
"みちとし 通敏"
"みちなり 道也 途也 道成"
"みちのく 陸奥"
"みちのり 道程 道のり"
"みちはば 道幅"
"みちはら 道原"
"みちはる 道春 亨治"
"みちば 道場"
"みちばた 道傍 道端"
"みちひで 通秀"
"みちひろ 道広 倫広 道洋 通博 倫洋 道宏 通洋 道弘"
"みちみち 道々"
"みちむこ 道向"
"みちむら 道村"
"みちゃく 未着"
"みちゆき 道行"
"みちょう 未聴"
"みちよ 三千代 道世 道代 美千代 通代 美千世 路代 美智代"
"みちよし 道由"
"みちる 未知瑠 未散"
"みちろう 道郎"
"みぢか 身近"
"みっか ３日 三日"
"みっかい 密会"
"みっかび 三ヶ日 三ケ日"
"みっきょう 密教"
"みっくす ミックス"
"みっこう 密航"
"みっこく 密告"
"みっし 密使"
"みっしつ 密室"
"みっしゅう 密集"
"みっしゅうたい 密集体"
"みっしょ 密書"
"みっせい 密生"
"みっせつ 密接"
"みっせん 密栓"
"みっそう 密送 密葬"
"みっちゃく 密着"
"みっつ 三つ ３つ"
"みっつう 密通"
"みっつめ 三つめ"
"みってい 密偵"
"みっぷう 密封"
"みっぺい 密蔽 密閉"
"みつ 謐 滿 櫁 円 充 満 三 光 蜜 密"
"みつあき 充璋 光璋 光明 光昭"
"みつい 三井"
"みついし 三ッ石 三石"
"みついとうあつかがく 三井東圧化学"
"みつうん 密雲"
"みつえ 光恵 御杖 光江 光枝"
"みつお 光穂 光生 満男 満雄 満夫 充雄 三雄 三夫 三男 光夫 光男 光雄"
"みつかいどう 水海道"
"みつかげ 光影"
"みつかん 蜜柑"
"みつき 観月 美月"
"みつぎ 三ツ木 密議 調 三ッ木"
"みつぎもの 貢ぎ物"
"みつぎょうれつ 密行列"
"みつくち 兎唇"
"みつぐ 貢"
"みつぐみ 三組 三つ組"
"みつけ 見附 見付"
"みつけつごう 密結合"
"みつげつ 蜜月"
"みつこ 充子 満子 光子 美都子 三津子 美津子"
"みつこし 三越"
"みつご 三子"
"みつさと 満里"
"みつざわ 光澤"
"みつしま 美津島"
"みつせ 光瀬 三瀬"
"みつせりゅう 光瀬龍"
"みつせん 蜜腺"
"みつぞう 密造"
"みつた 光田"
"みつたか 充隆"
"みつたけ 満武 光威"
"みつだ 満田 光田"
"みつだん 密談"
"みつつじ 光辻"
"みつづか 三塚"
"みつてる 充照 光輝"
"みつてん 密天"
"みつとし 充敏 光年 光俊"
"みつとも 三友"
"みつど 密度"
"みつどもえ 三つ巴"
"みつなが 満永 光永"
"みつなり 光成 実成 三成"
"みつにゅうこく 密入国"
"みつのぶ 光延 光伸 光信"
"みつのり 光徳 充則 光紀"
"みつはし 三ツ橋 三橋"
"みつはる 充治 光晴"
"みつば 三葉"
"みつばい 密売"
"みつばち 蜜蜂"
"みつひこ 美比古 光彦"
"みつひさ 三久 充久"
"みつひで 光秀"
"みつひろ 充洋 満浩 充浩 充弘 光裕 光宏 光浩 満弘 充博 充宏 光弘 円博 光博"
"みつびし 三菱"
"みつびしじかわさき 三菱自川崎"
"みつびしじこうきょうと 三菱自工京都"
"みつびしじみずしま 三菱自水島"
"みつびしはつ 三菱初"
"みつびしれいよん 三菱レイヨン"
"みつぶつ 密勿"
"みつぼし 三星 三っ星"
"みつぼしべると 三ツ星ベルト"
"みつまさ 光雅 光正 光政"
"みつまた 三椏"
"みつまたやり 三又槍"
"みつめ 三っ目"
"みつめい 密命"
"みつもと 光本"
"みつもり 三森 見積 見積り 見積もり"
"みつや 三ッ矢 三矢"
"みつやく 密約"
"みつゆ 密輸"
"みつゆき 充之 三幸 光之"
"みつゆしゅつ 密輸出"
"みつゆせん 密輸船"
"みつゆにゅう 密輸入"
"みつゆび 三ッ指"
"みつよ 光代"
"みつよし 光義"
"みつりょう 密猟 密漁"
"みつりん 密林"
"みつる 滿 美弦 満 充"
"みつろう 蜜蝋 光郎"
"みつわ 三輪"
"みづ 美津"
"みづき 観月"
"みづきしょぼう 三月書房"
"みづち 蛟"
"みづの 美津濃"
"みてい 未定"
"みてくれ 見て呉れ"
"みと 弥刀 美都 三戸 御津 水戸"
"みといずみ 水戸泉"
"みとう 美東 未踏"
"みとおし 見通し"
"みところ 三所"
"みとどけやく 見届け役"
"みとみ 三富"
"みとめ 三留"
"みとめいん 認め印"
"みとや 三刀屋"
"みとよ 三豊"
"みとり 見取"
"みとりず 見取り図"
"みどう 御堂"
"みどうすじ 御堂筋"
"みどく 未読"
"みどころ 見所 見どころ"
"みどし 巳年"
"みどり 美土里 碧 翠 ミドリ 美登里 緑"
"みどりいろ 緑色"
"みどりかい 緑会"
"みどりかわ 緑川"
"みどりがおか 緑が丘 緑が岡 緑ヶ丘 緑ケ丘"
"みどりく 緑区"
"みどりご 嬰児"
"みどりちょう 緑町"
"みどりでんし 緑電子"
"みどりまち 緑町"
"みどりまめ 緑豆"
"みどりみ 緑味"
"みどりや 緑屋"
"みどりやま 緑山"
"みどろいけ 深泥池"
"みどろがいけ 深泥池"
"みな 美那 美奈 皆"
"みない 美内 南井"
"みないっしょ 皆一緒"
"みなえ 美奈江"
"みなおし 見直し"
"みなかた 皆方"
"みなかたくまぐす 南方熊楠"
"みなかみ 水上"
"みなかわ 皆川"
"みながわ 皆川"
"みなきょうだい 皆兄弟"
"みなくち 水口"
"みなぐち 源口 皆口"
"みなげ 身投げ"
"みなこ 実奈子 みな子 美名子 美菜子 三奈子 皆子 美奈子"
"みなごろし 皆殺し"
"みなさま 皆様"
"みなさまがた 皆様方"
"みなさん 皆さん"
"みなつ 美夏"
"みなつき 水無月"
"みなづき 水無月 水月"
"みなと 湊 港"
"みなとおおはし 港大橋"
"みなとがわ 湊川"
"みなときたく 港北区"
"みなとく 港区"
"みなとせいき 港製機"
"みなとふじ 湊富士"
"みなとまち 港街 湊町 港町"
"みなとみなみぐち 港南口"
"みなの 皆野"
"みなびょうどう 皆平等"
"みなべ 南部"
"みなまた 水俣"
"みなみ 三波 美並 皆実 美波 南美 南"
"みなみあいづ 南会津"
"みなみあおやま 南青山"
"みなみあきた 南秋田"
"みなみあざぶ 南麻布"
"みなみあしがら 南足柄"
"みなみあずみ 南安曇"
"みなみあべかわばし 南安倍川橋"
"みなみあまべ 南海部"
"みなみありま 南有馬"
"みなみいず 南伊豆"
"みなみいばらき 南茨木"
"みなみうおぬま 南魚沼"
"みなみうらわ 南浦和"
"みなみうわ 南宇和"
"みなみおおさかせん 南大阪線"
"みなみおおさわ 南大沢"
"みなみおおつか 南大塚"
"みなみおおゆうばりてつどう 南大夕張鉄道"
"みなみおぎしま 南荻島"
"みなみおぐに 南小国"
"みなみおたり 南小谷"
"みなみかぜ 南風"
"みなみかた 南方"
"みなみかやべ 南茅部"
"みなみかるいざわ 南軽井沢"
"みなみかわ 南河"
"みなみかわち 南河内"
"みなみかん 南舘"
"みなみかんとう 南関東"
"みなみかんとうぜい 南関東勢"
"みなみかんのんざん 南観音山"
"みなみかんばら 南蒲原"
"みなみがわ 南側"
"みなみきゅうしゅう 南九州"
"みなみく 南区"
"みなみくしやま 南串山"
"みなみくまもとえきまえ 南熊本駅前"
"みなみぐち 南口"
"みなみこいずみ 南小泉"
"みなみこま 南巨摩"
"みなみごたんばえき 南御殿場駅"
"みなみさいたま 南埼玉"
"みなみさおり 南沙織"
"みなみさく 南佐久"
"みなみしが 南志賀"
"みなみしこく 南四国"
"みなみしたら 南設楽"
"みなみしなの 南信濃"
"みなみしまばら 南島原"
"みなみしゃめん 南斜面"
"みなみじゅうじせい 南十字星"
"みなみせん 南線"
"みなみたいへいよう 南太平洋"
"みなみたか 南高"
"みなみたかき 南高来"
"みなみたかぎ 南高来"
"みなみたかさき 南高崎"
"みなみたま 南多摩"
"みなみたまち 南田町"
"みなみだ 南田"
"みなみだい 南台"
"みなみだいとう 南大東"
"みなみだいとうじま 南大東島"
"みなみだか 南高"
"みなみだて 南館"
"みなみちいき 南地域"
"みなみちく 南地区"
"みなみちしま 南千島"
"みなみちた 南知多"
"みなみちとせ 南千歳"
"みなみちょう 南町"
"みなみちょうせん 南朝鮮"
"みなみつがる 南津軽"
"みなみつる 南都留"
"みなみで 南出"
"みなみとうきょう 南東京"
"みなみとうほく 南東北"
"みなみなか 南那珂"
"みなみなさま 皆皆様"
"みなみなす 南那須"
"みなみの 南野"
"みなみのかわち 南河内"
"みなみはっこうだ 南八甲田"
"みなみはんきゅう 南半球"
"みなみはんきゅうぜい 南半球勢"
"みなみはんぶん 南半分"
"みなみひろしまし 南広島市"
"みなみふくおか 南福岡"
"みなみふなばし 南船橋"
"みなみふらの 南富良野"
"みなみべっぷ 南別府"
"みなみほっかいどう 南北海道"
"みなみほんしゅく 南本宿"
"みなみほんじゅくでぐち 南本宿出口"
"みなみほんちょう 南本町"
"みなみぼうそう 南房総"
"みなみまき 南牧"
"みなみまち 南町"
"みなみまちだ 南町田"
"みなみまつうら 南松浦"
"みなみまわり 南回り"
"みなみまんしゅうてつどう 南満州鉄道"
"みなみみのわ 南箕輪"
"みなみみやざき 南宮崎"
"みなみむき 南向き"
"みなみむれ 南牟礼"
"みなみむろ 南牟婁"
"みなみもと 南本"
"みなみもとまち 南元町"
"みなみもりまち 南森町"
"みなみもん 南門"
"みなみやましろ 南山城"
"みなみやまて 南山手"
"みなみゆき 南行"
"みなみゆふ 南由布"
"みなみよの 南与野駅"
"みなみりんかん 南林間"
"みなみわっかない 南稚内"
"みなも 水面"
"みなもと 源"
"みなもとけ 源家"
"みなもとのよりとも 源頼朝"
"みなもとよしつね 源義経"
"みなもとよりよし 源頼義"
"みなよ 美奈代"
"みならい 見習い 見習"
"みならいこう 見習工"
"みなり 身形 身なり"
"みなわ 水泡"
"みに ミニ"
"みにまむ ミニマム"
"みね 三子 三根 岑 美根 美祢 美禰 嶺 峰 峯"
"みねい 嶺井"
"みねうち 峰打ち"
"みねお 峰雄 峯夫 実音夫 岑夫 岑生"
"みねぎし 嶺岸 峯岸 峰岸"
"みねこ 峰子"
"みねごし 峰越"
"みねざき 峯崎"
"みねの 峯野"
"みねのはら 峰の原"
"みねはま 峰浜"
"みねひさ 峰久"
"みねまつ 峰松"
"みねむら 峯村"
"みねやま 峰山"
"みねゆき 峰幸"
"みの 簔 簑 三野 箕 蓑 美濃"
"みのう 美濃 箕面 未納"
"みのうえ 身の上"
"みのうら 箕浦"
"みのお 箕面"
"みのけ 身の毛"
"みのげ 蓑毛"
"みのしま 箕島"
"みのしょう 美濃庄"
"みのしろきん 身代金"
"みのだ 簑田 蓑田 箕田"
"みのと 美濃戸"
"みのはら 蓑原 箕原"
"みのぶ 身延 美乃夫"
"みのぶさん 身延山"
"みのべ 美濃部"
"みのほど 身の程"
"みのまわり 身の回り"
"みのむし 蓑虫"
"みのり 実り 美野里 稔"
"みのる 穣 実 實 稔"
"みのわ 蓑輪 箕輪"
"みはい 未配"
"みはかし 御刀"
"みはし 三橋"
"みはた 御旗"
"みはま 御浜 美浜"
"みはら 美原 三原"
"みはらいきん 未払金"
"みはらし 見晴らし"
"みはり 見張り"
"みはりやく 見張り役"
"みはる 三春 美晴 美春"
"みばえ 見映え 見栄え"
"みばらい 未払"
"みばん 三晩"
"みひつ 未必"
"みひら 三平"
"みひらき 見開き"
"みびいき 身贔屓"
"みふしとうげ 三伏峠"
"みふじ 美富士"
"みふね 御船 三船"
"みぶ 壬生"
"みぶり 見ぶり 身振 身振り"
"みぶるい 身震い"
"みぶん 身分"
"みほ 美浦 美峰 美歩 美帆 実穂 海蜂 美保 美豊 美穂 三保"
"みほこ 美帆子 三穂子 美穂子 美保子"
"みほぜき 美保関"
"みほた 三保田"
"みほとけ 御仏"
"みほろ 美浦"
"みほん 見本"
"みほんちょう 見本帳"
"みぼうじん 未亡人"
"みま 三間 美馬"
"みまい 見舞 見舞い"
"みまき 御牧"
"みまさか 美作"
"みまた 三股"
"みまちがい 見間違い"
"みまつ 三松"
"みまね 見真似 見まね"
"みまわし 見廻し"
"みまわりひん 見回品"
"みまん 未満"
"みみ 耳"
"みみあか 耳垢"
"みみいがい 耳以外"
"みみうち 耳打 耳打ち"
"みみかざり 耳飾"
"みみがくもん 耳学問"
"みみしっかん 耳疾患"
"みみず ミミズ 蚯蚓"
"みみずく 木莵"
"みみせん 耳詮 耳栓"
"みみたぶ 耳朶"
"みみどしま 耳年増"
"みみないぶ 耳内部"
"みみなり 耳鳴 耳鳴り"
"みみにゅうりょく 耳入力信号"
"みみにゅうりょくしんごう 耳入力信号"
"みみぬき 耳抜"
"みみぶくろ 耳袋"
"みみもと 耳元 耳許"
"みみわ 耳輪"
"みむ 美夢"
"みむら 三村"
"みむろ 三室"
"みめ 眉目 見目 美茅"
"みめい 未明"
"みもち 身持"
"みもと 身元"
"みもの 見物"
"みもり 未森"
"みもりまる 美森丸"
"みもん 未聞"
"みゃく 脉 脈"
"みゃくあつ 脈圧"
"みゃくけい 脈系"
"みゃくどう 脈動"
"みゃくはく 脈搏 脈拍"
"みゃくみゃく 脈脈"
"みゃくらく 脈絡"
"みゃくりゃく 脈略"
"みゃくりゅう 脈流"
"みや 美弥 宮"
"みやい 宮井"
"みやいだい 宮医大"
"みやいり 宮入"
"みやうち 宮内"
"みやえき 宮駅"
"みやお 宮尾"
"みやおか 宮岡"
"みやおそうか ミヤオソウ科"
"みやかわ 宮川"
"みやがく 宮学"
"みやがわ 宮川"
"みやき 宮木"
"みやきょう 宮教"
"みやきょうだい 宮城教育大学"
"みやぎ 宮城"
"みやぎしま 宮城島"
"みやぎの 宮城野"
"みやくに 宮国"
"みやくぼ 宮窪"
"みやぐち 宮口"
"みやけ 三宅"
"みやけじま 三宅島"
"みやげ 土産"
"みやげばなし 土産話"
"みやげもの 土産物"
"みやこ 美也子 宮子 宮戸 宮古 都"
"みやこう 宮交"
"みやこおち 都落ち"
"みやこじ 都路"
"みやこじま 宮古島 都島"
"みやこのじょう 都城"
"みやこわん 宮古湾"
"みやごし 宮越"
"みやさか 宮坂"
"みやさと 宮里"
"みやざき 宮崎"
"みやざきおき 宮崎沖"
"みやざきはやお 宮崎駿"
"みやざきもの 宮崎物"
"みやざと 宮里"
"みやざわ 宮沢 宮澤"
"みやした 宮下"
"みやしの 宮篠"
"みやしろ 宮代"
"みやじ 宮路 宮地"
"みやじま 宮島 宮嶋"
"みやじょう 宮絛"
"みやずみ 宮住"
"みやせ 宮瀬"
"みやせん 美祢線"
"みやぞえ 宮副"
"みやぞの 宮苑"
"みやた 宮田"
"みやたけ 宮武 宮竹"
"みやたに 宮谷"
"みやだい 宮大"
"みやだいく 宮大工"
"みやち 宮地"
"みやちよ 宮千代"
"みやぢ 宮地"
"みやづ 宮津"
"みやづかえ 宮仕え"
"みやと 宮戸"
"みやなが 宮永"
"みやなぎ 三柳"
"みやの 宮野"
"みやのうえ 宮之上"
"みやのぎ 宮野木"
"みやのさわ 宮の沢"
"みやのじょう 宮之城"
"みやのぼり 宮登"
"みやはら 宮原"
"みやび 雅"
"みやふくせん 宮福線"
"みやふくてつどう 宮福鉄道"
"みやべ 宮部"
"みやま 美山 海山 三山 深山"
"みやまえ 宮前"
"みやまち 宮町"
"みやまる 宮丸"
"みやみ 未也美"
"みやむら 宮村"
"みやもと 宮本"
"みやもり 宮守 宮森"
"みやら 宮良"
"みやわき 宮脇"
"みゅー μ"
"みゅーじしゃん ミュージシャン"
"みゅう μ"
"みゆう 美憂"
"みゆき 美有紀 御幸 美由希 深雪 美雪 美幸 幸 美由起 美由紀"
"みゆきけおり 御幸毛織"
"みょう 螟 榠 冥 命 明 名 妙"
"みょうあん 妙案"
"みょうおう 明王"
"みょうおん 妙音"
"みょうおんどおり 妙音通"
"みょうが 茗荷 茗加"
"みょうがだに 茗荷谷"
"みょうぎ 妙義 妙技"
"みょうけん 妙見"
"みょうこう 妙高"
"みょうこうざんいき 妙高山域"
"みょうごにち 明後日"
"みょうしゅ 妙手"
"みょうしゅん 明春"
"みょうじ 名字 苗字"
"みょうじょう 明星"
"みょうじん 明神"
"みょうだい 名代"
"みょうちょう 明朝"
"みょうな 妙な"
"みょうにち 明日"
"みょうねん 明年"
"みょうばん 明礬 明晩"
"みょうみ 妙味"
"みょうやく 妙薬"
"みょうり 名利 冥利"
"みょうれい 妙齢"
"みょうれん 明連"
"みょうれんじ 妙蓮寺"
"みょんどん 明洞"
"みよ 御代 美代"
"みよう 見様"
"みようみまね 見よう見真似"
"みよこ 美代子"
"みよし 三芳 三吉 三善 三膳 三好"
"みよた 御代田"
"みより 身寄り"
"みらい 味蕾 未来"
"みらいけい 未来形"
"みらいぞう 未来像"
"みらくるがーるず ミラクル☆ガールズ"
"みらさか 三良坂"
"みらの 未蘭"
"みり ミリ"
"みりぐらむ 瓱"
"みりめーとる 粍"
"みりょう 魅了 未了"
"みりょく 魅力"
"みりりっとる 竓"
"みりん 未林 味醂"
"みりんあじ 味醂味"
"みるく ミルク"
"みるめ 見る目"
"みれい 美麗"
"みれん 未練"
"みろく 彌勒 弥勒"
"みわ 巳波 三和 三輪 美和"
"みわく 魅惑"
"みわけ 見分"
"みわこ 美和子"
"みわた 三輪田"
"みわだ 三輪田"
"みん 閔 ミン 明 眠 民"
"みんい 民意"
"みんえい 民営"
"みんおん 民音"
"みんか 民家"
"みんかへい 民家塀"
"みんかん 明槓 民間"
"みんけん 民権"
"みんげい 民芸"
"みんこう 民航"
"みんこく 民国"
"みんしゃ 民社"
"みんしゃとう 民社党"
"みんしゅ 民主"
"みんしゅう 民衆"
"みんしゅく 民宿"
"みんしゅてきい 民主的"
"みんしゅてききじゅん 民主的基準"
"みんしゅてきじち 民主的自治"
"みんしゅてきとうひょう 民主的投票"
"みんしゅてきほうほう 民主的方法"
"みんしん 民心"
"みんじ 民事"
"みんじゅ 民需"
"みんせい 民政 民青 民生"
"みんせいひん 民製品"
"みんぞく 民俗 民族"
"みんぞくがみ 民族神"
"みんたろう 民太郎"
"みんたんしゅう 民譚集"
"みんだ 民田"
"みんちょう 明朝"
"みんちょうたい 明朝体"
"みんてつ 民鉄"
"みんと ミント"
"みんど 民度"
"みんな 皆な 皆"
"みんはく 民博"
"みんぱく 民博"
"みんぶ 民部"
"みんぶんか 明文化"
"みんぺい 民兵 民平"
"みんぽう 民法 民放"
"みんぽうだい 民法第"
"みんまら 三厩"
"みんめいしょぼう 民明書房"
"みんゆう 民有"
"みんゆうりん 民有林"
"みんよう 民謡"
"みんりょく 民力"
"みんわ 民話"
"む 毋 无 梦 武 六 牟 鵡 矛 務 夢 霧 無"
"むーど ムード"
"むあつしき 無圧式"
"むい 無意 無為"
"むいか 六日 ６日"
"むいそん 無医村"
"むえき 無益"
"むえん 無援 無塩 無鉛 無煙 無縁"
"むえんたん 無煙炭"
"むおう 夢奥"
"むおん 無音"
"むかい 向かい 向 迎 向井"
"むかいかぜ 向い風"
"むかいがおか 向ケ丘"
"むかいがわ 向川"
"むかいがわら 向河原"
"むかいしま 向島"
"むかいたに 向谷"
"むかいなだ 向洋"
"むかいの 向野"
"むかいはら 向原"
"むかいや 向谷"
"むかいやま 向山"
"むかえ 迎"
"むかか 無花果"
"むかし 昔"
"むかしにほん 昔日本"
"むかしばなし 昔話"
"むかしふう 昔風"
"むかしむかし 昔昔 昔々"
"むかっぷかん 占冠間"
"むかで 百足 蜈蚣"
"むかわ 鵡川 武川"
"むかん 無感 無冠"
"むが 無我"
"むがい 無蓋 無害"
"むがく 無学"
"むき 牟岐 無記 無期 無機 向き"
"むきえ 向江"
"むきえん 無機塩"
"むきかた 剥き方"
"むきしつ 無機質"
"むきず 無傷"
"むきはい 無気肺"
"むきゅう 無窮 無級 無給 無休"
"むきょう 無響"
"むきん 無菌"
"むきんせいずいまくえん 無菌性髄膜炎"
"むぎ 麥 牟岐 麦"
"むぎくさとうげ 麦草峠"
"むぎたに 麥谷 麦谷"
"むぎちゃ 麦茶"
"むぎばたけ 麦畑"
"むぎひと 麦人"
"むぎめし 麦飯"
"むぎや 麦谷"
"むぎゆ 麦湯"
"むぎわら 麦わら 麦ワラ 麦藁"
"むく 向 無垢 椋"
"むくい 報"
"むくげ 葮 毳 槿"
"むくだ 椋田"
"むくだい 椋代"
"むくち 無口"
"むくどり 椋鳥"
"むくな 椋名"
"むくろ 躯 骸"
"むくろじもく ムクロジ目"
"むけ 向"
"むけい 無茎 無形"
"むけつ 無血 無欠"
"むけん 無間 無券"
"むげ 無下 無碍"
"むげい 無芸"
"むげがわ 武芸川"
"むげん 無幻 夢幻 ∞ 無限"
"むげんあつ 無限厚"
"むげんえん 無限遠"
"むげんえんてん 無限円点"
"むげんぎ 無限木"
"むげんしょう 無限小"
"むげんだい ∞"
"むげんれんさこう 無限連鎖講"
"むこ 聟 壻 無辜 婿"
"むこう 向う 無向 向こう 無効"
"むこういん 無効印"
"むこうがおか 向ケ丘 向ヶ丘"
"むこうじま 向島"
"むこうじょうめん 向正面"
"むこうずね 向こう脛"
"むこうちょう 向日町"
"むこうまち 向日町"
"むこがわ 婿側 武庫川"
"むこのそう 武庫之荘"
"むこようし 婿養子"
"むこん 無根"
"むごん 無言"
"むごんのぎょう 無言の行"
"むさいしょくこう 無採色光"
"むさく 無策"
"むさし 武蔵"
"むさしこうだい 武蔵工業大学"
"むさしさかい 武蔵境"
"むさしせき 武蔵関"
"むさしの 武蔵野"
"むさしぼうべんけい 武蔵坊弁慶"
"むさしまる 武蔵丸"
"むさん 無産"
"むざい 無罪"
"むざん 無残 無惨"
"むし 毟 無私 無死 虫 蟲 無視"
"むしあき 虫明"
"むしかえし 蒸し返し"
"むしがた 虫型"
"むしき 無支奇"
"むしけら 虫螻"
"むしず 虫唾 虫酸"
"むしつかい 蟲使い"
"むしとり 虫取り"
"むしば 虫歯"
"むしぼし 虫干し"
"むしめがね 虫眼鏡"
"むしもの 蒸し物"
"むしゃ 武者"
"むしゅう 無臭"
"むしゅく 無宿"
"むしょう 霧消 無性 無償"
"むしょく 無色 夢色 無職"
"むしよけ 虫除け"
"むしろ 寧ろ 莚 蓆 筵"
"むしん 無心"
"むしんろん 無神論"
"むじ 無事 無地"
"むじつ 無実"
"むじな 豸"
"むじゅん ⊥ 矛盾"
"むじょう 無上 無情 無常"
"むじるし 無印"
"むじん 無尽 無人"
"むじんせん 無人船"
"むじんぞう 無尽蔵"
"むじんとう 無人島"
"むすい 無水"
"むすいなべ 無水鍋"
"むすう 無数"
"むすこ 息子"
"むすび 結び"
"むすめ 娘"
"むすめじだい 娘時代"
"むすめむこ 娘婿"
"むすめやく 娘役"
"むずかしさ 難しさ"
"むせい 無声 夢精"
"むせきにんおとこ 無責任男"
"むせん 無銭 無線"
"むせんか 無線家"
"むぜい 無税"
"むそう 無双 夢想"
"むそうか 夢想家"
"むそうやま 武双山"
"むた 無佗 牟田"
"むたい 無体"
"むたぐち 牟田口"
"むだ 徒 ムダ 無駄"
"むだあし 無駄足"
"むだい 無題"
"むだがね 無駄金"
"むだじに 無駄死に"
"むだにく 無駄肉"
"むだばなし 無駄話"
"むだぼね 無駄骨"
"むだん 無断"
"むだんへんそく 無段変速"
"むち 笞 鞭 無知"
"むちうち 鞭打"
"むちゃ 無茶"
"むちゅう 霧中 夢中"
"むちん 無賃"
"むっつ 六つ"
"むつ 六 陸奥 睦"
"むつあい 六会"
"むつあき 睦明"
"むつう 無痛"
"むつうら 六浦"
"むつお 睦夫"
"むつき 睦月 睦紀"
"むつこ 睦子"
"むつごと 睦言"
"むつざわ 睦沢"
"むつしげ 睦茂"
"むつのり 睦典"
"むつひろ 睦裕"
"むつみ 六実 睦つ美 睦都美 睦 睦美"
"むつゆき 睦之"
"むつよ 睦予"
"むつわん 陸奥湾"
"むてき 霧笛 無敵"
"むでん 無電"
"むとう 無頭 無糖 無答 武藤"
"むとうかしゃ 無燈火車"
"むとどけ 無届け"
"むどう 武堂"
"むどく 無毒"
"むな 宗 棟 胸"
"むなかた 宗形 棟方 宗像 宗方"
"むなぐら 胸倉"
"むなげ 胸毛"
"むなさき 胸先"
"むなさわぎ 胸騒ぎ"
"むなざんよう 胸算用"
"むなせ 皆瀬"
"むなもと 胸元"
"むに 無二"
"むにえる ムニエル"
"むにねん 無二念"
"むね 刀背 棟 宗 胸 旨"
"むねあき 宗昭"
"むねあげ 棟上げ"
"むねあげしき 棟上式"
"むねうち 刀背打ち"
"むねお 宗夫 宗雄 宗男"
"むねかた 宗片"
"むねくに 宗国"
"むねざわ 宗澤"
"むねしげ 宗重"
"むねた 崇田"
"むねたか 宗高"
"むねたけ 宗武"
"むねだ 宗田"
"むねとし 宗俊"
"むねとも 宗朋"
"むねのり 宗典"
"むねはる 宗治"
"むねひさ 宗久"
"むねひろ 宗裕"
"むねふじ 宗藤"
"むねもと 胸元"
"むねゆき 宗幸"
"むねよし 宗吉 宗良"
"むねん 無念"
"むねんむそう 無念無想"
"むのう 無能"
"むはい 無配 無敗"
"むばつ 無罰"
"むひ 無比"
"むひょう 霧氷"
"むびゅう 無謬"
"むびょう 無病"
"むふう 無風"
"むへん 無辺"
"むべんか 無弁花"
"むほう 無法"
"むほうもの 無法物"
"むほけんしゃ 無保険車"
"むほん 謀叛 謀反"
"むぼう 無謀"
"むま 夢魔"
"むみ 無味"
"むみょう 無明"
"むめい 無銘 無名"
"むめいじゅく 無名塾"
"むやみ 無闇"
"むゆうびょう 夢遊病"
"むよう 無用"
"むよく 無慾 無欲"
"むら 斑 叢 邨 屯 群 邑 村"
"むらい 村井"
"むらいし 村石"
"むらいせんせい 村井線製"
"むらうち 村内"
"むらお 村生 村尾"
"むらおか 村岡"
"むらおこし 村起こし"
"むらかた 村方"
"むらかみ 村上"
"むらかみりゅう 村上龍"
"むらき 村木"
"むらくし 村櫛"
"むらくも 叢雲"
"むらこし 村越"
"むらさき 村さ来 紫"
"むらさきいろ 紫色"
"むらさきしきぶ 紫式部"
"むらさきすいしょう 紫水晶"
"むらさめ 村雨 叢雨"
"むらさわ 村澤 村沢"
"むらした 村下"
"むらじ 村地"
"むらせ 村瀬"
"むらた 邑田 村田"
"むらたに 村谷"
"むらち 村地"
"むらなか 村中"
"むらにし 村西"
"むらの 村野"
"むらはちぶ 村八分"
"むらびと 村人"
"むらまさ 村正"
"むらまつ 村松"
"むらまつり 村祭り"
"むらむすめ 村娘"
"むらむら 村々"
"むらもと 村本"
"むらやま 村山"
"むらわき 村脇"
"むり 無理"
"むりじい 無理強い"
"むりやり 無理槍"
"むりょ 無慮"
"むりょう 無聊 無量 無料"
"むりょうおうふくけん 無料往復券"
"むりょうけん 無料券"
"むりょうじゅ 無量寿"
"むりょく 無力"
"むるい 無類"
"むれ 牟礼 羣 群"
"むれい 牟礼"
"むろ 室町 榁 牟婁 室"
"むろい 室井"
"むろう 室生"
"むろおか 室岡"
"むろが 室賀"
"むろた 室田"
"むろたに 室谷"
"むろと 室戸"
"むろとみさき 室戸岬"
"むろどう 室堂"
"むろね 室根"
"むろはし 室橋"
"むろふし 室伏"
"むろまち 室町"
"むろみ 室見"
"むろや 室哉 室屋 室谷"
"むろやま 室山"
"むろらん 室蘭"
"むろん 無論"
"め 碼 睨 瑪 芽 眼 女 茅 目"
"めーか メーカ"
"めーかー メーカー"
"めーくあっぷ メークアップ"
"めーた メータ"
"めーでー メーデー"
"めーとる メートル"
"めーる メール"
"めあかん 雌阿寒"
"めあて 貭 目当て"
"めい 茗 溟 榠 暝 謎 酩 瞑 冥 姪 盟 鳴 銘 迷 命 明 名"
"めいあらし 明嵐"
"めいあん 明暗 名案"
"めいい 名医"
"めいうせん 名羽線"
"めいうん 命運"
"めいえん 名演"
"めいおう 冥王"
"めいおうせい 冥王星"
"めいか 名歌 銘菓 名家"
"めいかい 冥界 明快 明解"
"めいかく 明確"
"めいかん 名鑑"
"めいが 名画"
"めいがく 明学"
"めいがざ 名画座"
"めいがら 銘柄"
"めいがらごと 銘柄毎"
"めいき 銘機 名機 銘記 銘器 名器 明記"
"めいきゅう 迷宮"
"めいきゅういり 迷宮入り"
"めいきょう 明鏡"
"めいきょく 名局 名曲"
"めいきんせん 名金線"
"めいぎ 名儀 名義"
"めいく 名句 メイク"
"めいくん 明訓"
"めいけ 名家 女池"
"めいけいどう 茗渓堂"
"めいけつ 名血"
"めいけん 迷犬"
"めいげき 名劇"
"めいげつ 名月 明月"
"めいげついん 明月院"
"めいげん 迷言 明言 名言"
"めいこう 名港 名工"
"めいこうだいてっけん 名工大鉄研"
"めいご 明午 迷語"
"めいさい 明細書 迷彩 明細"
"めいさいずしゅう 明細図集"
"めいさいふく 迷彩服"
"めいさく 迷作 名作"
"めいさつ 明察 名刹"
"めいさま 名様"
"めいさん 名産"
"めいし 名氏 名士 名詞 名刺"
"めいしく 名詞句"
"めいしけい 名詞形"
"めいしゃ 眼医者 名車 目医者"
"めいしゅ 名酒 銘酒 盟主 名手"
"めいしょ 名処 名所"
"めいしょう 名将 名勝 名称"
"めいしょうあん 名称案"
"めいしょうせん 名松線"
"めいしん 名神 迷信"
"めいじ 名辞 明治 明示"
"めいじせん 明治戦"
"めいじつ 名實 名実"
"めいじつとも 名実共"
"めいじゃく 名弱"
"めいじょう 名状 名城"
"めいじん 明神 名人"
"めいじんげい 名人芸"
"めいじんせん 名人戦"
"めいすい 名水"
"めいすう 命数"
"めいせい 名聲 明星 名声"
"めいせき 明晰"
"めいぜりふ 名台詞"
"めいぜんりょう 明善寮"
"めいそう 面相 名僧 迷走 瞑想 冥想"
"めいたん 名短"
"めいだ 銘打"
"めいだい 名古屋大学 明大 名大 命題"
"めいだいこう 名大工"
"めいち 命知"
"めいちゅう 命中"
"めいちょ 名著"
"めいちょう 明徴"
"めいっぱい 目一杯"
"めいてい 名艇 酩酊"
"めいてつ 名鉄"
"めいてん 名店"
"めいでんこう 名電高"
"めいでんしゃ 明電舎"
"めいとう 明答 名刀 名東 名答"
"めいとうさんぎょう 明糖産業"
"めいとく 明徳"
"めいど 冥途 冥土 明度"
"めいどう 鳴動"
"めいにち 命日"
"めいはく 明白"
"めいはん 名阪"
"めいば 名馬"
"めいばめん 迷場面"
"めいばん 名盤"
"めいひょう 名票"
"めいひん 名牝 名品"
"めいび 名媚 明媚"
"めいふ 冥府"
"めいふく 冥福"
"めいぶつ 名物"
"めいぶつおとこ 名物男"
"めいぶつし 名物紙"
"めいぶん 銘文 明文 名文 名分"
"めいほう 盟邦 名豊 明芳"
"めいぼ 名簿"
"めいぼう 明眸"
"めいみゃく 命脈"
"めいめい 銘々 命名"
"めいめつ 明滅"
"めいもう 迷妄"
"めいもく 瞑目 名目"
"めいもん 名門"
"めいやく 盟約 名訳"
"めいゆう 名優 盟友"
"めいよ 名誉"
"めいよきそん 名誉棄損"
"めいよきそんざい 名誉毀損罪"
"めいよしょく 名誉職"
"めいりょう 明良 明瞭"
"めいりょどしけんけっか 明瞭度試験結果"
"めいりん 明林"
"めいりんかん 明倫館"
"めいりんどう 明林堂"
"めいりんどうしょてん 明倫堂書店"
"めいる 滅入る メイル"
"めいれい 命令"
"めいれいけい 命令形"
"めいろ 迷路"
"めいろう 明朗"
"めいわ 明和"
"めいわく 迷惑"
"めいわくもの 迷惑者"
"めいん メイン"
"めうえ 目上"
"めうし 雌牛"
"めうつり 目移り"
"めうまげんていしば 牝馬限定芝"
"めおし 目押し"
"めおと 娚 夫婦"
"めか メカ"
"めかくし 目隠し 目隠"
"めかけ 妾"
"めかた 目方"
"めかにずむ メカニズム"
"めかま 目蒲"
"めが 女鹿"
"めがしら 目頭"
"めがね メガネ 眼鏡"
"めがみ 女神"
"めがみぞう 女神像"
"めがわ 女川"
"めきしこ 墨西哥"
"めぎか メギ科"
"めぎつね 女狐"
"めくじら 目鯨"
"めくばせ 目配せ 眼配せ"
"めくら 盲"
"めくらばん 盲判"
"めくるめく 目眩く"
"めぐすり 目薬"
"めぐみ 愛美 惠 めぐ美 恵美 恵"
"めぐむ 萠 恵"
"めぐりあい 巡り合い"
"めぐろ 目黒"
"めさき 目崎 目先"
"めざし 目刺し"
"めざす 目指す"
"めざまし 目覚し"
"めざめ 目覚め"
"めし 飯"
"めしあい 飯合"
"めした 目下"
"めしつかい 召使 召使い"
"めしつぶ 飯粒"
"めしびつ 飯櫃"
"めしべ 雌蕊 雌蘂"
"めしや 飯屋"
"めじ 目時"
"めじか 女鹿"
"めじゃー メジャー"
"めじり 目尻"
"めじるし 目印"
"めじろ 目白"
"めじろおし 目白押"
"めす メス 雌 ♀ 牝"
"めすいぬ 牝犬"
"めすうま 雌馬 牝馬"
"めすかぶ 雌株"
"めすねこ 雌猫"
"めず 馬頭"
"めせん 目線"
"めぞねっと メゾネット"
"めた メタ"
"めたもるふぉーぜ メタモルフォーゼ"
"めたる メタル"
"めたん メタン"
"めだち 目立"
"めだつ 目立つ"
"めだま 眼球 目玉"
"めだまやき 目玉焼"
"めだる メダル"
"めちゃ 目茶"
"めちゃくちゃ 滅茶苦茶"
"めちゃめちゃ 滅茶滅茶"
"めっき 鍍金"
"めっきゃく 滅却 滅脚"
"めっきん 滅菌"
"めっさう 滅相"
"めっしつ 滅失"
"めっしほうこう 滅私奉行 滅私奉公"
"めっしゅ メッシュ"
"めっせーじ メッセージ"
"めっそう 滅相"
"めった 滅多"
"めったに 滅多に"
"めっぽう 滅法"
"めつ 滅"
"めつき 眼つき 眼付 目つき"
"めつけ 目付"
"めつぼう 滅亡"
"めて 右手"
"めでぃあ メディア"
"めでとう 目出当"
"めでゅさんどらもく メデュサンドラ目"
"めとき 目時"
"めど メド 目処 目途"
"めどぎ 蓍"
"めにゅー メニュー"
"めぬき 目抜き"
"めぬま 妻沼"
"めのう 瑪瑙"
"めのまえ 目の前"
"めはな 目鼻"
"めばえ 芽生え"
"めばな 雌花"
"めばり 目貼り"
"めびき 目引"
"めぶんりょう 目分量"
"めべり 目減り"
"めぼし 目星"
"めまい 目眩い 暈 眩暈"
"めまひ 目眩い 眩暈 目眩ひ"
"めまんべつ 女満別"
"めむろ 芽室"
"めめしい 女々しい"
"めも メモ"
"めもちょう メモ帳"
"めもと 目元"
"めもり 目盛り 目盛 メモリ"
"めやす 目安"
"めら 目良"
"めりか 芽里香"
"めりっと メリット"
"めりはり 減張 乙張 減り張り"
"めろでぃー メロディー"
"めん 眄 麪 緜 棉 免 綿 緬 麺 面"
"めんあつ 面圧"
"めんあつぶんぷ 面厚分布"
"めんいつ 面一"
"めんえき 免役 免疫"
"めんおりもの 綿織物"
"めんか 綿価 綿花"
"めんかい 面会"
"めんかやく 綿火薬"
"めんかん 免官"
"めんが 面画"
"めんきつ 面詰"
"めんきょ 免許"
"めんきょふしょじ 免許不所持"
"めんぎょ 面魚"
"めんくい 面食 面食い"
"めんけつごう 面結合"
"めんこうげん 面光源"
"めんざい 免罪"
"めんざいふ 免罪符"
"めんし 綿糸"
"めんしき 面識"
"めんしゅうごう 面集合"
"めんしょく 免職"
"めんじゅうふくはい 面従腹背"
"めんじょ 免除"
"めんじょう 面上 免状"
"めんすう 面数"
"めんせい 面性"
"めんせき 免責 面積"
"めんせきがく 免責額"
"めんせつ 面接"
"めんぜい 免税"
"めんぜん 面前"
"めんぜんちん 門前清"
"めんそ 面素 免訴 免租"
"めんそう 面相"
"めんたい 面対 面体"
"めんたいこ 明太子"
"めんだ 免田"
"めんだん 面談"
"めんちょう 面疔"
"めんつ 面子"
"めんて メンテナンス"
"めんてい 免停"
"めんとう 面頭"
"めんど 面倒"
"めんどう 面堂 面倒"
"めんどうみ 面倒見"
"めんどり 雌鳥"
"めんない 面内"
"めんば 面罵 メンバ"
"めんばー メンバー"
"めんぷ 綿布"
"めんぼう 麺棒 綿棒"
"めんぼく 面目"
"めんぽう 面皰"
"めんみつ 綿密"
"めんみつど 面密度"
"めんめん 面面 綿々 面々"
"めんもう 綿毛"
"めんもく 面目"
"めんよう 緬羊 面妖 綿羊"
"めんようそ 面要素"
"めんるい 麺類"
"めんれんけつ 面連結"
"も 糢 楙 姆 邑 貰 望 裳 喪 藻 摸 母 模 茂"
"もーせのじっかい モーセの十誡 モーセの十戒"
"もーた モータ"
"もーたー モーター"
"もーど モード"
"もう 芒 莽 艨 耄 罔 网 矇 濛 檬 朦 曚 亡 望 申 魍 孟 妄 毛 蒙 猛 盲 耗 網"
"もうあい 妄愛"
"もうい 猛威"
"もういちど もう一度"
"もううん 妄雲"
"もうか 真岡 猛火"
"もうかんじゅうそう 盲管銃創"
"もうがっこう 盲学校"
"もうきん 猛禽"
"もうぎゅう 猛牛"
"もうけ 儲"
"もうけやく 儲役"
"もうけん 猛犬"
"もうげん 妄言"
"もうこ 猛虎 蒙古"
"もうこう 猛攻"
"もうことう 猛虎党"
"もうこれき 猛虎暦"
"もうこん 毛根"
"もうさい 毛細"
"もうさいかんげんしょう 毛細管現象"
"もうさいけっかん 網細血管"
"もうし 孟子"
"もうしあわせ 申し合わせ 申し合せ"
"もうしいれ 申し入れ"
"もうしこみ 申し込み 申込"
"もうしこみうけつけじゅん 申込受付順"
"もうしたて 申立て 申立"
"もうしで 申し出"
"もうしぶん 申し分"
"もうしもく 網翅目"
"もうしゅう 妄執"
"もうしょ 猛暑"
"もうしわけ 申訳 申し訳け 申し訳"
"もうしわけない 申し訳ない"
"もうしん 盲進 猛進 盲信"
"もうじゃ 盲者 亡者"
"もうじゅう 盲従 猛獣"
"もうじょう 網状 毛状"
"もうじょうたい 毛状体 網状態"
"もうじょうみゃく 網状脈"
"もうじん 盲人"
"もうすこし もう少し"
"もうせい 猛省"
"もうせん 毛氈"
"もうぜん 猛然"
"もうそう 網総 妄想"
"もうそうか 妄想家"
"もうたい 毛帯"
"もうたくとう 毛沢東"
"もうだ 猛打"
"もうだん 妄断"
"もうちょう 盲腸"
"もうつい 猛追"
"もうてん 盲点"
"もうで 詣で 詣"
"もうとう 毛頭"
"もうとく 孟徳"
"もうどう 妄動 艨艟 盲導"
"もうどうけん 盲導犬"
"もうどく 猛毒"
"もうない 網内"
"もうねん 妄念"
"もうはつ 毛髪"
"もうはんげき 猛反撃"
"もうはんたい 猛反対"
"もうばく 猛爆"
"もうひつ 毛筆"
"もうひつたい 毛筆体"
"もうひょう 猛豹"
"もうふ 毛布"
"もうふぶき 猛吹雪"
"もうまい 矇昧 濛昧 曚昧 蒙昧"
"もうまく 網膜"
"もうもう 濛濛 濛々"
"もうもく 盲目"
"もうもん 網紋"
"もうよう 網様"
"もうようたい 毛様体"
"もうら 網羅"
"もうり 毛利"
"もうりょう 魍魎"
"もうれつ 猛烈"
"もうれんしゅう 猛練習"
"もうれんちゃん 猛連荘"
"もうろう 朦朧"
"もうろく 耄碌"
"もえ 萠 萌 燃"
"もえぎいろ 萌木色"
"もえこ 萌子"
"もおか 真岡"
"もがみ 最上"
"もぎ 茂木 摸擬 模擬"
"もぎせん 模擬戦"
"もぎてきせかい 模擬的世界"
"もぎどう 没義道"
"もく 默 沐 杢 黙 目 木"
"もくあみ 黙阿弥 木阿弥"
"もくきん 木金"
"もくきんど 木金土"
"もくぎょ 木魚"
"もくぐん 目群"
"もくげき 目撃"
"もくこうぞう 木構造"
"もくさつ 黙殺"
"もくさん 目算"
"もくざい 木材"
"もくざいこう 木材港"
"もくし 黙視 目視 目指"
"もくしつ 木質"
"もくしろく 黙示録"
"もくじ 黙示 目次"
"もくず 藻屑"
"もくせい 木犀 木製 木星"
"もくせいか モクセイ科"
"もくせいもく モクセイ目"
"もくぜん 黙然 目前"
"もくそう 黙想"
"もくそく 目測"
"もくぞう 木造"
"もくたん 木炭"
"もくだく 黙諾"
"もくづ 藻屑"
"もくてき 目的"
"もくてきかく 目的格"
"もくてきごと 目的毎"
"もくてきしょく 目的食"
"もくてきじょうせいとう 目的上正当"
"もくてきじょうひつよう 目的上必要"
"もくてきぜい 目的税"
"もくとう 黙祷"
"もくどく 黙読"
"もくにん 黙認"
"もくねん 黙念"
"もくの 杢野"
"もくば 木馬"
"もくひ 黙秘"
"もくひょう 目標"
"もくぶ 木部"
"もくへん 木片"
"もくほん 木本"
"もくまおうもく モクマオウ目"
"もくめ 木目"
"もくもく 黙々"
"もくよう 木曜"
"もくよく 沐浴"
"もくれい 目礼 黙礼"
"もくれん モクレン"
"もくろく 黙録 目録"
"もくろみ 目論見"
"もくろん 目論"
"もぐら 土竜 土龍"
"もけい 模型"
"もこ 糢糊 模糊"
"もこく 摸刻"
"もこと 藻琴"
"もさ 猛者"
"もさく 摸索 模策 模作 模索"
"もし 若し 模試"
"もしか 若しか"
"もしき 摸式 模式"
"もしくは 若しくは"
"もしゃ 摸冩 摸写 模写"
"もしゅ 喪主"
"もしょう 喪章"
"もじ 綟 門司 文字"
"もじおち 文字落"
"もじくばり 文字配り"
"もじこう 門司港"
"もじごと 文字毎"
"もじした 文字下"
"もじづら 文字面"
"もじばけ 文字化け"
"もじゅーる モジュール"
"もじり 捩"
"もじわく 文字枠"
"もすくわ 莫斯科"
"もず 鴃 鵙 百舌鳥 百舌"
"もずみ 茂住"
"もずめ 物集 物集女"
"もせうし 妹背牛"
"もそう 模奏"
"もぞう 摸造 模造"
"もぞうし 模造紙"
"もた 持た"
"もだえ 悶え"
"もち 望 持ち 餠 勿 持 餅"
"もちーふ モチーフ"
"もちあじ 持ち味"
"もちあわせ 持ち合せ"
"もちいえ 持ち家"
"もちうた 持ち歌"
"もちお 持尾"
"もちかぶ 持ち株"
"もちかぶかい 持株会"
"もちがせ 用瀬"
"もちがね 持ち金"
"もちこし 持越"
"もちこみうま 持込馬"
"もちごま 持駒"
"もちごめ 糯米 糯 餅米"
"もちだ 持田"
"もちづき 餅月 望月"
"もちぬし 持主 持ち主"
"もちはこび 持ち運び"
"もちば 持ち場"
"もちひろ 望洋"
"もちぶん 持分"
"もちまえ 貭"
"もちむね 用宗"
"もちもの 持物 持ち物"
"もちや 餅屋"
"もちゅう 喪中"
"もちろん 勿 勿論"
"もっか 目下"
"もっかどこんすい 木火土金水"
"もっかん 木管"
"もっきつ 勿吉"
"もっけ 勿怪"
"もっこう 黙考 木工"
"もったい 勿体"
"もったいない 勿体無い 勿体ない"
"もって 以て"
"もっとー モットー"
"もっとも 尤も 最も"
"もっともやく 尤役"
"もっぱら 専ら"
"もつ 勿 物"
"もつやく 没薬"
"もてぎ 茂木"
"もでる モデル"
"もと 望都 礎 幹 素 許 下 基 本 元"
"もとあき 元明 元昭"
"もとあり 本有"
"もとい 基"
"もといけ 本池"
"もといし 本石"
"もとうけ 元請け"
"もとうた 元歌"
"もとうり 元売り"
"もとえ 元絵"
"もとえい 基栄"
"もとお 誠生 基夫 元朗 元男 元夫"
"もとおか 元岡"
"もとおり 本居"
"もとかず 元一"
"もとかど 本門"
"もとかわ 本川"
"もとき 元紀 基樹 元基 元木 基紀 本木"
"もときゅう 本久"
"もときん 元金"
"もとこ 茂登子 基子 素子"
"もとさと 理元"
"もとざわ 本澤"
"もとし 基史 基志 元志 元司"
"もとじ 元司"
"もとじめ 元締 元締め"
"もとじゅく 本宿"
"もとじろう 基次郎"
"もとす 本栖 本巣"
"もとすこ 本栖湖"
"もとせん 元栓"
"もとたか 基隆 元孝"
"もとただ 元正"
"もとだ 元田"
"もとちょう 元帳"
"もとで 元手"
"もとでら 元寺"
"もとなが 源久"
"もとなり 元成 元就"
"もとに 基に 元に"
"もとにほんへい 元日本兵"
"もとね 元値"
"もとの 本埜 基乃 元野"
"もとのり 元紀 一徳 素典"
"もとはし 本橋"
"もとはま 元浜"
"もとはら 本原"
"もとはる 元春"
"もとばこ 元箱"
"もとばこづき 元箱付"
"もとばやし 本林"
"もとばらい 元払"
"もとひこ 元彦"
"もとひさ 基久 元久 幹久"
"もとひで 元英 元秀"
"もとひろ 礎弘 基史 元洋"
"もとび 元火"
"もとふみ 元文"
"もとぶ 本部"
"もとまち 元町"
"もとみや 本宮"
"もとむら 本村"
"もとめ 求め"
"もともと 基々 元々"
"もとや 元也"
"もとやま 元山 本山"
"もとやわた 本八幡"
"もとゆい 元結"
"もとゆき 幹之 基之"
"もとよし 元慶 基良 基吉 本吉 元吉"
"もとる 乖"
"もどしこうはい 戻し交配"
"もどりさき 戻り先"
"もどりち 戻値 戻り値"
"もなか 邑中 最中"
"もにた モニタ"
"もにみあか モニミア科"
"もにわ 茂庭"
"もぬけ 蛻"
"もぬし 喪主"
"もの モノ 者 物"
"ものいい 物言い"
"ものいっぱん 物一般"
"ものいみ 物忌み"
"ものうい 懶い 物憂い"
"ものうげ 物憂げ"
"ものお 桃生"
"ものおき 物置"
"ものおじ 物怖"
"ものおぢ 物怖"
"ものおと 物音"
"ものおぼえ 物覚え"
"ものかき 物書き"
"ものかげ 物陰"
"ものがたり 物語"
"ものくろ モノクロ"
"ものぐさ 懶"
"ものごい 物乞"
"ものごころ 物心"
"ものごし 物腰"
"ものごと 物事"
"ものさし 物指 物指し 物差し"
"ものしり 物知り"
"ものじたい 物自体"
"ものずき 物好き"
"ものたち 者達"
"ものたりない 物足りない"
"ものども 者共"
"もののけ 物怪 物の怪"
"もののふ 武士"
"もののべ 物部"
"もののほん 物の本"
"ものぶそく 物不足"
"ものべ 物部"
"ものほし 物干 物干し"
"ものまね 物真似"
"ものみ 物見"
"ものみゆさん 物見遊山"
"ものもち 物持ち"
"ものわかれ 物別れ"
"ものわすれ 物忘れ"
"もはや 最早"
"もはら 茂原"
"もはん 模範"
"もはんしゅう 模範囚"
"もはんじあい 模範試合"
"もばら 茂原"
"もふく 喪服"
"もほう 模倣"
"もみ 樅 籾"
"もみあい 揉み合い"
"もみあげ 揉み上げ"
"もみあらい 揉み洗い"
"もみい 籾井"
"もみじ 椛 楓 紅葉"
"もみて 揉み手"
"もめごと 揉事 揉め事"
"もめん 木綿"
"もめんばり 木綿針"
"もも 腿 百 桃"
"ももい 桃井"
"ももいし 百石"
"ももいろ 桃色"
"ももいろぞうさん 粉紅色仔象"
"ももうち 桃内"
"ももえ 百恵"
"ももかわ 桃川 百川"
"ももくりさんねん 桃栗三年"
"ももこ 桃子"
"ももさき 桃崎"
"ももじりむすめ 桃尻娘"
"ももせ 百瀬"
"ももぞの 桃園"
"ももた 百田"
"ももたろう 桃太郎"
"ももたろうざむらい 桃太郎侍"
"ももだに 桃谷"
"ももとみみ 桃と耳"
"もものき 桃の木"
"ももひめ 桃姫"
"ももみみ 桃耳"
"ももむら 百村"
"ももや 桃屋"
"ももやま 桃山"
"ももよ 百代"
"ももんが モモンガ"
"もや 靄 母屋"
"もよう 模様"
"もようがえ 模様替"
"もよおし 催し"
"もよおしじょう 催場"
"もよおしもの 催物 催し物"
"もより 最寄 最寄り"
"もらいて もらい手"
"もらる モラル"
"もり 銛 護 杜 盛 守 森"
"もりあい 盛合"
"もりあがり 盛り上がり"
"もりあき 守章"
"もりあげ 盛り上げ"
"もりあげかた 盛りあげ方"
"もりあわせ 盛り合せ"
"もりい 森井"
"もりいで 森出"
"もりうち 森内"
"もりえだ 森枝"
"もりお 盛夫 杜夫 森生 森男 守夫 盛雄 守男 森尾"
"もりおうがい 森鴎外"
"もりおか 森丘 守岡 森岡 盛岡"
"もりおかだいいちこう 盛岡第一高"
"もりおかだいさんこう 盛岡第三高"
"もりかげ 森景"
"もりかわ 森河 守川 森川"
"もりがき 森垣"
"もりきた 森北"
"もりくち 森口"
"もりくら 森蔵"
"もりぐち 森口 守口"
"もりけい 森景"
"もりさがり 盛り下がり"
"もりさき 森崎"
"もりさだ 森定"
"もりさと 森里"
"もりさわ 森沢"
"もりしげ 森重 護重"
"もりした 森下"
"もりしま 森嶋 森島"
"もりしんいち 森進一"
"もりじり 森尻"
"もりすえ 森末"
"もりすみ 森住"
"もりせ 森瀬"
"もりそば 盛蕎麦"
"もりぞう 森蔵"
"もりぞの 森園"
"もりた 盛田 守田 森田"
"もりたか 森高"
"もりたに 森谷 守谷"
"もりだくさん 盛り沢山 盛沢山"
"もりちょう 森町"
"もりつ 森津"
"もりつぐ 森嗣"
"もりつち 盛り土"
"もりつちしき 盛土式"
"もりてん 森店"
"もりと 森戸"
"もりとう 森藤"
"もりとお 盛遠"
"もりとし 守利"
"もりとも 守友"
"もりなが 森永"
"もりの 森野"
"もりのさと 森の里"
"もりのぶ 森信"
"もりのみや 森の宮"
"もりばな 盛り花"
"もりひこ 守彦"
"もりひろ 護煕 守弘"
"もりびと 守人"
"もりべ 森部"
"もりまつ 森松"
"もりみち 守倫"
"もりむら 森村"
"もりもち 守通"
"もりもと 盛本 森本 守本"
"もりや 森屋 森谷 守谷 守屋"
"もりやく 守役"
"もりやす 守安 森安 森保"
"もりやま 守山 森山"
"もりゆき 森雪"
"もりよし 守克 森吉"
"もりわか 森若"
"もりわき 森脇"
"もりわけ 守分"
"もるもっと モルモット"
"もれ 漏れ 洩れ"
"もろ 師 諸"
"もろえ 諸江"
"もろお 師尾"
"もろおか 師丘 師岡 諸岡"
"もろこし 蜀黍"
"もろさと 諸里"
"もろずみ 諸角 双墨"
"もろた 諸田"
"もろつか 諸塚"
"もろて 双手 諸手"
"もろどみ 諸富"
"もろは 両刃"
"もろはし 師橋 諸橋"
"もろば 両刃"
"もろほし 諸星"
"もろぼし 諸星"
"もろみ 醪"
"もろもろ 諸 諸々"
"もろやま 毛呂山"
"もん 捫 聞 悶 紋 文 問 門"
"もんえい 門衛"
"もんか 門下"
"もんがい 門外"
"もんがいかん 門外漢"
"もんきり 紋切り 紋切"
"もんく 文句"
"もんくなし 文句無し 文句無"
"もんげん 門限"
"もんこ 門戸"
"もんごん 文言"
"もんし 門歯 悶死"
"もんしょう 紋章"
"もんしろちょう 紋白蝶"
"もんしん 問診"
"もんじ 文字"
"もんじえきがわ 門司駅側"
"もんじゅ 文珠"
"もんすたー モンスター"
"もんせき 問責"
"もんせん 門扇"
"もんぜき 門跡"
"もんぜつ 悶絶"
"もんぜん 門前"
"もんぜんなかちょう 門前仲町"
"もんぜんなかまち 門前仲町"
"もんだい 問題"
"もんだいあり 問題有"
"もんだいさく 問題作"
"もんだいし 問題視"
"もんだいじ 問題児"
"もんだいなし 問題無"
"もんだんてん 問題点"
"もんち 門地"
"もんちゃく 悶着"
"もんちゅう 門柱 問中"
"もんつき 紋付"
"もんつきはかま 紋付袴"
"もんてい 門弟"
"もんてかるろほう モンテカルロ法"
"もんてつかんない 門鉄管内"
"もんでん 門田"
"もんど 門戸 主水"
"もんどう 問答"
"もんどうへん 問答篇"
"もんどころ 紋所"
"もんな 門奈"
"もんの 門野"
"もんばつ 門閥"
"もんばやし 門林"
"もんばん 門番"
"もんぴ 門扉"
"もんぴょう 門標"
"もんぶ 文部"
"もんぶしょう 文部省"
"もんべつ 門別 紋別"
"もんま 門真 門馬"
"もんみゃく 門脈"
"もんめ 問目 匁"
"もんもう 文盲"
"もんもん 悶々"
"もんよう 紋様 文様"
"や 埜 笶 椰 揶 ゃ ⇒ 彌 八 耶 爺 冶 哉 ↑ 弥 ← → ↓ 也 谷 家 夜 野 矢 屋"
"やー Я"
"やいた 矢板"
"やいづ 焼津"
"やいば 刃"
"やいん 夜陰"
"やえ 八重"
"やえい 野営"
"やえいずみ 八重泉"
"やえがき 八重垣"
"やえがし 八重樫"
"やえこ 彌生子 八重子"
"やえざくら 八重桜"
"やえす 八重洲 八重州"
"やえすぐち 八重洲口"
"やえば 八重歯"
"やえん 野猿"
"やお 矢尾 八百 八尾"
"やおい 矢追"
"やおいた 矢尾板"
"やおき 八起"
"やおくめ 八百粂"
"やおつ 八百津"
"やおとめ 八乙女"
"やおはら 八百原"
"やおもて 矢面"
"やおよろず 八百万"
"やおん 野音"
"やかい 夜会"
"やかいふく 夜会服"
"やかけちょう 矢掛町"
"やかげ 矢掛"
"やかた 舘 屋形 館"
"やかたぶね 屋形舟 屋形船"
"やから 輩"
"やかん 薬罐 夜間"
"やかんすいじょうせん 夜間水上戦"
"やが 屋我"
"やがい 屋外 野外"
"やがく 夜学"
"やがけ 矢掛"
"やがて 軈て 軈 軅"
"やがみ 矢上 八神"
"やがみだいこうしゃ 矢上台校舎"
"やがも 矢鴨"
"やがわ 矢川"
"やがわら 谷川原"
"やき 燒 夜気 焼"
"やきいも 焼芋"
"やきいん 焼き印"
"やきがし 焼き菓子"
"やきぎょうざ 焼餃子"
"やきぐり 燒栗"
"やきざかな 焼魚 焼き魚"
"やきそば 焼きそば"
"やきつけ 焼付 焼付け"
"やきとり 焼鳥 焼き鳥"
"やきにく 焼き肉 焼肉"
"やきはたのうぎょう 焼畑農業"
"やきはまぐり 焼蛤"
"やきびたい 焼額"
"やきふ 焼麩"
"やきぶた 焼豚"
"やきまし 焼増 焼き増し"
"やきめし 焼き飯"
"やきもの 焼物"
"やきゅう 野球"
"やきゅうきょう 野球狂"
"やきゅうずき 野球好き"
"やきょく 夜曲"
"やきりんご 焼林檎"
"やきん 冶金 夜勤"
"やぎ 山羊 柳 八木"
"やぎがわ 山羊革"
"やぎざ 山羊座"
"やぎた 八木田"
"やぎぬま 八木沼"
"やぎはし 八木橋"
"やぎゅう 柳生"
"やぎゅうさんだい 柳生三代"
"やぎょう ヤ行 夜業"
"やく ≒ 蜴 焼 鑰 譯 藥 葯 籥 檪 扼 屋久 龠 夜久 厄 繹 躍 薬 訳 役 約"
"やくあり 訳有"
"やくいん 薬院 役印 役員"
"やくえき 薬液"
"やくおとし 厄落とし"
"やくおん 約音"
"やくかさえき 薬価差益"
"やくがい 薬害"
"やくがく 薬学"
"やくがら 役柄"
"やくぎょうじほうしゃ 薬業時報社"
"やくご 訳語"
"やくごめん 役御免"
"やくさい 薬菜 厄災"
"やくさつ 扼殺 薬殺"
"やくざい 薬剤"
"やくし 薬師 訳詩 訳詞"
"やくしじ 薬師寺"
"やくしどう 薬師堂"
"やくしま 屋久島"
"やくしまる 薬師丸"
"やくしゃ 役者 訳者"
"やくしゅつ 訳出"
"やくしょ 訳書 役所"
"やくしょく 役職"
"やくしん 薬疹 躍進"
"やくじ 薬事"
"やくじょ 躍如"
"やくじょう 約定"
"やくじん 厄神"
"やくすう 約数"
"やくすぎ 屋久杉"
"やくずもう 役相撲"
"やくせき 薬石"
"やくぜん 薬膳"
"やくそう 躍層 薬草"
"やくそく 約束"
"やくそくごと 約束事"
"やくたい 益体"
"やくだつ 役立つ"
"やくちゅう 薬中 訳註 訳注"
"やくづき 役付き"
"やくて 約手"
"やくてい 約定"
"やくとく 役得"
"やくどう 躍動"
"やくどく 役得"
"やくどし 厄年"
"やくなし 訳無"
"やくにん 役人"
"やくの 夜久野"
"やくはんぶん 約半額"
"やくば 役場"
"やくばらい 厄払い"
"やくひん 薬品"
"やくひんしゅう 薬品臭"
"やくび 厄日"
"やくびょうがみ 厄病神"
"やくぶそく 役不足"
"やくぶつ 薬物"
"やくぶつてきしゅうかんせい 薬物的習慣性"
"やくぶん 訳文 約分"
"やくほう 薬包"
"やくほん 訳本"
"やくぼ 矢久保"
"やくまる 薬丸"
"やくまわり 役回り"
"やくまん 役満"
"やくみ 薬味"
"やくめ 役目"
"やくめい 役名"
"やくも 八雲"
"やくもの 役物"
"やくゆ 薬湯"
"やくよう 薬用"
"やくよけ 厄除"
"やくり 薬理"
"やくりきし 役力士"
"やくると ヤクルト"
"やくろう 薬籠"
"やくわり 役割"
"やぐ 夜具"
"やぐち 谷口 矢口"
"やぐら 矢倉 櫓"
"やぐらなげ 櫓投げ"
"やけ 自棄"
"やけあと 焼跡 焼け跡"
"やけい 野鶏 夜警 夜景"
"やけいし 焼け石"
"やけこげ 焼け焦げ"
"やけだけ 焼岳"
"やけど 火傷"
"やけのはら 焼け野原 焼野原"
"やけひばし 焼け火箸"
"やけびたい 焼額"
"やけびたいさん 焼額山"
"やけん 野犬"
"やこう 夜香 八高 夜光 矢向 夜行"
"やこうちゅう 夜光虫 夜行虫"
"やこぜん 野狐禅"
"やこびぎょうれつ ヤコビ行列"
"やごう 屋号"
"やごし 矢越"
"やごと 八事"
"やさい 野菜"
"やさいいため 野菜炒め"
"やさいぞえ 野菜添え"
"やさか 弥栄 八尺 八坂"
"やさき 矢先"
"やさく 矢作"
"やさと 八郷"
"やざき 矢崎"
"やざわ 谷沢 矢澤 矢沢"
"やし 椰 香具師 椰子"
"やしお 八入 八潮"
"やしき 廛 壥 邸 矢輔 屋輔 屋敷"
"やしち 弥七"
"やしのみ 椰子の実"
"やしま 矢島 屋島"
"やしもく ヤシ目"
"やしゃ 夜叉"
"やしゃご 玄孫"
"やしゅ 野手 野趣"
"やしゅう 夜襲"
"やしょく 夜食"
"やしろ 八代 社"
"やしわご 玄孫"
"やしん 野心"
"やじ 野次"
"やじうま 弥次馬 野次馬"
"やじうまてききょうみ 野次馬的興味"
"やじま 八島 矢嶋 矢島 谷島"
"やじゅう 野獣"
"やじゅうは 野獸派"
"やじり 鏃"
"やじるし ⇔ ⇒ ← ↑ → ↓ 矢印"
"やじろべい 弥次郎兵衛"
"やす 夜須 裕 保 恭 野洲 靖 泰 康 安"
"やすあき 保昭 泰昭 恭章 康明"
"やすい 保井 靖 安井"
"やすいけ 安池"
"やすいちろう 靖一郎"
"やすうら 安浦"
"やすうり 安売り 安売"
"やすえ 保江 安恵 安江 康恵"
"やすお 保生 寿男 恭朗 裕雄 八洲男 靖夫 保雄 保夫 保男 泰雄 泰夫 康男 安雄 安男 康雄 靖雄 泰男 泰生 康生 康夫"
"やすおか 泰阜 安岡"
"やすかが 安加賀"
"やすかず 康一 保一 保和"
"やすかわ 安川"
"やすき 靖己 安樹 泰樹 康己"
"やすきよ 安挙"
"やすぎ 八杉 安来"
"やすくに 靖国"
"やすげっきゅう 安月給"
"やすこ 安子 妥子 泰子 恭子 康子 靖子"
"やすさ 安さ"
"やすさだ 保貞"
"やすさと 安里"
"やすざか 安坂"
"やすざけ 安酒"
"やすし 靖志 安 廉史 保 泰士 靖史 保司 尉 也寸志 泰司 康史 泰 康 靖"
"やすしば 安柴"
"やすじ 康二 康次 康司"
"やすじろう 安二郎"
"やすたか 泰臣 泰孝 泰宇 泰隆 康隆"
"やすたけ 安武 康剛"
"やすたに 保谷"
"やすたみ 康民"
"やすだ 保田 安田"
"やすだきねんば 安田記念馬"
"やすっぽい 安っぽい"
"やすづか 安塚"
"やすて 野ステ"
"やすてつ 康哲"
"やすと 保人 靖人"
"やすとし 泰稔 康敏 康俊"
"やすとみ 安富"
"やすとめ 安留"
"やすとも 康友"
"やすなお 康尚"
"やすなが 保永 康永 安永"
"やすなり 康也 康成"
"やすね 安値"
"やすのう 安納"
"やすのぶ 泰信 保信 恭伸"
"やすのり 靖教 保憲 泰典 泰則 安紀 保徳 靖則 康徳 泰憲 安則 康則 保法 保則"
"やすは 泰葉"
"やすはら 保原 安原"
"やすはる 泰治 康治 泰晴"
"やすひこ 安彦 泰彦 靖彦 康彦"
"やすひさ 靖久 恭久"
"やすひで 保秀"
"やすひと 康仁 保人"
"やすひろ 靖弘 康広 康宏 靖太 靖浩 泰弘 泰寛 康浩 安浩 靖宏 安弘 保博 保浩 泰広 康裕 康弘 康博 恭弘 泰宏"
"やすふみ 康史 康文 泰史"
"やすぶしん 安普請"
"やすぶみ 康文"
"やすまさ 康雅 泰正 康正"
"やすまつ 安松"
"やすみ 保美 休み"
"やすみあけ 休み明け"
"やすみち 易道"
"やすみつ 康満 康光"
"やすむら 安村"
"やすもと 安本"
"やすもの 安物"
"やすや 恭也"
"やすやす 易々"
"やすやど 安宿"
"やすゆき 康幸 恭之 育志 康行 靖之 泰之 保之 康之 靖幸"
"やすよ 康世 康代 安代 靖代"
"やすよし 靖佳 康義 康良 康善"
"やすり 鑢"
"やすろう 康朗 恭郎"
"やずぎ 八杉"
"やせ 八瀬"
"やせい 野性 野生"
"やせいじ 野性児 野生児"
"やせいみ 野生味"
"やせがた やせ型"
"やせがまん 痩せ我慢"
"やせん 野戦 夜戦"
"やせんぐん 野戦軍"
"やせんこうじょう 野戦攻城"
"やそ 八十"
"やそう 野草 夜走"
"やそうきょく 夜想曲"
"やそかわ 八十川"
"やそすけ 八十助"
"やそよろず 八十万"
"やた 八咫 矢田"
"やたい 屋台"
"やたいぼね 屋台骨"
"やたがい 矢田貝"
"やたがらす 八咫鴉"
"やたでら 矢田寺"
"やたのかがみ 八咫鏡"
"やたべ 谷田部"
"やたま 矢玉"
"やたら 矢鱈"
"やたろう 弥太郎"
"やだ 煎田 矢田"
"やち 萢 谷地"
"やちた 谷地田"
"やちだ 谷内田"
"やちほ 八千穂"
"やちまた 八街"
"やちゅう 夜中"
"やちょう 野帳 野鳥"
"やちよ 八千代"
"やちん 屋賃 家賃"
"やちんほじょがく 家賃補助額"
"やっか 薬価 薬科"
"やっかい 厄介"
"やっかいごと 厄介事"
"やっかん 約款"
"やっき 躍起"
"やっきょう 薬莢 薬夾"
"やっきょく 薬局"
"やっこ 奴"
"やっこうはつげん 薬効発現"
"やっこそうか ヤッコソウ科"
"やっこそうもく ヤッコソウ目"
"やっつ 八つ"
"やっとこ 鋏"
"やっぱり 矢つ張り"
"やつ 谷 八 谷津 奴"
"やつお 八尾"
"やつか 八束"
"やつがたけ 八ヶ岳"
"やつがだけ 八ヶ岳 八岳"
"やつぎ 矢継"
"やつぎばや 矢次ぎ早 矢継ぎ早"
"やつざき 八つ裂き"
"やつしろ 八代"
"やつだ 谷津田"
"やつだま 八玉"
"やつはし 八つ橋"
"やつめうなぎ 鱧"
"やつもり 八ッ森"
"やつら 奴等"
"やと 野兎"
"やとい 雇"
"やといにん 雇人"
"やといぬし 雇い主 雇主"
"やとう 野党"
"やとみ 弥富"
"やど 宿"
"やどかり 寄居蟲 寄居虫"
"やどじょうほう 宿情報"
"やどだい 宿代"
"やどちょう 宿帳"
"やどちん 宿賃"
"やどぬし 宿主"
"やどや 宿屋"
"やどりぎ 宿り木"
"やどろく 宿六"
"やな 簗 梁"
"やない 屋内 矢内 柳井"
"やないづ 柳津"
"やなお 柳尾"
"やなか 谷中"
"やながわ 梁川 柳川"
"やなぎ 柳"
"やなぎごし 柳腰"
"やなぎさわ 柳澤 柳沢"
"やなぎしま 柳島"
"やなぎたに 柳谷"
"やなぎだ 柳田"
"やなぎちょう 柳町"
"やなぎはら 柳原"
"やなぎば 柳葉"
"やなぎぼり 柳堀"
"やなぎまち 柳町"
"やなぎもく ヤナギ目"
"やなぎもと 柳本"
"やなぎや 柳谷 柳家"
"やなざき 柳崎"
"やなせ 柳瀬"
"やなだに 柳谷"
"やなつ 柳津"
"やなとり 梁取"
"やなはら 柵原"
"やなば 簗塲"
"やなみ 家並み"
"やなる 矢鳴"
"やに 脂"
"やぬし 家主"
"やね 屋根"
"やねあと 屋敷跡"
"やねいた 屋根板"
"やねうま 屋根馬"
"やねうら 屋根裏"
"やねごし 屋根越し"
"やねざい 屋根材"
"やねした 屋根下"
"やねづけ 屋根付"
"やねゆき 屋根雪"
"やの 矢野"
"やのくら 矢野倉"
"やのぐち 矢野口"
"やはぎ 八萩 矢矧 矢作"
"やはた 八幡"
"やはたにし 八幡西"
"やはたの 八幡野"
"やはたひがし 八幡東"
"やはば 矢巾"
"やはり 矢張り"
"やはん 夜半"
"やばけい 耶馬渓"
"やばとん 矢場とん"
"やばん 野蛮"
"やひ 野卑"
"やひこ 弥彦"
"やひろ 八尋"
"やぶ 藪 薮"
"やぶうち 薮内"
"やぶか 薮蚊"
"やぶき 矢吹"
"やぶさか 吝か"
"やぶさめ 流鏑馬"
"やぶさわ 薮沢"
"やぶそば 薮蕎麦"
"やぶた 藪田"
"やぶにらみ 藪睨み"
"やぶはら 薮原"
"やぶへび 薮蛇"
"やぶみ 矢文"
"やぶもと 藪本 薮本"
"やぶん 夜分"
"やべ 矢部"
"やほ 屋舗"
"やほう 野砲"
"やほうず 野放図"
"やほこ 八穂子"
"やほり 矢堀"
"やぼ ヤボ 野暮"
"やぼう 野望"
"やま 岾 夜魔 耶麻 山"
"やまあい 山合"
"やまあし 山足"
"やまあるき 山歩き"
"やまい 山井 病"
"やまいこうこう 病膏肓"
"やまいち 山一證券"
"やまいちしょうけん 山一證券"
"やまいぬ 豺 犲 山犬"
"やまいも 山芋"
"やまいもあめ 山芋飴"
"やまうずら 鷓鴣"
"やまうち 山内"
"やまうら 山浦"
"やまえ 山江"
"やまお 山尾"
"やまおか 山岡"
"やまおき 山沖"
"やまおく 山奥"
"やまおとこ 山男"
"やまおり 山折り"
"やまかげ 山陰 山影"
"やまかさ 山笠"
"やまかみ 山上"
"やまかわ 山川"
"やまが 山香 山賀 山鹿"
"やまがさ 山笠"
"やまがた 山方 山型 山県 山縣 山形"
"やまがたきた 山形北"
"やまがただいこう 山形大工"
"やまがたひがし 山形東"
"やまがみ 山上"
"やまがわ 山川 山側"
"やまき 八巻 山木"
"やまきた 山北"
"やまぎし 山岸"
"やまぎわ 山際"
"やまぎん 山吟"
"やまくずれ 山崩れ"
"やまくに 山国"
"やまくら 山倉"
"やまぐち 山口"
"やまぐに 山国"
"やまぐるまか ヤマグルマ科"
"やまけい 山渓"
"やまこう 山交"
"やまこし 山古志 山腰 山越"
"やまごや 山小屋"
"やまさ 山佐"
"やまさか 山坂"
"やまさき 山崎"
"やまざき 山咲 山崎"
"やまざくら 山桜"
"やまざと 山里"
"やまし 山師"
"やました 山下"
"やましな 山科"
"やましろ 山城"
"やましろや 山代屋"
"やまじ 山地 山路"
"やますそ 山裾"
"やまずみ 山積"
"やませ 山瀬"
"やまぜん 山善"
"やまそだち 山育ち"
"やまぞい 山沿い"
"やまぞえ 山添"
"やまたい 耶馬台"
"やまたいこく 邪馬臺国 邪馬壹国 邪馬台国"
"やまたかぼう 山高帽"
"やまたけ 山武"
"やまたけはねうぇる 山武ハネウェル"
"やまたに 山谷"
"やまたねさんぎょう 山種産業"
"やまたねしょうけん 山種証券"
"やまたのおろち 八岐の大蛇 八岐大蛇 八俣之大蛇 八俣の大蛇"
"やまだ 山田"
"やまだい 山大"
"やまだいこう 山大工"
"やまだいすず 山田五十鈴"
"やまだにしき 山田錦"
"やまちく 山蓄"
"やまっけ 山っ気"
"やまつか 山塚"
"やまつり 矢祭"
"やまづみ 山積み"
"やまて 山手"
"やまてら 山寺"
"やまでら 山寺"
"やまでん 山電"
"やまと 山門 大和"
"やまとうんゆ ヤマト運輸"
"やまとぐさもく ヤマトグサ目"
"やまとじ 大和路"
"やまとじむしょ 大和事業所"
"やまとたける 日本武尊"
"やまとに 大和煮"
"やまとみ 山富"
"やまな 山名"
"やまなか 山中"
"やまなかこ 山中湖"
"やまなかごえ 山中越"
"やまなし 山梨"
"やまなみ 山並 山並み"
"やまなり 山形"
"やまにし 山西"
"やまね 山根"
"やまねこ 山猫"
"やまの 山野"
"やまのうえ 山上"
"やまのうち 山ノ内 山之内"
"やまのくち 山之口"
"やまのて 山手 山の手"
"やまのぼり 山登り"
"やまは 山葉 ヤマハ"
"やまはい 山廃"
"やまはいじこみ 山廃仕込み"
"やまはた 山畑"
"やまはだ 山肌"
"やまはら 山原"
"やまば 山場"
"やまばい 山廃"
"やまび 山日"
"やまびこ 谺 山彦"
"やまびらき 山開き"
"やまふじ 山藤"
"やまふだ 山札"
"やまぶき 山吹"
"やまぶし 山伏"
"やまぶち 山淵"
"やまべ 山辺 山部"
"やまほこじゅんこう 山鉾巡行"
"やまほど 山程"
"やまぼこ 山鉾"
"やままつ 山松"
"やままん 山万"
"やまみち 山道"
"やまむら 山村"
"やまめ 山女"
"やまもがしもく ヤマモガシ目"
"やまもと 山元 山本"
"やまもとちょう 山本丁"
"やまもとひろし 山本弘"
"やまもももく ヤマモモ目"
"やまもり 山守 山盛り 山森"
"やまや 山家 山屋 山矢"
"やまやしき 山屋敷"
"やまやま 山々"
"やまゆき 山行"
"やまよう 山用"
"やまわき 山脇"
"やまわけ 山分け"
"やまんば 山姥"
"やみ 闇"
"やみいち 闇市"
"やみうち 闇討"
"やみきょういく 闇教育"
"やみくも 闇雲"
"やみごめ 闇米"
"やみしょうばい 闇商売"
"やみつき 病み付き"
"やみなべ 闇鍋"
"やみね 闇値"
"やみもり 闇森"
"やみよ 闇夜"
"やみりょうがえ 闇両替"
"やむ 已む"
"やむちゃ 茶飲 飲茶"
"やむをえず 止むを得ず"
"やもお 鰥"
"やもと 矢本"
"やもめ 鰥夫 寡"
"やもり 夜森"
"やや 稍 漸"
"ややおも 稍重"
"やゆ 揶揄"
"やよい 弥生"
"やよいじだいごろ 弥生時代頃"
"やよいもん 弥生門"
"やら 屋良"
"やらい 矢来"
"やり 槍 矢理 鑓"
"やりかた やり方"
"やりがたけ 槍ヶ岳"
"やりがだけ 槍岳"
"やりきへい 槍騎兵"
"やりくち 遣口"
"やりしき やり式"
"やりた 鎗田"
"やりだま 槍玉 やり玉"
"やりて やり手"
"やりとり 遣り取り やり取り"
"やりみず 鑓水"
"やりよう やり様"
"やろう 野郎"
"やわ 夜話"
"やわた 八幡"
"やわたはま 八幡浜"
"やわはだ 柔肌"
"やわら 谷和原 柔"
"やんぐ ヤング"
"やんべ 山家"
"ゆ 柚 斎 逾 踰 諛 覦 蝓 臾 腴 瘉 瑜 渝 揄 兪 揃 喩 愈 愉 癒 湯 由 輸 諭 油"
"ゆーざ ユーザ"
"ゆーざーず ユーザーズ"
"ゆーみん ユーミン 松任谷由実"
"ゆあえるむ ユアエルム"
"ゆあさ 湯淺 湯浅"
"ゆあつ 油圧"
"ゆあつけい 油圧計"
"ゆい 由比 由衣 湯井 油井 遺 悠衣 由以 結 由 唯"
"ゆいいつ 惟一 唯一"
"ゆいいつち 唯一知"
"ゆいか 結花"
"ゆいが 唯我"
"ゆいごん 遺言"
"ゆいしょ 由緒"
"ゆいしん 唯心"
"ゆいしんろん 唯神論"
"ゆいのう 結納"
"ゆいのうろん 唯脳論"
"ゆいぶつ 唯物"
"ゆいめいろん 唯名論"
"ゆう 由宇 俑 木綿 黝 釉 蝣 蚰 蕕 莠 肬 疣 犹 游 攸 悒 尢 囿 侑 熊 酉 佑 尤 宥 悠 幽 柚 揖 右 涌 猷 憂 邑 湧 勇 猶 友 誘 郵 祐 遊 融 裕 由 雄 優 夕 有"
"ゆうあい 友愛"
"ゆうい 有意 有為 優位"
"ゆういぎ 有意義"
"ゆういち 優一 有一 友一 勇一 祐一 裕一 雄一"
"ゆういちろう 有一郎 裕一郎 雄一郎 勇一郎 祐一郎"
"ゆういみ 有意味"
"ゆういん 誘引 誘因"
"ゆううつ 憂鬱"
"ゆうえい 游泳 遊泳"
"ゆうえき 有益"
"ゆうえつ 勇悦 優越"
"ゆうえん 幽艶 遊園 有鉛 結縁"
"ゆうえんちけん 遊園地券"
"ゆうおう 勇徃"
"ゆうおんくかん 有音区間"
"ゆうか 有価"
"ゆうかい 幽界 融解 有界 誘拐"
"ゆうかいはん 誘拐犯"
"ゆうかいもの 誘拐物"
"ゆうかく 遊廓"
"ゆうかだん 憂歌団"
"ゆうかん 有感 有閑 勇敢 夕刊"
"ゆうが 勇牙 優雅"
"ゆうがい 有害"
"ゆうがお 夕顔"
"ゆうがく 遊学"
"ゆうがた 夕方"
"ゆうがたごろ 夕方頃"
"ゆうき 優樹 又木 誘起 祐希 優起 憂木 祐己 有基 夕樹 裕樹 有規 有紀 悠紀 勇喜 有希 幽鬼 雄規 雄基 友樹 雄希 夕希 裕木 優希 夕貴 結城 有機 勇気"
"ゆうきおん 有気音"
"ゆうきざい 有機材"
"ゆうきしつ 有機質"
"ゆうきせいおんがく 誘起性音楽"
"ゆうきたい 有機体"
"ゆうきち 有吉 勇吉"
"ゆうきゅう 有給 悠久 遊休 有休"
"ゆうきょう 遊興"
"ゆうきょうでん 遊侠伝"
"ゆうぎ 友誼 遊技 遊戯"
"ゆうぎょ 游魚 勇魚"
"ゆうぐう 優遇"
"ゆうぐれ 夕暮 夕暮れ"
"ゆうぐん 遊軍 友軍"
"ゆうけい 有形"
"ゆうけっていけい 優決定系"
"ゆうけん 有権"
"ゆうけんしゃぞう 有権者像"
"ゆうげ 夕餉"
"ゆうげき 遊撃"
"ゆうげきしゅ 遊撃手"
"ゆうげん 幽幻 有言 幽玄 祐源 有限"
"ゆうこ 侑子 由布子 有子 木綿子 悠子 夕子 由子 ゆう子 裕有子 優子 友子 祐子 裕子"
"ゆうこう 裕弘 有孔 遊興 友好 有向 有効"
"ゆうこうえだ 有向枝"
"ゆうこうきげん 有効期間"
"ゆうこうだ 有効打"
"ゆうこうちゅう 有孔虫"
"ゆうこく 幽谷 夕刻 憂国"
"ゆうごう 融合"
"ゆうごうろ 融合炉"
"ゆうごはん 夕御飯"
"ゆうさい 幽斎"
"ゆうさく 雄策 雄作 勇作 裕作 祐策 優作"
"ゆうざい 有罪"
"ゆうざん 雄山"
"ゆうざんかく 雄山閣"
"ゆうし 遊資 有史 雄姿 勇姿 勇士 勇史 有志 融資"
"ゆうしかく 有資格"
"ゆうしき 有識"
"ゆうしてっせん 有刺鉄線"
"ゆうしゃ 勇者"
"ゆうしゅう 有終 憂愁 優秀"
"ゆうしゅうきょくしょう 優秀曲賞"
"ゆうしゅつ 湧出"
"ゆうしゅん 優駿"
"ゆうしょう 湧昇 有償 優勝"
"ゆうしょうしゃ 優勝車"
"ゆうしょうせん 優勝戦"
"ゆうしょうば 優勝馬"
"ゆうしょく 有色 憂色 夕食"
"ゆうしょくしゃ 有職者"
"ゆうしょくどき 夕食時"
"ゆうしん 有心 有信"
"ゆうじ 裕史 裕慈 祐次 祐史 雄爾 雄次 裕志 祐地 祐治 有事 友二 雄司 右二 雄志 雄士 裕二 裕治 祐司 勇二 勇治 勇次 祐二 雄二 裕司"
"ゆうじゃ 雄者"
"ゆうじゅう 優柔"
"ゆうじょ 遊女"
"ゆうじょう 友情"
"ゆうじろう 悠二郎 裕次郎 雄二郎"
"ゆうじん 有人 友人"
"ゆうじんたく 友人宅"
"ゆうじんとう 有人島"
"ゆうすい 有水"
"ゆうすいち 遊水地"
"ゆうすう 有数"
"ゆうすけ 勇輔 雄輔 雄介 佳祐 祐輔 幽助 裕介 有祐 勇介 祐介"
"ゆうずい 雄蕊"
"ゆうずう 融通"
"ゆうせい 雄性 遊星 有性 優生 優牲 有生 有声 優性 優勢 郵政"
"ゆうせいがち 優勢勝ち"
"ゆうせいしょう 郵政省"
"ゆうせきせい 有責性"
"ゆうせつ 融雪"
"ゆうせつすいたいさく 融雪水対策"
"ゆうせん 郵船 有線 優先"
"ゆうせんじゅん 優先順"
"ゆうせんじゅんいつき 優先順位付"
"ゆうせんせき 優先席"
"ゆうせんわく 優先枠"
"ゆうぜい 游説 遊説 有税"
"ゆうぜん 悠然 友禅"
"ゆうそう 勇壮 郵送"
"ゆうそうさいぼう 遊走細胞"
"ゆうそうひ 郵送費"
"ゆうそく 有職"
"ゆうぞう 祐三 勇蔵 勇三 裕三 雄三"
"ゆうた 祐太 由宇太"
"ゆうたい 郵袋 幽体 融体 勇退 優待"
"ゆうたいけん 優待券"
"ゆうたいるい 有袋類"
"ゆうたろう 裕太郎"
"ゆうたんぽしゃさい 有担保社債"
"ゆうだい 雄大"
"ゆうだち 夕立ち 夕立"
"ゆうだん 勇断"
"ゆうだんしゃ 有段者"
"ゆうち 誘致"
"ゆうちゃく 融着"
"ゆうちょ 郵貯"
"ゆうちょう 悠長"
"ゆうづう 融通"
"ゆうづき 夕月 有月"
"ゆうづる 夕鶴"
"ゆうてい 夕定"
"ゆうてん 融点"
"ゆうてんじ 祐天寺"
"ゆうでん 誘電"
"ゆうでんたい 誘電体"
"ゆうと 勇人"
"ゆうとう 遊蕩 優等 雄踏"
"ゆうとうしゃ 優等車"
"ゆうど 尤度"
"ゆうどう 有働 誘導"
"ゆうどうたい 誘導体"
"ゆうどうだん 誘導弾"
"ゆうどく 有毒"
"ゆうなぎ 夕凪"
"ゆうねつき 有熱期"
"ゆうのう 有能"
"ゆうはい 有配"
"ゆうはつ 誘発"
"ゆうはもん 幽波紋"
"ゆうはん 夕飯"
"ゆうばえ 夕暎え"
"ゆうばく 誘爆"
"ゆうばり 夕張"
"ゆうぱっく ゆうパック"
"ゆうひ 雄飛 夕陽 夕日"
"ゆうひかく 有斐閣"
"ゆうひょうか 優評価"
"ゆうび 優美"
"ゆうびん 〒 郵便"
"ゆうびんうけ 郵便受け"
"ゆうびんしゃ 郵便車"
"ゆうびんばこ 郵便箱"
"ゆうびんばんごう 〒"
"ゆうふく 裕福"
"ゆうふつ 勇払"
"ゆうへい 裕平 雄平 幽閉"
"ゆうべ 夕 夕べ 昨夜"
"ゆうべつ 湧別"
"ゆうべん 雄弁"
"ゆうべんか 雄弁家"
"ゆうほう 友邦"
"ゆうほうどうしょてん 友朋堂書店"
"ゆうほどう 遊歩道"
"ゆうぼう 有望"
"ゆうぼうかぶ 有望株"
"ゆうぼうし 有望視"
"ゆうぼく 遊牧"
"ゆうぼくみん 遊牧民"
"ゆうま 遊馬"
"ゆうまぐれ 夕間暮れ"
"ゆうみ 裕美"
"ゆうみん 遊民"
"ゆうみんしゃ 遊眠社"
"ゆうむ 有無"
"ゆうめい 有名"
"ゆうめいしんがっこう 有名進学校"
"ゆうめいば 有名馬"
"ゆうめし 夕飯"
"ゆうもう 勇猛 有毛"
"ゆうもうせん 湧網線"
"ゆうもや 夕靄"
"ゆうもん 幽門"
"ゆうや 裕哉 雄也 裕弥 裕也"
"ゆうやく 釉薬 勇躍"
"ゆうやけ 夕焼 夕焼け"
"ゆうやみ 夕闇"
"ゆうゆう 悠々 悠悠"
"ゆうよ 猶余 猶予"
"ゆうよう 融溶 有用"
"ゆうよく 遊弋"
"ゆうらく 有楽"
"ゆうらん 遊覧"
"ゆうらんせん 遊覧船"
"ゆうり 遊里 悠理 遊離 有理 悠里 友里 有利"
"ゆうりすうたい 有理数体"
"ゆうりゃくてんのう 雄略天皇"
"ゆうりょ 憂慮"
"ゆうりょう 優良 有料"
"ゆうりょく 有力"
"ゆうりょくかぶ 有力株"
"ゆうりょくし 有力視"
"ゆうりょくば 有力馬"
"ゆうりん 友隣"
"ゆうりんどう 有隣堂"
"ゆうれい 幽霊"
"ゆうれいせん 幽霊船"
"ゆうれいやく 幽霊役"
"ゆうれつ 優劣"
"ゆうわ 宥和 雄和 友輪 優和 融和"
"ゆうわく 誘惑"
"ゆえ 湯江 優恵 故"
"ゆえき 輸液"
"ゆえつ 諛悦 愉悦"
"ゆえに ∴"
"ゆえん 油煙 由縁 結縁 所以"
"ゆおん 湯温 油温"
"ゆおんけい 油温計"
"ゆか 由架 夕夏 夕佳 裕香 友賀 友華 弓佳 油化 由加 由佳 由香 夕香 友香 ユカ 結花 床"
"ゆかい 愉快"
"ゆかいた 床板"
"ゆかいはん 愉快犯"
"ゆかうえ 床上"
"ゆかうんどう 床運動"
"ゆかぐみ 床組"
"ゆかげん 湯加減"
"ゆかこ 裕香子 由香子 有香子 友華子 優香子"
"ゆかした 床下"
"ゆかた 浴衣"
"ゆかたすがた 浴衣姿"
"ゆかだんぼう 床暖房"
"ゆかの 由佳乃"
"ゆかめん 床面"
"ゆかめんせき 床面積"
"ゆかり 由佳里 由佳利 友佳梨 由架梨 由加利 紫 由香利 由加里 由香里"
"ゆかわ 湯川 湯河"
"ゆが 瑜伽 憂花"
"ゆがしま 湯ケ島 湯ヶ島 湯が島"
"ゆがしゅう 瑜伽宗"
"ゆがま 湯釜"
"ゆがわ 湯川"
"ゆがわら 湯河原"
"ゆき 裕紀 由姫 由岐 油木 湯来 由季 有希 行き ユキ 裄 礼暁 由喜 油機 征 志 恭 倖 由紀 夕紀 由希 友紀 由妃 夕貴 有紀 行 由記 幸 由樹 由貴 之 雪"
"ゆきあか 雪垢"
"ゆきいり 雪入"
"ゆきえ 由紀江 幸枝 幸栄 幸恵 由起絵 由喜枝 雪絵 好恵"
"ゆきお 悠紀雄 由記雄 由紀夫 幸生 由希夫 行生 雪夫 行雄 行夫 幸雄 幸夫 幸男 由起夫"
"ゆきおとこ 雪男"
"ゆきおんな 雪女"
"ゆきか 幸香"
"ゆきかべ 雪壁"
"ゆきがっせん 雪合戦"
"ゆきき 行き来"
"ゆきくら 雪倉"
"ゆきぐに 雪国"
"ゆきけむり 雪煙"
"ゆきげしき 雪景色"
"ゆきげしょう 雪化粧"
"ゆきこ 有己子 有紀子 由季子 雪子 幸子 由希子 夕紀子 由起子 由貴子 友紀子 有希子 由紀子"
"ゆきしつ 雪質"
"ゆきじるし 雪印"
"ゆきすずめ 雪雀"
"ゆきぞう 行三"
"ゆきた 幸田"
"ゆきたか 幸貴"
"ゆきたけ 雪竹"
"ゆきたに 雪谷"
"ゆきだおれ 行き倒れ"
"ゆきだま 雪玉"
"ゆきち 諭吉"
"ゆきとし 幸俊 礼暁 幸敏"
"ゆきとみ 幸富"
"ゆきとり 雪取"
"ゆきどけ 雪解け"
"ゆきどころ 行き所"
"ゆきなり 志勢 幸成"
"ゆきの 雪野 雪乃"
"ゆきのじょう 雪之丞"
"ゆきのすけ 雪ノ助"
"ゆきのぶ 之宣"
"ゆきのり 幸徳 幸記 幸範 行徳 幸則 幸紀 行則"
"ゆきはる 幸春"
"ゆきば 行き場"
"ゆきひこ 幸彦 由記彦 由紀彦 行彦"
"ゆきひで 幸秀"
"ゆきひと 幸仁"
"ゆきひらなべ 雪平鍋"
"ゆきひろ 行弘 行宏 幸展 幸拾 幸博 幸広 幸宏 幸弘"
"ゆきふみ 幸史"
"ゆきぶそく 雪不足"
"ゆきほ 行穂"
"ゆきまさ 幸真 幸正 幸政"
"ゆきまつ 行松"
"ゆきみ 雪見"
"ゆきみち 幸道 雪路 雪道"
"ゆきみつ 幸光"
"ゆきむし 雪虫"
"ゆきむら 幸村"
"ゆきもと 雪本"
"ゆきや 幸也"
"ゆきやま 雪山"
"ゆきよ 雪代 幸代"
"ゆきよし 幸喜 幸義"
"ゆきれっしゃ 雪列車"
"ゆぎ 柚木 由木"
"ゆぎょう 遊行"
"ゆぎん 輸銀"
"ゆくえ 行く方 行方"
"ゆくさき 行先 行く先"
"ゆくすえ 行く末"
"ゆくはし 行橋"
"ゆくへ 行方"
"ゆけつ 輸血"
"ゆけむり 湯煙"
"ゆけん 油研"
"ゆげ 弓削 湯気"
"ゆげい 靫負"
"ゆげた 弓削田"
"ゆこく 諭告"
"ゆごう 癒合"
"ゆさ 遊佐"
"ゆさい 油彩"
"ゆさぼう 遊佐坊"
"ゆざめ 湯ざめ"
"ゆざわ 湯澤 湯沢"
"ゆし 諭旨 油脂"
"ゆしま 油島 湯島"
"ゆしゅつ 輸出"
"ゆしゅつしゃ 輸出車"
"ゆしゅつぜい 輸出税"
"ゆしゅつにゅう 輸出入"
"ゆすはら 梼原"
"ゆすら 桜桃"
"ゆず 梼 柚子 柚"
"ゆずき 柚木 柚月"
"ゆずこ 柚子"
"ゆずりうけにん 譲受人"
"ゆずりわたしにん 譲渡人"
"ゆずる 讓 穰 穣 譲"
"ゆせ 湯瀬"
"ゆせい 油井 油性"
"ゆせいかん 輸精管"
"ゆそう 湯槽 輸送"
"ゆそうかん 輸送管"
"ゆそうしゃ 輸送車"
"ゆそうせん 輸送船"
"ゆそうひ 輸送費"
"ゆそうろ 輸送路"
"ゆそつ 輸卒"
"ゆたか 穰 豐 優 泰 豊か 豊 裕"
"ゆたかさ 豊かさ"
"ゆたかしょうゆ 豊醤油"
"ゆたに 湯谷 由谷"
"ゆたんぽ 湯湯婆"
"ゆだ 湯田"
"ゆだなか 湯田中"
"ゆだや 猶太"
"ゆだん 油断"
"ゆちゃく 癒着"
"ゆづかみ 湯津上"
"ゆづき 弓月 由月"
"ゆてき 油滴"
"ゆてん 油点"
"ゆでたまご 茹で卵"
"ゆでん 油田"
"ゆとう 湯桶"
"ゆどうふ 湯豆腐"
"ゆに 由仁"
"ゆにっと ユニット"
"ゆにばーさる ユニバーサル"
"ゆにばーす ユニバース"
"ゆにふぉーむ ユニフォーム"
"ゆにもーる ユニモール"
"ゆにゅう 輸入"
"ゆにゅうざい 輸入材"
"ゆにゅうしゃ 輸入車"
"ゆにゅうぜい 輸入税"
"ゆにゅうば 輸入馬"
"ゆにゅうばんめあて 輸入盤目当"
"ゆにゅうまい 輸入米"
"ゆのかわ 湯野川"
"ゆのき 柚木"
"ゆのたに 湯之谷"
"ゆのつ 温泉津"
"ゆのはま 湯野浜"
"ゆのまえ 湯前"
"ゆのみ 湯飲み"
"ゆはら 湯原"
"ゆば 弓場 湯葉"
"ゆばら 湯原"
"ゆび 趾 指"
"ゆびいっぽん 指一本"
"ゆびおり 指折り"
"ゆびさき 指先"
"ゆびさしかくにん 指差確認"
"ゆびづかい 指使い"
"ゆびばん 指板"
"ゆびもじ 指文字"
"ゆびわ 指環 指輪"
"ゆふ 由府"
"ゆふいん 由布院 湯布院"
"ゆふこうげん 由布高原"
"ゆふね 湯舟"
"ゆふばえ 夕暎え"
"ゆぶね 湯舟 湯船 湯ぶね"
"ゆま 由真"
"ゆまく 油膜"
"ゆみ 有望 祐美 裕美 宙美 優美 由実 祐未 有美 友美 由美 弓"
"ゆみえ 由美恵 弓技"
"ゆみおか 弓岡"
"ゆみか 由美香"
"ゆみがはま 弓ヶ浜"
"ゆみこ 祐美子 祐三子 有美子 優美子 佑三子 裕美子 由美子 弓子"
"ゆみず 湯水"
"ゆみなか 弓仲"
"ゆみなが 弓長"
"ゆみの 弓野"
"ゆみへい 弓兵"
"ゆみや 弓矢"
"ゆむら 湯村"
"ゆめ 結女 梦 夢"
"ゆめいろ 夢色"
"ゆめかかく 夢価格"
"ゆめきこう 夢紀行"
"ゆめきぶん 夢気分"
"ゆめこ 夢子"
"ゆめこうぼう 夢工房"
"ゆめごこち 夢心地"
"ゆめさき 夢前"
"ゆめじ 夢路 夢二"
"ゆめぞの 夢園"
"ゆめでんせつ 夢伝説"
"ゆめと 夢人"
"ゆめどの 夢殿"
"ゆめの 夢野"
"ゆめのしま 夢の島"
"ゆめはんだん 夢判断"
"ゆめぼうけん 夢冒険"
"ゆめまくら 夢枕"
"ゆめみ 夢見"
"ゆめものがたり 夢物語"
"ゆめよ 夢代"
"ゆもと 湯元 湯本"
"ゆや 油谷"
"ゆやま 湯山"
"ゆゆ 結由"
"ゆゆしき 由々しき"
"ゆら 由良"
"ゆらい 由来"
"ゆらがわてっきょう 由良川鉄橋"
"ゆらのすけ 由良之助"
"ゆり 祐理 由理 憂里 祐里 有里 友理 友梨 友利 閖 岼 由利 由里 ユリ 百合 由梨"
"ゆりあげ 閖上"
"ゆりあげこう 閖上港"
"ゆりあにあもく ユリアニア目"
"ゆりえ 由梨絵 百合枝 友里恵"
"ゆりか 優里香"
"ゆりこ 祐理子 由利子 ゆり子 由里子 百合子"
"ゆりこう ユリ綱"
"ゆりのちょう 百合野町"
"ゆりみ 有里巳"
"ゆりょう 湯量"
"ゆる 閖"
"ゆるすまじ 許すまじ"
"ゆれ 揺れ"
"ゆわかし 湯沸し"
"ゆわかしき 湯沸器 湯沸かし器 湯沸かし機"
"ゆわり 湯割り"
"ゆゑ 故"
"ゆゑん 所以"
"ゆんで 左手"
"ゆんも 潤模"
"よ 餘 飫 譽 蕷 與 舁 畭 歟 丗 弥 豫 四 輿 誉 預 余 代 夜 与 予 世"
"よーぐると ヨーグルト"
"よーろっぱ 歐羅巴 欧羅巴 ヨーロッパ"
"よあけ 夜明け"
"よあつ 予圧"
"よい 酔 酔い 宵 良い"
"よいごし 宵越し"
"よいた 与板"
"よいち 余市"
"よいど 余緯度"
"よいまち 宵待"
"よいまちぐさ 宵待草"
"よいむ 酔夢"
"よいやま 宵山"
"よいやみ 宵闇"
"よいん 餘韻 餘音 余音 余韻"
"よいんしぎょうれつ 余因子行列"
"よう 腰 厭 怏 泱 陶 瑤 遙 鎔 邀 踴 謠 蛹 膺 窰 窈 穃 癰 癢 痒 珱 瓔 瑶 燿 煬 瀁 漾 殀 樣 榕 曄 暘 昜 杳 搖 拗 慵 慂 恙 徭 廱 幺 孕 姚 夭 壅 俑 佯 瘍 甬 傭 妖 揺 幼 雍 熔 窯 庸 擁 羊 耀 楊 揚 踊 容 溶 遥 蓉 謡 曜 養 葉 洋 様 陽 要 用"
"ようあん 溶暗"
"ようい 容易 用意"
"よういく 養育"
"よういくひ 養育費"
"よういち 要一 暢一 洋一 陽一"
"よういちろう 洋一郎 陽一郎"
"よういん 要員 要因"
"ようえき 葉腋 溶液"
"ようえん 揺炎 葉縁 妖艶 陽炎"
"ようおん 拗音"
"ようか 八鹿 蛹化 ８日 八日"
"ようかい 鎔解 容喙 溶解 妖怪"
"ようかいえき 溶解液"
"ようかん ヨウカン 羊羮 羊羹 洋館"
"ようかんすう 陽関数"
"ようが 幼芽 洋画 用賀"
"ようがい 要害"
"ようがく 洋学 洋楽"
"ようがさ 洋傘"
"ようがし 洋菓子"
"ようがん 熔岩 溶岩"
"ようき 妖鬼 妖気 陽気 容器"
"ようきひ 楊貴妃"
"ようきゅう 要求"
"ようきゅうがく 要求額"
"ようきょく 謡曲 陽極"
"ようきん 溶菌"
"ようぎ 八尾木 容疑"
"ようぎょ 幼魚 養魚"
"ようぎょう 窯業"
"ようぐ 用具"
"ようけい 幼形 養鶏"
"ようけつ 溶血"
"ようけん 要件 用件"
"ようけんどう 養賢堂"
"ようげき 邀撃"
"ようげん 揚言 用言"
"ようげんか 溶原化"
"ようこ 妖子 揚子 瑤子 暢子 耀子 楊子 庸子 よう子 容子 洋子 葉子 陽子"
"ようこう 用高 要綱 陽光 洋行 要項"
"ようこうぐてん 洋工具店"
"ようこうだい 洋光台"
"ようこうろ 鎔鉱炉 鎔鉱爐 溶鉱炉"
"ようこん 幼根"
"ようご 養護 擁護 用語"
"ようさい 洋才 洋裁 要塞"
"ようさいあと 要塞跡"
"ようざい 用材 溶剤"
"ようざっし 洋雑誌"
"ようざら 洋皿"
"ようざん 要斬 腰斬"
"ようし 洋紙 陽子 養子 要旨 容姿 用紙"
"ようしき 洋式 様式"
"ようしきび 様式美"
"ようしつ 洋室"
"ようしば 洋芝"
"ようしゃ 容赦"
"ようしゅ 洋酒"
"ようしゅん 陽春"
"ようしょ 要所 洋書"
"ようしょう 葉鞘 要衝 幼少"
"ようしょく 容色 要職 洋食 養殖"
"ようしょくうお 養殖魚"
"ようしょくぎょ 養殖魚"
"ようしょくもの 養殖物"
"ようしょてんかかく 洋書店価格"
"ようしろう 陽志郎"
"ようしん 葉身"
"ようじ 陽治 耀司 陽二 用字 洋治 曜示 庸治 楊枝 陽次 洋次 庸次 幼時 康次 洋二 洋司 幼児 用事"
"ようじゃく 幼若"
"ようじゅう 妖獣"
"ようじゅつ 妖術"
"ようじょ 葉序 妖女 養女 幼女"
"ようじょう 洋上 養生"
"ようじろう 洋次郎 陽治郎"
"ようじん 要人 用心"
"ようじんぼう 用心棒"
"ようす 様子"
"ようすい 揚水 用水 羊水 陽水"
"ようすけ 葉介 陽介 庸介 洋助 洋祐 洋輔 洋介"
"ようすこう 揚子江"
"ようすみ 様子見"
"ようせい 葉性 幼生 夭逝 陽性 養成 妖精 要請"
"ようせいじょ 養成所"
"ようせき 容積"
"ようせつ 殀折 熔接 夭折 溶接"
"ようせん 用船 用箋"
"ようぜん 陶然"
"ようそ 要素"
"ようそう 洋装 様相"
"ようぞう 陽三 容三 洋三"
"ようぞん 溶存"
"ようた 洋太"
"ようたい 容態 様態 容体"
"ようたつ 用達"
"ようたろう 洋太郎"
"ようだい 煬帝 容態 容体"
"ようだん 要談 用談"
"ようち 要地 夜討 用地 幼稚"
"ようちゅう 鎔鑄 幼虫"
"ようちょう 膺懲"
"ようつい 腰椎"
"ようつう 腰痛"
"ようてい 羊蹄 要諦"
"ようていざん 羊蹄山 羊帝山"
"ようてん 陽転 要点"
"ようでんし 陽電子"
"ようと 用途"
"ようとう 洋燈"
"ようとうくにく 羊頭狗肉"
"ようとん 養豚"
"ようど 用度"
"ようどう 陽動 揺動"
"ようどがかり 用度掛"
"ように 様に 陽に"
"ようにく 葉肉"
"ようにん 容認"
"ようねん 幼年"
"ようねんへい 幼年兵"
"ようのすけ 洋之介 陽之助"
"ようはい 遥拝"
"ようばい 溶媒"
"ようばん 洋盤"
"ようひ 要否"
"ようひん 洋品 用品"
"ようび 曜日"
"ようびごと 曜日毎"
"ようふ 養父"
"ようふう 洋風"
"ようふく 洋服"
"ようふぼ 養父母"
"ようぶ 洋舞"
"ようぶん 養分 幼文"
"ようへい 葉柄 傭兵 用兵 洋平"
"ようへん 窯変"
"ようほう 用法"
"ようぼう 容貌 要望"
"ようぼく 幼木"
"ようま 妖魔 洋間"
"ようまく 羊膜"
"ようまつ 洋松"
"ようみゃく 葉脈"
"ようみょう 幼名"
"ようむ 要務 妖霧 遥夢 用務"
"ようむき 用向き"
"ようめい 用命 養命"
"ようめいしゅ 養命酒"
"ようめん 容面"
"ようもう 羊毛"
"ようもく 要目"
"ようもの 洋物"
"ようやく 要約"
"ようゆう 熔融 溶融"
"ようよう 幼葉 妖々 要用 様々"
"ようようたい 幼葉態"
"ようらん 揺籃 要覧"
"ようりく 揚陸"
"ようりつ 擁立"
"ようりゃく 要略"
"ようりょう 用量 要領 容量"
"ようりょく 揚力 妖力"
"ようりょくそ 葉緑素"
"ようりょくたい 葉緑体"
"ようれい 用例"
"ようれき 陽暦"
"ようれつ 庸劣"
"ようろう 養老"
"ようろうのたき 養老の滝"
"ようろく 要録"
"ようろん 要論"
"よえつ 与悦"
"よか 餘暇 予価 予科 余暇"
"よかく 与格 余核"
"よかれ 善かれ"
"よかれん 予科練"
"よかわ 吉川"
"よかん 豫感 余寒 予感"
"よき 豫期 予期"
"よきょう 餘興 余興"
"よきょくいり 余曲入"
"よきん 預金"
"よきんがく 預金額"
"よぎ 余技 余儀"
"よぎしゃ 夜汽車"
"よぎた 与北"
"よぎり 夜霧"
"よく 翊 緘 杙 弋 峪 良く 慾 沃 抑 浴 欲 翌 翼"
"よくあさ 翌朝"
"よくあつ 抑圧"
"よくうかん 余空間"
"よくか 翼果"
"よくがた 翼型"
"よくき 翌期"
"よくけい 翼形"
"よくげつ 翌月"
"よくげつばらい 翌月払い"
"よくし 抑止"
"よくしつ 浴室"
"よくしゅう 翌秋 翌週"
"よくしゅん 翌春"
"よくしん 慾心"
"よくじつ 翌日"
"よくじょう 慾情 翼状 欲情 浴場"
"よくせい 抑制"
"よくせいぶっし 抑制物質"
"よくそう 浴槽"
"よくそくじ 抑速時"
"よくたん 翼端"
"よくちょう 翼長 翌朝"
"よくとく 欲得"
"よくとし 翌年"
"よくねん 翌年"
"よくばり 欲張 欲張り"
"よくぼう 慾望 欲望"
"よくめ 欲目"
"よくめん 翼面"
"よくめんせき 翼面積"
"よくや 沃野"
"よくよう 浴用 抑揚"
"よくよく 翌々"
"よくよくじつ 翌々日"
"よくりゅう 翼竜 翼龍 抑留"
"よくれつ 翼列"
"よぐち 与口"
"よけい 餘計 余計"
"よけん 豫見 与件 予見"
"よげつ 余月"
"よげん 豫言 預言 余弦 予言"
"よげんは 余弦波"
"よこ ━ ─ 横"
"よこあな 横穴"
"よこい 横井"
"よこいた 横板"
"よこいち 横位置"
"よこいちれつ 横一列"
"よこいっせん 横一線"
"よこいっちょくせん 横一直線"
"よこいと 横糸"
"よこいどう 横移動"
"よこう 予稿 予行"
"よこうち 横内"
"よこお 横尾"
"よこおき 横置"
"よこかいてん 横回転"
"よこかぜ 横風"
"よこかべ 横壁"
"よこかわ 横川 横河"
"よこがお 横顔"
"よこがき 横書き 横書"
"よこがた 横型"
"よこがめん 横画面"
"よこがわ 横川 横河"
"よこぎ 横木"
"よこく 豫告 予告"
"よこくとう 予告灯"
"よこくへん 予告篇"
"よこくら 横倉"
"よこぐみ 横組"
"よこぐるま 横車"
"よこけい 横罫"
"よこげり 横蹴り"
"よここうず 横構図"
"よここくだい 横国大"
"よこごし 横越"
"よこさと 横里"
"よこざひょう 横座標"
"よこざま 横樣 横方"
"よこざわ 横沢"
"よこしば 横芝"
"よこしま 邪ま 奸 辟 邪 横島"
"よこじく 横軸"
"よこじま 横縞"
"よこすか 横須賀"
"よこすかしたけ 横須賀市武"
"よこすじ 横筋"
"よこせ 横瀬"
"よこせん 横線"
"よこた 横田"
"よこたに 横谷"
"よこだおし 横倒し"
"よこちょう 横町 横丁"
"よこっつら 横っ面"
"よこつか 横塚"
"よこづけ 横付け"
"よこづな 横綱"
"よこづなずもう 横綱相撲"
"よこづみ 横積"
"よこて 横手"
"よこてさん 横手山"
"よこどり 横取り"
"よこなが 横長"
"よこながし 横流し"
"よこなみ 横波 横並"
"よこの 横野"
"よこはね 横羽"
"よこはば 横巾 横幅"
"よこはま 横濱 横浜"
"よこはまありーな 横浜アリーナ"
"よこはまがた 横浜方"
"よこはまこう 横浜港 横浜高"
"よこはましさかえく 横浜市栄区"
"よこはません 横浜戦"
"よこはまはく 横浜博"
"よこばい 横這い 横ばい"
"よこばいかく 横倍角"
"よこばしり 横走り"
"よこばら 横腹"
"よこひょうじ 横表示"
"よこひら 横平"
"よこぶんれつ 横分裂"
"よこほうこう 横方向"
"よこほり 横堀"
"よこぼう 横棒"
"よこぼり 横堀"
"よこまる 横丸"
"よこみぞ 横溝"
"よこみち 横道"
"よこみねでら 横峰寺"
"よこむき 横向"
"よこめ 横目"
"よこもじ 横文字"
"よこもり 横森"
"よこや 横矢 横谷"
"よこやま 横山"
"よこやり 横やり 横槍"
"よこよこ 横横"
"よこれんぼ 横恋慕"
"よこわけ 横分"
"よこわり 横割り"
"よご 余呉 豫後 予後"
"よごと 夜毎"
"よごれ 汚れ"
"よごれやく 汚役"
"よさ 与謝"
"よさく 与作"
"よさぶろう 与三郎"
"よさむ 夜寒"
"よさん 豫算 予讃 予算"
"よさんあん 予算案"
"よさんはん 予算班"
"よさんわく 予算枠"
"よざい 餘罪 余罪"
"よざくら 夜桜"
"よし ヨシ 禧 葭 譱 禎 祥 純 淑 宜 克 美 慶 圭 喜 佳 葦 善 膳 好 芳 良 嘉 義 由 吉"
"よしあき 嘉晃 克明 良秋 善昭 義朗 善章 吉晃 義晃 宜明 嘉昭 吉昭 良晃 嘉明 由明 義亮 良明 良昭 芳明 美明 吉明 義明 義昭 義章 嘉章 喜明"
"よしあし 善悪 善し悪し"
"よしい 芳井 吉井"
"よしいけ 吉池"
"よしいち 義一"
"よしうみ 吉海"
"よしうら 吉浦"
"よしえ 佳恵 良枝 吉江 ヨシエ 好江 芳恵 好恵"
"よしお 佳男 禧雄 昌男 好央 温雄 美夫 善男 新生 淑生 宗生 吉生 嘉夫 佳郎 誉志雄 善夫 好生 嘉雄 佳雄 良夫 良男 由夫 芳雄 芳夫 芳男 善雄 好雄 好夫 好男 吉雄 吉夫 吉男 義雄 義夫 義男 嘉男 良雄"
"よしおか 吉岡"
"よしおみ 善臣 佳臣"
"よしか 佳香"
"よしかず 英一 能収 慶一 芳一 美一 善和 佳一 佳和 好一 良和 由和 義一 義和 善一 喜一"
"よしかつ 良勝 隆克 好克 義勝"
"よしかわ 好川 吉川"
"よしき 美樹 芳季 好輝 喜紀 嘉樹 良樹 由樹 善樹 吉輝 慶樹 芳希 吉喜 義樹 芳樹 与式 吉敷 吉城 佳樹"
"よしきゅう 与死球"
"よしきよ 義清"
"よしくに 吉国 喜国"
"よしこ 嘉子 ヨシ子 よし子 淑子 芳子 賀子 美子 好子 由子 良子 佳子"
"よしこし 吉越"
"よしさだ 義貞 悦貞"
"よしさと 義聡"
"よしざき 吉崎"
"よしざわ 義澤 吉澤 吉沢"
"よしじ 良至 良治"
"よしじま 吉島"
"よしすけ 義介"
"よしずみ 吉住"
"よしぞう 芳三"
"よしたか 禎孝 孝高 良隆 善隆 善孝 吉高 芳孝 嘉隆 義隆 義孝 佳孝"
"よしたけ 義丈 吉武 義竹 美武 吉竹"
"よしたに 吉谷"
"よしたろう 由太郎 芳太郎"
"よしだ 慶田 吉田"
"よしだしげる 吉田茂"
"よしつ 好津"
"よしつぐ 善次 佳次 善嗣"
"よしつね 義経"
"よしつねぞう 義経像"
"よしづか 吉塚"
"よしてる 芳輝 喜照"
"よしと 圭人 芳人 義人"
"よしとお 義遠"
"よしとし 吉年"
"よしとせん 吉都線"
"よしとみ 善富 吉富"
"よしとも 義朋 義智 佳友 義恭 良知"
"よしどめ 吉留"
"よしなお 義直 喜直"
"よしなか 吉仲 義仲"
"よしなが 吉永"
"よしなり 善成 良成 義成 能成 義也 吉成 芳成 祐生"
"よしの 芳野 吉乃 淑乃 美乃 吉野"
"よしのだに 吉野谷"
"よしのぶ 栄伸 嘉伸 芳信 慶喜 義信"
"よしのや 吉野家"
"よしのり 嘉哲 良憲 吉典 佳則 良法 良教 芳規 義範 義昇 善徳 善典 好則 嘉典 佳典 善則 吉則 由典 良典 芳範 吉徳 彬伯 美徳 美則 義徳 芳則 善範 義典 義則 嘉則 良紀 良則"
"よしは 吉葉"
"よしはま 吉浜"
"よしはら 吉原"
"よしはる 喜治 佳春 喜晴 吉春 芳晴 義春 義晴 義治 善治"
"よしば 吉羽 吉場"
"よしひこ 善彦 慶彦 義比古 喜彦 良彦 芳彦 吉彦 義彦"
"よしひさ 芳久 嘉久 良久 善久 純央 慶久 由久 義久"
"よしひで 慶英"
"よしひと 芳仁 由人 善一 芳人 圭仁"
"よしひろ 良博 至寛 由泰 喜弘 善博 吉廣 義裕 義広 義宏 嘉浩 良祐 良広 好広 吉広 嘉伯 嘉宏 佳泰 佳寛 佳浩 義博 良浩 嘉弘 善弘 吉弘 美博 義弘 義浩 吉宏 喜博"
"よしふみ 好文 祥史 佳文 仁史 義文 良文 善文"
"よしほ 美穂"
"よしま 吉間"
"よしまさ 義正 良昌 好正 喜昌 義雅"
"よしまつ 吉松 由松"
"よしみ 由美 ヨシミ 由光 誼 義巳 嘉美 善美 良美 義美 芳美 好美 昌美 吉見"
"よしみず 吉水"
"よしみち 由道"
"よしみつ 芳充 喜光 善光 嘉光 義光"
"よしむね 義統"
"よしむら 義村 吉村"
"よしもと 芳本 吉本"
"よしもとしんきげき 吉本新喜劇"
"よしもり 吉森"
"よしや 善哉 吉屋 義哉"
"よしやす 好康 嘉康"
"よしやま 吉山"
"よしゅ 余種"
"よしゅう 豫習 予習"
"よしゆき 善之 由行 吉行 佳行 嘉之 嘉雪 嘉志 佳之 善幸 好幸 義幸 良之 義之 義行 良幸 誉志幸 芳行"
"よしろう 善郎 嘉朗 喜朗 与四郎 芳郎 義郎"
"よしわ 吉和"
"よしわら 吉原"
"よしん 餘震 余震"
"よじ 四時 四次"
"よじげん 四次元"
"よじみゃく 四次脈"
"よじょう 餘剩 餘情 余情 余剰"
"よじょうしゃ 余剰車"
"よじょうはん 四畳半"
"よじん 余人 餘人 余燼"
"よすて 世捨"
"よすみ 四隅"
"よずめ 余詰"
"よせ 寄席 寄せ"
"よせい 餘生 餘勢 余勢 余生"
"よせがき 寄書き"
"よせき 余積"
"よせつ 余接"
"よせなべ 寄せ鍋"
"よせもと 寄元"
"よせん 豫選 予餞 予選 予戦"
"よせんおち 予選落"
"よせんけん 予選券"
"よせんごと 予選毎"
"よぜみ 代ゼミ"
"よそ 餘所 余所 他所"
"よそう 豫想 予想"
"よそうや 予想家"
"よそおい 装い 装"
"よそく 豫測 予測"
"よそくがい 予期外"
"よそみ よそ見"
"よそもの 他所者"
"よぞら 夜空"
"よた 世太 与太"
"よたい 預貸"
"よたか 夜鷹"
"よたく 預託"
"よたばなし 与太話"
"よたろう 与太郎 四太郎"
"よだ 誉田 与田 余田 依田"
"よだいすう 余代数"
"よだつ 予奪 与奪"
"よだれ 涎"
"よだん 豫斷 餘談 四段 予断 余談"
"よち 予地 豫知 余値 予知 余地"
"よちむ 予知夢"
"よちょう 余丁 予兆"
"よちょきん 預貯金"
"よっか 四日 ４日"
"よっきゅう 欲求"
"よっつ 四つ"
"よって 依って ∴"
"よっぱらい 酔っぱらい"
"よつ 四"
"よつあし 四足"
"よついけ 四ツ池"
"よつかいどう 四街道"
"よつかど 四つ角"
"よつぎ 世嗣ぎ 世嗣 世継"
"よつぎり 四切"
"よつくら 四倉"
"よつば 四葉"
"よつや 四ツ谷 四谷"
"よつやなぎ 四柳"
"よつやま 四つ山"
"よつゆ 夜露"
"よづめ 余詰"
"よづり 夜釣り"
"よてい 豫定 予定"
"よていあん 予定案"
"よていこう 予定稿"
"よてき 余滴"
"よとう 与党"
"よとぎ 夜伽"
"よとく 余得"
"よとだ 豊田"
"よど 淀"
"よどえ 淀江"
"よどおし 夜通し"
"よどがわ 淀川"
"よどしゃこ 淀車庫"
"よどせん 予土線"
"よどはつじゅんきゅう 淀発準急"
"よどばやし 淀屋橋"
"よどみ 澱"
"よどみばし 澱橋"
"よどやばし 淀屋橋"
"よないやま 米内山"
"よなか 夜中"
"よなが 夜長"
"よなき 夜泣き"
"よなくに 与那国"
"よなくにとう 与那国島"
"よなぐすく 与那城"
"よなぐに 与那国"
"よなぐにじま 与那国島"
"よなご 米子"
"よなばる 与那原"
"よにげ 夜逃げ"
"よにゅう 預入"
"よにん 四人"
"よにんしゅう 四人衆"
"よね 米"
"よねい 米井"
"よねいちまる 米一丸"
"よねお 米雄"
"よねきち 米吉"
"よねくら 米倉"
"よねこ 米子"
"よねさかせん 米坂線"
"よねざき 米崎"
"よねざわ 米沢 米澤"
"よねしま 米嶋"
"よねしろがわ 米代川"
"よねじま 米嶋"
"よねだ 米田"
"よねつ 予熱 余熱"
"よねづ 米津"
"よねなが 米長"
"よねはら 米原"
"よねはる 米春"
"よねばやし 米林"
"よねみつ 米光"
"よねむら 米村"
"よねもと 米本"
"よねもり 米森"
"よねやま 米山"
"よねん 餘念 余念 ４年 四年"
"よの 与野"
"よのう 予納"
"よのうづ 米水津"
"よのじ よノ字"
"よのなか 世の中"
"よは 餘波 余波"
"よはく 餘白 余白"
"よばい 夜這い"
"よばんちょう 四番丁"
"よび 餘 豫備 呼び 予備"
"よびえき 予備役"
"よびかけ 呼掛 呼掛け"
"よびぐん 予備軍"
"よびけい 呼び径"
"よびけん 予備検"
"よびこせん 呼子線"
"よびごえ 呼び声"
"よびしゃ 予備車"
"よびしん 予備審"
"よびすて 呼びすて"
"よびせん 予備選"
"よびだし 呼出し 呼出 呼び出し"
"よびな 呼び名 呼名"
"よびね 呼び値"
"よびひ 予備費"
"よびみず 呼び水"
"よびもどし 呼び戻し"
"よびもの 呼び物"
"よびりん 呼び鈴"
"よふかし 夜更かし 夜更し"
"よふけ 夜更 夜更け"
"よぶん 餘分 余聞 余分"
"よへい 与平"
"よほう 豫報 余方 予報"
"よほうし 予報士"
"よほど 余程"
"よぼう 豫防 與望 予防"
"よぼうきん 予防菌"
"よみ 黄泉 読み"
"よみあわせ 読み合わせ"
"よみうり 讀売 読売"
"よみうりせん 読売戦"
"よみうりびいき 読売贔屓"
"よみうりらんど 読売ランド"
"よみきり 読切り"
"よみこみ 読込"
"よみじ 黄泉路"
"よみせ 夜店"
"よみたに 読谷"
"よみだし 読み出し"
"よみち 夜道"
"よみて 読み手"
"よみのくに 黄泉の国 黄泉国"
"よみびとしらず 詠人不知"
"よみもの 読み物 読物"
"よみょう 余命"
"よむ 読む"
"よめ 読め 夜目 嫁"
"よめい 餘命 余命"
"よめいり 嫁入 嫁入り"
"よめえらび 嫁選び"
"よめさん 嫁さん"
"よめしゅうとめ 嫁姑"
"よめとり 嫁取り"
"よも 四方"
"よもぎ 艾 蒿 蓬"
"よもぎた 蓬田"
"よもぎだ 蓮田 蓬田"
"よもすがら 終夜"
"よもつしこめ 黄泉津醜女"
"よもやまばなし 四方山話"
"よやく 豫約 予約"
"よやくきゃく 予約客"
"よやくじゅん 予約順"
"よやくせき 予約席"
"よやくひ 予約費"
"よやくよう 予約要"
"よやす 世安"
"よやとう 与野党"
"よゆう 餘裕 余裕"
"よよぎ 代々木"
"より 依 縒 頼 寄 依里 和"
"よりあい 寄り合い"
"よりあき 頼明 頼晶 頼芸"
"よりい 寄居"
"よりいと 縒り糸"
"よりお 頼男"
"よりきり 寄り切り"
"よりこ 夜梨子 依子 頼子"
"よりしま 寄島"
"よりしろ 憑代 依代"
"よりたおし 寄り倒し"
"よりちか 頼近"
"よりとも 頼朝"
"よりどころ 拠 據 より所 拠り所 拠所"
"よりのぶ 頼信"
"よりまし 憑巫"
"よりみち 寄り道"
"よりょく 餘力 余力"
"よる 倚 依 憑る 夜"
"よるがた 夜型"
"よるごはん 夜御飯"
"よるちゃく 夜着"
"よるよう 夜用"
"よれい 余齢 予鈴"
"よろい 鎧"
"よろいざわ 鎧沢"
"よろいせんし 鎧戦士"
"よろいむしゃ 鎧武者"
"よろく 余禄 余録"
"よろこび 憙 慶び 悦び 喜び"
"よろしく 宣しく"
"よろず 萬 万"
"よろずちょうほう 万朝報"
"よろずやきんのすけ 萬屋錦之介"
"よろん 与論 余論 餘論 與論 世論"
"よわい 齡 齢 弱い"
"よわき 弱気"
"よわごし 弱腰"
"よわたり 世渡り"
"よわね 弱音"
"よわび 弱火"
"よわふくみ 弱含み"
"よわみ 弱味"
"よわむし 弱虫"
"よわめ 弱目"
"よわよわ 弱々"
"よわよわしい 弱々しい"
"よん ４ 四"
"よんい 四位"
"よんかい 四階"
"よんかいせい 四回生"
"よんかいめ 四回目"
"よんかんおう 四冠王"
"よんがっか 四学科"
"よんき 四紀"
"よんきゅう 四級 四球"
"よんきょうか 四教科"
"よんぎょう 四行"
"よんく 四駆"
"よんけたほう 四桁法"
"よんけん 四研 ４研"
"よんげんすう 四元数"
"よんげんそせつ 四元素説"
"よんごう 四合"
"よんごうびん 四合瓶"
"よんさいば 四歳馬"
"よんしまい 四姉妹"
"よんしゃたくいつ 四者択一"
"よんしゅうかん 四週間"
"よんしゅる 四種類"
"よんしょう 四章"
"よんしょうめ 四勝目"
"よんしょく 四色"
"よんじゅう 四十 四重"
"よんじゅうそうばん 四重奏番"
"よんじゅうだいぜんはん 四十代前半"
"よんせい 四声"
"よんせんねん 四千年"
"よんだい 四大 四台"
"よんちゃく 四着"
"よんとうこく 四等国"
"よんど 四度"
"よんなん 四男"
"よんねん 四年"
"よんぱく 四白"
"よんひき 四匹"
"よんぶ 四部"
"よんぶん 四分"
"よんぶんかつ 四分割"
"よんほん 四本"
"よんまい 四枚"
"よんめい ４名"
"よんめん 四面"
"よんもく 四目"
"よんりん 四輪"
"よんりんくどうしゃ 四輪駆動車"
"よんりんしゃ 四輪車"
"よんろくばん 四六版"
"ら 騾 邏 蘿 們 鑼 良 螺 等 羅 裸"
"らーめん 拉麺 ラーメン"
"らい 醴 賚 耒 罍 籟 磊 癩 櫑 擂 徠 儡 來 莢 蕾 莱 頼 雷 来"
"らいいん 来院"
"らいう 雷雨"
"らいうん 雷雲"
"らいえん 来演"
"らいおん ライオン"
"らいか 来夏"
"らいかい 来会"
"らいかん 来館"
"らいが 雷牙 来駕"
"らいがく 来学"
"らいき 来季 来期"
"らいきゃく 来客"
"らいぎょ 雷魚"
"らいげき 雷撃"
"らいげつ 来月"
"らいこう 雷光 来冦 来光 来校 来航"
"らいさん 礼讃 礼賛"
"らいしつ 来室"
"らいしゃ 来社"
"らいしゅう 来襲 来秋 来週"
"らいしゅうあたま 来週頭"
"らいしゅん 来春"
"らいしょ 来所"
"らいしん 来診 来信"
"らいじょう 来状 来場"
"らいじん 雷神"
"らいじんおう 雷神王"
"らいす ライス"
"らいせ 来世"
"らいせん 来仙"
"らいせんす ライセンス"
"らいぞう 頼三"
"らいた 雷太 ライタ"
"らいたー ライター"
"らいたく 来宅"
"らいだん 来談"
"らいちょう 雷鳥 来聴"
"らいちょうさわ 雷鳥沢"
"らいちょうざわしゅうへん 雷鳥沢周辺"
"らいちょうざわほうめん 雷鳥沢方面"
"らいてい 雷帝"
"らいてん 来店"
"らいでん 来電 雷電"
"らいでんためえもん 雷電為衛門"
"らいと ライト"
"らいどう 雷同"
"らいなつ 来夏"
"らいにち 来日"
"らいねん 来年"
"らいねんあき 来年秋"
"らいねんなつ 来年夏"
"らいねんはる 来年春"
"らいはい 礼拝"
"らいばしょ 來場所"
"らいばる ライバル"
"らいひん 来賓"
"らいひんせき 来賓席"
"らいびょう 癩病"
"らいふ ライフ"
"らいぶ ライブ"
"らいぶらり ライブラリ"
"らいほう 来訪"
"らいむ 来夢"
"らいめい 雷鳴"
"らいらい 来々"
"らいらく 磊落"
"らいりん 来臨"
"らいれき 来歴"
"らいん 莱因 ライン"
"らうす 羅臼"
"らうどねす ラウドネス"
"らうんど ラウンド"
"らおん ラ音"
"らかん 羅漢"
"らがん 裸眼"
"らぎょう ラ行"
"らく ラク 駱 珞 犖 烙 樂 洛 絡 酪 落 楽"
"らくいん 落胤 烙印"
"らくえん 楽園"
"らくかん 楽観"
"らくがい 洛外"
"らくがき 落書き 落書"
"らくがきちょう 落書帳 らく書き帳"
"らくがん 落雁"
"らくご 落伍 落後 落語"
"らくごか 落語家"
"らくさ 落差"
"らくさつ 落札"
"らくしゃ 落車"
"らくしゅ 落手"
"らくしょ 落書"
"らくしょう 酪漿 落掌 楽勝"
"らくじつ 落日"
"らくじょう 落城"
"らくせい 落成"
"らくせき 落石"
"らくせん 落選"
"らくたん 落胆"
"らくだ 駱駝"
"らくだい 落第"
"らくちゃく 落着"
"らくちゃわん 楽茶碗"
"らくちゅう 洛中"
"らくちょう 落丁"
"らくちん 楽珍"
"らくてつ 落鉄"
"らくてん 楽天"
"らくてんか 楽天家"
"らくてんし 楽天使"
"らくとうこうじょうりゅう 洛東江上流"
"らくとうこうりゅういき 洛東江流域"
"らくど 楽土"
"らくなんしんとしん 洛南新都心"
"らくのう 酪農"
"らくば 落馬"
"らくばん 落盤 落磐"
"らくび 楽日"
"らくほく 洛北"
"らくめい 落命"
"らくよう 落陽 洛陽 落葉"
"らくようじゅ 落葉樹"
"らくらい 落雷"
"らくらく 楽々"
"らくるい 落涙"
"らぐびー ラグビー"
"らぐらんじゅ ラグランジュ"
"らけっと ラケット"
"らし 裸子 螺子"
"らしゅつ 裸出"
"らしょうもん 羅生門"
"らしん 裸身"
"らしんばん 羅針盤"
"らじ 裸耳"
"らじお ラジオ"
"らすた ラスタ"
"らすと ラスト"
"らせつ 羅刹 羅切"
"らせん ら旋 螺旋"
"らそく 裸足"
"らたい 裸体"
"らち 拉致 埓 埒"
"らちがい 埒外"
"らっか 落花 落下"
"らっかさん 落下傘"
"らっかん 楽観"
"らっきゅう 落球"
"らっこ ラッコ"
"らっしゅ ラッシュ"
"らっと ラット"
"らっぱ 喇叭 ラッパ"
"らつ 溂 拉 喇 剌 辣"
"らつわん 辣腕"
"らでん 螺鈿"
"らば 騾馬"
"らびおり ラビオリ"
"らびりんす ラビリンス"
"らふ 裸婦"
"らぶ ラブ"
"らべる ラベル"
"らぼ ラボ"
"らむだ λ ラムダ Λ"
"らむにく ラム肉"
"らりー ラリー"
"られつ 羅列"
"らん 鸞 闌 覽 襴 襤 臠 纜 繿 籃 爛 瀾 欖 檻 攬 懶 巒 嬾 婪 儖 亂 欒 濫 藍 蘭 卵 嵐 乱 覧 欄"
"らんおう 卵黄"
"らんおうのう 卵黄嚢"
"らんおうまく 卵黄膜"
"らんかく 濫獲 乱獲"
"らんかつ 卵割"
"らんかん 卵管 藍関 欄干"
"らんかんさい 卵管采"
"らんがい 欄外"
"らんがく 蘭学 乱学"
"らんきゅう 卵丘"
"らんきりゅう 乱気流"
"らんぎょく 藍玉"
"らんく ランク"
"らんこ 蘭子"
"らんこう 乱交 乱行"
"らんこし 蘭越"
"らんさいぼう 卵細胞"
"らんざつ 乱雑"
"らんざん 嵐山"
"らんし 乱視 卵子"
"らんしま 蘭島"
"らんしゃ 乱射"
"らんしゅう 蘭州"
"らんしょう 濫觴"
"らんしん 乱臣 乱心"
"らんじゅ 藍綬"
"らんじゅく 爛熟"
"らんすう 乱数"
"らんせい 乱世"
"らんせん 乱戦"
"らんぜん 爛然"
"らんそ 濫訴"
"らんそう 藍藻 卵巣"
"らんぞう 濫造 乱造"
"らんたろう 乱太郎"
"らんだ 乱打"
"らんだせん 乱打戦"
"らんだむ ランダム"
"らんちき 乱痴気"
"らんちょう 鸞鳥 乱調 乱丁"
"らんちょん ランチョン"
"らんでぃ 蘭泥"
"らんでい 蘭泥"
"らんでん 藍田"
"らんとう 乱闘"
"らんどく 濫讀 濫読 乱読"
"らんどり 乱取り"
"らんなー ランナー"
"らんにゅう 闌入 乱入"
"らんはんしゃ 乱反射"
"らんばい 乱売"
"らんばつ 濫伐 乱伐"
"らんぱく 卵白"
"らんぱつ 乱発"
"らんぴ 濫費 乱費"
"らんぴつ 乱筆"
"らんぶ 乱舞"
"らんぶん 乱文"
"らんぶんかつ 卵分割"
"らんぷ ランプ"
"らんぼう 乱暴"
"らんぼうもの 乱暴者"
"らんぽ 乱歩"
"らんぽう 卵胞 蘭方"
"らんぽうい 蘭方医"
"らんぽん 藍本"
"らんま 乱麻 乱馬"
"らんまる 蘭丸"
"らんまん 爛縵 爛漫"
"らんみゃく 乱脈"
"らんもく ラン目"
"らんよう 濫用 乱用"
"らんらん 爛爛 爛々"
"らんりつ 乱立"
"らんりゅう 乱流"
"らんる 藍縷 襤褸"
"り 哩 浬 驪 釐 詈 莅 籬 漓 罹 悧 俐 俚 吏 莉 李 梨 璃 裡 履 痢 離 裏 里 利 理"
"りー 李"
"りーぐ リーグ"
"りーじょん リージョン"
"りーす リース"
"りーだ リーダ"
"りーち 立直"
"りーど リード"
"りあ 里亜"
"りあげ 利上げ"
"りありずむ リアリズム"
"りいち 理一 利一 理１"
"りいちろう 理一郎"
"りえ 莉英 理央 里枝 里恵 理恵 利枝 利恵 利栄 リエ 里絵 理絵"
"りえき 利益"
"りえきしゃふたん 利益者負担"
"りえきぞう 利益増"
"りえこ 利江子 理恵子"
"りえん 離縁"
"りお 理音"
"りおち 利落ち"
"りおな 里緒菜"
"りか 里佳 理加 理化 梨果 梨香 李下 利佳 里香 理香 リカ 里歌 利香 理科"
"りかい 理解"
"りかがくじてん 理科学辞典"
"りかく 離角"
"りかこ 里佳子 理香子 りか子"
"りかじょしだい 梨花女子大"
"りかん 罹患"
"りがい 利害"
"りがく 理学"
"りがっか 理学科"
"りがん 離岸"
"りき 篥 理器 利器 力"
"りきいし 力石"
"りきえい 力泳"
"りきえん 力演"
"りきお 力雄 力男 理紀夫"
"りきかく 力覚"
"りきかん 力感"
"りきがく 力学"
"りきさく 力作"
"りきし 力士"
"りきせつ 力説"
"りきせん 力線 力戦"
"りきそう 力走"
"りきぞう 力蔵"
"りきたけ 力武"
"りきち 利吉"
"りきてん 力点"
"りきとう 力闘"
"りきどうかん 力動感"
"りきどうざん 力道山"
"りきば 力場 力馬"
"りきや 力哉 力也"
"りきゅう 利休 離宮"
"りきりょう 力量"
"りく 淕 戮 勠 陸"
"りくあげ 陸揚 陸揚げ"
"りくう 陸羽"
"りくうん 陸運"
"りくうんぎょう 陸運業"
"りくえすと リクエスト"
"りくお 陸男"
"りくかい 陸海"
"りくかいくう 陸海空"
"りくかいぐん 陸海軍"
"りくかぜ 陸風"
"りくかわ 陸川"
"りくがわ 陸側"
"りくがん 陸岸"
"りくきょう 陸橋"
"りくくういったい 陸空一体"
"りくぐん 陸軍"
"りくぐんしょう 陸軍省"
"りくし 陸士"
"りくしき 陸式"
"りくしょう 戮笑"
"りくじ 陸自"
"りくじょう 陸上"
"りくじょく 戮辱"
"りくせい 陸生"
"りくせん 陸戦"
"りくぜん 陸前"
"りくそう 陸送"
"りくたん 陸単"
"りくだな 陸棚"
"りくち 陸地"
"りくちゅう 陸中"
"りくつ 理屈"
"りくとう 陸稲"
"りくどう 六道"
"りくの 陸野"
"りくべつ 陸別"
"りくぼつ 戮没"
"りくやね 陸屋根"
"りくよう 陸用"
"りくりょく 戮力"
"りくるーと リクルート"
"りくれん 陸連"
"りくろ 陸路"
"りぐい 利食い"
"りけい 理系 理経"
"りけん 利権 理研"
"りけんがらみ 利権絡み"
"りげん 理元"
"りこ 利己"
"りこー リコー"
"りこう 利巧 履行 利口 理工"
"りこうがくしょせんもん 理工学書専門"
"りこん 離婚"
"りご 俚語"
"りごう 離合"
"りさ 里紗 里沙 梨沙 リサ 理佐 理沙"
"りさーち リサーチ"
"りさい り災 罹災"
"りさげ 利下げ"
"りさこ りさ子"
"りさぶろう 利三郎"
"りさん 理III 離散"
"りざーぶ リザーブ"
"りざや 利鞘"
"りし 利子"
"りしゅう 履習 履修"
"りしゅたい 利主体"
"りしょく 利殖 離職"
"りしり 利尻"
"りしりとう 利尻島"
"りしん 離心"
"りじ 理事"
"りじぇくと リジェクト"
"りじつ 離日"
"りじゅん 利潤"
"りじょう 鯉城"
"りじょく 詈辱"
"りす 栗鼠 リス"
"りすい 理水"
"りすう 理数"
"りすく リスク"
"りすけ 理介"
"りすと リスト"
"りずむ リズム"
"りせい 離生 理性"
"りせき 離席"
"りせん 離仙"
"りそう 理想"
"りそうきょう 理想境 理想郷"
"りそうけい 理想形"
"りそうぞう 理想像"
"りそく 利足 利息"
"りそん 離村"
"りぞっと リゾット"
"りた 利他"
"りたーん リターン"
"りたい 履帯"
"りたいあ リタイア"
"りだつ 離脱"
"りだん 離断"
"りち 篥 律 理知"
"りちうむ リチウム"
"りちぎ 律儀 律義"
"りちゃくりく 離着陸"
"りちょう 李朝"
"りっか 立夏"
"りっきゃく 立客 立脚"
"りっきょう 陸橋 立教"
"りっきょうせん 立教戦"
"りっけん 立憲 立件"
"りっこうほ 立候補"
"りっこく 立国"
"りっし 立志"
"りっしゃくじ 立石寺"
"りっしゅう 立秋"
"りっしゅん 立春"
"りっしょう 立正 立証"
"りっしょく 立食"
"りっしん 立身"
"りっすい 立錐"
"りっすいのち 立錐之地 立錐の地"
"りっせき 立席"
"りっそく 律速"
"りったい 立体"
"りったいかく 立体角"
"りったいし 立体視"
"りったいぞう 立体像"
"りっち 立地"
"りっとう 立東 栗東 立冬"
"りっとる リットル"
"りっぱ 立派"
"りっぷく 立腹"
"りっぽう 立法 立方"
"りっぽうこん 立方根"
"りっぽうたい 立方体"
"りっぽうたいばいせき 立方体倍積"
"りつ 慄 栗 葎 律 立 率"
"りつあん 立案"
"りつき 利付き"
"りつきょう 立教"
"りつけいさん 率計算"
"りつこ 理津子 利津子 里葎子 りつ子 律子"
"りつぜん 慄然"
"りつぞう 立像"
"りつだい 立大"
"りつどう 律動"
"りつめい 立命"
"りつめいせん 立命戦"
"りつめんず 立面図"
"りつりつ 栗栗 慄慄"
"りつりょう 律令"
"りつりん 栗林"
"りつれつ 慄冽"
"りつろん 立論"
"りづめ 理詰め 理詰"
"りてい 里程"
"りてき 理的"
"りてん 利点"
"りとう 離島"
"りとく 利得"
"りな 莉菜 梨名 梨奈 理奈 梨菜 里奈 里菜 利奈 リナ ＲＩＮＡ"
"りに 理２"
"りにあ リニア"
"りにち 離日"
"りにゅう 離乳"
"りにゅうしょく 離乳食"
"りにょう 利尿"
"りにん 離任"
"りねん 理念"
"りねんてきそんざい 理念的存在"
"りの 梨乃"
"りのう 離農"
"りはく 李白 理博"
"りはっちゃく 離発着"
"りはつ 利発 理髪"
"りはつりく 離発陸"
"りはば 利幅"
"りはびり リハビリ"
"りはん 離叛 離反"
"りばけ 理化"
"りばらい 利払い"
"りびょう 罹病"
"りふ 利府"
"りふじん 理不尽"
"りふと リフト"
"りふとけん リフト券"
"りぶつ 理物"
"りぷらい リプライ"
"りへい 利平"
"りべい 離米"
"りべつ 離別"
"りべん 離弁 利便"
"りべんか 離弁花"
"りべんせい 履便性"
"りほ 理穂 理保 里穂"
"りほう 理法 李鵬"
"りほこ 理保子"
"りぼん リボン"
"りぽーたー リポーター"
"りぽーと リポート"
"りまわり 利回り"
"りみ 梨美"
"りめん 裡面 裏面"
"りもーと リモート"
"りゃく 畧 擽 掠 略"
"りゃくかい 略解"
"りゃくき 略記"
"りゃくぎ 略儀"
"りゃくこう 略光"
"りゃくご 略語"
"りゃくごう 略号"
"りゃくしき 略式"
"りゃくしょう 略称"
"りゃくじ 略字"
"りゃくじゅつ 略述"
"りゃくず 略図"
"りゃくせつ 略説"
"りゃくそう 略装"
"りゃくだつ 掠奪 略奪"
"りゃくひつ 略筆"
"りゃくふく 略服"
"りゃくめい 略名"
"りゃくれき 略歴"
"りゃっき 略記"
"りゃんそう 二索"
"りゃんはんしばり 二翻縛"
"りやく 理薬 利益"
"りゅう 餾 霤 鏐 鉚 苙 窿 瘤 畄 瀏 澑 旒 嶐 嚠 瑠 柳 笠 榴 溜 硫 琉 劉 粒 立 竜 隆 龍 留 流"
"りゅうあん 硫安"
"りゅうい 留意"
"りゅういいそう 緑一色"
"りゅういき 流域"
"りゅういち 竜一 隆一 龍一"
"りゅういちろう 隆一郎 竜一郎"
"りゅういん 溜飲"
"りゅうおう 龍玉 龍王 竜王"
"りゅうおうせん 竜王戦"
"りゅうおん 流音"
"りゅうか 硫化"
"りゅうかい 流会"
"りゅうかん 流感"
"りゅうがく 留学"
"りゅうがさき 竜ヶ崎 竜ケ崎 龍崎 竜崎"
"りゅうがだけ 竜ヶ岳"
"りゅうがん 龍眼 竜眼 竜顔"
"りゅうき 劉貴 隆起"
"りゅうきし 竜騎士"
"りゅうきへい 竜騎兵"
"りゅうきゅう 琉球"
"りゅうきょく 流局"
"りゅうぎ 流儀"
"りゅうぐう 竜宮 龍宮"
"りゅうけつ 流血"
"りゅうけん 竜権"
"りゅうげん 流言"
"りゅうこ 隆子 龍虎 竜子"
"りゅうこう 龍宏 流行"
"りゅうこうか 流行歌"
"りゅうこく 龍谷 竜谷"
"りゅうご 龍五 隆吾"
"りゅうさ 流砂"
"りゅうさん 流酸 硫酸"
"りゅうざき 竜崎"
"りゅうざん 竜山 流産"
"りゅうし 粒子"
"りゅうしそく 粒子束"
"りゅうしつ 流失"
"りゅうしゅつ 流出"
"りゅうしゅつすい 流出水"
"りゅうしょう 隆昌"
"りゅうじ 隆史 隆司 隆治 龍二 竜二 隆二"
"りゅうじゅ 龍樹"
"りゅうじょう 粒状"
"りゅうじん 龍神"
"りゅうすい 流水"
"りゅうすう 留数"
"りゅうすけ 竜助 龍輔 竜介 隆介 龍介"
"りゅうず 竜頭"
"りゅうせい 隆盛 流星"
"りゅうせいう 流星雨"
"りゅうせいじん 流星塵"
"りゅうせん 流線"
"りゅうせんかく 竜泉閣"
"りゅうせんけい 流線形"
"りゅうせんけいじょうき 流線形蒸機"
"りゅうぜつらん 龍舌蘭"
"りゅうそうざん 流早産"
"りゅうそく 流束 流速"
"りゅうぞう 竜三 龍蔵 隆三"
"りゅうぞうじ 龍造寺"
"りゅうた 竜太"
"りゅうたい 流体"
"りゅうたいけん 流体科学研究所"
"りゅうたく 流謫"
"りゅうたろう 竜太郎 龍太郎"
"りゅうだい 龍大 琉大"
"りゅうだん 榴彈 榴弾"
"りゅうち 留置"
"りゅうちしゅう 笠智衆"
"りゅうちばり 留置針"
"りゅうちょう 流暢"
"りゅうつう 流通"
"りゅうつうぎょう 流通業"
"りゅうつうまい 流通米"
"りゅうでん 流電"
"りゅうとう 竜党"
"りゅうど 粒度"
"りゅうどう 竜堂 竜童 流動"
"りゅうどうしょく 流動食"
"りゅうにち 留日"
"りゅうにゅう 流入"
"りゅうにん 留任"
"りゅうねん 留年"
"りゅうのすけ 竜之介 龍之介"
"りゅうは 流派"
"りゅうひょう 流氷"
"りゅうび 劉備"
"りゅうへい 龍平"
"りゅうほ 留保"
"りゅうほう 隆法 龍鳳"
"りゅうほく 竜北"
"りゅうぼく 立木 流木"
"りゅうま 竜馬"
"りゅうよう 竜洋 流用"
"りゅうりゅう 隆々"
"りゅうりょう 流量"
"りゅうれい 流麗"
"りゅうろ 流路"
"りゆう 理由"
"りゆうづけ 理由付"
"りょ 閭 踉 膂 絽 梠 呂 侶 虜 旅 慮"
"りょう 裲 怜 嶺 令 椋 靈 鷯 鬣 鐐 輌 輛 蓼 聊 繚 繆 粮 粱 獵 燎 楞 暸 撩 廖 崚 寥 喨 凉 倆 霊 兩 漁 菱 綾 魎 梁 凌 稜 亮 了 僚 瞭 遼 療 猟 陵 涼 糧 諒 領 料 良 両 寮 量"
"りょうあし 両脚 両足"
"りょうあて 寮宛"
"りょうあん 良案 両案"
"りょうあんじ 竜安寺"
"りょうい 霊異 良為"
"りょういき 領域"
"りょういち 竜一 遼一 領一 凌一 良一 亮一"
"りょういちろう 良一郎 良一朗"
"りょういん 両院"
"りょううで 両腕"
"りょううんしゃ 両運車"
"りょうえき 両駅"
"りょうえん 遼遠 良縁"
"りょうか 良家 良過 良貨 良化 量化"
"りょうかい 諒解 領海 了解"
"りょうかた 両肩"
"りょうかみ 両神"
"りょうかん 寮管 良寛 寮監 両艦 僚艦 量感"
"りょうが 凌駕"
"りょうがえ 両替"
"りょうがえしょう 両替商"
"りょうがえじょ 両替所"
"りょうがわ 両側"
"りょうがん 両岸 両眼"
"りょうき 両機 僚機 猟期 猟奇 漁期"
"りょうきおう 猟奇王"
"りょうきごう 量記号"
"りょうきち 良吉"
"りょうきょく 両極"
"りょうきん 料金"
"りょうきんけん 料金券"
"りょうきんじょ 料金所"
"りょうきんねんさげ 料金値下げ 料金値下"
"りょうきんばこ 料金箱"
"りょうぎし 両岸"
"りょうくう 領空"
"りょうくん 両君"
"りょうぐん 両群 両軍"
"りょうけ 良家 両家"
"りょうけい 両系 量刑 良形"
"りょうけつ 良血"
"りょうけつば 良血馬"
"りょうけん 料簡 了簡 良兼 両県 猟犬 了見"
"りょうげん 両舷 燎原"
"りょうこ 凌子 寮子 僚子 遼子 領子 了子 亮子 涼子 良子 量子"
"りょうこう 良港 両校 良好"
"りょうこく 両国"
"りょうごく 両国"
"りょうごくはなにしきとうし 両国花錦闘士"
"りょうさい 良妻 寮祭"
"りょうさいけんぼ 良妻賢母"
"りょうさく 良策"
"りょうさん 量産"
"りょうさんけい 量産形"
"りょうさんしゃ 量産車"
"りょうざぶろう 量三朗"
"りょうざんぱく 梁山泊"
"りょうし 良之 両誌 両市 猟師 漁師 量子 両氏"
"りょうしき 両式 良識"
"りょうしきか 良識家"
"りょうしつ 良質"
"りょうしば 量子場"
"りょうしゃ 両社 両者"
"りょうしゅ 料酒 領取 領主"
"りょうしゅう 領袖 領収"
"りょうしゅういん 領収印"
"りょうしゅうがく 領収額"
"りょうしゅうずみ 領収済"
"りょうしょ 良書 両書"
"りょうしょう 了承"
"りょうしょく 寮食"
"りょうしょくどう 寮食堂"
"りょうしん 両身 良心 両親"
"りょうしんとも 両親共"
"りょうじ 良至 良知 亮治 亮二 良司 領事 両耳 良二 療治 良治"
"りょうじく 両軸"
"りょうじちかい 寮自治会"
"りょうじつ 両日"
"りょうじゅう 猟銃"
"りょうじょく 凌辱"
"りょうじん 梁塵 猟人"
"りょうすいき 量水器"
"りょうすう 輛数 両数"
"りょうすけ 了介 領介 良介 良助 良祐"
"りょうず 両図"
"りょうせい 両棲 両生 両性 良性 寮生"
"りょうせいか 両性花"
"りょうせいかつ 寮生活"
"りょうせいしょく 寮生食"
"りょうせん 僚船 両船 両線 両川 稜線"
"りょうぜん 霊山 瞭然"
"りょうそく 両側 寮則"
"りょうそで 両袖"
"りょうぞう 良三"
"りょうぞく 良俗"
"りょうた 亮太 良太"
"りょうたろう 亮太郎 遼太郎"
"りょうたん 両端"
"りょうだて 両建て"
"りょうだん 両断"
"りょうち 領地"
"りょうちょう 寮長"
"りょうつ 両津"
"りょうて 両手"
"りょうてい 料亭"
"りょうてき 量的"
"りょうてなべ 両手鍋"
"りょうでん 菱電"
"りょうとう 両刀 両党"
"りょうとく 両得"
"りょうど 領土"
"りょうどう 糧道 両道"
"りょうどうたい 良導体"
"りょうどなり 両隣"
"りょうない 寮内 領内"
"りょうなん 綾南"
"りょうにん 両人"
"りょうねん 両年"
"りょうの 稜野"
"りょうのう 両脳"
"りょうは 両派"
"りょうはい 両肺"
"りょうはし 両端"
"りょうはじ 両端"
"りょうはんてん 量販店"
"りょうば 両馬"
"りょうばば 良馬場"
"りょうひ 良否 寮費"
"りょうひざ 両膝"
"りょうひん 良品"
"りょうび 綾美"
"りょうぶん 領文 領分 両分"
"りょうへい 良平"
"りょうへき 両壁"
"りょうへん 両辺"
"りょうほう 療法 両方"
"りょうほうとも 両方共"
"りょうほぞん 量保存"
"りょうぼ 寮母"
"りょうま 遼麻 龍馬 竜馬"
"りょうまつ 糧秣"
"りょうみ 涼味"
"りょうみみ 両耳"
"りょうむ 寮務"
"りょうめ 両目"
"りょうめい 両名"
"りょうめん 両面"
"りょうもう 両毛"
"りょうもん 良問"
"りょうや ⇔"
"りょうやく 良薬"
"りょうゆう 両雄 領有 僚友"
"りょうゆうともにはたたず 両雄倶には立たず 両雄不倶立"
"りょうゆうならびたたず 両雄並び立たず"
"りょうよう 両用 両様 療養"
"りょうよういん 療養院"
"りょうようじょ 療養所"
"りょうようひ 療養費"
"りょうよく 両翼"
"りょうらん 繚乱 撩乱"
"りょうり 料理"
"りょうりしゅ 料理酒"
"りょうりつ 料率 両立"
"りょうりょう 寥寥 稜稜 喨喨 両両 了了"
"りょうりん 両輪"
"りょうれん 寮連"
"りょうろん 両論"
"りょうわき 両脇"
"りょうわん 両腕"
"りょかく 旅客"
"りょかっき 旅客機"
"りょかん 旅館"
"りょかんなみ 旅館並み"
"りょがい 慮外"
"りょきゃく 旅客"
"りょきゃくしゃ 旅客車"
"りょきゃっき 旅客機"
"りょく 仂 緑 力"
"りょくいん 緑陰"
"りょくえんとし 緑園都市"
"りょくおうしょくやさい 緑黄色野菜"
"りょくおうやさい 緑黄野菜"
"りょくか 緑化"
"りょくしきもう 緑色盲"
"りょくしょく 緑色"
"りょくすい 緑水"
"りょくすいてい 緑水亭"
"りょくせいしきもう 緑青色盲"
"りょくち 緑地"
"りょくちゃ 緑茶"
"りょくでんか 緑電化"
"りょくないしょう 緑内障"
"りょくのうきん 緑膿菌"
"りょけん 旅券"
"りょこう 旅行"
"りょこううかがい 旅行伺"
"りょこうかばん 旅行鞄"
"りょこうき 旅行紀 旅行記"
"りょこうぎょうほう 旅行業法"
"りょこうけん 旅行券"
"りょこうしゃあん 旅行社案"
"りょこうずき 旅行好き"
"りょこうぼう 旅行帽"
"りょしゅう 旅愁 慮囚"
"りょじゅん 旅順"
"りょじょう 旅情"
"りょそう 旅装"
"りょだん 旅団"
"りょっか 緑化"
"りょてい 旅程"
"りょてつ 旅鉄"
"りょひ 旅費"
"りょふ 呂布"
"りょりちかく 距離知覚"
"りょりょく 膂力"
"りよう 理容 利用"
"りようかく 利用角"
"りようがかり 利用掛"
"りようがく 利用額"
"りようきゃく 利用客"
"りようけん 利用券"
"りようしゃごと 利用者毎"
"りよく 利欲"
"りよこ 理代子"
"りよん 里昴"
"りりーす リリース"
"りりく 離陸"
"りりこ 梨々子"
"りりつ 利率"
"りりょく 理力"
"りるい 離塁"
"りれー リレー"
"りれき 履歴"
"りろ 理路"
"りろん 理論"
"りろんか 理論家"
"りろんかい 理論解"
"りろんじく 理論軸"
"りろんてきはしら 理論的柱"
"りん 凜 霖 醂 鄰 躪 躙 藺 菻 綸 禀 痳 淪 棆 懍 悋 廩 吝 凛 稟 厘 鈴 淋 燐 琳 鱗 麟 倫 林 臨 隣 輪"
"りんいち 倫一"
"りんいちろう 倫一郎"
"りんう 霖雨"
"りんか 輪禍 隣家"
"りんかい 臨界 臨海"
"りんかいかく 臨界角"
"りんかく 輪郭 隣隔"
"りんかん 林間"
"りんがく 林学"
"りんがっか 林学科"
"りんがっかい 林学会"
"りんき 臨機"
"りんきょうしん 臨教審"
"りんぎ 稟議 禀議"
"りんぎょう 林業"
"りんぎょうか 林業家"
"りんく リンク"
"りんくう 臨空"
"りんぐ リング"
"りんけい 鱗茎"
"りんけいきょう 林経協"
"りんけん 臨検"
"りんげつ 臨月"
"りんこ 凛乎"
"りんこう 輪行 臨港 燐光 林光 輪講"
"りんこうしゃ 輪行車"
"りんこうじゅん 輪講順"
"りんご 林檎"
"りんごく 隣国"
"りんごばたけ 林檎畑"
"りんさいぼう 林災防"
"りんさく 輪作"
"りんさん 林産 リン酸"
"りんざい 林材"
"りんし 臨死"
"りんししつ 燐脂質"
"りんしつ 隣室"
"りんしもく 鱗翅目"
"りんしゃ 倫社"
"りんしゃん 嶺上"
"りんしゃんかいほう 嶺上開花"
"りんしゅう 凛秋"
"りんしゅつ 臨出"
"りんしょう 輪唱 臨牀 臨床"
"りんしょうい 臨床医"
"りんしょうか 臨床家"
"りんしょうちけん 臨床治験"
"りんしょく 悋嗇 吝嗇"
"りんしん 凛森 禀申 稟申"
"りんじ 臨時"
"りんじゅう 臨終"
"りんじょう 輪状 臨場"
"りんじん 隣人"
"りんず 綾子 綸子"
"りんせい 輪生 林政"
"りんせき 隣席 臨席"
"りんせつ 隣接"
"りんせつせき 隣接席"
"りんせんじ 林泉寺"
"りんぜん 凛然"
"りんたい 輪帯"
"りんたいさく 倫対策"
"りんだ リンダ"
"りんち 林地 隣地"
"りんちょう 臨調"
"りんてん 輪転"
"りんどう 竜胆 林道"
"りんどうか リンドウ科"
"りんどうもく リンドウ目"
"りんどく 輪読"
"りんない 林内"
"りんね 輪廻"
"りんば 臨場"
"りんばん 輪番"
"りんぱ リンパ"
"りんびょう 淋病"
"りんぶ 輪舞"
"りんぶん 林分"
"りんぷん 鱗粉"
"りんぽう 隣邦"
"りんむ 林務"
"りんや 林野"
"りんやちょう 林野庁"
"りんらく 淪落"
"りんり 淋漓 倫理"
"りんりつ 林立"
"りんりん 凛凛 凛々"
"りんれつ 凛冽"
"りんわ 輪話室"
"りんわしつ 輪話室"
"る 陋 鏤 褸 縷 畄 璢 婁 琉 屡 留 流 瑠"
"るーじゅ ルージュ"
"るーと √ ルート"
"るーぶる ルーブル"
"るーぷ ループ"
"るーまにあ 羅馬尼"
"るーむ ルーム"
"るーる ルール"
"るい ルイ 瑠維 瑠偉 誄 羸 縲 瘰 泪 壘 留衣 塁 累 涙 類"
"るいか 累加 ルイ華"
"るいぎ 類義"
"るいけい 類形 累計 類型"
"るいこ ルイ子"
"るいご 類語"
"るいさん 累算"
"るいしょ 類書"
"るいしょう 類症 類焼"
"るいしん 塁審 累進"
"るいしんぜい 累進税"
"るいしんてきしょとくぜい 累進的所得税"
"るいじ 類字 類似"
"るいじょう 塁上 累乗"
"るいじょうこん 累乗根"
"るいじんえん 類人猿"
"るいすい 類推"
"るいせき 累積"
"るいせん 涙線"
"るいたいろん 類体論"
"るいだすう 塁打数"
"るいひ 類比"
"るいべつ 類別"
"るいるい 累累 塁々 累々"
"るいれい 類例"
"るいわ 累和"
"るえん 流涎"
"るか 流花"
"るくす ルクス"
"るけい 流刑"
"るけいせつ 流刑説"
"るざい 流罪"
"るす 留守"
"るすたく 留守宅"
"るすつ 留寿都"
"るすでん 留守電"
"るそん 呂宋"
"るたく 流謫"
"るっくす ルックス"
"るつこ 路津子"
"るつぼ 坩堝"
"るてん 流転"
"るにん 流人"
"るび ルビ"
"るふ 流布"
"るべしべ 留辺蕊"
"るべつ 留別"
"るぽるたーじゅ ルポルタージュ"
"るみ ルミ 留実 瑠美 留美 流美"
"るみこ るみ子 留美子"
"るもい 留萌"
"るり 瑠璃"
"るりこ 留理子 るり子 ルリ子 瑠璃子"
"るる 縷縷 縷々"
"るろう 流浪"
"るろうのたみ 流浪の民"
"るん ♪"
"れーざー レーザー"
"れーざこう レーザ光"
"れーす レース"
"れーだ レーダ"
"れーと レート"
"れーべる レーベル"
"れーる レール"
"れい 〇 砺 蛎 齡 黎 鴒 驪 靈 隸 醴 蠡 蛉 茘 聆 羚 綟 糲 禮 癘 犁 犂 澪 櫺 囹 唳 勵 儷 祈 レイ 戻 伶 怜 嶺 苓 零 隷 励 令 鈴 玲 齢 霊 麗 礼 冷 例"
"れいあんしつ 霊安室"
"れいあんじょ 冷暗所"
"れいいち 鈴一"
"れいえん 霊園"
"れいおんたい 冷温帯"
"れいか 麗華 麗香 隷下 玲花 零下 冷夏"
"れいかい 霊界 例解 例会"
"れいかん 冷汗 霊感"
"れいがい 冷害 例外"
"れいき 冷機 励起 冷気"
"れいきゃく 冷却"
"れいきゃくえき 冷却液"
"れいきゃくけいぜんたい 冷却系全体"
"れいきゃくすい 冷却水"
"れいきゅう 霊柩"
"れいきゅうしゃ 霊柩車"
"れいきん 礼金"
"れいぎ 礼儀"
"れいく 麗句"
"れいぐう 冷遇"
"れいけい 令閨"
"れいけつ 冷血"
"れいけつかん 冷血漢"
"れいけん 霊験"
"れいげつ 例月"
"れいげん 霊言 冷源 霊験 冷厳"
"れいげんどうし 霊幻道士"
"れいこ レイコ 怜子 玲香 令子 祈子 礼子 麗子 玲子"
"れいこう 励行"
"れいこく 冷酷"
"れいこん 霊魂"
"れいさい 零細"
"れいし 霊視"
"れいしき 零式 礼式"
"れいしゅ 冷酒"
"れいしょ 隷書"
"れいしょう 醴漿 冷笑 例証"
"れいしょく 令色"
"れいしん 励振"
"れいじ 零次 禮二 零士 玲司 怜二 礼仁 零時 例示 玲二"
"れいじゅう 霊獣 隷従"
"れいじょう 霊場 礼状 令状 令嬢"
"れいじろう 礼二郎 霊次郎 令二朗"
"れいじん 麗人"
"れいすい 冷水"
"れいず 例図"
"れいせい 冷静"
"れいせつ 礼節"
"れいせん 零戰 零戦 冷戦"
"れいぜん 霊前 冷然"
"れいそう 礼装"
"れいそく 令息"
"れいぞう 冷蔵"
"れいぞうこ 冷藏庫 冷蔵庫"
"れいぞく 隸屬 隷属"
"れいたい 冷帯"
"れいたん 冷淡"
"れいだい 例題"
"れいだんぼう 冷暖房"
"れいだんぼうひ 冷暖房費"
"れいちょうけん 霊長研"
"れいちょうるい 霊長類"
"れいてき 霊的"
"れいてつ 冷徹"
"れいてん 零点"
"れいとう 冷凍"
"れいとうこ 冷凍庫"
"れいとうもの 冷凍物"
"れいとねりあもく レイトネリア目"
"れいど 零度"
"れいな レイナ 伶奈 麗奈 玲奈"
"れいにゅう 戻入"
"れいねつ 冷熱"
"れいねん 例年"
"れいの 例の"
"れいのう 霊能"
"れいはい 礼拝"
"れいはいどう 礼拝堂"
"れいばい 冷媒 霊媒"
"れいびょう 霊廟"
"れいふう 冷風"
"れいふうせん 冷風扇"
"れいふく 礼服"
"れいふじん 令夫人"
"れいぶん 麗文 例文"
"れいぶんみゃくもでる 例文脈モデル"
"れいほう 礼砲 礼法"
"れいぼう 麗貌 冷房"
"れいぼうしゃ 冷房車"
"れいみ 麗美"
"れいめい 令名 黎明"
"れいめん 冷麺"
"れいや 麗也"
"れいやく 霊薬"
"れいよう 羚羊"
"れいようしゅ 冷用酒"
"れいらく 零落"
"れいり 伶俐"
"れいりょう 冷涼"
"れいりょく 霊力"
"れいろう 玲朧 玲瓏"
"れおな 玲於奈 玲央名"
"れき 靂 轣 轢 礫 癧 瀝 櫪 檪 暦 歴"
"れきがん 礫岩"
"れきし 轢死 歴史"
"れきしか 歴史家"
"れきしてきつづり 歴史的綴り 歴史的綴"
"れきしもの 歴史物"
"れきじつ 暦日"
"れきせい 瀝青"
"れきせん 歴戦"
"れきぜん 歴然"
"れきだい 歴代"
"れきにん 歴任"
"れきねん 歴年"
"れきねんれい 暦年齢"
"れきはく 歴博"
"れきひょう 暦表"
"れきぶ 暦部"
"れきほう 暦法 歴訪"
"れきほん 暦本"
"れきれき 歴々"
"れぎゅらー レギュラー"
"れくいえむ レクイエム"
"れくちゃー レクチャー"
"れこーでぃんぐ レコーディング"
"れこーど レコード"
"れしーと レシート"
"れじ レジ"
"れじーむ レジーム"
"れじゃー レジャー"
"れじゅめ レジュメ"
"れすちおもく レスチオ目"
"れすとらん レストラン"
"れすりんぐ レスリング"
"れせぷしょん レセプション"
"れたー レター"
"れち 裂"
"れっか 烈火 劣化"
"れっかい 裂開"
"れっかいか 裂開果"
"れっき 列記"
"れっきょ 列挙"
"れっきょう 列強"
"れっこく 列国"
"れっし 列子"
"れっしゃ 列車"
"れっしゃほう 列車砲"
"れっしょう 裂傷"
"れっしん 烈震"
"れっせい 冽清 列聖 劣勢 劣性"
"れっせき 列席"
"れっちゅう 列柱"
"れっとう 列島 劣等"
"れっど レッド"
"れっぱ 裂破"
"れっぱく 裂帛"
"れっぴんかん 列品館"
"れっぷう 烈風"
"れっぺん 裂片"
"れつ 洌 冽 劣 烈 裂 列"
"れつあく 劣悪"
"れつくうかん 列空間"
"れつけっていけい 劣決定系"
"れつじつ 烈日"
"れつじょう 劣情"
"れつたんい 列単位"
"れつでん 裂伝 列伝"
"れつなみ 列並"
"れつばんごう 列番号"
"れつべくとる 列ベクトル"
"れつめ 列目"
"れつりろん 列理論"
"れつれつ 冽冽"
"れとると レトルト"
"れな 玲奈 レナ"
"ればー レバー"
"ればのん レバノン"
"れびゅー レビュー"
"れぶぇる レヴェル"
"れぶん 礼文"
"れぶんとう 礼文島"
"れべっか レベッカ"
"れべる レベル"
"れぽーと レポート"
"れみ 礼美"
"れもねーど レモネード"
"れもん 檸檬 レモン"
"れん 錬 鏈 輦 臠 聨 縺 瀲 濂 斂 戀 奩 嗹 匳 鎌 漣 煉 簾 廉 憐 攣 聯 練 蓮 恋 連"
"れんあい 恋愛"
"れんあいばなし 恋愛話"
"れんあいべた 恋愛下手"
"れんおんほうそく 連音法則"
"れんか 簾価 連歌 廉価"
"れんかん 連環 連関 聯関"
"れんが 煉瓦 連歌"
"れんき 練気 連記"
"れんきゅう 連休"
"れんきゅうあけ 連休明 連休明け"
"れんきょ 蓮炬"
"れんきん 錬金"
"れんぐん 連軍"
"れんけい 連系 聯係 連係 連携"
"れんけいわざ 連携技"
"れんけつ 連結"
"れんげ 蓮華"
"れんげん ∧ 連言"
"れんげんけい 連言形"
"れんげんし 連言肢"
"れんこ 連呼"
"れんこう 攣拘 簾鉤 連衡 連行"
"れんこうあし 練行足"
"れんこん 蓮根"
"れんご 連語"
"れんごう 聯合 連合"
"れんごうぐん 連合軍"
"れんごうたい 連合体"
"れんごうや 連合野"
"れんごく 煉獄"
"れんさ 連銷 連鎖"
"れんさい 連載"
"れんさく 連作"
"れんざ 連座"
"れんざせいきょうか 連座制強化"
"れんざぶろう 錬三郎"
"れんざん 連産 連山"
"れんしゃ 連写 連射"
"れんしゅ 連取"
"れんしゅう 練習"
"れんしゅうしゃ 練習車"
"れんしゅうじあい 練習試合"
"れんしゅうじょ 練習所"
"れんしゅうせん 練習船"
"れんしゅうちょう 練習帳"
"れんしゅく 攣縮"
"れんしょ 連署"
"れんしょう 連勝"
"れんじ 蓮司 櫺 レンジ"
"れんじく 連軸"
"れんじつ 連日"
"れんじゃく 連雀 連尺"
"れんじゅ 連珠"
"れんじょう 連声 連城"
"れんすうじ 連数字"
"れんせい 連成 連製 連星 錬成"
"れんせつ 連接"
"れんせつしゃ 連接車"
"れんせん 連戦"
"れんそう 聯想 連装 連奏 連想"
"れんそうらむ 連想ＲＡＭ"
"れんぞく 連續 連続"
"れんぞくこ 連続弧"
"れんぞくし 連続紙"
"れんぞくそく 連続束"
"れんぞくたい 連続体"
"れんぞくだ 連続打"
"れんぞくだん 連続弾"
"れんぞくもの 連続もの"
"れんぞくわざ 連続技"
"れんたい 聨隊 聯隊 連対 連隊 連帯 連体"
"れんたいけい 連体形"
"れんたいし 連体詞"
"れんたつ 練達"
"れんたる レンタル"
"れんたん 煉炭 練炭 連単"
"れんだ 連打"
"れんだく 連濁"
"れんだん 連弾"
"れんちゃん 連チャン 連荘"
"れんちゅう 連中"
"れんちょう 連長"
"れんちょく 廉直"
"れんとう 連投 連騰 連闘"
"れんとげん レントゲン"
"れんど 練度"
"れんどう 連動"
"れんどら 連ドラ"
"れんにゅう 煉乳 練乳"
"れんねん 連年"
"れんばい 廉売"
"れんばく 恋縛"
"れんばん 連番"
"れんぱ 連覇 連破"
"れんぱい 連敗"
"れんぱく 練帛 連泊"
"れんぱつ 連発"
"れんびん 憐憫 憐愍"
"れんふく 連複"
"れんぶんすう 連分数"
"れんぶんせつ 連文節"
"れんぷ 連符"
"れんぺい 錬兵"
"れんほう 連舫 蓮舫"
"れんぼ 恋慕"
"れんぼう 連坊"
"れんぽう 連峰 連邦"
"れんぽうぎむ 通報義務"
"れんぽうぐん 連邦軍"
"れんま 練磨 錬磨"
"れんめい 聯盟 連名 連盟"
"れんめん 連綿"
"れんや 連夜"
"れんよう 連用"
"れんようけい 連用形"
"れんらく 聯絡 連絡"
"れんらくきょう 連絡橋"
"れんらくぐち 連絡口"
"れんらくじょ 連絡所"
"れんらくせん 連絡船"
"れんらくちょう 連絡帳"
"れんらくもう 連絡網"
"れんりつ 聯立 連立"
"れんれん 恋々 恋恋 攣攣"
"ろ 蕗 櫨 蘆 鹵 髏 驢 顱 轤 輅 艪 臚 絽 爐 瀘 滷 櫚 枦 廬 鷺 盧 賂 炉 櫓 魯 呂 露 路"
"ろー ρ"
"ろーかる ローカル"
"ろーず ローズ"
"ろーとせいやく ロート製薬"
"ろーとる 老頭"
"ろーま 羅馬 ローマ"
"ろーん ローン"
"ろあく 露悪"
"ろう 糧 滝 縷 隴 陋 鑞 褸 螻 螂 蘢 薐 臈 臘 粮 簍 籠 瓏 瑯 琅 焜 潦 樓 槞 柆 朧 朖 撈 實 壟 哢 咾 勞 僂 癆 瘻 露 榔 婁 弄 廊 漏 篭 楼 聾 労 狼 牢 蝋 浪 老 朗 郎"
"ろうあ 聾唖"
"ろうえい 朗詠 漏洩 漏曳"
"ろうえき 労役"
"ろうえん 狼煙"
"ろうおく 陋屋"
"ろうか 蝋花 老化 廊下"
"ろうかい 老獪"
"ろうかく 楼閣"
"ろうがい 老害"
"ろうがっこう 聾学校"
"ろうがん 蝋丸 老眼"
"ろうきほう 労基法"
"ろうきゅう 籠球 篭球 老朽"
"ろうきょ 蝋炬 籠居"
"ろうきょう 老境"
"ろうきょうじゅ 老教授"
"ろうきょく 浪曲"
"ろうきん 労金"
"ろうく 労苦"
"ろうくみ 労組"
"ろうこ 牢固"
"ろうこう 陋巷 漏光"
"ろうご 老後"
"ろうごく 牢獄"
"ろうさい 労災"
"ろうさく 労作"
"ろうし 老師 老子 浪士 労使"
"ろうしつ 狼疾"
"ろうしゃ 聾者"
"ろうしゅ 蝋珠"
"ろうしゅう 陋習 老醜"
"ろうしゅつ 漏出"
"ろうしゅん 老春"
"ろうしょう 老将 労相"
"ろうしんし 老紳士"
"ろうじゃくだんじょ 老若男女"
"ろうじゅう 老中"
"ろうじゅく 老熟"
"ろうじょ 老女"
"ろうじょう 篭城"
"ろうじん 老人"
"ろうじんはん 老人斑"
"ろうすい 老衰 漏水"
"ろうすいし 老衰死"
"ろうせい 労政 老成"
"ろうぜき 狼藉"
"ろうそ 労組"
"ろうそうしそう 老荘思想"
"ろうそく ロウソク 蝋燭"
"ろうたい 老体"
"ろうたいか 老大家"
"ろうちん 労賃"
"ろうていとく 老提督"
"ろうでん 漏電"
"ろうと 漏斗"
"ろうとう 蝋灯 郎党"
"ろうどう 労動 労働"
"ろうどうしょう 労働省"
"ろうどく 朗読"
"ろうなぬし 牢名主"
"ろうにゃく 老若"
"ろうにゃくなんにょ 老若男女"
"ろうにん 浪人"
"ろうにんぎょう 蝋人形"
"ろうねん 老年"
"ろうはい 老廃"
"ろうば 老婆"
"ろうばい 狼狽"
"ろうばいか ロウバイ科"
"ろうばしん 老婆心"
"ろうひ 浪費"
"ろうふうふ 老夫婦"
"ろうふじん 老婦人"
"ろうへい 老兵"
"ろうほう 朗報"
"ろうほきゅうだん 老舗球団"
"ろうぼく 老木"
"ろうまん 浪漫"
"ろうむ 労務"
"ろうめ 浪目"
"ろうめいじん 老名人"
"ろうもう 老耄"
"ろうや 牢屋"
"ろうらく 篭絡"
"ろうらんどう 楼蘭堂"
"ろうりょく 労力"
"ろうるい 蝋涙"
"ろうれい 老齢"
"ろうれつ 陋劣"
"ろうれん 老練 労連"
"ろうろう 朗々 朗朗"
"ろうわん 六萬"
"ろえい 露営"
"ろおわん 六萬"
"ろか 瀘過 芦花 濾過"
"ろかく 鹵獲"
"ろかた 路肩"
"ろく 鹿 戮 勒 轆 祿 碌 淕 漉 ６ 麓 肋 禄 緑 六 録"
"ろくおん 録音"
"ろくおんずみ 録音済"
"ろくおんひょう 録音評"
"ろくおんもの 録音物"
"ろくが 録画"
"ろくがつ 水無月 六月 ６月"
"ろくがどり 録画撮り"
"ろくがもの 録画物"
"ろくごう 六合 六郷 麓郷"
"ろくごうざきとうだい 禄剛崎灯台"
"ろくごうせん 六号線"
"ろくさい 録再"
"ろくさぶろう 六三郎"
"ろくさわ 六沢"
"ろくざい 肋材"
"ろくしゃく 六尺"
"ろくしょう 碌青 六章"
"ろくしんがったい 六神合体"
"ろくしんたい 六神体"
"ろくじぞう 六地蔵"
"ろくじっさい 六十歳"
"ろくじっぴき 六十匹"
"ろくじゅう 六十"
"ろくじゅうさんじょう 六三条"
"ろくじゅうそう 六重奏"
"ろくじゅっさい 六十歳"
"ろくじゅっぴき 六十匹"
"ろくじょう 六畳"
"ろくすけ 六輔"
"ろくせい 鹿西"
"ろくせんまい 六千枚"
"ろくぞう 六蔵"
"ろくたま 六玉"
"ろくだいがく 六大学"
"ろくだん 六段"
"ろくどう 六道"
"ろくに 碌に 陸に"
"ろくにん 六人"
"ろくねん 六年"
"ろくのへ 六戸"
"ろくば 六馬"
"ろくばん 六番"
"ろくぶんぎ 六分儀"
"ろくべえ 六兵衛"
"ろくまく 肋膜"
"ろくめい 六名"
"ろくめいかん 鹿鳴館"
"ろくめんたい ６面体"
"ろくや 六哉"
"ろくよう 六曜"
"ろくりょうへんせい 六両編成"
"ろくれん ６連"
"ろくろ 轆轤"
"ろくろう 六郎"
"ろぐ ログ"
"ろぐいんめい ログイン名"
"ろけっと ロケット"
"ろけん 露見"
"ろこ 路子 ロコ"
"ろこう 炉工 露光"
"ろこうきょう 盧溝橋 蘆溝橋"
"ろこうまど 露光窓"
"ろこつ 露骨"
"ろご ロゴ"
"ろさんじん 魯山人"
"ろざん 廬山"
"ろし ろ紙 濾紙"
"ろしあ 露西亜 魯西亜 ロシア"
"ろしゅつ 露出"
"ろしゅつきょう 露出狂"
"ろしゅつけい 露出計"
"ろしん 炉心"
"ろじ 露地 路地"
"ろじうら 路地裏"
"ろじょう 路上"
"ろじん 魯迅"
"ろすい 呂翠"
"ろせん 路線"
"ろせんしゃ 路線車"
"ろせんもう 路線網"
"ろそくたい 路側帯"
"ろちゅう 路駐"
"ろちょう 路長"
"ろっかー ロッカー"
"ろっかく 六角"
"ろっかくや 六角家"
"ろっかっけい 六角形"
"ろっかん 六巻 肋間"
"ろっきとう 六気筒"
"ろっきゃく 六脚"
"ろっく ロック"
"ろっこう 六興 六甲"
"ろっこうおろし 六甲颪"
"ろっこうさん 六甲山"
"ろっこうみち 六甲道"
"ろっこつ 肋骨"
"ろっこん 六根"
"ろっぴき 六匹"
"ろっぷ 六腑"
"ろっぺい 六平"
"ろっぽう 六方 六法"
"ろっぽん 六本"
"ろっぽんぎ 六本木"
"ろっぽんまつ 六本松"
"ろてい 露呈"
"ろてき 蘆荻"
"ろてん 露店 露天"
"ろとう 露頭 路頭"
"ろない 炉内"
"ろねつ 炉熱"
"ろはば 路幅"
"ろば 驢馬"
"ろばた 爐端 炉端"
"ろばん 路盤"
"ろぶつ 炉物"
"ろぼう 路傍"
"ろぼっと ロボット"
"ろまん 浪漫"
"ろまんてぃしずむ ロマンティシズム"
"ろまんは ロマン派"
"ろみ 路美"
"ろめん 路面"
"ろもう 路網"
"ろゆう 芦有"
"ろりこん ロリコン"
"ろれつ 呂律"
"ろん 栄 崘 崙 堽 侖 論"
"ろんかく 論客"
"ろんがい 論外"
"ろんきゃく 論客"
"ろんきゅう 論究 論及"
"ろんきょ 論拠"
"ろんぎ 論議"
"ろんこう 論考"
"ろんこく 論告"
"ろんご 論語"
"ろんし 論旨"
"ろんしゃ 論者"
"ろんしゅう 論集"
"ろんしょう 論証"
"ろんじゅつ 論述"
"ろんじん 論陣"
"ろんせつ 論説"
"ろんせん 論戦"
"ろんそう 論爭 論争"
"ろんそうし 論争史"
"ろんだい 論題"
"ろんだん 論壇"
"ろんちょう 論調"
"ろんてき 論的 論敵"
"ろんてん 論点"
"ろんどん 倫敦"
"ろんばく 論駁"
"ろんぱ 論破"
"ろんひょう 論評"
"ろんぴょう 論評"
"ろんぶん 論文"
"ろんほうら 栄和了"
"ろんぽう 論法"
"ろんり 論理"
"ろんりせき 論理積"
"ろんりわ 論理和"
"わ 吾 萵 啝 琶 杷 環 把 我 羽 倭 輪 話 和"
"わーく ワーク"
"わーどぷろせっさ ワードプロセッサ"
"わーぷ ワープ"
"わーぷろ ワープロ"
"わーるど ワールド"
"わーるどかっぷ Ｗ杯"
"わい 薈 淮 矮 猥 賄 隈 歪"
"わいあ ワイア"
"わいおく 矮屋"
"わいか 猥歌"
"わいきょく 歪曲"
"わいく 矮躯"
"わいざつ 猥雑"
"わいしかんぎ 矮子看戯"
"わいしゃつ ワイシャツ"
"わいしょう 矮小"
"わいせい 矮星"
"わいせつ 猥褻"
"わいだん 猥談"
"わいど 歪度 ワイド"
"わいばら 莪原"
"わいぱー ワイパー"
"わいほん 猥本"
"わいや ワイヤ"
"わいやー ワイヤー"
"わいろ 賄賂"
"わいろう 矮陋"
"わいん ワイン"
"わう 皇 黄 王 横 往"
"わえい 和英"
"わおうぶんかん 和欧文間"
"わおん 和音"
"わか 和歌 若"
"わかい 若井 和解 和賀井"
"わかいずみ 和解済"
"わかいろ 若色"
"わかうらしゅうへん 和歌浦周辺"
"わかお 稚郎"
"わかおくさま 若奥様"
"わかき 若木"
"わかぎ 若木"
"わかくさ 若草"
"わかくわ 若桑"
"わかげ 若気"
"わかこ 和佳子 和歌子"
"わかさ 若狭"
"わかさき 若桜木"
"わかさだに 若狭谷"
"わかさと 若里"
"わかしおこくたい 若潮国体"
"わかしま 若島"
"わかしまづ 若嶋津"
"わかしゅ 若衆"
"わかしゅう 若衆"
"わかしょうよう 若翔洋"
"わかじし 若獅子"
"わかすぎ 若杉"
"わかせ 若瀬"
"わかぞう 若僧 若造"
"わかた 若田"
"わかたか 若貴"
"わかたに 若谷"
"わかたべ 若田部"
"わかだいしょう 若大将"
"わかだんな 若旦那"
"わかちがき わかち書き"
"わかつき 若槻 若月"
"わかて 若手"
"わかと 若戸"
"わかとの 若殿"
"わかどしより 若年寄"
"わかどり 若鶏"
"わかな 若菜"
"わかのはな 若ノ花 若乃花"
"わかはげ 若禿"
"わかはなだ 若花田"
"わかはら 若原"
"わかば 若葉"
"わかばやし 若林"
"わかふうふ 若夫婦"
"わかまつ 若松"
"わかみ 若美"
"わかみや 若宮"
"わかむら 若村"
"わかむらさき 若紫"
"わかめ 若芽 若布"
"わかもとせいやく わかもと製薬"
"わかもの 若者"
"わかものむき 若者向"
"わかものやく 若者役"
"わかもり 若森"
"わかやく 若役"
"わかやなぎ 若柳"
"わかやま 若山"
"わかれ 別れ"
"わかれみち 別れ道"
"わかれめ 分かれ目"
"わかん 和漢"
"わが 和賀 我"
"わがくに 我が國 わが国 我が国"
"わがこ 吾子"
"わがし 和菓子"
"わがしゃ 我が社 我社"
"わがっき 和楽器"
"わがつま 我妻"
"わがな 我名"
"わがはい 吾輩 我輩"
"わがまま 我侭 我がまま 我儘"
"わがみ 我身 我が身"
"わがや 我家 我が家"
"わき 和氣 腋 和紀 和気 脇"
"わきあいあい 和気藹藹 和気合い合い"
"わきが 腋臭"
"わきげ 腋毛 脇毛"
"わきこ 和貴子"
"わきさか 脇坂"
"わきすじ 脇筋"
"わきた 脇田"
"わきのさわ 脇野沢"
"わきはま 脇浜"
"わきばら わき腹 脇腹"
"わきみ 脇見 わき見"
"わきみち 脇道"
"わきむら 脇村"
"わきめ 脇目"
"わきもと 脇本"
"わきや 脇谷"
"わきやく 脇役"
"わきやま 脇山"
"わきん 和金 和巾"
"わぎ 和木 和議"
"わぎゅう 和牛"
"わぎょう ワ行"
"わぎり 輪切り"
"わく 或 惑 枠"
"わくい 涌井 和久井"
"わくいり 枠入り"
"わくおち 枠落"
"わくがい 枠外"
"わくきん 枠金"
"わくぐみ 枠組み 枠組"
"わくじゅん 枠順"
"わくせい 枠制 惑星"
"わくせいかんじん 惑星間塵"
"わくせん 枠線"
"わくた 和久田"
"わくだ 和久田"
"わくちん ワクチン"
"わくない 枠内"
"わくなし 枠無し"
"わくばん 枠番"
"わくべつ 湧別"
"わくや 涌谷"
"わくら 和倉"
"わくり 和久利 和栗"
"わくれん 枠連"
"わけ 分 分け 譯 理由 和気 訳"
"わけい 和敬"
"わけべ 分部"
"わげい 話芸"
"わこう 和幸 和寇 和孝 倭寇 若生 和光"
"わこうど 若人"
"わこうどう 和光堂"
"わこく 倭国"
"わこんようさいてき 和魂洋才的"
"わご 和語"
"わごう 和合"
"わごむ 輪ゴム"
"わごん ワゴン"
"わごんしゃ ワゴン車"
"わさい 和裁"
"わさび 山葵"
"わさんぼん 和三盆"
"わざ 術 伎 業 技"
"わざせん 技戦"
"わざと 態と"
"わざら 和皿"
"わざわ 和沢"
"わざわい 禍 災 災い"
"わし 和紙 儂 鷲"
"わしお 鷲尾"
"わしき 和式"
"わしさか 鷲坂"
"わしつ 和室"
"わしづ 鷲津"
"わしづかみ 鷲掴み"
"わしのぎ 鷲之樹"
"わしま 和島"
"わしみ 鷲見"
"わしみや 鷲宮"
"わしゃ 話者"
"わしゅうごう ∪ 和集合"
"わしょ 和書"
"わしょく 和食"
"わしょくどう 和食堂"
"わしょっき 和食器"
"わしんとん 華盛頓"
"わじ 和字"
"わじき 鷲敷"
"わじま 和島 輪島 和嶋"
"わじゅつ 話術"
"わじん 倭人"
"わじんでん 倭人伝"
"わすう 話数"
"わすれ 忘れ"
"わすれなぐさ 勿忘草"
"わすれもの 忘れ物"
"わせ 早生 早稲"
"わせい 和生 話声 和製 和声"
"わせだ 早稲田"
"わせだぐち 早稲田口"
"わせださい 早稲田祭"
"わせだだいがくあて 早稲田大学宛"
"わそう 和装"
"わぞく 倭族"
"わた 緜 棉 綿 渡"
"わたかべ 渡壁"
"わたがし 棉菓子"
"わたくし 私"
"わたくしあて 私宛"
"わたくしぎ 私儀"
"わたくしごと 私事"
"わたくしども 私供 私共"
"わたげ 綿毛"
"わたごみ 綿ゴミ"
"わたし 渡し 私"
"わたしあて 私宛"
"わたしいがい 私以外"
"わたしこじん 私個人"
"わたしじしん 私自身"
"わたしたち 私逹 私たち 私達"
"わたしたちあて 私達宛"
"わたしども 私供"
"わたしひとり 私一人"
"わたしぶね 渡船 渡し船"
"わたしゃ 私ゃ"
"わたしら 私等"
"わたしりゅう 私流"
"わたせ 綿瀬 渡瀬"
"わたたに 綿谷"
"わただ 和多田"
"わたなべ 渡邉 渡部 渡邊 渡辺"
"わたぬき 綿貫"
"わたのは 渡波"
"わたびき 綿引"
"わたべ 渡部"
"わたむら 綿村"
"わたもり 渡森"
"わたや 渡谷"
"わたらい 度会"
"わたり 亘 渡 亘理"
"わたりどり 渡り鳥"
"わたる 亙 亘 渡 弥 航 渉"
"わだ 和田"
"わだい 話題"
"わだいこ 和太鼓"
"わだいさく 話題作"
"わだいぬし 話題主"
"わだち 和達 轍"
"わだつみ 海神 海童"
"わち 和知 和智"
"わちゅう 話中"
"わっかない 稚内"
"わっさむ 和寒"
"わっと ワット"
"わづか 和束"
"わて 和手"
"わていしょく 和定食"
"わどくじてん 和独辞典"
"わどまり 和泊"
"わどめ 輪止め"
"わな 罠"
"わに 和邇 鰐"
"わにがわ 鰐皮"
"わにぐち 鰐口"
"わにりょうり 鰐料理"
"わのうち 輪之内"
"わび 佗 詫 侘"
"わびじょう 詫状"
"わびずまい 佗住い 佗び住まい"
"わふう 和風"
"わふく 和服"
"わふつ 和仏"
"わぶん 和文"
"わへい 和平"
"わほう 話法"
"わぼく 和睦"
"わめい 和名"
"わやく 和訳"
"わよう 和洋"
"わら 和良 稿 藁 原"
"わらい 笑 笑い （笑）"
"わらいがお 笑い顔"
"わらいごえ 笑い声"
"わらいばなし 笑い話"
"わらいもの 笑い者"
"わらがい 藁谷"
"わらし 童"
"わらしや 藁谷"
"わらじ 鞋 草鞋"
"わらじばき 草鞋履"
"わらばんし 藁半紙"
"わらび 蕨"
"わらべ 童"
"わらべうた 童歌"
"わらわ 童 妾"
"わり 割り 割"
"わりあい 割合"
"わりあて 割当て 割当 割り当て"
"わりいん 割り印 割印"
"わりかた 割方"
"わりかん 割勘 割り勘"
"わりこみ 割込 割込み"
"わりざん 割算 割り算"
"わりした 割下"
"わりだか 割高"
"わりだし 割出し 割り出し"
"わりつけ 割り付け 割付"
"わりばし 割り箸 割箸"
"わりびき 割引"
"わりびきけん 割引券"
"わりびきさい 割引債"
"わりふり 割り振り"
"わりまえ 割前"
"わりまし 割増し 割増"
"わりもどし 割戻し"
"わりやす 割安"
"わる 惡 ÷ 悪"
"わるお 悪男"
"わるがき 悪餓鬼"
"わるぎ 悪気"
"わるくち 悪口"
"わるぐち 悪口"
"わるさ 悪さ"
"わるじえ 悪知恵"
"わるだくみ 悪巧み"
"わるだま 悪玉"
"わるぢえ 悪知恵"
"わるもの 悪者"
"わるやく 悪役"
"われ 吾 我"
"われき 和暦"
"われさき 我先"
"われながら 我ながら"
"われめ 割れ目"
"われもの 割れ物"
"われら 我們 我ら 我等"
"われわれ 我我 我々"
"わん 豌 綰 灣 彎 万 王 弯 萬 椀 碗 腕 湾"
"わんがい 湾外"
"わんがた 碗型"
"わんがん 湾岸"
"わんきょく 彎曲 弯曲 湾曲"
"わんしょう 腕章"
"わんじょう 椀状"
"わんたん 雲呑 ワンタン"
"わんちゃい 湾仔"
"わんない 湾内"
"わんにゅう 彎入 湾入"
"わんぱい 王牌"
"わんぱく 腕白"
"わんりゅう 湾流"
"わんりょく 腕力"
"を 汚 尾 牡 男 雄 緒 惡 悪 小"
"をう 翁"
"をんな 女"
)

;;
(provide 'ja-dic)

;;; ja-dic.el ends here
